(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    144886,       4506]*)
(*NotebookOutlinePosition[    172537,       5458]*)
(*  CellTagsIndexPosition[    171509,       5434]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Calculus Review I",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 1.  (Limit Definition).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is defined at all points in a deleted neighborhood of  ",
  Cell[BoxData[
      \(x\_0\)]],
  ",  i.e. to the left and right of  ",
  Cell[BoxData[
      \(x\_0\)]],
  "  but not necessarily at  ",
  Cell[BoxData[
      \(x\_0\)]],
  ".  We write   \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), 
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["L",
          FontSize->12]}]]],
  ", \n\nand say that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  has the limit  L  as  x  approaches  ",
  Cell[BoxData[
      \(x\_0\)]],
  ",  provided that \" ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " gets close to ",
  Cell[BoxData[
      \(L\)]],
  "\" when  \"",
  Cell[BoxData[
      \(x\)]],
  " gets close to ",
  Cell[BoxData[
      \(x\_0\)]],
  ".\"  In rigor we write   \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), 
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["L",
          FontSize->12]}]]],
  ", \n\t\nand say that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  has the limit  ",
  Cell[BoxData[
      \(L\)]],
  "  as  ",
  Cell[BoxData[
      \(x\)]],
  "  approaches  ",
  Cell[BoxData[
      \(x\_0\)]],
  ",  provided that for every  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there exists a  ",
  Cell[BoxData[
      \(\[Delta] > 0\)]],
  "  such that  \n\n\t",
  Cell[BoxData[
      \(\(\(|\)\(f \((x)\)\)\) - L | \(\(<\)\(\[Epsilon]\)\)\)]],
  "  for all x  satisfying  ",
  Cell[BoxData[
      \(\(\(\(0\)\(<\)\)\(|\)\(x - 
          x\_0\)\(|\)\(\(<\)\(\[Delta]\)\)\(\ \)\)\)]],
  ".  "
}], "Text",
  CellTags->"Limit Definition"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = \(x\^2\  + \ 2\ x\  - \ 3\)\/\(x\  - \ 1\)\)]],
  ".  Show that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ 1\)\), 
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["4",
          FontSize->12]}]]],
  ".  Note that  ",
  Cell[BoxData[
      \(f \((1)\)\)]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined, but the graph \"looks like every thing is o.k. !\""
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, x];\)\ \ \), "\n", 
    \(\(f[x_] = \(x\^2 + 2\ x - 3\)\/\(x - 1\)\ ;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, 
        PlotStyle \[Rule] Red];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<f[1] = \>", f[1]\ ];\)\ \ \)}], "Input"],

Cell["\<\
Note both the numerator and denominator of f(x) evaluate to be zero, hence we \
have a zero divide by zero situation.  In this case, both numerator and \
denominator have a common factor of  (x - 1).\
\>", "Text"],

Cell[BoxData[{
    \(\(n\ \  = Factor[Numerator[f[x]]];\)\ \ \), "\n", 
    \(\(n1 = ReplaceAll[Numerator[f[x]], x \[Rule] 1];\)\ \ \), "\n", 
    \(\(d\ \  = Denominator[f[x]];\)\ \ \), "\n", 
    \(\(d1 = ReplaceAll[Denominator[f[x]], x \[Rule] 1];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", ToString[n]/ToString[d]];\)\ \ \), "\n", 
    \(\(Print["\<f[1] = \>", ToString[n1], "\</\>", 
        ToString[d1]];\)\ \ \)}], "Input"],

Cell["\<\
Simplify  f(x)  to remove the common factor and call this new function  g(x). \
 Now observe that the graphs of f(x) and g(x) \"appear to be similar.\"  \
\>", "Text"],

Cell[BoxData[{
    \(\(g[x_] = Simplify[f[x]];\)\ \ \), "\n", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<g[1] = \>", g[1]\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(gr1 = 
        Plot[f[x], {x, 0, 2}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr2 = 
        Plot[g[x], {x, 0, 2}, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[GraphicsArray[{gr1, gr2}], 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \)}], "Input",
  CellTags->"GraphicsArray"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to check out the limit of f(x)."
}], "Text"],

Cell[BoxData[{
    \(\(lim\  = \ 
        Limit[\ f[x], x \[Rule] 1\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 1\)\) \>\""\ , f[x], "\< = \>", 
        lim\ ];\)\ \ \)}], "Input"],

Cell["We can define f(x) to be 4 at x = 1 as follows:", "Text"],

Cell[BoxData[{
    \(\(f[1]\  = \ 4;\)\ \ \), "\n", 
    \(\(f[x_] = \(x\^2 + 2\ x - 3\)\/\(x - 1\);\)\ \ \)}], "Input"],

Cell["Now check it out.", "Text"],

Cell[BoxData[
    \(\(Print["\<f[1] = \>", f[1]\ ];\)\)], "Input"],

Cell[TextData[{
  "What does ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " store for this function? Let's see.  "
}], "Text"],

Cell[BoxData[
    \(\(?f\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = \(\(|\)\(x\)\(|\)\)\/x\)]],
  ".  Show that  ",
  Cell[BoxData[
      RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ 0\)\), 
        StyleBox["f",
          FontSize->12], 
        RowBox[{"(", 
          StyleBox["x",
            FontSize->12], 
          StyleBox[")",
            FontSize->12]}]}]]],
  "  does ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " exist, but the left and right limits both exist.  Note that  ",
  Cell[BoxData[
      \(f \((0)\)\)]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, x];\)\ \ \), "\n", 
    \(\(f[x_]\  = \ Abs[x]\/x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-2\), 2}, PlotStyle \[Rule] Red];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<f[0] = \>", f[0]\ ];\)\ \ \)}], "Input"],

Cell["\<\
Note both the numerator and denominator of f(x) evaluate to be zero at x = 0. \
 Hence we have a zero divide by zero situation.  \
\>", "Text"],

Cell[BoxData[{
    \(\(n1 = ReplaceAll[Numerator[f[x]], x \[Rule] 0];\)\ \ \), "\n", 
    \(\(d1 = ReplaceAll[Denominator[f[x]], x \[Rule] 0];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<f[0] = \>", ToString[n1], "\</\>", 
        ToString[d1]];\)\ \ \)}], "Input"],

Cell[TextData[{
  "In this case, there is NO common factor.  \n\nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to check out the limit of f(x) approaching from the left, and observe \
that this function evaluates to be  -1  to the left of zero.  "
}], "Text"],

Cell[BoxData[{
    \(\(lim1 = 
        Limit[f[x], x \[Rule] 0, 
          Direction \[Rule] 1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] \(0\^-\)\)\) f[x] = \>\"", 
        lim1\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(\(-1\)\/1000\)] = \>\"", 
        f[\(-1\)\/1000]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to check out the limit of f(x) approaching from the right, and observe \
that this function evaluates to be  +1  to the right of zero.  "
}], "Text"],

Cell[BoxData[{
    \(\(lim2 = 
        Limit[f[x], x \[Rule] 0, 
          Direction \[Rule] \(-1\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] \(0\^+\)\)\) f[x] = \>\"", 
        lim2\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(1\/1000\)] = \>\"", f[1\/1000]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Since the right and left limits are different, ",
  Cell[BoxData[
      \(\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ 0\)\) f[x]\)]],
  " does ",
  StyleBox["NOT",
    FontColor->RGBColor[1, 0, 0]],
  " exist.  \n\n",
  StyleBox["Caution.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " default direction will give an answer corresponding to the right limit.  \
"
}], "Text"],

Cell[BoxData[
    \(Limit[\ f[x], x \[Rule] 0\ ]\)], "Input"],

Cell["\<\
Often times computer algebra systems are not programmed to handle all the \
\"special cases\" of involving mathematical concepts.  The concept of limit \
is one such instance where the \"true meaning\" of \"limit\" cannot be fully \
understood by \"artificial intelligence.\"  \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 1.  (Squeeze Theorem for Limits).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], "\[LessEqual]", \(g \((x)\)\), 
        "\[LessEqual]", \(h \((x)\)\)}]]],
  "  for  ",
  Cell[BoxData[
      \(a < x < x\_0\)]],
  "  and  ",
  Cell[BoxData[
      \(x\_0 < x < b\)]],
  ".  \n\n\tIf  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), 
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["L",
          FontSize->12]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), "h", 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["L",
          FontSize->12]}]]],
  "  then  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), "g", 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["L",
          FontSize->12]}]]],
  ".  "
}], "Text",
  CellTags->"Squeeze Theorem for Limits"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[\(1 - x\^2\/2\),
          FontSize->12]}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"g", 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[\(cos \((x)\)\),
          FontSize->12]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(h \((x)\)\), 
        StyleBox["=",
          FontSize->12], 
        StyleBox[\(1 - x\^2\/3\),
          FontSize->12]}]]],
  ".  \nAssume that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], "\[LessEqual]", \(g \((x)\)\), 
        "\[LessEqual]", \(h \((x)\)\)}]]],
  "  for  ",
  Cell[BoxData[
      \(\(-\ \[Pi]\)\/2 < x < 0\)]],
  "  and  ",
  Cell[BoxData[
      \(0 < x < \[Pi]\/\(\(2\)\(\ \)\)\)]],
  "   (This is a fact that can be established !).  \nSince  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ 0\)\), 
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["1",
          FontSize->12]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ 0\)\), "h", 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["1",
          FontSize->12]}]]],
  "  we conclude that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ 0\)\), "g", 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["1",
          FontSize->12]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 1 - x\^2\/2;\)\ \ \), "\n", 
    \(\(g[x_] = Cos[x];\)\ \ \), "\n", 
    \(\(h[x_] = 1 - x\^2\/3;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], g[x], h[x]}, {x, \(-\[Pi]\)\/2, \[Pi]\/2}, \n\t
        PlotRange \[Rule] {{\(-\[Pi]\)\/2, \[Pi]\/2}, {0, 1.1}}, \n\t
        Ticks \[Rule] {Range[\(-\(\[Pi]\/2\)\), \[Pi]\/2, \[Pi]\/4], 
            Range[0, 1, 0.2]}, \n\t
        PlotStyle \[Rule] {Green, Red, 
            Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<,  g[x] = \>", g[x], "\<,  h[x] = \>", 
        h[x]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(L1 = Limit[f[x], x \[Rule] 0];\)\ \ \), "\n", 
    \(\(L2 = Limit[h[x], x \[Rule] 0];\)\ \ \), "\[IndentingNewLine]", 
    \(\(L3 = Limit[g[x], x \[Rule] 0];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \>\"", f[x]\ , "\< = \>", 
        L1];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \>\"", h[x]\ , "\< = \>", 
        L2];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \>\"", g[x]\ , "\< = \>", 
        L3];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 2.  (Continuous Function).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " is defined at all points in a neighborhood of  ",
  Cell[BoxData[
      \(x\_0\)]],
  ",  then  \n\n\t",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous at  ",
  Cell[BoxData[
      \(x\_0\)]],
  "  provided that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), 
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox[\(f \((x\_0)\)\),
          FontSize->12]}]]],
  ".  "
}], "Text",
  CellTags->"Continuous Function"],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Verify that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ \[Pi]\/6\)\), 
          "sin", 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox[\(sin \((\[Pi]\/6)\)\),
          FontSize->12]}]]],
  "  and conclude that  ",
  Cell[BoxData[
      StyleBox[\(sin \((x)\)\),
        FontSize->12]]],
  " is continuous at  ",
  Cell[BoxData[
      \(x\_0 = \[Pi]\/6\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(lim\  = \ Limit[Sin[x], x \[Rule] \[Pi]\/6];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] \[Pi]\/6\)\) Sin[x] = \>\"", 
        lim];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   Sin[\!\(\[Pi]\/6\)] = \>\"", 
        Sin[\[Pi]\/6]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<Is \!\(lim\+\(x \[Rule] \[Pi]\/6\)\) Sin[x] = \>\"", \*"\
\"\<Sin[\!\(\[Pi]\/6\)] ?  \>\"", \ \n\t
        Limit[Sin[x], x \[Rule] \[Pi]\/6] \[Equal] 
          Sin[\[Pi]\/6]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(linex = 
        Graphics[{Green, 
            Line[{{\[Pi]\/6, 0}, {\[Pi]\/6, 
                  Sin[\[Pi]\/6]\ }}]}];\)\ \ \), "\n", 
    \(\(liney = 
        Graphics[{Cyan, 
            Line[{{0, Sin[\[Pi]\/6]\ }, {\[Pi]\/6, 
                  Sin[\[Pi]\/6]\ }}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[Sin[x], {x, 0, \[Pi]\/2}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \n\t
          Ticks \[Rule] {Range[0, \[Pi]\/2, \[Pi]\/12], 
              Range[0, 1, 1\/4]}, \n\t
          PlotLabel \[Rule] "\<                        y = sin(x)\>", 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, linex, liney, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 2.  (Limits and Continuous Functions).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      StyleBox[\(f \((x)\)\),
        FontSize->12]]],
  "  is defined on the set  ",
  Cell[BoxData[
      StyleBox["S",
        FontSize->12]]],
  "  and  ",
  Cell[BoxData[
      StyleBox["x",
        FontSize->12]]],
  "  is an element of   ",
  Cell[BoxData[
      StyleBox["S",
        FontSize->12]]],
  ".  \nThe following statements are equivalent:  \n\n\t",
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   \tThe function  ",
  Cell[BoxData[
      StyleBox[\(f \((x)\)\),
        FontSize->12]]],
  " is continuous at  ",
  Cell[BoxData[
      \(x\_0\)]],
  ".  \n\n\t",
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \tIf  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\), 
          StyleBox[\(x\_n\),
            FontSize->12]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox[\(x\_0\),
          FontSize->12]}]]],
  " ,  then  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\), 
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox[\(x\_n\),
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox[\(f \((x\_0)\)\),
          FontSize->12]}]]],
  "  \n\t\tholds true for all sequences  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          StyleBox[\(x\_n\),
            FontSize->12], 
          StyleBox["}",
            FontSize->12]}], "\[Subset]", "S"}]]],
  "  that converge to  ",
  Cell[BoxData[
      StyleBox[\(x\_0\),
        FontSize->12]]],
  ".  "
}], "Text",
  CellTags->"Limits and Continuous Functions"],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      StyleBox[\(f \((x)\) = sin \((x)\)\),
        FontSize->12]]],
  ".  If  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\), 
          StyleBox[\(x\_n\),
            FontSize->12]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], \(\[Pi]\/4\)}]]],
  ",  verify that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\), 
          StyleBox["f",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox[\(x\_n\),
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox[\(f \((\[Pi]\/4)\)\),
          FontSize->12]}]]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, grf, Lx0, Ly0, Lxy, X, X0, Y, y0, Y0, XY];\)\ \ \), "\n", 
    \(\(f[x_] = Sin[x];\)\ \ \), "\n", 
    \(\(X = Table[N[\[Pi]]\/4 - 2.0\^\(-p\), {p, 1, 15}];\)\ \ \), "\n", 
    \(\(Y = Sin[X];\)\ \ \), "\n", 
    \(\(X0 = Transpose[{X, 0\ X}];\)\ \ \), "\n", 
    \(\(Y0 = Transpose[{0\ Y, Y}];\)\ \ \), "\n", 
    \(\(XY = Transpose[{X, Y}];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Lx0 = 
        ListPlot[X0, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Ly0 = 
        ListPlot[Y0, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Lxy = 
        ListPlot[XY, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(grf = 
        Plot[f[x], {x, 0, 0.8}, PlotStyle \[Rule] Red, 
          PlotRange \[Rule] {{0, 0.8}, {0, 1.05}}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[grf, Lx0, Ly0, Lxy, PlotRange \[Rule] {{0, 0.8}, {0, 0.72}}, 
        Prolog \[Rule] {PointSize[0.02]}, 
        Ticks \[Rule] {Range[0, \[Pi]\/4, \[Pi]\/8], Range[0, 1, 0.1]}, 
        AxesLabel \[Rule] {x, y}, PlotLabel \[Rule] "\<y = sin(x)\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(pts\  = \ 
        Prepend[\ 
          XY, {\*"\"\<\!\(x\_k\)      \>\"", \*"\"\<\!\(y\_k\) = Sin[\!\(x\_k\
\)]\>\""}];\)\ \ \), "\n", 
    \(\(Print["\<y = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print[TableForm[pts]];\)\ \ \), "\n", 
    \(\(Print["\<The limiting values are:\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(x\_0\)           \!\(y\_0\) = Sin[\!\(x\_0\)]\>\""];\
\)\ \ \), "\n", 
    \(\(Print[N[\[Pi]\/4], "\<     \>", N[f[\[Pi]\/4]]];\)\ \ \), "\n", 
    \(\(Print[\[Pi]\/4, "\<           \>", f[\[Pi]\/4]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(y0 = Limit[f[x], x \[Rule] \[Pi]\/4];\)\ \ \), "\n", 
    \(\(f0 = f[\[Pi]\/4];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] \[Pi]\/4\)\) f[x] = \>\"", 
        y0, \*"\"\<   and   f[\!\(\[Pi]\/4\)] = \>\"", 
        f0];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Is f[x] continuous at x = \!\(x\_0\) ?   \>\"", 
        y0 \[Equal] f0];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Verify that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ 0\)\), 
          FractionBox[
            StyleBox[\(sin \((x)\)\),
              FontSize->12], 
            StyleBox["x",
              FontSize->12]]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["1",
          FontSize->12]}]]],
  ".  Notice that the function  ",
  Cell[BoxData[
      RowBox[{\(f \((x)\)\), "=", 
        FractionBox[
          StyleBox[\(sin \((x)\)\),
            FontSize->12], 
          StyleBox["x",
            FontSize->12]]}]]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined at  ",
  Cell[BoxData[
      StyleBox[\(x = 0\),
        FontSize->12]]],
  ",  hence  ",
  Cell[BoxData[
      StyleBox[\(f \((x)\)\),
        FontSize->12]]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " continuous at  ",
  Cell[BoxData[
      StyleBox[\(x = 0\),
        FontSize->12]]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, x];\)\ \ \), "\n", 
    \(\(f[x_] = Sin[x]\/x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-\[Pi]\), \[Pi]}, PlotStyle \[Rule] Red, 
        AxesLabel \[Rule] {x, y}, 
        Ticks \[Rule] {Range[\(-\[Pi]\), \[Pi], \[Pi]\/2], 
            Range[0, 1, 0.2]}, \n\t
        PlotLabel \[Rule] \*"\"\<                        y = \!\(\(sin \
\((x)\)\)\/x\)\>\""];\)\ \ \), "\n", 
    \(\(lim\  = \ Limit[f[x], x \[Rule] 0];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \!\(Sin[x]\/x\) = \>\"", 
        lim];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<f[0] = \>", f[0]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Verify that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ \[Infinity]\)\), 
          StyleBox["x",
            FontSize->12], 
          StyleBox[" ",
            FontSize->12], \(\[ExponentialE]\^\(-x\)\)}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["0",
          FontSize->12]}]]],
  ",  \nNotice that the function  ",
  Cell[BoxData[
      RowBox[{\(f \((x)\)\), "=", 
        RowBox[{
          StyleBox["x",
            FontSize->12], 
          StyleBox[" ",
            FontSize->12], \(\[ExponentialE]\^\(-x\)\)}]}]]],
  "  is not defined at  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["x",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], "\[Infinity]"}]]],
  "."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, x];\)\ \ \), "\n", 
    \(\(f[x_]\  = \ x\ \[ExponentialE]\^\(-x\);\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[x\ \[ExponentialE]\^\(-x\), {x, 0, 10}, PlotStyle \[Rule] Red, 
        Ticks \[Rule] {Range[0, 10, 2], Range[0, 0.35, 0.05]}, 
        AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] \*"\"\<y = x \!\(\[ExponentialE]\^\(-x\)\) \
\>\""];\)\ \ \), "\n", 
    \(\(lim\  = \ 
        Limit[x\ \[ExponentialE]\^\(-x\), 
          x \[Rule] \[Infinity]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] \[Infinity]\)\) x \!\(\
\[ExponentialE]\^\(-x\)\) = \>\"", lim];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<f[\[Infinity]] = \>", f[\[Infinity]]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Property 1.  (Properties of \[Infinity]).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The extended real numbers includes the numbers  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["-",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], "\[Infinity]"}]]],
  " and   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["+",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], "\[Infinity]"}]]],
  ".   Some of the mathematical properties are:"
}], "Text",
  CellTags->"Properties of \[Infinity]"],

Cell[TextData[{
  StyleBox["i.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(c\/\[Infinity] = 0\)]],
  "  \n",
  StyleBox["ii (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(c\ \[Infinity]\  = \ \[Infinity]\)]],
  "  \twhen  ",
  Cell[BoxData[
      \(c > 0\)]],
  "  \n",
  StyleBox["ii (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(c\ \[Infinity]\  = \ \(-\ \[Infinity]\)\)]],
  "  \twhen  ",
  Cell[BoxData[
      \(c < 0\)]],
  "  \n",
  StyleBox["iii (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\[Infinity]\  + \ \[Infinity]\  = \ \[Infinity]\)]],
  "   \n",
  StyleBox["iii (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\(-\ \[Infinity]\)\  - \ \[Infinity]\  = \ \(-\ \[Infinity]\)\)]],
  "   \n",
  StyleBox["iv (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\[Infinity]\[Times]\[Infinity]\  = \ \[Infinity]\)]],
  "   \n",
  StyleBox["iv (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\((\(-\ \[Infinity]\))\)\[Times]\((\(-\ \[Infinity]\))\)\  = \ \ \
\[Infinity]\)]],
  "   \n",
  StyleBox["v.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\tSubtraction of two infinite quantities is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  \n",
  StyleBox["vi.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(0  \[Infinity]\)]],
  "  \tis ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  \n",
  StyleBox["vii.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\[Infinity]\)\)\/\(\(\ \)\(\[Infinity]\)\)\)]],
  "  \tis ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  \n",
  StyleBox["viii.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\[Infinity]\^0\)]],
  "   \tis ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  \n",
  StyleBox["ix.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(1\^\[Infinity]\)]],
  "   \tis ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  \n",
  StyleBox["x.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(0\^0\)]],
  "  \tis ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Derivations for Properties of",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 1]],
  Cell[BoxData[
      \(\[Infinity]\)],
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["i.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(c\/\[Infinity] = 0\)]],
  "  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c];\)\ \ \), "\[IndentingNewLine]", 
    \(c\/\(\(\[Infinity]\)\(\ \ \ \)\)\)}], "Input"],

Cell[TextData[{
  StyleBox["ii (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(c\ \[Infinity]\  = \ \[Infinity]\)]],
  "  when  ",
  Cell[BoxData[
      \(c > 0\)]],
  "  "
}], "Text"],

Cell[BoxData[
    \(\(\(c\)\(\ \)\(\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Simplify[\ c\ \[Infinity], \ c > 0\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["ii (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(c\ \[Infinity]\  = \ \(-\ \[Infinity]\)\)]],
  "  when  ",
  Cell[BoxData[
      \(c < 0\)]],
  "  "
}], "Text"],

Cell[BoxData[
    \(\(\(c\)\(\ \)\(\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Simplify[\ c\ \[Infinity], \ c < 0\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["iii (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\[Infinity]\  + \ \[Infinity]\  = \ \[Infinity]\)]],
  "   "
}], "Text"],

Cell[BoxData[
    \(\(\(\[Infinity]\)\(+\)\(\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["iii (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(-\ \[Infinity]\)\  - \ \[Infinity]\  = \ \(-\ \[Infinity]\)\)]],
  "   "
}], "Text"],

Cell[BoxData[
    \(\(\(-\ \[Infinity]\)\(-\)\(\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["iv (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\[Infinity]\[Times]\[Infinity]\  = \ \[Infinity]\)]],
  "   "
}], "Text"],

Cell[BoxData[
    \(\(\(\[Infinity]\)\(\ \)\(\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["iv (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\((\(-\ \[Infinity]\))\)\[Times]\((\(-\ \[Infinity]\))\)\  = \ \ \
\[Infinity]\)]],
  "   "
}], "Text"],

Cell[BoxData[
    \(\(\((\(-\[Infinity]\))\) \((\(-\[Infinity]\))\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["v.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tSubtraction of two infinite quantities is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  "
}], "Text"],

Cell[BoxData[
    \(\(\(\[Infinity]\)\(-\)\(\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Infinity]\^2\)\(-\)\(\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Infinity]\)\(-\)\(\[Infinity]\^2\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Rules involving limits at infinity are important.  "
}], "Text"],

Cell[BoxData[
    \(\(\(Limit[\ a\ x\^2 - \ b\ x, \ 
      x \[Rule] \[Infinity]]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Simplify[\ Limit[\ a\ x\^2 - \ b\ x, \ x \[Rule] \[Infinity]], \ 
      a > 0\ ]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Limit[\ a\ x\  - \ b\ x\^2, \ 
      x \[Rule] \[Infinity]]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Simplify[\ Limit[\ a\ x\  - \ b\ x\^2, \ x \[Rule] \[Infinity]], 
      b > 0\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["vi.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tNotice that  ",
  Cell[BoxData[
      \(0  \[Infinity]\)]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  "
}], "Text"],

Cell[BoxData[
    \(\(\(0\)\(\ \)\(\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["vii.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tNotice that  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Infinity]\)\)\/\(\(\ \)\(\[Infinity]\)\)\)]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  "
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(\[Infinity]\)\)\/\(\(\ \)\(\[Infinity]\)\)\)], "Input"],

Cell[TextData[{
  StyleBox["viii.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tNotice that   ",
  Cell[BoxData[
      \(\[Infinity]\^0\)]],
  "   is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  "
}], "Text"],

Cell[BoxData[
    \(\(\(\[Infinity]\^0\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["ix.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tNotice that   ",
  Cell[BoxData[
      \(1\^\[Infinity]\)]],
  "   is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  "
}], "Text"],

Cell[BoxData[
    \(\(\(1\^\[Infinity]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["x.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tNotice that  ",
  Cell[BoxData[
      \(0\^0\)]],
  "  is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 1]],
  " defined.  "
}], "Text"],

Cell[BoxData[
    \(\(\(0\^0\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 3.  (Limits for a Composite Function).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(z = f \((y)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(y = g \((x)\)\)]],
  ".  Assume that  ",
  Cell[BoxData[
      \(f \((y)\)\)]],
  "  is continuous at  ",
  Cell[BoxData[
      \(y\_0\)]],
  "  and assume that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), 
          StyleBox["g",
            FontSize->12], 
          RowBox[{"(", 
            StyleBox["x",
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox[\(y\_0\),
          FontSize->12]}]]],
  ".  Then  \n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), "f", 
          RowBox[{"(", 
            RowBox[{"g", 
              RowBox[{"(", 
                StyleBox["x",
                  FontSize->12], 
                StyleBox[")",
                  FontSize->12]}]}], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12]}]]],
  Cell[BoxData[
      RowBox[{
        RowBox[{"f", 
          RowBox[{"(", 
            
            RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), "g", 
              
              RowBox[{"(", 
                StyleBox["x",
                  FontSize->12], 
                StyleBox[")",
                  FontSize->12]}]}], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12]}]]],
  Cell[BoxData[
      RowBox[{
        RowBox[{"f", 
          RowBox[{"(", 
            StyleBox[\(y\_0\),
              FontSize->12], 
            StyleBox[")",
              FontSize->12]}]}], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox["=",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        StyleBox[\(z\_0\),
          FontSize->12]}]]],
  ".  "
}], "Text",
  CellTags->"Limits for a Composite Function"],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Verify that  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{\(\(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\), "f", 
            RowBox[{"(", 
              RowBox[{"g", 
                RowBox[{"(", 
                  StyleBox["x",
                    FontSize->12], 
                  StyleBox[")",
                    FontSize->12]}]}], 
              StyleBox[")",
                FontSize->12]}]}],
          FontSize->12], " ", "=", " ", 
        StyleBox[
          RowBox[{
            RowBox[{"g", 
              RowBox[{"(", 
                StyleBox[\(y\_0\),
                  FontSize->12], 
                StyleBox[")",
                  FontSize->12]}]}], " ", "=", " ", \(z\_0\)}],
          FontSize->12]}]]],
  ",  using   ",
  Cell[BoxData[
      RowBox[{\(f \((y)\)\), "=", 
        RowBox[{
          RowBox[{"ArcTan", \((2  y)\), "   ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "    ", "g", \((x)\)}], 
          "=", \(\(1\  - \ Cos \((x)\)\)\/x\^2\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[y_] = ArcTan[2  y];\)\ \ \), "\n", 
    \(\(g[x_] = \(1 - Cos[x]\)\/x\^2;\)\ \ \), "\n", 
    \(\(L1 = Limit[g[x], x \[Rule] 0];\)\ \ \), "\n", 
    \(\(L2 = Limit[f[g[x]], x \[Rule] 0];\)\ \ \), "\n", 
    \(\(Print["\<f[y] = \>", f[y]];\)\ \ \), "\n", 
    \(\(Print["\<g[x] = \>", g[x]];\)\ \ \), "\n", 
    \(\(Print["\<f[g[x]] = \>", f[g[x]]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \>\"", g[x]\ , "\< = \>", 
        L1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] 0\)\) \>\"", 
        f[g["\<x\>"]]\ , "\< = ArcTan[2(\>", L1, "\<)] = \>", 
        L2];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(linex = Graphics[{Green, Line[{{0, 0}, {0, 0.5}}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[g[x], {x, \(-12\), 12}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \n\t
          Ticks \[Rule] {Range[\(-10\), 10, 5], Range[0, 1\/2, 1\/4]}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, linex, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y = \>", g[x]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(liney = 
        Graphics[{Green, Line[{{0.5, 0}, {0.5, f[0.5]}}]}];\)\ \ \), "\n", 
    \(\(linez = 
        Graphics[{Cyan, Line[{{0, f[0.5]}, {0.5, f[0.5]}}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[f[y], {y, 0, 1}, AxesLabel \[Rule] {"\<y\>", "\<z\>"}, \n\t
          Ticks \[Rule] {Range[0, 1, 1\/4], Range[0, \[Pi]\/2, \[Pi]\/8]}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, liney, linez, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z = \>", f[y]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(linex = 
        Graphics[{Cyan, Line[{{0, 0}, {0, f[0.5]}}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[f[g[x]], {x, \(-6\), 6}, 
          AxesLabel \[Rule] {"\<x\>", "\<z\>"}, \n\t
          Ticks \[Rule] {Range[\(-6\), 6, 2], Range[0, \[Pi]\/2, \[Pi]\/8]}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, linex, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z = \>", f[g[x]]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 3.  (Limit Definition of the Derivative).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The definition for the ",
  StyleBox["derivative",
    FontColor->RGBColor[0, 0, 1]],
  " of   ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  at  ",
  Cell[BoxData[
      \(x = x\_0\)]],
  "  is  \n\n\t",
  Cell[BoxData[
      \(f' \((x\_0)\)\  = \ \ \(\(\ \)\(lim\)\(\ \)\)\+\(x\  \[Rule] \ x\_0\)\
\ \(f \((x)\)\  - \ f \((x\_0)\)\)\/\(x\  - \ x\_0\)\)]],
  ",  \nor\n\t",
  Cell[BoxData[
      \(f' \((x\_0)\) = \ \(\(\ \)\(lim\)\(\ \)\)\+\(\[CapitalDelta]x\  \
\[Rule] \ 0\)\ \(f \((x\_0\  + \ \[CapitalDelta]x)\)\  - \ f \((x\_0)\)\)\/\
\[CapitalDelta]x\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  CellTags->"Limit Definition of the Derivative"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Animations for Calculus the Derivative",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/AnimationsD.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Animations for Calculus the Derivative",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/AnimationsD.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox["). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " \nInternet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = \ x\^3 - x\^2 - x + 2\)]],
  "  use the limit definition to find the derivative.  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Using the first definition we obtain:  ", "Text"],

Cell[BoxData[{
    \(\(Clear[\[CapitalDelta]x, f, x, X];\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[x_] = \ x\^3 - x\^2 - x + 2;\)\ \ \), "\n", 
    \(\(q\  = \ \(f[x] - f[X\_0]\)\/\(x - X\_0\);\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(f[x] - f[X\_0]\)\/\(x - X\_0\)\) = \>\"", 
        q];\)\ \ \), "\[IndentingNewLine]", 
    \(\(q = Expand[Simplify[q]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(f[x] - f[X\_0]\)\/\(x - X\_0\)\) = \>\"", 
        q];\)\ \ \), "\n", 
    \(\(lim = Limit[\ q, x \[Rule] X\_0\ ]\ ;\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] X\_0\)\) \>\"", \*"\"\<\!\(\(f[x] - \
f[X\_0]\)\/\(x - X\_0\)\) = \>\"", lim];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<f'[\!\(X\_0\)] = \>\"", lim];\)\ \ \)}], "Input"],

Cell["Using the second definition we obtain:  ", "Text"],

Cell[BoxData[{
    \(\(Clear[\[CapitalDelta]x, f, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[x_] = \ x\^3 - x\^2 - x + 2\ ;\)\ \ \), "\n", 
    \(\(q = \(f[x + \[CapitalDelta]x] - f[x]\)\/\[CapitalDelta]x\ ;\)\ \ \), \
"\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\), "\n", 
    \(\(Print[\*"\"\<\!\(\(f[x + \[CapitalDelta]x] - f[x]\)\/\(x + \
\[CapitalDelta]x - x\)\) = \>\"", q];\)\ \ \), "\n", 
    \(\(q = Expand[q];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(f[x + \[CapitalDelta]x] - f[x]\)\/\[CapitalDelta]x\
\) = \>\"", q];\)\ \ \), "\n", 
    \(\(lim = Limit[q, \[CapitalDelta]x \[Rule] 0];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(\[CapitalDelta]x \[Rule] 0\)\) \>\"", \*"\"\<\
\!\(\(f[x + \[CapitalDelta]x] - f[x]\)\/\[CapitalDelta]x\) = \>\"", 
        lim];\)\ \ \), "\n", 
    \(\(Print["\<f'[x] = \>", lim];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(df[x_] = \(f'\)[x];\)\ \ \), "\n", 
    \(\(a = 0;\)\ \ \), "\n", 
    \(\(c = 1.2;\)\ \ \), "\n", 
    \(\(b = 2;\)\ \ \), "\n", 
    \(\(ln0 = {};\)\ \ \), "\n", 
    \(\(pt0 = {};\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(For[j = 1, 
        j \[LessEqual] 6, \(j++\), \[IndentingNewLine]x0 = 
          N[c]; \ \ \[IndentingNewLine]y0 = 
          N[f[x0]]; \ \ \[IndentingNewLine]x1 = 
          N[c + 1\/4\^j]; \ \ \[IndentingNewLine]y1 = 
          N[f[x1]]; \ \ \[IndentingNewLine]dx = 
          x1 - x0; \ \ \[IndentingNewLine]dy = 
          y1 - y0; \ \ \[IndentingNewLine]m = 
          dy\/dx; \ \ \[IndentingNewLine]ln0 = 
          Append[ln0, 
            Graphics[{Hue[1 - \(j - 1\)\/7], 
                Line[{{x0, y0}, {b, 
                      y0 + \((b - c)\)\ m}}]}]]; \ \ \[IndentingNewLine]pt0 = 
          Append[pt0, {dx, dy, dy\/dx}];\ ];\)\ \ \), "\n", 
    \(\(grf = 
        Plot[f[x], {x, a, b}, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[grf, ln0, PlotRange \[Rule] {{a, b}, {0, 5}}, 
        AspectRatio \[Rule] 1, AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<Table of values for the slope.\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<  \[CapitalDelta]x               \[CapitalDelta]y        \
       \!\(\[CapitalDelta]y\/\[CapitalDelta]x\)\>\""];\)\ \ \), "\n", 
    \(\(Print[TableForm[pt0]];\)\ \ \), "\n", 
    \(\(Print["\<The  function     f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<The derivative   f'[x] = \>", \(f'\)[x]];\)\ \ \), "\n", 
    \(\(Print["\<The derivative f'[1.2] = \>", \(f'\)[
          1.2]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = \(\(|\)\(x\)\(|\)\)\)]],
  "  use the limit definition to find the derivative."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Using the first definition we obtain:", "Text"],

Cell[BoxData[{
    \(\(Clear[f, x, x0];\)\ \ \), "\n", 
    \(\(f[x_] = \ Abs[x]\ ;\)\ \ \), "\n", 
    \(\(f[x_] = \ \@x\^2\ ;\)\ \ \), "\[IndentingNewLine]", 
    \(\(q\  = \ \(f[x] - f[x0]\)\/\(x - x0\);\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(f[x] - f[x0]\)\/\(x - x0\)\) = \>\"", 
        q];\)\ \ \), "\n", 
    \(\(lim = Limit[q, x \[Rule] x0];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] x0\)\) \>\"", \*"\"\<\!\(\(f[x] - \
f[x0]\)\/\(x - x0\)\) = \>\"", lim];\)\ \ \), "\n", 
    \(\(Print["\<f'[x0] = \>", lim];\)\ \ \)}], "Input"],

Cell["At x = -1 the derivative is:", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<f'[-1] = \!\(\@\((\(-1\))\)\^2\/\((\(-1\))\)\)\>\""];\)\ \
\ \), "\n", 
    \(\(Print["\<f'[-1] = \>", \@\((\(-1\))\)\^2\/\((\(-1\))\)];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f'[-1] = \>", \(f'\)[\(-1\)]\ ];\)\ \ \)}], "Input"],

Cell["At x = 1 the derivative is:", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<f'[1] = \!\(\@\((1)\)\^2\/\((1)\)\)\>\""];\)\ \ \), "\n\
", 
    \(\(Print["\<f'[1] = \>", \@\((1)\)\^2\/\((1)\)];\)\ \ \ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f'[1] = \>", \(f'\)[1]\ ];\)\ \ \)}], "Input"],

Cell["At x = 0 the derivative on the right is:", "Text"],

Cell[BoxData[{
    \(\(q = \(f[x] - f[0]\)\/\(x - 0\);\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(f[x] - f[0]\)\/\(x - 0\)\) = \>\"", 
        q];\)\ \ \), "\n", 
    \(\(lim = 
        Limit[q, x \[Rule] 0, Direction \[Rule] \(-1\)]\ ;\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] \(0\^+\)\)\) \>\"", \
\*"\"\<\!\(\(f[x] - f[0]\)\/\(x - 0\)\) = \>\"", lim];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<f'[\!\(\(0\^+\)\)] = \>\"", lim];\)\ \ \)}], "Input"],

Cell["At x = 0 the derivative on the left is:", "Text"],

Cell[BoxData[{
    \(\(q = \(f[x] - f[0]\)\/\(x - 0\);\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(f[x] - f[0]\)\/\(x - 0\)\) = \>\"", 
        q];\)\ \ \), "\n", 
    \(\(lim = Limit[q, x \[Rule] 0, Direction \[Rule] 1]\ ;\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(x \[Rule] \(0\^-\)\)\) \>\"", \
\*"\"\<\!\(\(f[x] - f[0]\)\/\(x - 0\)\) = \>\"", lim];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<f'[\!\(\(0\^-\)\)] = \>\"", lim];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(p1 = 
        Plot[f[x], {x, \(-1\), 1}, DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] Red, PlotPoints \[Rule] 101];\)\ \ \), "\n", 
    \(\(p2 = 
        Plot[\@x\^2\/x, {x, \(-1\), 1}, DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] Blue, PlotPoints \[Rule] 101];\)\ \ \), "\n", 
    \(\(Show[GraphicsArray[{p1, p2}]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["(Differential Approximation).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  "  be a differentiable function, then\n\n\t",
  Cell[BoxData[
      \(\[CapitalDelta]y\  \[TildeTilde] \ 
        f' \((x\_0)\) \[CapitalDelta]x\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  CellTags->"Differential Approximation"],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = sin \((x)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(x\_0 = 1\)]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(\[CapitalDelta]x = 0.1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "0.01", 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", "0.001", 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", "0.0001"}]]],
  ".\nUse the differential to approximate corresponding values for  ",
  Cell[BoxData[
      \(\[CapitalDelta]y\)]],
  "."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x];\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = 0.1;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(linex = 
        Graphics[{Green, 
            Line[{{1, f[1]}, {1 + \[CapitalDelta]x, 
                  f[1]\ }}]}];\)\ \ \), "\n", 
    \(\(liney = 
        Graphics[{Magenta, 
            Line[{{1 + \[CapitalDelta]x, f[1]\ }, {1 + \[CapitalDelta]x, \ 
                  f[1] + \(f'\)[1] \[CapitalDelta]x}}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[Sin[x], {x, 0, 1.5}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          Ticks \[Rule] {Range[0, 1.5, 0.2], Range[0, 1, 0.2]}, \n\t
          PlotLabel \[Rule] "\<                        y = sin(x)\>", 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, linex, liney, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(linex = 
        Graphics[{Green, 
            Line[{{1, f[1]}, {1 + \[CapitalDelta]x, 
                  f[1]\ }}]}];\)\ \ \), "\n", 
    \(\(liney = 
        Graphics[{Magenta, 
            Line[{{1 + \[CapitalDelta]x, f[1]\ }, {1 + \[CapitalDelta]x, \ 
                  f[1] + \(f'\)[1] \[CapitalDelta]x}}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[Sin[x], {x, 0.9, 1.2}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \n\t
          PlotLabel \[Rule] "\<                        y = sin(x)\>", 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, linex, liney, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]x \[TildeTilde] \>", \
\[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", \(f'\)[
          1], "\< \[Times] \>", \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", 
        N[\(f'\)[1]], "\< \[Times] \>", \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", \(f'\)[
            1] \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<f[1+\[CapitalDelta]x]-f[1] = \>", 
        f[1 + \[CapitalDelta]x] - f[1]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x];\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = 0.01;\)\ \ \), "\n", 
    \(\(linex = 
        Graphics[{Green, 
            Line[{{1, f[1]}, {1 + \[CapitalDelta]x, 
                  f[1]\ }}]}];\)\ \ \), "\n", 
    \(\(liney = 
        Graphics[{Magenta, 
            Line[{{1 + \[CapitalDelta]x, f[1]\ }, {1 + \[CapitalDelta]x, \ 
                  f[1] + \(f'\)[1] \[CapitalDelta]x}}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[Sin[x], {x, 1 - 2  \[CapitalDelta]x, 1 + 2  \[CapitalDelta]x}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \n\t
          PlotLabel \[Rule] "\<                        y = sin(x)\>", 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, linex, liney, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]x \[TildeTilde] \>", \
\[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", \(f'\)[
          1], "\< \[Times] \>", \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", 
        N[\(f'\)[1]], "\< \[Times] \>", \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", \(f'\)[
            1] \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<f[1+\[CapitalDelta]x]-f[1] = \>", 
        f[1 + \[CapitalDelta]x] - f[1]\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x];\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = 0.001;\)\ \ \), "\n", 
    \(\(linex = 
        Graphics[{Green, 
            Line[{{1, f[1]}, {1 + \[CapitalDelta]x, 
                  f[1]\ }}]}];\)\ \ \), "\n", 
    \(\(liney = 
        Graphics[{Magenta, 
            Line[{{1 + \[CapitalDelta]x, f[1]\ }, {1 + \[CapitalDelta]x, \ 
                  f[1] + \(f'\)[1] \[CapitalDelta]x}}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[Sin[x], {x, 1 - 2  \[CapitalDelta]x, 1 + 2  \[CapitalDelta]x}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \n\t
          PlotLabel \[Rule] "\<                        y = sin(x)\>", 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, linex, liney, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]x \[TildeTilde] \>", \
\[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", \(f'\)[
          1], "\< \[Times] \>", \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", 
        N[\(f'\)[1]], "\< \[Times] \>", \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", \(f'\)[
            1] \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<f[1+\[CapitalDelta]x]-f[1] = \>", 
        f[1 + \[CapitalDelta]x] - f[1]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x];\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = 0.0001;\)\ \ \), "\n", 
    \(\(linex = 
        Graphics[{Green, 
            Line[{{1, f[1]}, {1 + \[CapitalDelta]x, 
                  f[1]\ }}]}];\)\ \ \), "\n", 
    \(\(liney = 
        Graphics[{Magenta, 
            Line[{{1 + \[CapitalDelta]x, f[1]\ }, {1 + \[CapitalDelta]x, \ 
                  f[1] + \(f'\)[1] \[CapitalDelta]x}}]}];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[Sin[x], {x, 1 - 2  \[CapitalDelta]x, 1 + 2  \[CapitalDelta]x}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \n\t
          PlotLabel \[Rule] "\<                        y = sin(x)\>", 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, linex, liney, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]x \[TildeTilde] \>", \
\[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", \(f'\)[
          1], "\< \[Times] \>", \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", 
        N[\(f'\)[1]], "\< \[Times] \>", \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<          \[CapitalDelta]y \[TildeTilde] \>", \(f'\)[
            1] \[CapitalDelta]x];\)\ \ \), "\n", 
    \(\(Print["\<f[1+\[CapitalDelta]x]-f[1] = \>", 
        f[1 + \[CapitalDelta]x] - f[1]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Rules 1.  Rules for Differentiation.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  CellTags->"Rules for Differentiation"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        InterpretationBox[\("\n"\[InvisibleSpace]"Derivative of a scalar \
multiple."\),
          SequenceForm[ "\n", "Derivative of a scalar multiple."],
          Editable->False], "\n", 
        InterpretationBox[
          
          RowBox[{"\<\" F[x] = \"\>", "\[InvisibleSpace]", \(c\ f[x]\), 
            "\[InvisibleSpace]", "\<\"\\n\"\>", 
            "\[InvisibleSpace]", "\<\"F'[x] = \"\>", "\[InvisibleSpace]", 
            RowBox[{"c", " ", 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}],
          SequenceForm[ " F[x] = ", 
            Times[ c, 
              f[ x]], "\n", "F'[x] = ", 
            Times[ c, 
              Derivative[ 1][ f][ x]]],
          Editable->False], "\n", 
        InterpretationBox[\("\n"\[InvisibleSpace]"Derivative of a linear \
combination."\),
          SequenceForm[ "\n", "Derivative of a linear combination."],
          Editable->False], "\n", 
        InterpretationBox[
          
          RowBox[{"\<\" F[x] = \"\>", 
            "\[InvisibleSpace]", \(a\ f[x] + b\ g[x]\), 
            "\[InvisibleSpace]", "\<\"\\n\"\>", 
            "\[InvisibleSpace]", "\<\"F'[x] = \"\>", "\[InvisibleSpace]", 
            RowBox[{
              RowBox[{"a", " ", 
                RowBox[{
                  SuperscriptBox["f", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}]}], "+", 
              RowBox[{"b", " ", 
                RowBox[{
                  SuperscriptBox["g", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}]}]}]}],
          SequenceForm[ " F[x] = ", 
            Plus[ 
              Times[ a, 
                f[ x]], 
              Times[ b, 
                g[ x]]], "\n", "F'[x] = ", 
            Plus[ 
              Times[ a, 
                Derivative[ 1][ f][ x]], 
              Times[ b, 
                Derivative[ 1][ g][ x]]]],
          Editable->False], "\n", 
        InterpretationBox[\("\n"\[InvisibleSpace]"Derivative of the product \
of two functions."\),
          SequenceForm[ "\n", "Derivative of the product of two functions."],
          Editable->False], "\n", 
        InterpretationBox[
          
          RowBox[{"\<\" F[x] = \"\>", "\[InvisibleSpace]", \(f[x]\ g[x]\), 
            "\[InvisibleSpace]", "\<\"\\n\"\>", 
            "\[InvisibleSpace]", "\<\"F'[x] = \"\>", "\[InvisibleSpace]", 
            RowBox[{
              RowBox[{\(g[x]\), " ", 
                RowBox[{
                  SuperscriptBox["f", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}]}], "+", 
              RowBox[{\(f[x]\), " ", 
                RowBox[{
                  SuperscriptBox["g", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}]}]}]}],
          SequenceForm[ " F[x] = ", 
            Times[ 
              f[ x], 
              g[ x]], "\n", "F'[x] = ", 
            Plus[ 
              Times[ 
                g[ x], 
                Derivative[ 1][ f][ x]], 
              Times[ 
                f[ x], 
                Derivative[ 1][ g][ x]]]],
          Editable->False], "\n", 
        InterpretationBox[\("\n"\[InvisibleSpace]"Derivative of the quotient \
of two functions."\),
          SequenceForm[ "\n", "Derivative of the quotient of two functions."],
          
          Editable->False], "\n", 
        InterpretationBox[
          
          RowBox[{"\<\" F[x] = \"\>", "\[InvisibleSpace]", \(f[x]\/g[x]\), 
            "\[InvisibleSpace]", "\<\"\\n\"\>", 
            "\[InvisibleSpace]", "\<\"F'[x] = \"\>", "\[InvisibleSpace]", 
            FractionBox[
              RowBox[{
                RowBox[{\(g[x]\), " ", 
                  RowBox[{
                    SuperscriptBox["f", "\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}]}], "-", 
                RowBox[{\(f[x]\), " ", 
                  RowBox[{
                    SuperscriptBox["g", "\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}]}]}], \(g[
                    x]\^2\)]}],
          SequenceForm[ " F[x] = ", 
            Times[ 
              f[ x], 
              Power[ 
                g[ x], -1]], "\n", "F'[x] = ", 
            Times[ 
              Power[ 
                g[ x], -2], 
              Plus[ 
                Times[ 
                  g[ x], 
                  Derivative[ 1][ f][ x]], 
                Times[ -1, 
                  f[ x], 
                  Derivative[ 1][ g][ x]]]]],
          Editable->False], "\n", 
        InterpretationBox[\("\n"\[InvisibleSpace]"Derivative of the \
composition of two functions."\),
          SequenceForm[ 
          "\n", "Derivative of the composition of two functions."],
          Editable->False], "\n", 
        InterpretationBox[
          
          RowBox[{"\<\" F[x] = \"\>", "\[InvisibleSpace]", \(f[g[x]]\), 
            "\[InvisibleSpace]", "\<\"\\n\"\>", 
            "\[InvisibleSpace]", "\<\"F'[x] = \"\>", "\[InvisibleSpace]", 
            RowBox[{
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "[", \(g[x]\), "]"}], " ", 
              RowBox[{
                SuperscriptBox["g", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}],
          SequenceForm[ " F[x] = ", 
            f[ 
              g[ x]], "\n", "F'[x] = ", 
            Times[ 
              Derivative[ 1][ f][ 
                g[ x]], 
              Derivative[ 1][ g][ x]]],
          Editable->False]}],
      FontColor->GrayLevel[0]]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivations for the Rules for Differentiation.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, c, F, f, g, g1, g2, g3, g4, g5, x];\)\ \ \), "\n", 
    \(\(g1[x_]\  = \ c\ f[x];\)\ \ \), "\n", 
    \(\(\(g1'\)[x];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Derivative of a scalar multiple.\>"];\)\ \ \), "\n\
", 
    \(\(Print["\< F[x] = \>", 
        g1[x], "\<\n\>", "\<F'[x] = \>", \(g1'\)[x]\ ];\)\ \ \), "\n", 
    \(\(g2[x_]\  = \ a\ f[x]\  + \ b\ g[x];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Derivative of a linear combination.\>"];\)\ \ \), \
"\n", 
    \(\(Print["\< F[x] = \>", 
        g2[x], "\<\n\>", "\<F'[x] = \>", \(g2'\)[x]\ ];\)\ \ \), "\n", 
    \(\(g3[x_]\  = \ f[x]\ g[x];\)\ \ \), "\n", 
    \(\(\(g3'\)[x];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Derivative of the product of two functions.\>"];\)\
\ \ \), "\n", 
    \(\(Print["\< F[x] = \>", 
        g3[x], "\<\n\>", "\<F'[x] = \>", \(g3'\)[x]\ ];\)\ \ \ \), "\n", 
    \(\(g4[x_]\  = \ f[x]\/g[x];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Derivative of the quotient of two \
functions.\>"];\)\ \ \), "\n", 
    \(\(Print["\< F[x] = \>", g4[x], "\<\n\>", "\<F'[x] = \>", 
        Together[\(g4'\)[x]]\ ];\)\ \ \), "\n", 
    \(\(g5[x_]\  = \ f[g[x]];\)\ \ \), "\n", 
    \(\(\(g5'\)[x];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Derivative of the composition of two \
functions.\>"];\)\ \ \), "\n", 
    \(\(Print["\< F[x] = \>", g5[x], "\<\n\>", "\<F'[x] = \>", 
        Together[\(g5'\)[x]]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Formulas 1.  Formulas for Differentiation.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  CellTags->"Formulas for Differentiation"],

Cell[TextData[{
  StyleBox["i.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tDerivative formulas for  ",
  Cell[BoxData[
      RowBox[{\(x\^n\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(\[ExponentialE]\^x\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Log[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(b\^x\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(Log[b, x]\)}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation i.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\(\(\[PartialD]\_x\ x\^n\  \[Equal] \ 
        n\ x\^\(n - 1\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ \[ExponentialE]\^x\  \[Equal] \ \
\[ExponentialE]\^x\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\[PartialD]\_x\ Log[x]\  \[Equal] \ 1\/\(\(x\)\(\[IndentingNewLine]\)
          \)\), "\n", 
      \(\(\(\[PartialD]\_x\ b\^x\  \[Equal] \ 
        b\^x\ Log[b]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\[PartialD]\_x\ Log[b, x]\  \[Equal] \ 1\/\(x\ \ Log[b]\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Execute each cell to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the derivative."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[n, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\[PartialD]\_x\ x\^n\)}], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Log[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ b\^x\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Log[b, x]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["ii.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tDerivative formulas for  ",
  Cell[BoxData[
      RowBox[{\(Cos[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Sin[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Tan[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Csc[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Sec[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Cot[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcCos[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman"], " "}]], \(ArcSin[x]\)}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation ii.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\(\(\[PartialD]\_x\ Cos[x]\  \[Equal] \ \(-\ 
          Sin[x]\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ Sin[x]\  \[Equal] \ 
        Cos[x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ Tan[x]\  \[Equal] \ 
        Sec[x]\^2\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          Csc[x]\  \[Equal] \ \(-\ Cot[x]\)\ Csc[x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ Sec[x]\  \[Equal] \ 
        Sec[x]\ Tan[x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ Cot[x]\  \[Equal] \ \(-\ 
          Csc[x]\^2\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          ArcCos[x]\  \[Equal] \ \(-\ \(1\/\@\(1\  - \ x\^2\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\[PartialD]\_x\ ArcSin[x]\  \[Equal] \ 1\/\@\(1\  - \ x\^2\)\)}]]
}], "Text"],

Cell[TextData[{
  "Execute each cell to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the derivative."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_x\ Cos[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Sin[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Tan[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Csc[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Sec[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Cot[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCos[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcSin[x]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["iii.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tDerivative formulas for  ",
  Cell[BoxData[
      RowBox[{\(ArcTan[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcCsc[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcSec[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", \(ArcCot[x]\)}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation iii.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\[PartialD]\_x\ ArcTan[x]\  \[Equal] \ 
        1\/\(\(1\  + \ x\^2\)\(\[IndentingNewLine]\)
          \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          ArcCsc[x]\  \[Equal] \ \(-\(1\/\(x \@\(\( x\^2\)\(\ \)\(-\)\(\ \
\)\(1\)\(\ \)\)\)\)\)\)\(\n\)
      \)\t\t\t\), "\n", 
      \(\[PartialD]\_x\ ArcSec[x]\  \[Equal] \ 
        1\/\(\(x \@\(\( x\^2\)\(\ \)\(-\)\(\ \)\(1\)\(\ \)\)\)\(\n\)
          \)\), "\n", 
      \(\[PartialD]\_x\ 
          ArcCot[x]\  \[Equal] \ \(-\(1\/\(1\  + \ x\^2\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "Execute each cell to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the derivative."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcTan[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCsc[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcSec[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCot[x]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["iv.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tDerivative formulas for  ",
  Cell[BoxData[
      RowBox[{\(Cosh[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Sinh[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Tanh[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Csch[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Sech[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(and\ \ Coth[x]\)}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation iv.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\(\(\[PartialD]\_x\ Cosh[x]\  \[Equal] \ \ Sinh[
          x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ Sinh[x]\  \[Equal] \ 
        Cosh[x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ Tanh[x]\  \[Equal] \ 
        Sech[x]\^2\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          Csch[x]\  \[Equal] \ \(-\ Coth[x]\)\ Csch[
            x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          Sech[x]\  \[Equal] \ \(-\ Sech[x]\)\ Tanh[
            x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\[PartialD]\_x\ Coth[x]\  \[Equal] \ \(-\ Csch[x]\^2\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Execute each cell to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the derivative."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_x\ Cosh[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Sinh[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Tanh[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Csch[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Sech[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Coth[x]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["v.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tDerivative formulas for  ",
  Cell[BoxData[
      RowBox[{\(ArcCosh[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcSinh[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcTanh[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcCsch[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcSech[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], "   ", \(ArcCoth[x]\)}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation v.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\[PartialD]\_x\ ArcCosh[x]\  \[Equal] \ 1\/\@\(x\^2\  - \ 1\)\), 
    "\n", 
      \(\[PartialD]\_x\ ArcSinh[x]\  \[Equal] \ 1\/\@\(1\  + \ x\^2\)\), 
    "\n", 
      \(\[PartialD]\_x\ ArcTanh[x]\  \[Equal] \ 1\/\(1\  - \ x\^2\)\), "\n", 
      \(\[PartialD]\_x\ 
          ArcCsch[x]\  \[Equal] \ \(-\(1\/\(\(Abs[
                  x]\) \(\@\(1\  + \ x\^2\)\)\(\ \)\)\)\)\), "\n", 
      \(\[PartialD]\_x\ 
          ArcSech[x]\  == \ \(-\(1\/\(x\ \@\(1\  - \ x\^2\)\)\)\)\), "\n", 
      \(\[PartialD]\_x\ ArcCoth[x]\  \[Equal] \ 1\/\(1\  - \ x\^2\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Execute each cell to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the derivative."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCosh[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcSinh[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcTanh[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCsch[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcSech[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCoth[x]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["vi.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tDerivative formulas for  ",
  Cell[BoxData[
      RowBox[{\(u[x]\^n\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(\[ExponentialE]\^u[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Log[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(b\^u[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", 
          RowBox[{"Log", "[", 
            RowBox[{"b", 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(u[x]\)}], "]"}]}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation vi.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\(\(\[PartialD]\_x\ u[x]\^n\  \[Equal] \ 
        n\ u[x]\^\(n - 1\)\ \(u'\)[x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ \[ExponentialE]\^u[x]\  \[Equal] \ \
\[ExponentialE]\^u[x]\ \(u'\)[x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\[PartialD]\_x\ 
          Log[u[x]]\  \[Equal] \ \(u'\)[x]\/\(\(u[x]\)\(\[IndentingNewLine]\)
          \)\), "\n", 
      \(\(\(\[PartialD]\_x\ b\^u[x]\  \[Equal] \ 
        b\^u[x]\ Log[b]\ \(u'\)[x]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\[PartialD]\_x\ 
          Log[b, u[x]]\  \[Equal] \ \(u'\)[x]\/\(Log[b]\ u[x]\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Execute each cell to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the derivative."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_x\ u[x]\^n\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ \[ExponentialE]\^u[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Log[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ b\^u[x]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Log[b, u[x]]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["vii.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tDerivative formulas for  ",
  Cell[BoxData[
      RowBox[{\(Cos[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Sin[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Tan[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Csc[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(Sec[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", \(Cot[u[x]]\)}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation vii.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\[PartialD]\_x\ 
          Cos[u[x]] \[Equal] \ \(\(\(-\ Sin[u[x]]\)\ \(u'\)[
            x]\)\(\[IndentingNewLine]\)
        \)\), "\n", 
      \(\[PartialD]\_x\ 
          Sin[u[x]] \[Equal] \ \(\(Cos[u[x]]\ \(u'\)[
            x]\)\(\[IndentingNewLine]\)
        \)\), "\n", 
      \(\[PartialD]\_x\ 
          Tan[u[x]] \[Equal] \ \(\(Sec[u[x]]\^2\ \(u'\)[
            x]\)\(\[IndentingNewLine]\)
        \)\), "\n", 
      \(\[PartialD]\_x\ 
          Csc[u[x]] \[Equal] \ \(\(\(-\ Cot[u[x]]\)\ Csc[u[x]]\ \(u'\)[
            x]\)\(\[IndentingNewLine]\)
        \)\), "\n", 
      \(\[PartialD]\_x\ 
          Sec[u[x]] \[Equal] \ \(\(Sec[u[x]]\ Tan[u[x]]\ \(u'\)[
            x]\)\(\[IndentingNewLine]\)
        \)\), "\n", 
      \(\[PartialD]\_x\ 
          Cot[u[x]] \[Equal] \(-\ Csc[u[x]]\^2\)\ \(u'\)[x]\)}]]
}], "Text"],

Cell[TextData[{
  "Execute each cell to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the derivative."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_x\ Cos[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Sin[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Tan[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Csc[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Sec[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ Cot[u[x]]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["viii.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tDerivative formulas for  ",
  Cell[BoxData[
      RowBox[{\(ArcCos[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcSin[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcTan[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcCsc[u[x]]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(ArcSec[u[x]]\)}]]],
  ",",
  "  and  ",
  Cell[BoxData[
      \(\(\(\ \)\(ArcCot[u[x]]\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation viii.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]]], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\(\(\[PartialD]\_x\ 
          ArcCos[u[
              x]]\  \[Equal] \ \(-\(\(u'\)[
                x]\/\@\(1\  - \ u[x]\^2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          ArcSin[u[
              x]]\  \[Equal] \ \(u'\)[x]\/\@\(1\  - \ u[x]\^2\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          ArcTan[u[
              x]]\  \[Equal] \ \(u'\)[x]\/\(1\  + \ u[x]\^2\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          ArcCsc[u[
              x]]\  \[Equal] \ \(-\(\(u'\)[
                x]\/\(u[
                  x] \@\(\(\ \)\(\(u[x]\^2\)\(\ \)\(-\)\(\ \)\(1\)\(\ \
\)\)\)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\(\(\[PartialD]\_x\ 
          ArcSec[u[
              x]]\  \[Equal] \ \(u'\)[x]\/\(u[x] \@\(\(\ \)\(\(u[x]\^2\)\(\ \
\)\(-\)\(\ \)\(1\)\(\ \)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\[PartialD]\_x\ 
          ArcCot[u[
              x]]\  \[Equal] \ \(-\(\(u'\)[x]\/\(1\  + \ u[x]\^2\)\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Execute each cell to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the derivative."
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCos[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcSin[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcTan[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCsc[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcSec[u[x]]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_x\ ArcCot[u[x]]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 4.  (The Chain Rule).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let   ",
  Cell[BoxData[
      \(z = f \((y)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(y = g \((x)\)\)]],
  "  be differentiable functions,  and define  ",
  Cell[BoxData[
      \(h \((x)\)\)]],
  "  as their composition  \n\n\t\t",
  Cell[BoxData[
      \(h \((x)\) = f \((g \((x)\))\)\)]],
  ". \n\t\t\nThen  ",
  Cell[BoxData[
      \(h \((x)\)\)]],
  "  is differentiable and its derivative is  \n\n\t\t",
  Cell[BoxData[
      \(h' \((x)\) = \ f' \((g \((x)\))\)\ g' \((x)\)\)]],
  ".  "
}], "Text",
  CellTags->"The Chain Rule"],

Cell[BoxData[{
    \(\(Clear[e, f, g, h, p, q, x];\)\ \ \ \), "\n", 
    \(\(Print["\< h[x] = \>", f[g[x]]\ ];\)\ \ \), "\n", 
    \(\(Print["\<h'[x] = \>", \[PartialD]\_x\ f[g[x]]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["\n",
    FontWeight->"Bold"],
  StyleBox["Example 12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((y)\) = 1\/\(1\  - \ y\^2\)\)]],
  "  and  ",
  Cell[BoxData[
      \(g \((x)\) = \((Sin[x])\)\^2\)]],
  ".  Find the derivative of  ",
  Cell[BoxData[
      \(h \((x)\) = f \((g \((x)\))\)\)]],
  ".   "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[y_] = 1\/\(1\  - \ y\^2\);\)\ \ \), "\n", 
    \(\(g[x_] = \((Sin[x])\)\^2;\)\ \ \), "\n", 
    \(\(h[x_] = f[g[x]];\)\ \ \), "\n", 
    \(\(f1[y_] = \[PartialD]\_y\ f[y];\)\ \ \), "\n", 
    \(\(g1[x_] = \[PartialD]\_x\ g[x];\)\ \ \), "\n", 
    \(\(h1[x_] = \[PartialD]\_x\ h[x];\)\ \ \), "\n", 
    \(\(Print["\<f[y] = \>", f[y]\ ];\)\ \ \), "\n", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<h[x] = f[g[x]] = \>", f[g[x]]\ ];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\< f'[y] = \>", f1[y]\ ];\)\ \ \), "\n", 
    \(\(Print["\< f'[g[x]] = \>", f1[g[x]]\ ];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\< g'[x] = \>", 
        g1[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f'[g[x]] g'[x] = \>", 
        f1[g[x]]\ g1[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<          h'[x] = \>", h1[x]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 5.  (Intermediate Value Theorem for Continuous \
Functions).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is a continuous on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(L\)]],
  "  is  any number between  ",
  Cell[BoxData[
      \(f \((a)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(f \((b)\)\)]],
  ".  Then there exists a value  ",
  Cell[BoxData[
      \(c\)]],
  "  with  ",
  Cell[BoxData[
      \(a < c < b\)]],
  "  such that  ",
  Cell[BoxData[
      \(f \((c)\) = L\)]],
  ".  "
}], "Text",
  CellTags->"Intermediate Value Theorem for Continuous Functions"],

Cell[TextData[{
  StyleBox["Example 13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the function  ",
  Cell[BoxData[
      \(f \((x)\) = cos \((x - 1)\)\)]],
  ",  which is continuous on the interval  ",
  Cell[BoxData[
      \(\([0, 2.5]\)\)]],
  "  and suppose that  ",
  Cell[BoxData[
      \(L = 0.8\)]],
  "   Since  ",
  Cell[BoxData[
      \(f \((0)\) = \(0.540302 < L < 1 = \ f \((1)\)\)\)]],
  ",  there exists a value  ",
  Cell[BoxData[
      \(c\_1\)]],
  "  with  ",
  Cell[BoxData[
      \(0 < c\_1 < 1\)]],
  " so that  ",
  Cell[BoxData[
      \(f \((c\_1)\) = L\)]],
  ".   Also, since  ",
  Cell[BoxData[
      \(f \((2.5)\) = \(0.0707372 < L < 1 = f \((1)\)\)\)]],
  ",  there exists a value  ",
  Cell[BoxData[
      \(c\_2\)]],
  "  with  ",
  Cell[BoxData[
      \(1 < c\_2 < 2.5\)]],
  "  so that  ",
  Cell[BoxData[
      \(f \((c\_2)\) = L\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a1, a2, b1, b2, c, c1, c2, f, grf, ln0, ln1, ln2, L, x, y1, 
        y2];\)\ \ \), "\n", 
    \(\(f[x_] = Cos[x - 1];\)\ \ \), "\n", 
    \(\(a1 = 0;\)\ \ \), "\n", 
    \(\(b1 = 1;\)\ \ \), "\n", 
    \(\(a2 = 1;\)\ \ \), "\n", 
    \(\(b2 = 2.5;\)\ \ \), "\n", 
    \(\(L = 0.8;\)\ \ \), "\n", 
    \(\(solset\  = \ Solve[\ f[c]\  \[Equal] \ L, c\ ];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<   L = \>", L];\)\ \ \), "\n", 
    \(\(Print["\<f[c] = \>", L];\)\ \ \), "\n", 
    \(\(Print["\<Solve  f[c] \[Equal] L  for c.\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_1\) = \>\"", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_2\) = \>\"", 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(c1 = 1 - ArcCos[0.8];\)\ \ \), "\n", 
    \(\(y1 = Cos[c1 - 1];\)\ \ \), "\n", 
    \(\(c2 = 1 + ArcCos[0.8];\)\ \ \), "\n", 
    \(\(y2 = Cos[c2 - 1];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(grf = 
        Plot[f[x], {x, 0, 1 + \[Pi]\/2}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(ln0 = 
        Graphics[{Cyan, Line[{{0, L}, {1 + \[Pi]\/2, L}}]}];\)\ \ \), "\n", 
    \(\(ln1 = Graphics[{Green, Line[{{c1, 0}, {c1, y1}}]}];\)\ \ \), "\n", 
    \(\(ln2 = Graphics[{Green, Line[{{c2, 0}, {c2, y1}}]}];\)\ \ \), "\n", 
    \(\(Show[grf, ln0, ln1, ln2, AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] "\<y = Cos[x-1]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f(x) = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<[a,b] = [\>", a1, "\<, \>", b1, "\<]\>"];\)\ \ \), "\n", 
    \(\(Print["\<f[\>", a1, "\<] = \>", N[f[a1]], "\<,   f[\>", 
        b1, "\<] = \>", N[f[b1]]\ ];\)\ \ \), "\n", 
    \(\(Print["\<L = \>", L];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_1\) = \>\"", c1];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(c\_1\)] = \>\"", f[c1]\ ];\)\ \ \), "\n", 
    \(\(Print[a1, "\<  <  \>", c1\ "\<  <  \>", b1];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \ \), "\n", 
    \(\(Print["\<f(x) = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<[a,b] = [\>", a2, "\<, \>", b2, "\<]\>"];\)\ \ \), "\n", 
    \(\(Print["\<f[\>", a2, "\<] = \>", N[f[a2]], "\<,   f[\>", 
        b2, "\<] = \>", N[f[b2]]\ ];\)\ \ \), "\n", 
    \(\(Print["\<L = \>", L];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_2\) = \>\"", c2];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(c\_2\)] = \>\"", f[c2]\ ];\)\ \ \), "\n", 
    \(\(Print[a2, "\<  <  \>", c2\ "\<  <  \>", b2];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 6.  (Extreme Value Theorem for a Continuous Function).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is a continuous function on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".  Then there exists a lower bound  ",
  Cell[BoxData[
      \(M\_1\)]],
  "  and an upper bound  ",
  Cell[BoxData[
      \(M\_2\)]],
  "  and two numbers  ",
  Cell[BoxData[
      \(x\_1\)]],
  "  and  ",
  Cell[BoxData[
      \(x\_2\)]],
  "  in  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  such that   ",
  Cell[BoxData[
      RowBox[{\(M\_1\), " ", "=", " ", 
        RowBox[{
          RowBox[{
            RowBox[{"f", 
              RowBox[{"(", 
                StyleBox[
                  RowBox[{"x", 
                    StyleBox["1",
                      FontSize->10,
                      FontVariations->{"CompatibilityType"->"Subscript"}]}]], 
                ")"}]}], " ", "\[LessEqual]", " ", \(f \((x)\)\), " ", 
            "\[LessEqual]", " ", 
            RowBox[{"f", 
              RowBox[{"(", 
                StyleBox[
                  RowBox[{"x", 
                    StyleBox["2",
                      FontSize->10,
                      FontVariations->{"CompatibilityType"->"Subscript"}]}]], 
                ")"}]}]}], " ", "=", " ", \(M\_2\)}]}]]],
  ",    whenever  ",
  Cell[BoxData[
      StyleBox[\(a \[LessEqual] x \[LessEqual] b\),
        FontWeight->"Plain",
        FontColor->GrayLevel[0]]], "Input"],
  "."
}], "Text",
  CellTags->"Extreme Value Theorem for a Continuous Function"],

Cell[TextData[{
  StyleBox["Example 14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = 35 + 59.5\ x - 66.5\ x\^2 + 15\ x\^3\)]],
  ".  Find the minimum and maximum of  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  over the interval  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Method i.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in function for finding a minimum value.  Compute approximations \
for the minimum and maximum of  f(x)  over the interval  [0, 3]."
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(Clear[dot, f, x];\)\ \ \), "\n", 
    \(\(f[x_]\  = \ 35 + 59.5\ x - 66.5\ x\^2 + 15\ x\^3;\)\ \ \), "\n", 
    \(\(minset\  = \ FindMinimum[f[x], {x, 2.5}];\)\ \ \), "\n", 
    \(\(maxset\  = \ FindMinimum[\(-f[x]\), {x, 0.5}];\)\ \ \), "\n", 
    \(\(maxset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\  \
= \ \(-\ maxset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\);\
\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(dot1\  = \ 
        Graphics[{Green, PointSize[0.025], 
            Point[{minset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\), 
                minset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)}]}];\)\ \ \), "\n", 
    \(\(dot2\  = \ 
        Graphics[{Blue, PointSize[0.025], 
            Point[{maxset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\), 
                maxset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)}]}];\)\ \ \), "\n", 
    \(\(grf = 
        Plot[f[x], {x, 0, 3}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[grf, dot1, dot2, AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] \*"\"\<     y = 35+59.5 x-66.5 \!\(x\^2\)+15 \
\!\(x\^3\)\>\"", DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<For the minimum we have:  \>", minset];\)\ \ \), "\n", 
    \(\(Print["\<For the maximum we have:  \>", maxset];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Method ii.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Since the given function  f(x)  is also differentiable,  locate the \
critical values where  f '(x) = 0."
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"solset", "=", 
          RowBox[{"Solve", "[", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["f", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
                "0"}], ",", "x"}], "]"}]}], ";"}], "  "}], "\n", 
    RowBox[{\(xmin\  = \ 
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\), "  "}], "\n", 
    RowBox[{\(ymin\  = \ f[xmin];\), "  "}], "\n", 
    RowBox[{\(xmax\  = \ 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\), "  "}], "\n", 
    RowBox[{\(ymax\  = \ f[xmax];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), "  "}], "\[IndentingNewLine]",
   
    RowBox[{\(dot1\  = \ 
          Graphics[{Green, PointSize[0.025], 
              Point[{minset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\), 
                  minset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)}]}];\), "  "}], "\n", 
    RowBox[{\(dot2\  = \ 
          Graphics[{Blue, PointSize[0.025], 
              Point[{maxset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\), 
                  maxset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)}]}];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(lmin = 
          Graphics[{Green, 
              Line[{{xmin + 0.5, ymin}, {xmin - 0.5, ymin}}]}];\), 
      "  "}], "\n", 
    RowBox[{\(lmax = 
          Graphics[{Blue, Line[{{xmax + 0.5, ymax}, {xmax - 0.5, ymax}}]}];\),
       "  "}], "\n", 
    RowBox[{\(Show[grf, dot1, dot2, lmin, lmax, 
          Prolog \[Rule] {PointSize[0.02]}, 
          Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 60, 10]}, 
          AxesLabel \[Rule] {x, y}, \n\t
          PlotLabel \[Rule] \*"\"\<     y = 35+59.5 x-66.5 \!\(x\^2\)+15 \
\!\(x\^3\)\>\"", DisplayFunction \[Rule] $DisplayFunction];\), "  "}], "\n", 
    RowBox[{\(Print["\< f[x] = \>", f[x]\ ];\), "  "}], "\n", 
    RowBox[{\(Print["\<f'[x] = \>", \(f'\)[x]\ ];\), "  "}], "\n", 
    RowBox[{\(Print["\<Solve   f'[x] = 0\>"];\), "  "}], "\n", 
    RowBox[{\(Print[solset];\), "  "}], "\n", 
    RowBox[{\(Print["\<\n\>", "\<The maximum value for the function \
f(x):\>"];\), "  "}], "\n", 
    RowBox[{\(Print["\<f(x) = \>", f[x]];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(x\_1\) = \>\"", xmax];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(max\+\(0 \[LessEqual] x \[LessEqual] 3\)\) \
\>\"", "\<f(x) = f(\>", xmax, \*"\"\<) = \!\(y\_1\) = \>\"", ymax];\), 
      "   "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\n\>", "\<The minimum value for the function \
f(x):\>"];\), "  "}], "\n", 
    RowBox[{\(Print["\<f(x) = \>", f[x]];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(x\_2\) = \>\"", xmin];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(min\+\(0 \[LessEqual] x \[LessEqual] 3\)\) \
\>\"", "\<f(x) = f(\>", xmin, \*"\"\<) = \!\(y\_2\) = \>\"", ymin];\), 
      "  "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 7.  (Differentiable Function Implies Continuous \
Function).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nIf  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is differentiable at  ",
  Cell[BoxData[
      \(x = x\_0\)]],
  ",  then  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous at  ",
  Cell[BoxData[
      \(x = x\_0\)]],
  "."
}], "Text",
  CellTags->"Differentiable Function Implies Continuous Function"],

Cell[TextData[{
  StyleBox["Example 15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = sin \((x + 1)\)\)]],
  ".  Investigate the derivative via limiting slopes of secant lines at  ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, df, f, ln0, lns, m, pt0, x0, x1, dx, y0, y1, 
        yx];\)\ \ \), "\n", 
    \(\(f[x_] = Sin[x + 1];\)\ \ \), "\n", 
    \(\(df[x_] = Cos[x + 1];\)\ \ \), "\n", 
    \(\(a = 0;\)\ \ \), "\n", 
    \(\(b = 1.85;\)\ \ \), "\n", 
    \(\(ln0 = {};\)\ \ \), "\n", 
    \(\(pt0 = {};\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(For[j = 1, 
        j \[LessEqual] 14, \(j++\), \[IndentingNewLine]x0 = 
          N[a]; \ \ \[IndentingNewLine]y0 = 
          N[f[x0]]; \ \ \[IndentingNewLine]x1 = 
          N[a + 1\/2\^j]; \ \ \[IndentingNewLine]y1 = 
          N[f[x1]]; \ \ \[IndentingNewLine]dx = 
          x1 - x0; \ \ \[IndentingNewLine]dy = 
          y1 - y0; \ \ \[IndentingNewLine]m = 
          dy\/dx; \ \ \[IndentingNewLine]ln0 = 
          Append[ln0, 
            Graphics[{Hue[1 - \(j - 1\)\/20], 
                Line[{{x0, y0}, {b, 
                      y0 + b\ m}}]}]]; \ \ \[IndentingNewLine]pt0 = 
          Append[pt0, {dx, dy, dy\/dx}];\ ];\)\ \ \), "\n", 
    \(\(grf = 
        Plot[f[x], {x, a, b}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[grf, ln0, PlotRange \[Rule] {{0, 1.85}, {0, 1.85}}, 
        AspectRatio \[Rule] 1, AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] "\<y = Sin[x+1]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<y = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Table of values for the slope.\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<  \[CapitalDelta]x               \[CapitalDelta]y        \
       \!\(\[CapitalDelta]y\/\[CapitalDelta]x\)\>\""];\)\ \ \), "\n", 
    \(\(Print[TableForm[pt0]\ ];\)\ \ \), "\n", 
    \(\(Print["\<The function f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<is differentiable at x = \>", a];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(x00 = {};\)\ \ \), "\n", 
    \(\(y00 = {};\)\ \ \), "\n", 
    \(\(xy0 = {};\)\ \ \), "\n", 
    \(\(For[j = 1, 
        j \[LessEqual] 14, \(j++\), \[IndentingNewLine]x1 = 
          N[a + 1\/2\^j]; \ \ \[IndentingNewLine]y1 = 
          N[f[x1]]; \ \ \[IndentingNewLine]x00 = 
          Append[x00, {x1, 0}]; \ \ \[IndentingNewLine]y00 = 
          Append[y00, {0, y1}]; \ \ \[IndentingNewLine]xy0 = 
          Append[xy0, {x1, y1}];\ ];\)\ \ \), "\n", 
    \(\(dot0 = 
        ListPlot[xy0, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(dotx = 
        ListPlot[x00, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(doty = 
        ListPlot[y00, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(grf = 
        Plot[f[x], {x, a, b}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[grf, dot0, dotx, doty, PlotRange \[Rule] {{0, 0.5}, {0, 1.0}}, 
        Prolog \[Rule] {PointSize[0.02]}, AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] "\<y = Sin[x+1]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<y = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<  \!\(x\_n\)               \!\(y\_n\)\>\""];\)\ \ \), "\n\
", 
    \(\(Print[TableForm[xy0]\ ];\)\ \ \), "\n", 
    \(\(Print["\<The limiting values are:\>"];\)\ \ \), "\n", 
    \(\(Print[x0, "\<\t \t \t\>", y0];\)\ \ \), "\n", 
    \(\(Print["\<The function f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<is continuous at x = \>", a];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 8.  (Rolle's Theorem).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous on the (closed and finite) interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ",  and that  ",
  Cell[BoxData[
      \(f' \((x)\)\)]],
  "  exists for all  ",
  Cell[BoxData[
      \(a < x < b\)]],
  ".   If  ",
  Cell[BoxData[
      \(f \((a)\) = 0\)]],
  "  and  ",
  Cell[BoxData[
      \(f \((b)\) = 0\)]],
  ",  then there exists a value  ",
  Cell[BoxData[
      \(c\)]],
  ",  with  ",
  Cell[BoxData[
      \(a < c < b\)]],
  ",  such that  ",
  Cell[BoxData[
      \(f' \((c)\) = 0\)]],
  ".  "
}], "Text",
  CellTags->"Rolle's Theorem"],

Cell[TextData[{
  StyleBox["Example16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The function  ",
  Cell[BoxData[
      \(f \((x)\) = sin \((x)\) - 1\/2\)]],
  "  has two zeros in  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  ".  According to Rolle's theorem, there exists a value  ",
  Cell[BoxData[
      \(c\)]],
  "  with  ",
  Cell[BoxData[
      \(0 < c < 3\)]],
  "  such that  ",
  Cell[BoxData[
      \(f' \((c)\) = 0\)]],
  ".  Find  ",
  Cell[BoxData[
      \(c\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Find the two zeros of  f(x).", "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(Clear[f, x];\)\ \ \), "\n", 
    \(\(f[x_] = Sin[x] - 1\/2;\)\ \ \), "\n", 
    \(\(solset\  = \ Solve[f[x] \[Equal] 0, x];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<Solve  f[x] = 0 .\>"];\)\ \ \), "\n", 
    \(\(Print[solset];\)\ \ \), "\n", 
    \(\(Print["\<A  solution is   \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \ \), "\n", 
    \(\(Print["\<Another one is  \>", \[Pi] - 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \ \)}], "Input"],

Cell["Or, the two roots can obtained using the inverse function.", "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(r1 = ArcSin[1\/2];\)\ \ \), "\n", 
    \(\(r2 = r1 + 2\ \((\[Pi]\/2 - r1)\);\)\ \ \), "\n", 
    \(\(Print[\*"\"\<   \!\(r\_1\) = \>\"", r1];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(r\_1\)] = \>\"", f[r1]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<   \!\(r\_2\) = \>\"", r2];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<f[\!\(r\_2\)] = \>\"", f[r2]];\)\ \ \)}], "Input"],

Cell["Find the function  f '(x)  and its zeros.", "Text",
  Evaluatable->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"solset", "=", 
          RowBox[{"Solve", "[", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["f", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
                "0"}], ",", "x"}], "]"}]}], ";"}], "  "}], "\n", 
    RowBox[{\(c = 
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\), "  "}], "\n", 
    RowBox[{\(yc = f[c];\), "  "}], "\n", 
    RowBox[{\(Print["\<f[x] = \>", f[x]\ ];\), "  "}], "\n", 
    RowBox[{\(Print["\< f'[x] = \>", \(f'\)[x]\ ];\), "  "}], "\n", 
    RowBox[{\(Print["\<Solve f'[c] = 0.\>"];\), "  "}], "\n", 
    RowBox[{\(Print["\<   c  = \>", c];\), "  "}], "\n", 
    RowBox[{\(Print["\< f[c] = \>", yc];\), "  "}], "\n", 
    RowBox[{\(Print["\<f'[c] = \>", \(f'\)[c]\ ];\), "  "}]}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(grf = 
        Plot[f[x], {x, 0, \[Pi]}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(dot\  = \ 
        Graphics[{Green, PointSize[0.025], 
            Point[{c, f[c]}]}];\)\ \ \), "\n", 
    \(\(lmax = 
        Graphics[{Green, 
            Line[{{c + 1, f[c]}, {c - 1, f[c]}}]}];\)\ \ \), "\n", 
    \(\(Show[grf, lmax, dot, PlotRange \[Rule] {{0, \[Pi]}, {\(-0.5\), 0.5}}, 
        Prolog \[Rule] {PointSize[0.02]}, 
        Ticks \[Rule] {Range[0, \[Pi], \[Pi]\/4], Range[\(-1\), 1, 0.25]}, 
        AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] \*"\"\<y = Sin[x] - \!\(1\/2\)\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<The value c for Rolle's theorem for the function\>"];\)\ \ \
\), "\n", 
    \(\(Print["\<f(x) = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<c = \>", c];\)\ \ \), "\n", 
    \(\(Print["\<f(c) = f(\>", c, \*"\"\<) = \!\(y\_c\) = \>\"", 
        f[c]\ ];\)\ \ \), "\n", 
    \(\(Print["\<f'(c) = \>", \(f'\)[c]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 9.  (Mean Value Theorem for Derivatives).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ",  and that  ",
  Cell[BoxData[
      \(f' \((x)\)\)]],
  "  exists for all  ",
  Cell[BoxData[
      \(a < x < b\)]],
  ".  Then there exists a number  ",
  Cell[BoxData[
      \(c\)]],
  ",  with  ",
  Cell[BoxData[
      \(a < c < b\)]],
  ",  such that \n\n\t",
  Cell[BoxData[
      RowBox[{\(f' \((c)\)\), " ", "=", " ", 
        RowBox[{
          FractionBox[
            StyleBox[\(f \((b)\)\  - \ f \((a)\)\),
              FontSize->12], 
            StyleBox[\(b\  - \ a\),
              FontSize->12]], " ", "=", " ", "m"}]}]]],
  " .  "
}], "Text",
  CellTags->"Mean Value Theorem for Derivatives"],

Cell[TextData[{
  StyleBox["Example 17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider  ",
  Cell[BoxData[
      \(f \((x)\) = sin \((x)\)\)]],
  "  over  ",
  Cell[BoxData[
      \(\([0.1, 2.1]\)\)]],
  ".   According to the Mean Value theorem, there exists a value  ",
  Cell[BoxData[
      \(c\)]],
  "  with  ",
  Cell[BoxData[
      \(0.1 < c < 2.1\)]],
  "  such that  \n\n\t",
  Cell[BoxData[
      RowBox[{\(f' \((c)\)\), " ", "=", " ", 
        RowBox[{
          FractionBox[
            StyleBox[\(f \((2.1)\)\  - \ f \((0.1)\)\),
              FontSize->12], 
            StyleBox[\(2.1\  - \ 0.1\),
              FontSize->12]], " ", "=", " ", "m"}]}]]],
  " .   Find  ",
  Cell[BoxData[
      \(c\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the function  f(x)  and compute  m.  ", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, f];\)\ \ \), "\n", 
    \(\(f[x_] = Sin[x];\)\ \ \), "\n", 
    \(\(a = 0.1;\)\ \ \), "\n", 
    \(\(b = 2.1;\)\ \ \), "\n", 
    \(\(m = \(f[b] - f[a]\)\/\(b - a\);\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<The interval is  [a,b] = [\>", a, "\<, \>", 
        b, "\<].\>"];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", \*"\"\<m = \!\(\(f[b] - f[a]\)\/\(b - a\)\) = \
(f[\>\"", b, "\<] - f[\>", a, "\<])/(\>", b, "\< - \>", 
        a, "\<)\>"\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<m = \!\(\(f[b] - f[a]\)\/\(b - a\)\) = (\>\"", 
        f[b] - f[a], "\<)/(\>", 
        b\  - \ a, "\<)\>"\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The slope is  m = \>", m];\)\ \ \)}], "Input"],

Cell["Use the function  f '(x)  and find where  f '(c) = m.  ", "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(solset = Solve[\ \(f'\)[x] \[Equal] m, x\ ];\)\ \ \), "\n", 
    \(\(c0 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(y0 = f[c0];\)\ \ \), "\n", 
    \(\(ya = f[a];\)\ \ \), "\n", 
    \(\(yb = f[b];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(dots = 
        Graphics[{Red, Point[{a, f[a]}], Point[{b, f[b]}]}];\)\ \ \), "\n", 
    \(\(dot\  = \ 
        Graphics[{Blue, PointSize[0.025], 
            Point[{c0, f[c0]}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(lines = 
        Graphics[{RGBColor[0, 1, 0], Line[{{a, f[a]}, {b, f[b]}}], 
            Line[{{c0 - 1\/2, f[c0] - m\/2}, {c0 + 1\/2, 
                  f[c0] + m\/2}}]}];\)\ \ \), "\n", 
    \(\(line1 = 
        Graphics[{Blue, 
            Line[{{c0 - 1\/2, f[c0] - m\/2}, {c0 + 1\/2, 
                  f[c0] + m\/2}}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(line2 = 
        Graphics[{Red, 
            Line[{{a, f[a]}, {b, f[b]}}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(grf = 
        Plot[f[x], {x, 0.1, 2.1}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[grf, dots, dot, line1, line2, 
        PlotRange \[Rule] {{0, 2.2}, {0, 1.12}}, 
        Prolog \[Rule] {PointSize[0.02]}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1, 0.5]}, 
        AxesLabel \[Rule] {x, y}, \n\tPlotLabel \[Rule] "\<y = Sin[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<The interval is [\>", a, "\< , \>", 
        b, "\<]\>"];\)\ \ \), "\n", 
    \(\(Print["\<f'[x] = \>", \(f'\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(f[2.1] - f[0.1]\)\/\(2.1 - 0.1\)\) = \>\"", 
        m];\)\ \ \), "\n", 
    \(\(Print["\<The value c where  f'[c] = m = \>", 
        m, "\<  is:\>"];\)\ \ \), "\n", 
    \(\(Print["\<c = \>", c0];\)\ \ \), "\n", 
    \(\(Print[a, "\<  <  \>", c0, "\<  <  \>", b];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 10.  (Extreme Value Theorem for a Differentiable \
Function).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous on the interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  "  and that  ",
  Cell[BoxData[
      \(f' \((x)\)\)]],
  "  exists for all  ",
  Cell[BoxData[
      \(a < x < b\)]],
  ".  Then there exists a lower bound  ",
  Cell[BoxData[
      \(M\_1\)]],
  "  and an upper bound  ",
  Cell[BoxData[
      \(M\_2\)]],
  "  and two numbers  ",
  Cell[BoxData[
      \(x\_1\)]],
  "  and  ",
  Cell[BoxData[
      \(x\_2\)]],
  "  in  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  "  such that  ",
  Cell[BoxData[
      RowBox[{\(M\_1\), " ", "=", " ", 
        RowBox[{
          RowBox[{
            RowBox[{"f", 
              RowBox[{"(", 
                StyleBox[
                  RowBox[{"x", 
                    StyleBox["1",
                      FontSize->10,
                      FontVariations->{"CompatibilityType"->"Subscript"}]}]], 
                ")"}]}], " ", "\[LessEqual]", " ", \(f \((x)\)\), " ", 
            "\[LessEqual]", " ", 
            RowBox[{"f", 
              RowBox[{"(", 
                StyleBox[
                  RowBox[{"x", 
                    StyleBox["2",
                      FontSize->10,
                      FontVariations->{"CompatibilityType"->"Subscript"}]}]], 
                ")"}]}]}], " ", "=", " ", \(M\_2\)}]}]]],
  ",    whenever  ",
  Cell[BoxData[
      \(a \[LessEqual] x \[LessEqual] b\)]],
  ".  The numbers  ",
  Cell[BoxData[
      \(x\_1\)]],
  "  and  ",
  Cell[BoxData[
      \(x\_2\)]],
  "  are either critical points of  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  or an endpoint of  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ".  "
}], "Text",
  CellTags->"Extreme Value Theorem for a Differentiable Function"],

Cell[TextData[{
  StyleBox["Example 18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = 35 + 119\/2\ x - 133\/2\ x\^2 + 15\ x\^3\)]],
  ".  Find the minimum and maximum of  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  over the interval  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  "."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, c, f, x];\)\ \ \), "\n", 
    \(\(f[x_] = 35 + 119\/2\ x - 133\/2\ x\^2 + 15\ x\^3;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(grf = 
        Plot[f[x], {x, 0, 3}, PlotStyle \[Rule] Magenta, 
          AxesLabel \[Rule] {x, y}, \n\t
          PlotLabel \[Rule] \*"\"\<         y = 35+\!\(119\/2\)x-\!\(133\/2\)\
\!\(x\^2\)+15\!\(x\^3\)\>\""];\)\ \ \), "\n", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \ \)}], "Input"],

Cell["\<\
Since the given function  f(x)  is also differentiable, locate the critical \
values where  f '(x) = 0.\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[x] = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "]"}], ";"}], 
      "  "}]], "Input"],

Cell[TextData[{
  "The quadratic equation can be used to solve  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], \((x)\)}], 
        "=", \(a\ x\^2\  + \ b\ x\  + \ c = 0\)}]]],
  ". "
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    RowBox[{\(a\  = \ 45;\), "  "}], "\n", 
    RowBox[{\(b\  = \ \(-133\);\), "  "}], "\n", 
    RowBox[{\(c\  = \ 119\/2;\), "  "}], "\n", 
    RowBox[{\(x1 = \(\(-b\) - \@\(b\^2 - 4\ a\ c\)\)\/\(2\ a\);\), 
      "  "}], "\n", 
    RowBox[{\(x2 = \(\(-b\) + \@\(b\^2 - 4\ a\ c\)\)\/\(2\ a\);\), 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<Solve   f'[x] = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], ",", 
            "\"\< = 0 .\>\""}], "]"}], ";"}], "  "}], "\n", 
    RowBox[{\(Print["\<\n\>", \*"\"\<    \!\(x\_1\) = \>\"", x1];\), 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[\!\(x\_1\)] = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "x1", "]"}]}], "]"}], ";"}], 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[\!\(x\_1\)] = \>\"", ",", 
            RowBox[{"Simplify", "[", 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "[", "x1", "]"}], "]"}]}], "]"}], 
        ";"}], "  "}], "\n", 
    RowBox[{\(Print["\<\n\>", \*"\"\<    \!\(x\_2\) = \>\"", x2];\), 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[\!\(x\_2\)] = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "x2", "]"}]}], "]"}], ";"}], 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[\!\(x\_2\)] = \>\"", ",", 
            RowBox[{"Simplify", "[", 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "[", "x2", "]"}], "]"}]}], "]"}], 
        ";"}], "  "}]}], "Input"],

Cell[TextData[{
  "Or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s can be used to solve f '(x) = 0.\nFirst, we do it symbolically and then \
numerically."
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    RowBox[{\(Print["\<Solve  \>", \(f'\)[x], "\< = 0\>"];\), "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"solset", "=", 
          RowBox[{"Solve", "[", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["f", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
                "0"}], ",", "x"}], "]"}]}], ";"}], "  "}], "\n", 
    RowBox[{\(Print[solset];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(xmin = 
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\), "  "}], "\n", 
    RowBox[{\(ymin = f[xmin];\), "  "}], "\n", 
    RowBox[{\(xmax = 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\), "  "}], "\n", 
    RowBox[{\(ymax = f[xmax];\), "  "}], "\n", 
    RowBox[{\(Print["\<\n\>", \*"\"\<\!\(x\_min\) = \>\"", xmin];\), 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[\!\(x\_min\)] = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "xmin", "]"}]}], "]"}], ";"}], 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[\!\(x\_min\)] = \>\"", ",", 
            RowBox[{"Simplify", "[", 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "[", "xmin", "]"}], "]"}]}], 
          "]"}], ";"}], "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(y\_min\) = f[\!\(x\_min\)] = \>\"", 
          f[xmin]];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(y\_min\) = f[\!\(x\_min\)] = \>\"", 
          Simplify[f[xmin]]];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(y\_min\) = f[\!\(x\_min\)] = \>\"", 
          N[f[xmin]]];\), "  "}], "\n", 
    RowBox[{\(Print["\<\n\>", \*"\"\<\!\(x\_max\) = \>\"", xmax];\), 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[\!\(x\_max\)] = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "xmax", "]"}]}], "]"}], ";"}], 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f'[\!\(x\_max\)] = \>\"", ",", 
            RowBox[{"Simplify", "[", 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "[", "xmax", "]"}], "]"}]}], 
          "]"}], ";"}], "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(y\_max\) = f[\!\(x\_max\)] = \>\"", 
          f[xmax]];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(y\_max\) = f[\!\(x\_max\)] = \>\"", 
          Simplify[f[xmax]]];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(y\_max\) = f[\!\(x\_max\)] = \>\"", 
          N[f[xmax]]];\), "  "}]}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<Solve  \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], ",", 
            "\"\< = 0\>\""}], "]"}], ";"}], "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"solset", "=", 
          RowBox[{"NSolve", "[", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["f", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
                "0"}], ",", "x"}], "]"}]}], ";"}], "  "}], "\n", 
    RowBox[{\(Print[solset];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(xmin = 
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\), "  "}], "\n", 
    RowBox[{\(ymin = f[xmin];\), "  "}], "\n", 
    RowBox[{\(xmax = 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\), "  "}], "\n", 
    RowBox[{\(ymax = f[xmax];\), "  "}], "\n", 
    RowBox[{\(Print["\<\n\>", \*"\"\<\!\(x\_min\) = \>\"", xmin];\), 
      "  "}], "\n", 
    RowBox[{\(Print[\*"\"\< f'[\!\(x\_min\)] = \>\"", \(f'\)[xmin]\ ];\), 
      "  "}], "\n", 
    RowBox[{\(Print[\*"\"\< f'[\!\(x\_min\)] = \>\"", 
          Chop[\(f'\)[xmin]]\ ];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(y\_min\) = f[\!\(x\_min\)] = \>\"", 
          f[xmin]];\), "  "}], "\n", 
    RowBox[{\(Print["\< \>"];\), "  "}], "\n", 
    RowBox[{\(Print["\<\n\>", \*"\"\<\!\(x\_max\) = \>\"", xmax];\), 
      "  "}], "\n", 
    RowBox[{\(Print[\*"\"\< f'[\!\(x\_max\)] = \>\"", \(f'\)[xmax]\ ];\), 
      "  "}], "\n", 
    RowBox[{\(Print[\*"\"\< f'[\!\(x\_max\)] = \>\"", 
          Chop[\(f'\)[xmax]]\ ];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(y\_max\) = f[\!\(x\_max\)] = \>\"", 
          f[xmax]];\), "  "}]}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(grf = 
        Plot[f[x], {x, 0, 3}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(dot1\  = \ 
        Graphics[{Green, PointSize[0.025], 
            Point[{xmin, ymin}]}];\)\ \ \), "\n", 
    \(\(dot2\  = \ 
        Graphics[{Blue, PointSize[0.025], 
            Point[{xmax, ymax}]}];\)\ \ \), "\n", 
    \(\(lmin = 
        Graphics[{Green, 
            Line[{{xmin + 0.5, ymin}, {xmin - 0.5, ymin}}]}];\)\ \ \), "\n", 
    \(\(lmax = 
        Graphics[{Blue, 
            Line[{{xmax + 0.5, ymax}, {xmax - 0.5, ymax}}]}];\)\ \ \), "\n", 
    \(\(Show[grf, dot1, dot2, lmin, lmax, Prolog \[Rule] {PointSize[0.02]}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 60, 10]}, 
        AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] \*"\"\<         y = 35+\!\(119\/2\)x-\!\(133\/2\)\!\
\(x\^2\)+15\!\(x\^3\)\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<The maximum value for the function f(x):\>"];\)\ \ \), "\n", \

    \(\(Print["\<f(x) = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(x\_1\) = \>\"", xmax];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(max\+\(0 \[LessEqual] x \[LessEqual] 3\)\) \>\"", \
"\<f(x) = f(\>", xmax, \*"\"\<) = \!\(y\_1\) = \>\"", 
        ymax];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The minimum value for the function f(x):\>"];\)\ \ \
\), "\n", 
    \(\(Print["\<f(x) = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(x\_2\) = \>\"", xmin];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(min\+\(0 \[LessEqual] x \[LessEqual] 3\)\) \>\"", \
"\<f(x) = f(\>", xmin, \*"\"\<) = \!\(y\_2\) = \>\"", 
        ymin];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 11.  (Generalized Rolle's Theorem).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous on the interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  and that the derivatives  ",
  Cell[BoxData[
      RowBox[{\(f' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(f'' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", " ", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((n)\),
              Derivative],
            MultilineFunction->None], \((x)\)}]}]]],
  "  exist on  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], ")"}]]],
  ",  and that  ",
  Cell[BoxData[
      RowBox[{\(x\_0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(x\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(x\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", " ", 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(x\_n\)}]]],
  "  all lie in  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ".  \n\n\tIf  ",
  Cell[BoxData[
      \(f \((x\_j)\) = 0\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(j = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", " ", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "n"}]]],
  "  then there exists a value  ",
  Cell[BoxData[
      \(c\)]],
  ",  with  ",
  Cell[BoxData[
      \(a < c < b\)]],
  ",  such that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((n)\),
              Derivative],
            MultilineFunction->None], \((c)\)}], "=", "0"}]]],
  "."
}], "Text",
  CellTags->"Generalized Rolle's Theorem"],

Cell[TextData[{
  StyleBox["Example 19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The function  ",
  Cell[BoxData[
      \(f \((x)\) = x\^3 - 7\ x\^2 + 14\ x - 8\)]],
  "  has three zeros in  ",
  Cell[BoxData[
      \(\([0, 5]\)\)]],
  ".  Applying the generalized Rolle's theorem, there exists a value  ",
  Cell[BoxData[
      \(c\)]],
  "  with  ",
  Cell[BoxData[
      \(0 < c < 5\)]],
  "  such that  ",
  Cell[BoxData[
      \(f'' \((c)\) = 0\)]],
  ".  Find  ",
  Cell[BoxData[
      \(c\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the function  f(x)  and find its zeros.  ", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, c0, c1, c2, f, r1, r2, r3];\)\ \ \), "\n", 
    \(\(a = 0;\)\ \ \), "\n", 
    \(\(b = 5;\)\ \ \), "\n", 
    \(\(f[x_] = x\^3 - 7\ x\^2 + 14\ x - 8;\)\ \ \), "\n", 
    \(\(solset = Solve[f[x] \[Equal] 0, x];\)\ \ \), "\n", 
    \(\(r1 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(r2 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(r3 = 
        solset\_\(\(\[LeftDoubleBracket]\)\(3, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<Solve  \>", f[x], "\< = 0 .\>"];\)\ \ \), "\n", 
    \(\(Print[solset];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", r1];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(r\_2\) = \>\"", r2];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(r\_3\) = \>\"", r3];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Use the function  f '(x)  and find its zeros.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can be used to find the roots.  These values are entered into  ",
  Cell[BoxData[
      \(c\_1\)]],
  "  and  ",
  Cell[BoxData[
      \(c\_2\)]],
  "."
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(Print["\< f'[x] = \>", \(f'\)[x]];\)\ \ \), "\n", 
    \(\(Print["\<Solve  \>", \(f'\)[x], "\< = 0 .\>"];\)\ \ \), "\n", 
    \(\(solset1 = Solve[\(f'\)[x] \[Equal] 0, x];\)\ \ \), "\n", 
    \(\(Print[solset1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(c1 = 
        solset1\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\[RightDoubleBracket]\
\)\);\)\ \ \), "\n", 
    \(\(c2 = 
        solset1\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\[RightDoubleBracket]\
\)\);\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_1\) = \>\"", c1, "\< = \>", 
        N[c1]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(c\_2\) = \>\"", c2, "\< = \>", 
        N[c2]];\)\ \ \)}], "Input"],

Cell["Use the function  f ''(x)  and find its root(s).  ", "Text",
  Evaluatable->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< f''[x] = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[DoublePrime]",
                MultilineFunction->None], "[", "x", "]"}]}], "]"}], ";"}], 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<Solve  \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", "\[DoublePrime]",
                MultilineFunction->None], "[", "x", "]"}], ",", 
            "\"\< = 0 .\>\""}], "]"}], ";"}], "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"solset2", "=", 
          RowBox[{"Solve", "[", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["f", "\[DoublePrime]",
                    MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
                "0"}], ",", "x"}], "]"}]}], ";"}], "  "}], "\n", 
    RowBox[{\(Print[solset2];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(c0 = 
          solset2\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\);\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(c\_0\) = \>\"", c0, "\< = \>", N[c0]];\), 
      "  "}]}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(grf0 = 
        Plot[f[x], {x, a, b}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(dots = 
        Graphics[{Red, Point[{r1, f[r1]}], Point[{r2, f[r2]}], 
            Point[{r3, f[r3]}]}];\)\ \ \), "\n", 
    \(\(Show[grf0, dots, PlotRange \[Rule] {{0, 5}, {\(-5\), 5}}, 
        Prolog \[Rule] {PointSize[0.02]}, 
        Ticks \[Rule] {Range[0, 5, 1], Range[\(-5\), 5, 1]}, 
        AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] \*"\"\<y = f[x] = \
\!\(x\^3\)-7\!\(x\^2\)+14x-8\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<The interval is [\>", a, "\< , \>", 
        b, "\<]\>"];\)\ \ \), "\n", 
    \(\(Print["\<There are 3 roots of f[x] in this interval.\>"];\)\ \ \), "\n\
", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", r1, \*"\"\<,   \!\(r\_2\) = \>\"", 
        r2, \*"\"\<,   \!\(r\_3\) = \>\"", r3];\)\ \ \)}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"grf1", "=", 
          RowBox[{"Plot", "[", 
            RowBox[{
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}], 
              ",", \({x, a, b}\), ",", \(PlotStyle \[Rule] Blue\), 
              ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], 
      "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"dots", "=", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{"Blue", ",", 
                RowBox[{"Point", "[", 
                  RowBox[{"{", 
                    RowBox[{"c1", ",", 
                      RowBox[{
                        SuperscriptBox["f", "\[Prime]",
                          MultilineFunction->None], "[", "c1", "]"}]}], "}"}],
                   "]"}], ",", 
                RowBox[{"Point", "[", 
                  RowBox[{"{", 
                    RowBox[{"c2", ",", 
                      RowBox[{
                        SuperscriptBox["f", "\[Prime]",
                          MultilineFunction->None], "[", "c2", "]"}]}], "}"}],
                   "]"}]}], "}"}], "]"}]}], ";"}], "  "}], "\n", 
    RowBox[{\(Show[grf1, dots, PlotRange \[Rule] {{0, 5}, {\(-3\), 9}}, 
          Prolog \[Rule] {PointSize[0.02]}, 
          Ticks \[Rule] {Range[0, 5, 1], Range[\(-4\), 15, 2]}, 
          AxesLabel \[Rule] {x, y}, \n\t
          PlotLabel \[Rule] \*"\"\<y = f[x] = 14-14x+3\!\(x\^2\)\>\"", 
          DisplayFunction \[Rule] $DisplayFunction];\), "  "}], "\n", 
    RowBox[{\(Print["\<y =  f'[x] = \>", \(f'\)[x]\ ];\), "  "}], "\n", 
    RowBox[{\(Print["\<The interval is [\>", a, "\< , \>", b, "\<]\>"];\), 
      "  "}], "\n", 
    RowBox[{\(Print["\<There are 2 roots of  f'[x] in this interval.\>"];\), 
      "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(c\_1\) = \>\"", 
          N[c1], \*"\"\<,   \!\(c\_2\) = \>\"", N[c2]];\), "  "}]}], "Input"],

Cell[BoxData[{
    RowBox[{\(grf2 = 
          Plot[\(f''\)[x], {x, a, b}, PlotStyle \[Rule] Green, 
            DisplayFunction \[Rule] Identity];\), "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"dots", "=", 
          RowBox[{"Graphics", "[", 
            RowBox[{"{", 
              RowBox[{"DarkGreen", ",", 
                RowBox[{"Point", "[", 
                  RowBox[{"{", 
                    RowBox[{"c0", ",", 
                      RowBox[{
                        SuperscriptBox["f", "\[DoublePrime]",
                          MultilineFunction->None], "[", "c0", "]"}]}], "}"}],
                   "]"}]}], "}"}], "]"}]}], ";"}], "  "}], "\n", 
    RowBox[{\(Show[grf2, dots, PlotRange \[Rule] {{0, 5}, {\(-9\), 9}}, 
          Prolog \[Rule] {PointSize[0.02]}, 
          Ticks \[Rule] {Range[0, 5, 1], Range[\(-14\), 15, 2]}, 
          AxesLabel \[Rule] {x, y}, \n\t
          PlotLabel \[Rule] "\<y = f''[x] = -14+6x\>", 
          DisplayFunction \[Rule] $DisplayFunction];\), "  "}], "\n", 
    RowBox[{\(Print["\<y =  f''[x] = \>", \(f''\)[x]\ ];\), "  "}], "\n", 
    RowBox[{\(Print["\<The interval is [\>", a, "\< , \>", b, "\<]\>"];\), 
      "  "}], "\n", 
    RowBox[{\(Print["\<There is 1 root of  f''[x] in this interval.\>"];\), 
      "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<\!\(c\_0\) = \>\"", N[c0]\ ];\), "  "}]}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Calculus",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CalculusBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Calculus",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CalculusBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  \nInternet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The Mean Value Theorem",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/MeanValueTheoremBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Mean Value Theorem",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/MeanValueTheoremBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  \nInternet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The Fundamental Theorem of Calculus",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/FunTheoremCalculusBib.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Fundamental Theorem of Calculus",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/FunTheoremCalculusBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  \nInternet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Maclaurin and Taylor Series",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/TaylorPolyBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Maclaurin and Taylor Series",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/TaylorPolyBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  \nInternet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{955, 626},
WindowMargins->{{6, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
CellLabelAutoDelete->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Limit Definition"->{
    Cell[3428, 111, 2483, 99, 238, "Text",
      CellTags->"Limit Definition"]},
  "GraphicsArray"->{
    Cell[8363, 287, 417, 9, 70, "Input",
      CellTags->"GraphicsArray"]},
  "Squeeze Theorem for Limits"->{
    Cell[13498, 452, 2053, 77, 77, "Text",
      CellTags->"Squeeze Theorem for Limits"]},
  "Continuous Function"->{
    Cell[19804, 676, 973, 37, 77, "Text",
      CellTags->"Continuous Function"]},
  "Limits and Continuous Functions"->{
    Cell[23104, 787, 2163, 82, 151, "Text",
      CellTags->"Limits and Continuous Functions"]},
  "Properties of \[Infinity]"->{
    Cell[33003, 1107, 591, 20, 30, "Text",
      CellTags->"Properties of \[Infinity]"]},
  "Limits for a Composite Function"->{
    Cell[41745, 1489, 2444, 92, 70, "Text",
      CellTags->"Limits for a Composite Function"]},
  "Limit Definition of the Derivative"->{
    Cell[48045, 1688, 802, 25, 122, "Text",
      Evaluatable->False,
      CellTags->"Limit Definition of the Derivative"]},
  "Differential Approximation"->{
    Cell[56959, 1919, 549, 19, 68, "Text",
      Evaluatable->False,
      CellTags->"Differential Approximation"]},
  "Rules for Differentiation"->{
    Cell[65298, 2118, 189, 4, 30, "Text",
      Evaluatable->False,
      CellTags->"Rules for Differentiation"]},
  "Formulas for Differentiation"->{
    Cell[72833, 2311, 198, 4, 30, "Text",
      Evaluatable->False,
      CellTags->"Formulas for Differentiation"]},
  "The Chain Rule"->{
    Cell[89825, 2937, 660, 24, 144, "Text",
      CellTags->"The Chain Rule"]},
  "Intermediate Value Theorem for Continuous Functions"->{
    Cell[92146, 3012, 735, 31, 49, "Text",
      CellTags->"Intermediate Value Theorem for Continuous Functions"]},
  "Extreme Value Theorem for a Continuous Function"->{
    Cell[96737, 3148, 1639, 54, 49, "Text",
      CellTags->"Extreme Value Theorem for a Continuous Function"]},
  "Differentiable Function Implies Continuous Function"->{
    Cell[104178, 3345, 481, 19, 68, "Text",
      CellTags->"Differentiable Function Implies Continuous Function"]},
  "Rolle's Theorem"->{
    Cell[108712, 3462, 749, 33, 49, "Text",
      CellTags->"Rolle's Theorem"]},
  "Mean Value Theorem for Derivatives"->{
    Cell[113478, 3608, 893, 33, 92, "Text",
      CellTags->"Mean Value Theorem for Derivatives"]},
  "Extreme Value Theorem for a Differentiable Function"->{
    Cell[118327, 3749, 2234, 80, 68, "Text",
      CellTags->"Extreme Value Theorem for a Differentiable Function"]},
  "Generalized Rolle's Theorem"->{
    Cell[131312, 4114, 2260, 78, 87, "Text",
      CellTags->"Generalized Rolle's Theorem"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Limit Definition", 168882, 5369},
  {"GraphicsArray", 168984, 5372},
  {"Squeeze Theorem for Limits", 169094, 5375},
  {"Continuous Function", 169212, 5378},
  {"Limits and Continuous Functions", 169334, 5381},
  {"Properties of \[Infinity]", 169464, 5384},
  {"Limits for a Composite Function", 169593, 5387},
  {"Limit Definition of the Derivative", 169732, 5390},
  {"Differential Approximation", 169892, 5394},
  {"Rules for Differentiation", 170042, 5398},
  {"Formulas for Differentiation", 170193, 5402},
  {"The Chain Rule", 170333, 5406},
  {"Intermediate Value Theorem for Continuous Functions", 170472, 5409},
  {"Extreme Value Theorem for a Continuous Function", 170643, 5412},
  {"Differentiable Function Implies Continuous Function", 170815, 5415},
  {"Rolle's Theorem", 170955, 5418},
  {"Mean Value Theorem for Derivatives", 171078, 5421},
  {"Extreme Value Theorem for a Differentiable Function", 171237, 5424},
  {"Generalized Rolle's Theorem", 171390, 5427}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 170, 4, 35, "Text"],
Cell[1949, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3428, 111, 2483, 99, 238, "Text",
  CellTags->"Limit Definition"],
Cell[5914, 212, 901, 33, 41, "Text"],

Cell[CellGroupData[{
Cell[6840, 249, 101, 2, 33, "Text"],
Cell[6944, 253, 397, 7, 147, "Input"],
Cell[7344, 262, 223, 4, 52, "Text"],
Cell[7570, 268, 433, 7, 130, "Input"],
Cell[8006, 277, 177, 3, 52, "Text"],
Cell[8186, 282, 174, 3, 70, "Input"],
Cell[8363, 287, 417, 9, 70, "Input",
  CellTags->"GraphicsArray"],
Cell[8783, 298, 126, 5, 33, "Text"],
Cell[8912, 305, 215, 4, 58, "Input"],
Cell[9130, 311, 63, 0, 33, "Text"],
Cell[9196, 313, 120, 2, 66, "Input"],
Cell[9319, 317, 33, 0, 33, "Text"],
Cell[9355, 319, 66, 1, 30, "Input"],
Cell[9424, 322, 138, 5, 33, "Text"],
Cell[9565, 329, 39, 1, 30, "Input"]
}, Closed]],
Cell[9619, 333, 721, 27, 37, "Text"],

Cell[CellGroupData[{
Cell[10365, 364, 101, 2, 33, "Text"],
Cell[10469, 368, 357, 6, 144, "Input"],
Cell[10829, 376, 153, 3, 33, "Text"],
Cell[10985, 381, 306, 5, 90, "Input"],
Cell[11294, 388, 275, 6, 71, "Text"],
Cell[11572, 396, 415, 8, 111, "Input"],
Cell[11990, 406, 231, 6, 52, "Text"],
Cell[12224, 414, 401, 7, 111, "Input"],
Cell[12628, 423, 487, 16, 77, "Text"],
Cell[13118, 441, 61, 1, 30, "Input"],
Cell[13182, 444, 301, 5, 52, "Text"]
}, Closed]],
Cell[13498, 452, 2053, 77, 77, "Text",
  CellTags->"Squeeze Theorem for Limits"],
Cell[15554, 531, 2906, 111, 86, "Text"],

Cell[CellGroupData[{
Cell[18485, 646, 101, 2, 33, "Text"],
Cell[18589, 650, 666, 12, 258, "Input"],
Cell[19258, 664, 531, 9, 154, "Input"]
}, Closed]],
Cell[19804, 676, 973, 37, 77, "Text",
  CellTags->"Continuous Function"],
Cell[20780, 715, 809, 31, 48, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[21614, 750, 101, 2, 33, "Text"],
Cell[21718, 754, 516, 9, 181, "Input"],
Cell[22237, 765, 852, 19, 219, "Input"]
}, Closed]],
Cell[23104, 787, 2163, 82, 151, "Text",
  CellTags->"Limits and Continuous Functions"],
Cell[25270, 871, 1119, 41, 40, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[26414, 916, 101, 2, 33, "Text"],
Cell[26518, 920, 1890, 37, 520, "Input"],
Cell[28411, 959, 457, 8, 153, "Input"]
}, Closed]],
Cell[28883, 970, 1222, 49, 37, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[30130, 1023, 101, 2, 33, "Text"],
Cell[30234, 1027, 751, 14, 265, "Input"]
}, Closed]],
Cell[31000, 1044, 1013, 37, 56, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32038, 1085, 101, 2, 33, "Text"],
Cell[32142, 1089, 846, 15, 218, "Input"]
}, Closed]],
Cell[33003, 1107, 591, 20, 30, "Text",
  CellTags->"Properties of \[Infinity]"],
Cell[33597, 1129, 2679, 114, 267, "Text"],

Cell[CellGroupData[{
Cell[36301, 1247, 331, 12, 33, "Text"],
Cell[36635, 1261, 166, 8, 35, "Text"],
Cell[36804, 1271, 118, 2, 61, "Input"],
Cell[36925, 1275, 234, 11, 33, "Text"],
Cell[37162, 1288, 71, 1, 30, "Input"],
Cell[37236, 1291, 86, 1, 30, "Input"],
Cell[37325, 1294, 241, 11, 33, "Text"],
Cell[37569, 1307, 71, 1, 30, "Input"],
Cell[37643, 1310, 86, 1, 30, "Input"],
Cell[37732, 1313, 202, 8, 33, "Text"],
Cell[37937, 1323, 80, 1, 30, "Input"],
Cell[38020, 1326, 216, 8, 33, "Text"],
Cell[38239, 1336, 83, 1, 30, "Input"],
Cell[38325, 1339, 202, 8, 33, "Text"],
Cell[38530, 1349, 81, 1, 30, "Input"],
Cell[38614, 1352, 232, 9, 33, "Text"],
Cell[38849, 1363, 90, 1, 30, "Input"],
Cell[38942, 1366, 222, 8, 33, "Text"],
Cell[39167, 1376, 80, 1, 30, "Input"],
Cell[39250, 1379, 83, 1, 30, "Input"],
Cell[39336, 1382, 83, 1, 30, "Input"],
Cell[39422, 1385, 180, 5, 33, "Text"],
Cell[39605, 1392, 106, 2, 31, "Input"],
Cell[39714, 1396, 129, 2, 31, "Input"],
Cell[39846, 1400, 108, 2, 31, "Input"],
Cell[39957, 1404, 129, 2, 31, "Input"],
Cell[40089, 1408, 249, 11, 33, "Text"],
Cell[40341, 1421, 71, 1, 30, "Input"],
Cell[40415, 1424, 288, 11, 36, "Text"],
Cell[40706, 1437, 85, 1, 39, "Input"],
Cell[40794, 1440, 253, 11, 33, "Text"],
Cell[41050, 1453, 63, 1, 30, "Input"],
Cell[41116, 1456, 251, 11, 33, "Text"],
Cell[41370, 1469, 63, 1, 30, "Input"],
Cell[41436, 1472, 238, 11, 33, "Text"],
Cell[41677, 1485, 53, 1, 30, "Input"]
}, Closed]],
Cell[41745, 1489, 2444, 92, 70, "Text",
  CellTags->"Limits for a Composite Function"],
Cell[44192, 1583, 1187, 38, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[45404, 1625, 101, 2, 33, "Text"],
Cell[45508, 1629, 662, 12, 220, "Input"],
Cell[46173, 1643, 600, 12, 166, "Input"],
Cell[46776, 1657, 703, 14, 165, "Input"],
Cell[47482, 1673, 548, 12, 123, "Input"]
}, Closed]],
Cell[48045, 1688, 802, 25, 122, "Text",
  Evaluatable->False,
  CellTags->"Limit Definition of the Derivative"],
Cell[48850, 1715, 783, 24, 52, "Text"],
Cell[49636, 1741, 266, 9, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[49927, 1754, 101, 2, 33, "Text"],
Cell[50031, 1758, 55, 0, 33, "Text"],
Cell[50089, 1760, 794, 13, 274, "Input"],
Cell[50886, 1775, 56, 0, 33, "Text"],
Cell[50945, 1777, 854, 15, 266, "Input"],
Cell[51802, 1794, 1828, 36, 601, "Input"]
}, Closed]],
Cell[53645, 1833, 263, 9, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[53933, 1846, 102, 2, 33, "Text"],
Cell[54038, 1850, 53, 0, 33, "Text"],
Cell[54094, 1852, 610, 11, 235, "Input"],
Cell[54707, 1865, 44, 0, 33, "Text"],
Cell[54754, 1867, 277, 5, 116, "Input"],
Cell[55034, 1874, 43, 0, 33, "Text"],
Cell[55080, 1876, 253, 5, 116, "Input"],
Cell[55336, 1883, 56, 0, 33, "Text"],
Cell[55395, 1885, 516, 9, 171, "Input"],
Cell[55914, 1896, 55, 0, 33, "Text"],
Cell[55972, 1898, 502, 8, 171, "Input"],
Cell[56477, 1908, 467, 8, 112, "Input"]
}, Closed]],
Cell[56959, 1919, 549, 19, 68, "Text",
  Evaluatable->False,
  CellTags->"Differential Approximation"],
Cell[57511, 1940, 681, 24, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[58217, 1968, 102, 2, 33, "Text"],
Cell[58322, 1972, 2349, 47, 470, "Input"],
Cell[60674, 2021, 1534, 30, 290, "Input"],
Cell[62211, 2053, 1533, 30, 290, "Input"],
Cell[63747, 2085, 1536, 30, 290, "Input"]
}, Closed]],
Cell[65298, 2118, 189, 4, 30, "Text",
  Evaluatable->False,
  CellTags->"Rules for Differentiation"],
Cell[65490, 2124, 5723, 147, 420, "Print"],

Cell[CellGroupData[{
Cell[71238, 2275, 136, 2, 33, "Text"],
Cell[71377, 2279, 1441, 29, 406, "Input"]
}, Closed]],
Cell[72833, 2311, 198, 4, 30, "Text",
  Evaluatable->False,
  CellTags->"Formulas for Differentiation"],
Cell[73034, 2317, 651, 20, 33, "Text"],

Cell[CellGroupData[{
Cell[73710, 2341, 103, 2, 33, "Text"],
Cell[73816, 2345, 586, 16, 201, "Text"],
Cell[74405, 2363, 137, 5, 33, "Text"],
Cell[74545, 2370, 109, 2, 50, "Input"],
Cell[74657, 2374, 55, 1, 30, "Input"],
Cell[74715, 2377, 53, 1, 30, "Input"],
Cell[74771, 2380, 58, 1, 30, "Input"]
}, Closed]],
Cell[74844, 2384, 957, 29, 30, "Text"],

Cell[CellGroupData[{
Cell[75826, 2417, 104, 2, 33, "Text"],
Cell[75933, 2421, 966, 26, 324, "Text"],
Cell[76902, 2449, 137, 5, 33, "Text"],
Cell[77042, 2456, 55, 1, 30, "Input"],
Cell[77100, 2459, 55, 1, 30, "Input"],
Cell[77158, 2462, 55, 1, 30, "Input"],
Cell[77216, 2465, 55, 1, 30, "Input"],
Cell[77274, 2468, 55, 1, 30, "Input"],
Cell[77332, 2471, 55, 1, 30, "Input"],
Cell[77390, 2474, 58, 1, 30, "Input"],
Cell[77451, 2477, 58, 1, 30, "Input"]
}, Closed]],
Cell[77524, 2481, 536, 17, 30, "Text"],

Cell[CellGroupData[{
Cell[78085, 2502, 105, 2, 33, "Text"],
Cell[78193, 2506, 569, 15, 189, "Text"],
Cell[78765, 2523, 137, 5, 33, "Text"],
Cell[78905, 2530, 58, 1, 30, "Input"],
Cell[78966, 2533, 58, 1, 30, "Input"],
Cell[79027, 2536, 58, 1, 30, "Input"],
Cell[79088, 2539, 58, 1, 30, "Input"]
}, Closed]],
Cell[79161, 2543, 594, 18, 30, "Text"],

Cell[CellGroupData[{
Cell[79780, 2565, 104, 2, 33, "Text"],
Cell[79887, 2569, 749, 22, 221, "Text"],
Cell[80639, 2593, 137, 5, 33, "Text"],
Cell[80779, 2600, 56, 1, 30, "Input"],
Cell[80838, 2603, 56, 1, 30, "Input"],
Cell[80897, 2606, 56, 1, 30, "Input"],
Cell[80956, 2609, 56, 1, 30, "Input"],
Cell[81015, 2612, 56, 1, 30, "Input"],
Cell[81074, 2615, 56, 1, 30, "Input"]
}, Closed]],
Cell[81145, 2619, 701, 21, 30, "Text"],

Cell[CellGroupData[{
Cell[81871, 2644, 103, 2, 33, "Text"],
Cell[81977, 2648, 628, 15, 195, "Text"],
Cell[82608, 2665, 137, 5, 33, "Text"],
Cell[82748, 2672, 59, 1, 30, "Input"],
Cell[82810, 2675, 59, 1, 30, "Input"],
Cell[82872, 2678, 59, 1, 30, "Input"],
Cell[82934, 2681, 59, 1, 30, "Input"],
Cell[82996, 2684, 59, 1, 30, "Input"],
Cell[83058, 2687, 59, 1, 30, "Input"]
}, Closed]],
Cell[83132, 2691, 761, 23, 30, "Text"],

Cell[CellGroupData[{
Cell[83918, 2718, 104, 2, 33, "Text"],
Cell[84025, 2722, 685, 18, 201, "Text"],
Cell[84713, 2742, 137, 5, 33, "Text"],
Cell[84853, 2749, 56, 1, 30, "Input"],
Cell[84912, 2752, 70, 1, 30, "Input"],
Cell[84985, 2755, 58, 1, 30, "Input"],
Cell[85046, 2758, 56, 1, 30, "Input"],
Cell[85105, 2761, 61, 1, 30, "Input"]
}, Closed]],
Cell[85181, 2765, 696, 21, 30, "Text"],

Cell[CellGroupData[{
Cell[85902, 2790, 105, 2, 33, "Text"],
Cell[86010, 2794, 883, 25, 221, "Text"],
Cell[86896, 2821, 137, 5, 33, "Text"],
Cell[87036, 2828, 58, 1, 30, "Input"],
Cell[87097, 2831, 58, 1, 30, "Input"],
Cell[87158, 2834, 58, 1, 30, "Input"],
Cell[87219, 2837, 58, 1, 30, "Input"],
Cell[87280, 2840, 58, 1, 30, "Input"],
Cell[87341, 2843, 58, 1, 30, "Input"]
}, Closed]],
Cell[87414, 2847, 607, 20, 30, "Text"],

Cell[CellGroupData[{
Cell[88046, 2871, 106, 2, 33, "Text"],
Cell[88155, 2875, 1131, 34, 292, "Text"],
Cell[89289, 2911, 137, 5, 33, "Text"],
Cell[89429, 2918, 61, 1, 30, "Input"],
Cell[89493, 2921, 61, 1, 30, "Input"],
Cell[89557, 2924, 61, 1, 30, "Input"],
Cell[89621, 2927, 61, 1, 30, "Input"],
Cell[89685, 2930, 61, 1, 30, "Input"],
Cell[89749, 2933, 61, 1, 30, "Input"]
}, Closed]],
Cell[89825, 2937, 660, 24, 144, "Text",
  CellTags->"The Chain Rule"],
Cell[90488, 2963, 204, 3, 70, "Input"],
Cell[90695, 2968, 421, 17, 57, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[91141, 2989, 102, 2, 33, "Text"],
Cell[91246, 2993, 885, 16, 305, "Input"]
}, Closed]],
Cell[92146, 3012, 735, 31, 49, "Text",
  CellTags->"Intermediate Value Theorem for Continuous Functions"],
Cell[92884, 3045, 942, 39, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[93851, 3088, 102, 2, 33, "Text"],
Cell[93956, 3092, 906, 19, 290, "Input"],
Cell[94865, 3113, 1857, 32, 553, "Input"]
}, Closed]],
Cell[96737, 3148, 1639, 54, 49, "Text",
  CellTags->"Extreme Value Theorem for a Continuous Function"],
Cell[98379, 3204, 381, 15, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[98785, 3223, 102, 2, 33, "Text"],
Cell[98890, 3227, 341, 10, 52, "Text",
  Evaluatable->False],
Cell[99234, 3239, 1594, 29, 292, "Input"],
Cell[100831, 3270, 244, 7, 33, "Text",
  Evaluatable->False],
Cell[101078, 3279, 3085, 63, 526, "Input"]
}, Closed]],
Cell[104178, 3345, 481, 19, 68, "Text",
  CellTags->"Differentiable Function Implies Continuous Function"],
Cell[104662, 3366, 326, 12, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[105013, 3382, 102, 2, 33, "Text"],
Cell[105118, 3386, 1892, 37, 621, "Input"],
Cell[107013, 3425, 1684, 34, 486, "Input"]
}, Closed]],
Cell[108712, 3462, 749, 33, 49, "Text",
  CellTags->"Rolle's Theorem"],
Cell[109464, 3497, 543, 24, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[110032, 3525, 102, 2, 33, "Text"],
Cell[110137, 3529, 66, 1, 33, "Text",
  Evaluatable->False],
Cell[110206, 3532, 604, 12, 184, "Input"],
Cell[110813, 3546, 96, 1, 33, "Text",
  Evaluatable->False],
Cell[110912, 3549, 385, 6, 155, "Input"],
Cell[111300, 3557, 79, 1, 33, "Text",
  Evaluatable->False],
Cell[111382, 3560, 917, 20, 190, "Input"],
Cell[112302, 3582, 1161, 23, 277, "Input"]
}, Closed]],
Cell[113478, 3608, 893, 33, 92, "Text",
  CellTags->"Mean Value Theorem for Derivatives"],
Cell[114374, 3643, 785, 30, 76, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[115184, 3677, 102, 2, 33, "Text"],
Cell[115289, 3681, 59, 0, 33, "Text"],
Cell[115351, 3683, 785, 15, 252, "Input"],
Cell[116139, 3700, 93, 1, 33, "Text",
  Evaluatable->False],
Cell[116235, 3703, 2077, 43, 513, "Input"]
}, Closed]],
Cell[118327, 3749, 2234, 80, 68, "Text",
  CellTags->"Extreme Value Theorem for a Differentiable Function"],
Cell[120564, 3831, 383, 15, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[120972, 3850, 102, 2, 33, "Text"],
Cell[121077, 3854, 508, 9, 159, "Input"],
Cell[121588, 3865, 149, 4, 33, "Text",
  Evaluatable->False],
Cell[121740, 3871, 284, 8, 30, "Input"],
Cell[122027, 3881, 300, 10, 33, "Text",
  Evaluatable->False],
Cell[122330, 3893, 2042, 53, 308, "Input"],
Cell[124375, 3948, 204, 7, 52, "Text",
  Evaluatable->False],
Cell[124582, 3957, 2943, 70, 390, "Input"],
Cell[127528, 4029, 1958, 44, 330, "Input"],
Cell[129489, 4075, 1808, 36, 379, "Input"]
}, Closed]],
Cell[131312, 4114, 2260, 78, 87, "Text",
  CellTags->"Generalized Rolle's Theorem"],
Cell[133575, 4194, 567, 24, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[134167, 4222, 102, 2, 33, "Text"],
Cell[134272, 4226, 63, 0, 33, "Text"],
Cell[134338, 4228, 949, 20, 290, "Input"],
Cell[135290, 4250, 311, 12, 33, "Text",
  Evaluatable->False],
Cell[135604, 4264, 679, 14, 170, "Input"],
Cell[136286, 4280, 88, 1, 33, "Text",
  Evaluatable->False],
Cell[136377, 4283, 1240, 32, 130, "Input"],
Cell[137620, 4317, 1089, 21, 212, "Input"],
Cell[138712, 4340, 1993, 44, 192, "Input"],
Cell[140708, 4386, 1376, 28, 190, "Input"]
}, Closed]],
Cell[142099, 4417, 158, 3, 32, "Text"],
Cell[142260, 4422, 532, 16, 52, "Text"],
Cell[142795, 4440, 592, 18, 52, "Text"],
Cell[143390, 4460, 617, 18, 52, "Text"],
Cell[144010, 4480, 576, 16, 52, "Text"],
Cell[144589, 4498, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

