(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    138956,       4132]*)
(*NotebookOutlinePosition[    167702,       5098]*)
(*  CellTagsIndexPosition[    166340,       5070]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Calculus Review II",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 5.  (Definite Integral as a Limit of a Riemann Sum).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "   be continuous over the interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  and let  P  be a partition of  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  "  where  ",
  Cell[BoxData[
      \(a = \(\(x\_0 < x\_1 < x\_2 <  ... \) < x\_n = b\)\)]],
  " then  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            SubsuperscriptBox["\[Integral]", 
              StyleBox["a",
                FontSize->10], 
              StyleBox["b",
                FontSize->10]],
            FontSize->18], \(f \((x)\)\ \[DifferentialD]x\)}], " ", "=", 
        " ", \(\(\(\ \)\(lim\)\(\ \)\)\+\(\[LeftDoubleBracketingBar]P\
\[RightDoubleBracketingBar]\  \[Rule] \ 0\)\ \ \(\[Sum]\+\(k = 1\)\%n f[
                x\_k] \[CapitalDelta]x\_k\)\)}]]],
  ".  "
}], "Text",
  CellTags->"Definite Integral as a Limit of a Riemann Sum"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Animations for Calculus for Riemann Sums",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/AnimationsR.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Animations for Calculus for Riemann Sums",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/AnimationsR.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox["). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "\nInternet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 20.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f[x] = x\)]],
  "  over  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  Use the limit of the Riemann sum to find the value of the integral.  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, k, n, x];\)\ \ \), "\n", 
    \(\(a = 0;\)\ \ \), "\n", 
    \(\(b = 1;\)\ \ \), "\n", 
    \(\(n = 10;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 20;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 40;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 80;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Clear[a, b, k, n, x];\)\ \ \ \), "\n", 
    \(\(a = 0;\)\ \ \ \), "\n", 
    \(\(b = 1;\)\ \ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \ \), "\n", 
    \(\(X\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \ \), "\n", 
    \(\(f[x_] = x;\)\ \ \ \), "\n", 
    \(\(sum = \[Sum]\+\(k = 1\)\%n f[
              X\_k]\ \[CapitalDelta]x;\)\ \ \ \), "\n", 
    \(\(lim = 
        Limit[\[Sum]\+\(k = 1\)\%n f[X\_k]\ \[CapitalDelta]x, 
          n \[Rule] \[Infinity]];\)\ \ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\), "\n", 
    \(\(Print[\*"\"\<f[\!\(x\_k\)] = \>\"", f[X\_k]\ \ ];\)\), "\n", 
    \(\(Print["\<\[CapitalDelta]x = \>", \[CapitalDelta]x\ \ ];\)\), "\n", 
    \(\(Print[\*"\"\<f[\!\(x\_k\)]\[CapitalDelta]x = \>\"", 
        f[X\_k] \[CapitalDelta]x\ \ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", sum\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", "\<\[Sum]\>"\
\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\[CapitalDelta]x = \>\"", 
        lim\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f[x] = x\^2\)]],
  "  over  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  Use the limit of the Riemann sum to find the value of the integral."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, k, n, x];\)\ \ \), "\n", 
    \(\(a = 0;\)\ \ \), "\n", 
    \(\(b = 1;\)\ \ \), "\n", 
    \(\(n = 10;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x\^2;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 20;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x\^2;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 40;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x\^2;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 80;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x\^2;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Clear[a, b, k, n, x];\)\ \ \ \), "\n", 
    \(\(a = 0;\)\ \ \ \), "\n", 
    \(\(b = 1;\)\ \ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \ \), "\n", 
    \(\(X\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \ \), "\n", 
    \(\(f[x_] = x\^2;\)\ \ \ \), "\n", 
    \(\(sum = \[Sum]\+\(k = 1\)\%n f[
              X\_k]\ \[CapitalDelta]x;\)\ \ \ \), "\n", 
    \(\(lim = 
        Limit[\[Sum]\+\(k = 1\)\%n f[X\_k]\ \[CapitalDelta]x, 
          n \[Rule] \[Infinity]];\)\ \ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\), "\n", 
    \(\(Print[\*"\"\<f[\!\(x\_k\)] = \>\"", f[X\_k]\ \ ];\)\), "\n", 
    \(\(Print["\<\[CapitalDelta]x = \>", \[CapitalDelta]x\ \ ];\)\), "\n", 
    \(\(Print[\*"\"\<f[\!\(x\_k\)]\[CapitalDelta]x = \>\"", 
        f[X\_k] \[CapitalDelta]x\ \ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", sum\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", "\<\[Sum]\>"\
\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\[CapitalDelta]x = \>\"", 
        lim\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f[x] = x\^3\)]],
  "  over  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  Use the limit of the Riemann sum to find the value of the integral."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, k, n, x];\)\ \ \), "\n", 
    \(\(a = 0;\)\ \ \), "\n", 
    \(\(b = 1;\)\ \ \), "\n", 
    \(\(n = 10;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x\^3;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 20;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x\^3;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 40;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x\^3;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 80;\)\ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \), "\n", 
    \(\(x\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(f[x_] = x\^3;\)\ \ \), "\n", 
    \(\(val = \[Sum]\+\(k = 1\)\%n f[x\_k]\ \[CapitalDelta]x;\)\ \ \), "\n", 
    \(\(Plot[{f[x], f[Ceiling[n\ x]\/n]}, {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] {Magenta, Green}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", val\ , "\< = \>", N[val]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Clear[a, b, k, n, x];\)\ \ \ \), "\n", 
    \(\(a = 0;\)\ \ \ \), "\n", 
    \(\(b = 1;\)\ \ \ \), "\n", 
    \(\(\[CapitalDelta]x = \(b - a\)\/n;\)\ \ \ \), "\n", 
    \(\(X\_k_ = a + k\ \[CapitalDelta]x;\)\ \ \ \), "\n", 
    \(\(f[x_] = x\^3;\)\ \ \ \), "\n", 
    \(\(sum = \[Sum]\+\(k = 1\)\%n f[
              X\_k]\ \[CapitalDelta]x;\)\ \ \ \), "\n", 
    \(\(lim = 
        Limit[\[Sum]\+\(k = 1\)\%n f[X\_k]\ \[CapitalDelta]x, 
          n \[Rule] \[Infinity]];\)\ \ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 1}, PlotPoints \[Rule] 101, 
        PlotStyle \[Rule] Red];\)\), "\n", 
    \(\(Print["\<f[x] = \>", f[x], "\<  over [\>", a, "\<,\>", 
        b, "\<].\>"\ ];\)\), "\n", 
    \(\(Print[\*"\"\<f[\!\(x\_k\)] = \>\"", f[X\_k]\ \ ];\)\), "\n", 
    \(\(Print["\<\[CapitalDelta]x = \>", \[CapitalDelta]x\ \ ];\)\), "\n", 
    \(\(Print[\*"\"\<f[\!\(x\_k\)]\[CapitalDelta]x = \>\"", 
        f[X\_k] \[CapitalDelta]x\ \ ];\)\ \ \), "\n", 
    \(\(Print["\<\[Sum]\>"\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\
\[CapitalDelta]x = \>\"", sum\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(n \[Rule] \[Infinity]\)\) \>\"", "\<\[Sum]\>"\
\+\("\<k=1\>"\)\%n, \*"\"\<f[\!\(x\_k\)]\[CapitalDelta]x = \>\"", 
        lim\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.  (First Fundamental Theorem of Calculus).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous over the interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  then there exists a function  ",
  Cell[BoxData[
      \(F \((x)\)\)]],
  ",  called the antiderivative of  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  ",  such that  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            SubsuperscriptBox["\[Integral]", 
              StyleBox["a",
                FontSize->10], 
              StyleBox["b",
                FontSize->10]],
            FontSize->18], \(f \((x)\)\ \[DifferentialD]x\)}], " ", "=", 
        " ", \(F \((b)\) - F \((a)\)\)}]]],
  "  where  ",
  Cell[BoxData[
      \(F' \((x)\) = f \((x)\)\)]],
  ".  "
}], "Text",
  CellTags->"First Fundamental Theorem of Calculus"],

Cell[TextData[{
  StyleBox["Example 23.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\) = tan \((x)\)\)]],
  ".  Show that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            SubsuperscriptBox["\[Integral]", 
              StyleBox[\(\(-\[Pi]\)/3\),
                FontSize->10], 
              StyleBox[\(\[Pi]/4\),
                FontSize->10]],
            FontSize->18], \(f \((x)\)\ \[DifferentialD]x\)}], "=", 
        RowBox[{
          RowBox[{"F", 
            RowBox[{"(", 
              FractionBox[
                StyleBox["\[Pi]",
                  FontSize->10], 
                StyleBox["4",
                  FontSize->10]], ")"}]}], "-", 
          RowBox[{"F", 
            RowBox[{"(", 
              FractionBox[
                StyleBox[\(-\[Pi]\),
                  FontSize->10], 
                StyleBox["3",
                  FontSize->10]], ")"}]}]}]}]]],
  ",   where  ",
  Cell[BoxData[
      \(F' \((x)\) = f \((x)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, f, F, v, x];\)\ \ \), "\n", 
    \(\(f[x_] = Tan[x];\)\ \ \), "\n", 
    \(\(F[x_] = \[Integral]f[x] \[DifferentialD]x;\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<The indefinite integral is:\>"];\)\ \ \), "\n", 
    \(\(Print["\<F[x] = \[Integral] f[x] \[DifferentialD]x\>"];\)\ \ \), "\n\
", 
    \(\(Print["\<F[x] = \[Integral] Tan[x] \[DifferentialD]x = \>", 
        F[x]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(a = \(-\(\[Pi]\/3\)\);\)\ \ \), "\n", 
    \(\(b = \[Pi]\/4;\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<F[x] = \>", F[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<The interval is  [\>", a, "\<,\>", 
        b, "\<]\>"];\)\ \ \), "\n", 
    \(\(Print["\<The value of the definite integral is:\>"];\)\ \ \), "\n", 
    \(\(Print["\<F[b] - F[a] = \>", F[b], "\< - \>", F[a], "\<  =  \>", 
        N[F[b] - F[a]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[b] - F[a] = \>", F[b] - \ F[a], "\<  =  \>", 
        N[F[b] - F[a]]\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(\(-\[Pi]\)/3\)\%\(\[Pi]/4\)\)f[x]\
\[DifferentialD]x = \>\"", "\<F[\>", b, "\<] - F[\>", 
        a, "\<]\>"\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(\(-\[Pi]\)/3\)\%\(\[Pi]/4\)\)f[x]\
\[DifferentialD]x = \>\"", "\< - Log[Cos[[\>", b, "\<] + Log[Cos[[\>", 
        a, "\<]\>"\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(\(-\[Pi]\)/3\)\%\(\[Pi]/4\)\)f[x]\
\[DifferentialD]x = \>\"", "\< (\>", \(-\ Log[Cos[b]]\), "\<) + (\>", 
        Log[Cos[a]], "\<)\>"\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(\(-\[Pi]\)/3\)\%\(\[Pi]/4\)\)f[x]\
\[DifferentialD]x = \>\"", F[b]\  - \ F[a]\ , "\< = \>", 
        N[F[b]\  - \ F[a]]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Or use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s integrate command with limits of integration:"
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(a = \(-\(\[Pi]\/3\)\);\)\), "\n", 
    \(\(b = \[Pi]\/4;\)\), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\), "\n", 
    \(\(v = \[Integral]\_a\%b f[x] \[DifferentialD]x;\)\), "\n", 
    \(\(Print["\<The interval is  [\>", a, "\<,\>", b, "\<]\>"];\)\), "\n", 
    \(\(Print["\<The value of the integral is:\>"];\)\), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(\(-\[Pi]\)/3\)\%\(\[Pi]/4\)\)f[x]\
\[DifferentialD]x = \>\"", v, "\< = \>", N[v]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr1\  = \ 
        FilledPlot[{f[x]}, \ {x, a, 0}, Fills \[Rule] {{{1, Axis}, Red}}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr2\  = \ 
        FilledPlot[{f[x]}, \ {x, \ 0, b}, Fills \[Rule] {{{1, Axis}, Green}}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(grf = 
        Plot[f[x], {x, a, b}, 
          Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[\(-2\), 1, 0.5]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(lines = 
        Graphics[{Line[{{a, 0}, {a, f[a]}}], 
            Line[{{b, 0}, {b, f[b]}}]}];\)\ \ \), "\n", 
    \(\(Show[gr1, gr2, grf, lines, AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] "\<y = Tan[x]              \>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<The function is f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<The value of the integral is over [\>", a, "\<,\>", 
        b, "\<] is:  \>", N[v]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_\(\(-\[Pi]\)/3\)\%\(\[Pi]/4\)\)Tan[x]\
\[DifferentialD]x = \>\"", v, "\< = \>", N[v]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 13.  (Second Fundamental Theorem of Calculus).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous over the interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  then  ",
  Cell[BoxData[
      \(\[PartialD]\_x\ \((\[Integral]\_a\%x\ 
              f \((t)\) \[DifferentialD]t)\)\  = \ f \((x)\)\)]],
  ",  where  ",
  Cell[BoxData[
      RowBox[{"a", 
        StyleBox["<",
          FontFamily->"Times New Roman"], 
        StyleBox["x",
          FontFamily->"Times New Roman"], 
        StyleBox["<",
          FontFamily->"Times New Roman"], "b"}]]],
  ".  "
}], "Text",
  CellTags->"Second Fundamental Theorem of Calculus"],

Cell[BoxData[{
    \(\(Clear[f, F, t, x];\)\ \ \), "\n", 
    \(\(F[x_]\  = \ \[Integral]\_a\%x f[t] \[DifferentialD]t;\)\ \ \), "\n", 
    \(\(Print["\< F[x] = \>", F[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<F'[x] = \>", \(F'\)[x]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Example 24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\)\  = \ \(x\^2\) \(\[ExponentialE]\^x\) sin \((x)\)\)]],
  ".  Show that  ",
  Cell[BoxData[
      \(\[PartialD]\_x\ \((\[Integral]\_a\%x\ 
              f \((t)\) \[DifferentialD]t)\)\  = \ f \((x)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, F, t, x];\)\ \ \), "\n", 
    \(\(f[t_] = 2\ t\^2\ Exp[t]\ Sin[t];\)\ \ \), "\n", 
    \(\(F[x_] = \[Integral]\_0\%x f[t] \[DifferentialD]t;\)\ \ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]\ ];\)\ \ \), "\n", 
    \(\(F[x_] = \[Integral]\_0\%x f[t] \[DifferentialD]t;\)\ \ \), "\n", 
    \(\(Print[\*"\"\<F[x] = \
\!\(\[Integral]\_0\%x\)f[t]\[DifferentialD]t\>\""];\)\ \ \), "\n", 
    \(\(Print["\<F[x] = \>", F[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<F'[x] = \>", \(F'\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<F'[x] = \>", Expand[\(F'\)[x]]\ ];\)\ \ \), "\n", 
    \(\(Print["\< f[x] = \>", f[x]\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 4}, PlotStyle \[Rule] Magenta, 
        AxesLabel \[Rule] {x, y}];\)\ \ \), "\n", 
    \(\(Print["\<y = \>", f[x]\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[\(F'\)[x], {x, 0, 4}, PlotStyle \[Rule] Blue, 
        AxesLabel \[Rule] {x, y}];\)\ \ \), "\n", 
    \(\(Print["\<y = \>", \(F'\)[x]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 25.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f \((x)\)\  = \ \(1\/\@\(2\ \[Pi]\)\) \[ExponentialE]\^\(\(-\ \
x\^2\)/2\)\)]],
  ".  Show that  ",
  Cell[BoxData[
      \(\[PartialD]\_x\ \((\[Integral]\_a\%x\ 
              f \((t)\) \[DifferentialD]t)\)\  = \ f \((x)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear[f, F, t, x];\), "  "}], "\n", 
    RowBox[{\(f[
            t_] = \(1\/\@\(2\ \[Pi]\)\) \[ExponentialE]\^\(\(-\ t\^2\)/2\);\),
       "  "}], "\n", 
    RowBox[{\(F[x_] = \[Integral]\_0\%x f[t] \[DifferentialD]t;\), 
      "  "}], "\n", 
    RowBox[{\(Print["\< f[t] = \>", f[t]\ ];\), "  "}], "\n", 
    RowBox[{\(Print[\*"\"\< F[x] = \
\!\(\[Integral]\_0\%x\)f[t]\[DifferentialD]t\>\""];\), "  "}], "\n", 
    RowBox[{\(Print["\< F[x] = \>", F[x]\ ];\), "  "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\\n\>\"", ",", "\"\<F'[x] = \>\"", ",", 
            RowBox[{
              SuperscriptBox["F", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], " ", "]"}], 
        ";"}], "  "}], "\n", 
    RowBox[{\(Print["\< f[x] = \>", f[x]\ ];\), "  "}]}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-4\), 4}, PlotStyle \[Rule] Magenta, 
        AxesLabel \[Rule] {x, y}];\)\ \ \), "\n", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[\(F'\)[x], {x, \(-4\), 4}, PlotStyle \[Rule] Blue, 
        AxesLabel \[Rule] {x, y}];\)\ \ \), "\n", 
    \(\(Print["\<y = F'[x] = \>", \(F'\)[x]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Rules 2.  Rules for Integration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  CellTags->"Rules for Integration"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        InterpretationBox[\("\n"\[InvisibleSpace]"Integral of a scalar \
multiple."\),
          SequenceForm[ "\n", "Integral of a scalar multiple."],
          Editable->False], "\n", 
        InterpretationBox[\("\[Integral]c f[x]\[DifferentialD]x = "\
\[InvisibleSpace]\(c\ \(\[Integral]f[x] \[DifferentialD]x\)\)\),
          SequenceForm[ "\[Integral]c f[x]\[DifferentialD]x = ", 
            Times[ c, 
              Integrate[ 
                f[ x], x]]],
          Editable->False], "\n", 
        InterpretationBox[\("\n"\[InvisibleSpace]"Integral of a linear \
combination."\),
          SequenceForm[ "\n", "Integral of a linear combination."],
          Editable->False], "\n", 
        InterpretationBox[\("\[Integral](a f[x]+b g[x])\[DifferentialD]x = "\
\[InvisibleSpace]\(a\ \(\[Integral]f[x] \[DifferentialD]x\) + 
              b\ \(\[Integral]g[x] \[DifferentialD]x\)\)\),
          SequenceForm[ "\[Integral](a f[x]+b g[x])\[DifferentialD]x = ", 
            Plus[ 
              Times[ a, 
                Integrate[ 
                  f[ x], x]], 
              Times[ b, 
                Integrate[ 
                  g[ x], x]]]],
          Editable->False], "\n", 
        InterpretationBox[\("\n"\[InvisibleSpace]"Integral of a composition \
of functions."\),
          SequenceForm[ "\n", "Integral of a composition of functions."],
          Editable->False], "\n", 
        InterpretationBox[\("\[Integral] f'[g[x]]g'[x]\[DifferentialD]x = "\
\[InvisibleSpace]f[g[x]]\),
          SequenceForm[ "\[Integral] f'[g[x]]g'[x]\[DifferentialD]x = ", 
            f[ 
              g[ x]]],
          Editable->False], "\n", 
        InterpretationBox[\("\n"\[InvisibleSpace]"Integral involving products \
of functions."\),
          SequenceForm[ "\n", "Integral involving products of functions."],
          Editable->False], "\n", 
        InterpretationBox[\("\[Integral](f'[x]g[x] + f[x]g'[x])\
\[DifferentialD]x = "\[InvisibleSpace]\(f[x]\ g[x]\)\),
          SequenceForm[ 
          "\[Integral](f'[x]g[x] + f[x]g'[x])\[DifferentialD]x = ", 
            Times[ 
              f[ x], 
              g[ x]]],
          Editable->False], "\n", 
        InterpretationBox[\("\n"\[InvisibleSpace]"Integral involving \
quotients of functions."\),
          SequenceForm[ "\n", "Integral involving quotients of functions."],
          Editable->False], "\n", 
        InterpretationBox[\("\[Integral]\!\(\(g[x]\\ \(f'\)[x] - f[x]\\ \
\(g'\)[x]\)\/g[x]\^2\)\[DifferentialD]x = "\[InvisibleSpace]f[x]\/g[x]\),
          SequenceForm[ 
          "\[Integral]\!\(\(g[x]\\ \(f'\)[x] - f[x]\\ \(g'\)[x]\)\/g[x]\^2\)\
\[DifferentialD]x = ", 
            Times[ 
              f[ x], 
              Power[ 
                g[ x], -1]]],
          Editable->False]}],
      FontColor->GrayLevel[0]]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivations for the Rules for Integration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, c, F, f, g, g1, g2, g3, g4, g5, x];\)\ \ \), "\n", 
    \(\(F1[x_]\  = \ \[Integral]c\ f[x] \[DifferentialD]x;\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Integral of a scalar multiple.\>"];\)\ \ \), "\n", \

    \(\(Print["\<\[Integral]c f[x]\[DifferentialD]x = \>", 
        F1[x]];\)\ \ \), "\n", 
    \(\(F2[x_]\  = \ 
        Thread[\[Integral]\((a\ f[x] + \ b\ g[x])\) \[DifferentialD]x, 
          Plus];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Integral of a linear combination.\>"];\)\ \ \), "\n\
", 
    \(\(Print["\<\[Integral](a f[x]+b g[x])\[DifferentialD]x = \>", 
        F2[x]];\)\ \ \), "\n", 
    \(\(F3[
          x_]\  = \[Integral]\ \(f'\)[g[x]] \(g'\)[
              x] \[DifferentialD]x\ ;\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Integral of a composition of functions.\>"];\)\ \ \
\), "\n", 
    \(\(Print["\<\[Integral] f'[g[x]]g'[x]\[DifferentialD]x = \>", 
        F3[x]];\)\ \ \), "\n", 
    \(\(F4[
          x_]\  = \[Integral]\((\(f'\)[x] g[x] + 
                f[x] \(g'\)[x])\) \[DifferentialD]x\ ;\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Integral involving products of functions.\>"];\)\ \
\ \), "\n", 
    \(\(Print["\<\[Integral](f'[x]g[x] + f[x]g'[x])\[DifferentialD]x = \>", 
        F4[x]];\)\ \ \), "\n", 
    \(\(F5[
          x_]\  = \[Integral]\(\(g[x]\ \(f'\)[x] - 
                  f[x]\ \(g'\)[
                      x]\)\/g[x]\^2\) \[DifferentialD]x\ ;\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<Integral involving quotients of functions.\>"];\)\ \
\ \), "\n", 
    \(\(Print[\*"\"\<\[Integral]\!\(\(g[x] \(f'\)[x] - f[x] \(g'\)[x]\)\/g[x]\
\^2\)\[DifferentialD]x = \>\"", F5[x]];\)\ \)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Formulas 2.  Formulas for Integration.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  CellTags->"Formulas for Integration"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]\ u \[DifferentialD]v\  = \ 
        u\ v\  - \ \[Integral]\ v \[DifferentialD]u\)]],
  "   "
}], "Text"],

Cell[BoxData[
    \(\(\(\[Integral]\(u\^n\) \[DifferentialD]u\)\(\ \)\(\[Equal]\)\(\ \
\)\(u\^\(n + 1\)\/\(n + 1\)\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "provided that  ",
  Cell[BoxData[
      \(n \[NotEqual] \(-1\)\)]],
  "\n\nThe next case is   ",
  Cell[BoxData[
      \(n = \(-1\)\)]]
}], "Text"],

Cell[BoxData[
    \(\(\(\[Integral]\(1\/u\) \[DifferentialD]u\)\(\ \)\(\[Equal]\)\(\ \
\)\(Log[u]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Integral]\(\[ExponentialE]\^u\) \[DifferentialD]u\)\(\ \)\(\
\[Equal]\)\(\ \)\(\[ExponentialE]\^u\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Integral]\(b\^u\) \[DifferentialD]u\)\(\ \)\(\[Equal]\)\(\ \
\)\(b\^u\/Log[b]\)\(\ \ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Integral]Cos[u] \[DifferentialD]u\)\(\ \)\(\[Equal]\)\(\ \)\(Sin[
        u]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Integral]Sin[u] \[DifferentialD]u\  \[Equal] \ \(\(-Cos[
          u]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Integral]Tan[u] \[DifferentialD]u\  \[Equal] \ \(\(-Log[
          Cos[u]]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Integral]Sec[u] \[DifferentialD]u\  \[Equal] \ \(\(-Log[
            Cos[u\/2] - Sin[u\/2]]\)\(+\)\(Log[
          Cos[u\/2] + Sin[u\/2]]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\(\(\[Integral]Sec[u] \[DifferentialD]u\)\(\ \)\(=\)\(\ \)\(Log[
          Sec[u] + Tan[u]]\)\(\ \)\)\)]],
  "  "
}], "Text"],

Cell[BoxData[
    \(\[Integral]Csc[u] \[DifferentialD]u\  \[Equal] \ \(\(-Log[
            Cos[u\/2]]\)\(+\)\(Log[Sin[u\/2]]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]Csc[u] \[DifferentialD]u\  = \ Log[Csc[u] - Cot[u]]\)]],
  "  "
}], "Text"],

Cell[BoxData[
    \(\(\(\[Integral]Cot[u] \[DifferentialD]u\)\(\ \)\(\[Equal]\)\(\ \)\(Log[
        Sin[u]]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Integral]\(Sec[
                u]\^2\) \[DifferentialD]u\)\(\ \)\(\[Equal]\)\(\ \)\(Tan[
        u]\)\(\ \ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Integral]Sec[u]\ Tan[
            u] \[DifferentialD]u\)\(\ \)\(\[Equal]\)\(\ \)\(Sec[
        u]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Integral]\(Csc[u]\^2\) \[DifferentialD]u\  \[Equal] \ \(\(-Cot[
          u]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Integral]Cot[u]\ Csc[u] \[DifferentialD]u\  \[Equal] \ \(\(-Csc[
          u]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Integral]\(1\/\@\(a\^2 + u\^2\)\) \[DifferentialD]u\)\(\ \)\(\
\[Equal]\)\(\ \)\(Log[u + \@\(a\^2 + u\^2\)]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]\(1\/\@\(a\^2 + u\^2\)\) \[DifferentialD]u\  = \ 
        ArcSinh[u\/a]\)]],
  "    "
}], "Text"],

Cell[BoxData[
    \(\[Integral]\(1\/\(a\^2 - 
                u\^2\)\) \[DifferentialD]u\  \[Equal] \ \(\(1\/a\) \(ArcTanh[
          u\/a]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]\(1\/\(a\^2 - 
                  u\^2\)\) \[DifferentialD]u\  = \ \(-\(1\/\(2  a\)\)\)\ Log[
              u - a] + 1\/\(2  a\)\ Log[u + a]\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]\(1\/\@\(a\^2 - u\^2\)\) \[DifferentialD]u\  = \ 
        ArcSin[u\/a]\)]],
  "  "
}], "Text"],

Cell[BoxData[
    \(\[Integral]\(1\/\(a\^2 + 
                u\^2\)\) \[DifferentialD]u\  \[Equal] \ \(\(1\/a\) \(ArcTan[
          u\/a]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]\(1\/\(u \@\(\(\(\ \)\(u\^2 - a\^2\)\)\(\ \)\)\)\) \
\[DifferentialD]u\ \  = \ \(1\/a\) ArcSec[u\/a]\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]\(1\/\(u \@\(\(\(\ \)\(u\^2 - 1\)\)\(\ \)\)\)\) \
\[DifferentialD]u\  = \ \[Pi]\/2 - ArcTan[1\/\@\(\(-1\) + u\^2\)]\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]\(1\/\(u \@\(\(\(\ \)\(u\^2 - 1\)\)\(\ \)\)\)\) \
\[DifferentialD]u\ \  = \ \[Pi]\/2 - ArcCot[\@\(\(-1\) + u\^2\)]\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(\[Integral]\(1\/\(u \@\(\(\(\ \)\(u\^2 - 1\)\)\(\ \)\)\)\) \
\[DifferentialD]u\  = \ ArcSec[u]\)]],
  "  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 14.  (Mean Value Theorem for Integrals).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is continuous over  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  then there exists a number  ",
  Cell[BoxData[
      \(c\)]],
  ",  with  ",
  Cell[BoxData[
      \(a < c < b\)]],
  ",  such that  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox["1",
              FontSize->12], 
            StyleBox[\(b\  - \ a\),
              FontSize->12]], 
          RowBox[{
            StyleBox[
              SubsuperscriptBox["\[Integral]", 
                StyleBox["a",
                  FontSize->10], 
                StyleBox["b",
                  FontSize->10]],
              FontSize->18], 
            StyleBox[" ",
              FontSize->18], \(f \((x)\) \[DifferentialD]x\)}]}], " ", "=", 
        " ", \(f \((c)\)\)}]]],
  "."
}], "Text",
  CellTags->"Mean Value Theorem for Integrals"],

Cell[TextData[{
  StyleBox["Example 26.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      RowBox[{\(f \((x)\)\), "=", 
        RowBox[{\(sin \((x)\)\), "+", 
          RowBox[{
            FractionBox[
              StyleBox["1",
                FontSize->12], 
              StyleBox["3",
                FontSize->12]], " ", "sin", \((3\ x)\)}]}]}]]],
  ",  find  ",
  Cell[BoxData[
      \(c\)]],
  "  so that  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox["1",
              FontSize->12], 
            StyleBox["2.5",
              FontSize->12]], 
          RowBox[{
            StyleBox[
              SubsuperscriptBox["\[Integral]", 
                StyleBox["0",
                  FontSize->10], 
                StyleBox["2.5",
                  FontSize->10]],
              
              FontSize->
                18], \(\((sin \((x)\) + 
                  1\/3\ sin \((3\ x)\))\) \[DifferentialD]x\)}]}], " ", "=", 
        " ", \(f \((c)\)\)}]]],
  "."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, c, f, g, h, L, solset, v, val, x];\)\ \ \), "\n", 
    \(\(f[x_] = Sin[x] + 1\/3\ Sin[3\ x];\)\ \ \), "\n", 
    \(\(g[x_] = \[Integral]f[x] \[DifferentialD]x;\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<g[x] = \[Integral]f[x]\[DifferentialD]x = \>", 
        g[x]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(a = 0;\)\ \ \), "\n", 
    \(\(b = 2.5;\)\ \ \), "\n", 
    \(\(v = \[Integral]\_a\%b f[x] \[DifferentialD]x;\)\ \ \), "\n", 
    \(\(val = \(\[Integral]\_a\%b f[x] \[DifferentialD]x\)\/\(2.5 - 0\);\)\ \ \
\), "\n", 
    \(\(solset = FindRoot[f[x] \[Equal] val, {x, 1}];\)\ \ \), "\n", 
    \(\(c = 
        solset\[LeftDoubleBracket]1, 2\[RightDoubleBracket];\)\ \ \), "\n", 
    \(\(h\  = \ f[c];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<    \!\(\[Integral]\_0.0\%2.5\)f[x]\[DifferentialD]x = \
\>\"", v];\)\), "\n", 
    \(\(Print[\*"\"\<\!\(1\/2.5\)\!\(\[Integral]\_0.0\%2.5\)f[x]\
\[DifferentialD]x = \>\"", val];\)\), "\n", 
    \(\(Print["\<          f[c] = \>", h];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<             c = \>", c];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr1\  = \ 
        FilledPlot[{f[x]}, {x, a, b}, Fills \[Rule] {{{1, Axis}, Green}}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(grf = 
        Plot[f[x], {x, a, b}, 
          Ticks \[Rule] {Range[0, 2.5, 0.5], Range[0, 1, 0.2]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(lines = 
        Graphics[{Line[{{a, 0}, {a, f[a]}}], 
            Line[{{b, 0}, {b, f[b]}}]}];\)\ \ \), "\n", 
    \(\(line2 = 
        Graphics[{Line[{{a, 0}, {a, h}}], Line[{{a, h}, {b, h}}], 
            Line[{{b, h}, {b, 0}}]}];\)\ \ \), "\n", 
    \(\(Show[gr1, grf, lines, line2, AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] \*"\"\<y = f[x] = Sin[x]+\!\(1\/3\) Sin[3x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<The function is f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<The value of the integral is over [\>", a, "\<,\>", 
        b, "\<] is  \>", N[v]\ ];\)\ \ \), "\n", 
    \(\(Print["\<The area under the curve is the same as\>"];\)\ \ \), "\n", 
    \(\(Print["\<the area of a rectangle of height  h = \>", 
        h];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 15.  (Weighted Mean Value Theorem for Integrals).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that both  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(g \((x)\)\)]],
  "  are continuous over  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  and that  ",
  Cell[BoxData[
      \(0 \[LessEqual] g \((x)\)\)]],
  "  for  ",
  Cell[BoxData[
      \(a \[LessEqual] x \[LessEqual] b\)]],
  ".  Then there exists a number  ",
  Cell[BoxData[
      \(c\)]],
  ",  with  ",
  Cell[BoxData[
      \(a < c < b\)]],
  ",  such that  \n\n\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ f \((x)\) g \((x)\) \[DifferentialD]x\  = \ 
        f \((c)\)\ \(\[Integral]\_a\%b\ g \((x)\) \[DifferentialD]x\)\)]],
  ".   "
}], "Text",
  CellTags->"Weighted Mean Value Theorem for Integrals"],

Cell[TextData[{
  StyleBox["Example 27.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let   ",
  Cell[BoxData[
      \(f \((x)\) = x\^2\)]],
  "  and  ",
  Cell[BoxData[
      \(g \((x)\) = 1 + sin \((x)\)\)]],
  "  and let  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman"], "b"}], "]"}], " ", "=", 
        RowBox[{"[", 
          RowBox[{"0", 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(\(3\ \[Pi]\)\/2\)}], 
          "]"}]}]]],
  ".   Find the value  ",
  Cell[BoxData[
      \(c\)]],
  ",  so that  \n\n\t",
  Cell[BoxData[
      \(\[Integral]\_0\%\(3  \[Pi]/2\)\ 
          f \((x)\) g \((x)\) \[DifferentialD]x\  = \ 
        f \((c)\)\ \(\[Integral]\_0\%\(3  \[Pi]/2\)\ 
            g \((x)\) \[DifferentialD]x\)\)]],
  ".   "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[c, f, fc, g, h\ , L, R, x];\)\ \ \), "\n", 
    \(\(f[x_] = x\^2;\)\ \ \), "\n", 
    \(\(g[x_] = 1 + Sin[x];\)\ \ \), "\n", 
    \(\(Print["\<     f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<     g[x] = \>", g[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<f[x] g[x] = \>", f[x]\ g[x]\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(L = 
        Expand[\[Integral]\_0\%\(3  \[Pi]/2\)f[x]\ g[
                x] \[DifferentialD]x];\)\ \ \), "\n", 
    \(\(R = \[Integral]\_0\%\(3\ \[Pi]/2\)g[
              x] \[DifferentialD]x;\)\ \ \), "\n", 
    \(\(c = \@\(L\/R\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(3  \[Pi]/2\)\)f[x]g[x]\
\[DifferentialD]x = f[c] \!\(\[Integral]\_0\%\(3  \[Pi]/2\)\)g[x]\
\[DifferentialD]x\>\""];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(3  \[Pi]/2\)\)f[x]g[x]\
\[DifferentialD]x = \>\"", L];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%\(3  \
\[Pi]/2\)\)g[x]\[DifferentialD]x = \>\"", R];\)\ \ \), "\n", 
    \(\(Print["\<f[c] = \>", L\/R];\)\ \ \), "\n", 
    \(\(Print["\<f[c] = \>", Simplify[L\/R]];\)\ \ \), "\n", 
    \(\(Print["\<f[c] = \>", N[L\/R]];\)\ \ \), "\n", 
    \(\(Print["\<  c  = \>", \@Simplify[L\/R], "\< = \>", 
        N[\@\(L\/R\)]\ ];\)\ \ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<   c = \>", c];\)\ \ \), "\n", 
    \(\(Print["\<f[c] =  \>", f[c]];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", \*"\"\<\!\(\[Integral]\_0\%\(3  \[Pi]/2\)\)f[x]g[x]\
\[DifferentialD]x = f[c] \!\(\[Integral]\_0\%\(3  \[Pi]/2\)\)g[x]\
\[DifferentialD]x\>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", L, "\< = (\>", f[c], "\<)(\>", 
        R, "\<)\>"];\)\ \ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<        \>", N[L], "\< = (\>", N[f[c]], "\<)(\>", 
        N[R], "\<)\>"];\)\ \ \ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 16.  (Taylor's Theorem and Lagrange's Remainder).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  and its derivatives  ",
  Cell[BoxData[
      RowBox[{\(f' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(f'' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", " ", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((n + 1)\),
              Derivative],
            MultilineFunction->None], \((x)\)}]}]]],
  "  are all continuous on  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  and  ",
  Cell[BoxData[
      \(x\_0\)]],
  "  is a fixed value.  Then  \n\n\t\t",
  Cell[BoxData[
      \(f \((x)\)\  = \ \(P\_n\) \((x)\)\  + \ \(R\_n\) \((x)\)\)]],
  "   \nwhere\t\n\t\t",
  Cell[BoxData[
      RowBox[{\(\(P\_n\) \((x)\)\), " ", "=", " ", 
        RowBox[{
          StyleBox[
            UnderoverscriptBox["\[Sum]", 
              StyleBox[\(k = 0\),
                FontSize->10], 
              StyleBox["n",
                FontSize->10]],
            FontSize->18], " ", 
          RowBox[{
            FractionBox[
              StyleBox[
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((k)\),
                      Derivative],
                    MultilineFunction->None], \((x\_0)\)}],
                FontSize->12], 
              StyleBox[\(k!\),
                FontSize->12]], \(\((x - x\_0)\)\^k\)}]}]}]]],
  "  \n\t\nis the n-th degree Taylor polynomial expanded about  ",
  Cell[BoxData[
      \(x\_0\)]],
  ".  There exists a value  ",
  Cell[BoxData[
      \(c\)]],
  "  that lies somewhere between  and  ",
  Cell[BoxData[
      \(x\)]],
  "  and  ",
  Cell[BoxData[
      \(x\_0\)]],
  "  and\n\n\t\t",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{\(\(R\_n\) \((x)\)\), " ", "=", " ", 
          RowBox[{
            FractionBox[
              StyleBox[
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((n + 1)\),
                      Derivative],
                    MultilineFunction->None], \((c)\)}],
                FontSize->12], 
              StyleBox[\(\((n + 1)\)!\),
                FontSize->12]], \(\((x - x\_0)\)\^\(n + 1\)\)}]}]}]]],
  "  \n\t\nwhich is the ",
  StyleBox["Lagrange form of the remainder",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text",
  CellTags->"Taylor's Theorem and Lagrange's Remainder"],

Cell[TextData[{
  StyleBox["Example 28.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let   ",
  Cell[BoxData[
      \(f \((x)\) = sin \((x)\)\)]],
  ".  Find the Taylor polynomial of degree   ",
  Cell[BoxData[
      \(n = 9\)]],
  "  for  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  expanded about the point  ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  "."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 28.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, n, P9, x0];\)\ \ \), "\n", 
    \(\(n = 9;\)\ \ \), "\n", 
    \(\(x0 = 0;\)\ \ \), "\n", 
    \(\(f[x_] = Sin[x];\)\ \ \), "\n", 
    \(\(P9[x_] = Normal[Series[f[x], {x, x0, n}]];\)\ \ \), "\n", 
    \(\(Print["\< f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(P\_9\)[x] = \>\"", P9[x]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], P9[x]}, {x, 0, 2\ \[Pi]}, 
        PlotRange \[Rule] {{0, 2  \[Pi]}, {\(-1\), 2}}, 
        PlotStyle \[Rule] {Magenta, Blue}, AxesLabel \[Rule] {x, y}, \n\t
        PlotLabel \[Rule] \*"\"\<y = Sin[x]  and  y = \!\(P\_9\)[x]\>\""];\)\ \
\ \), "\n", 
    \(\(Print["\<y =  f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<y = \!\(P\_9\)[x] = \>\"", P9[x]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 17.  (Horner's Method for Polynomial Evaluation).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(P \((x)\) = \ \(a\_\(n + 1\)\) x\^n\  + \ \(a\_n\) 
            x\^\(n - 1\)\  + \[CenterEllipsis] + \ \(a\_3\) x\^2\  + \ 
          a\_2\ x\  + \ a\_1\)]],
  ".  \nThen\t",
  Cell[BoxData[
      \(P \((x)\)\)]],
  "  can be computed recursively as follows.  \n\n\tSet  ",
  Cell[BoxData[
      \(b\_\(n + 1\)\  = \ a\_\(n + 1\)\)]],
  " ,  \n\t",
  Cell[BoxData[
      \(b\_k\  = \ a\_k\  + \ x\ a\_\(k + 1\)\)]],
  "   for  ",
  Cell[BoxData[
      RowBox[{\(k = n\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(n - 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", " ", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "1"}]]],
  ".  \n\nThen\t",
  Cell[BoxData[
      \(P \((x)\)\  = \ b\_1\)]],
  ".  \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  This is also known as synthetic division.  "
}], "Text",
  CellTags->"Horner's Method for Polynomial Evaluation"],

Cell[TextData[{
  StyleBox["Example 29.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Horner's method to evaluate  ",
  Cell[BoxData[
      \(P \((3)\)\)]],
  "  where  ",
  Cell[BoxData[
      \(P \((x)\) = x\^5 - 6\ x\^4 + 8\ x\^3 + 8\ x\^2 + 4\ x - 40\)]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 29.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Construct a Horner's method subroutine called  ",
  StyleBox["H[x]",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, H, k, n, P, Q, x];\)\ \ \), "\n", 
    \(\(P[x_] = 
        x\^5 - 6\ x\^4 + 8\ x\^3 + 8\ x\^2 + 4\ x - 40;\)\ \ \), "\n", 
    \(\(Q[
          x_] = \(-40\) + \((4 + \((8 + \((8 + \((\(-6\) + 
                                  x)\)\ x)\)\ x)\)\ x)\)\ x;\)\ \ \), "\n", 
    \(\(a\  = \ CoefficientList[P[x], x];\)\ \ \), "\n", 
    \(\(n\  = \ Length[a];\)\ \ \), "\n", 
    \(\(H[x_] := 
        Module[{}, \n\ \ \ \ b = 
            Table[0, {n}]; \n\ \ \ \ b\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\) = 
            a\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\); \ \
\ \n\ \ \ \ \ \ \ \ For[\ k = n - 1, \ 
            1 \[LessEqual] 
              k, \ \(k--\), \n\ \ \ \ \ \ \ \ \
b\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\) = 
              a\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\  \
+ \ x\ b\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\[RightDoubleBracket]\)\)]; \ \
\ \n\ \ \ \ Return[\ 
            b\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ ];\
\ \ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<P[x] = \>", P[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Q[x] = \>", Q[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<H[x] = \>", H[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<P[3] = \>", P[3]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Q[3] = \>", Q[3]\ ];\)\ \ \), "\n", 
    \(\(Print["\<H[3] = \>", 
        H[3], "\<\n\>"\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(For[\ k = n, \ 
        1 \[LessEqual] 
          k, \ \(k--\), \[IndentingNewLine]\(Print["\<b\>"\_k, "\< = \>", 
            b\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)];\)\
\ ];\)\ \ \)}], "Input"],

Cell["\<\
Consider the computational time for vector arguments for evaluating  P(x)  \
and the nested form  Q(x).\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(Clear[i, m, V];\)\ \ \), "\n", 
    \(\(m = 5000;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[x] = \>", P[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Q[x] = \>", Q[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(V = Table[i, {i, 1, m}];\)\ \ \), "\n", 
    \(\(Ptimeset = Timing[\ P[V]\ ];\)\ \ \), "\n", 
    \(\(Qtimeset = Timing[\ Q[V]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Time to evaluate P[x]; \>", m, "\< times is \>", 
        Ptimeset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ \
];\)\ \ \), "\n", 
    \(\(Print["\<Time to evaluate Q[x]; \>", m, "\< times is \>", 
        Qtimeset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ \
];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 18.  (Geometric Series).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If   ",
  Cell[BoxData[
      \(\(\(|\)\(r\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  then the geometric series  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          UnderoverscriptBox["\[Sum]", 
            StyleBox[\(n = 0\),
              FontSize->10], 
            StyleBox["\[Infinity]",
              FontSize->10]],
          FontSize->18], \(r\^n\), " "}]]],
  "  converges, and     \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            UnderoverscriptBox["\[Sum]", 
              StyleBox[\(n = 0\),
                FontSize->10], 
              StyleBox["\[Infinity]",
                FontSize->10]],
            FontSize->18], \(r\^n\)}], " ", "=", " ", 
        StyleBox[
          FractionBox[
            StyleBox["1",
              FontSize->12], 
            StyleBox[\(1 - r\),
              FontSize->12]],
          FontSize->12]}]]],
  "    \ni.e.  \n\t",
  Cell[BoxData[
      RowBox[{\(\(1\  + \ r\  + \ r\^2\  +  ... \) + \ r\^\(n - 1\)\  + \ 
            r\^n\  +  ... \), " ", "=", " ", 
        StyleBox[
          FractionBox[
            StyleBox["1",
              FontSize->12], 
            StyleBox[\(1 - r\),
              FontSize->12]],
          FontSize->12]}]]],
  ".\n\nIf   ",
  Cell[BoxData[
      \(\(\(|\)\(r\)\(|\)\(\(\[GreaterEqual]\)\(1\)\)\)\)]],
  "  then the geometric series diverges.  "
}], "Text",
  CellTags->"Geometric Series"],

Cell[TextData[{
  StyleBox["Example 30.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Sum the infinite series  ",
  Cell[BoxData[
      \(\(1 + 1\/4 + 1\/4\^2 + 1\/4\^3 + 1\/4\^4 + 1\/4\^5 +  ... \) + 
            1\/4\^n +  ... \  = \ \[Sum]\+\(n = 0\)\%\[Infinity] 1\/4\^n\)]],
  "."
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 30.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[n, S, V];\)\ \ \ \), "\n", 
    \(\(V = {};\)\ \ \ \), "\n", 
    \(\(S = 0;\)\ \ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(For[n = 0, 
        n \[LessEqual] 12, \(n++\), \[IndentingNewLine]S = 
          S + N[1\/4\^n]; \ \ \[IndentingNewLine]V = 
          Append[V, {n, S}]];\)\ \ \), "\n", 
    \(\(dots = 
        ListPlot[V, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(line = 
        Graphics[{Green, Line[{{0, 4\/3}, {12, 4\/3}}]}];\)\ \ \), "\n", 
    \(\(Show[line, dots, Axes \[Rule] True, 
        PlotRange \[Rule] {{0, 12}, {0, 1.35}}, 
        Prolog \[Rule] {PointSize[0.02]}, 
        Ticks \[Rule] {Range[0, 15, 1], Range[0, 1.5, 0.25]}, 
        AxesLabel \[Rule] {"\<n\>", "\<S\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<Partial sums \!\(\[Sum]\+\(k = 0\)\%n\)\!\(1\/4\^k\) for \
the infinite series \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(1\/4\^n\).\>\""];\
\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  can find the sum of the infinite series.  "
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(Clear[n, val];\)\ \ \), "\n", 
    \(\(val\  = \ \[Sum]\+\(n = 0\)\%\[Infinity] 1\/4\^n;\)\ \ \), "\n", 
    \(\(Print[\*"\"\< \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(1\/4\^n\) = \
\>\"", val, "\< = \>", N[val]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 31.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the sum of the binary number  ",
  Cell[BoxData[
      \(S = 0.1011001100110  \[CenterEllipsis]\_two\)]],
  " .  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 31.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We can write  S  as the sum of geometric series  \n\n\t",
  Cell[BoxData[
      \(S = 
        1\/2 + \ \(1\/8\) \((1 + 1\/16 + \[CenterEllipsis] + 
                1\/16\^n + \[CenterEllipsis])\)\)]],
  Cell[BoxData[
      \(\(+\ \(1\/16\)\) \((1 + 1\/16 + \[CenterEllipsis] + 
            1\/16\^n + \[CenterEllipsis])\)\)]],
  "  \n\n\t",
  Cell[BoxData[
      \(S = \(\(1\/2\)\(+\)\(\ \)\)\)]],
  Cell[BoxData[
      \(\(3\/16\) \((1 + 1\/16 + 1\/16\^2 + 1\/16\^3 + \[CenterEllipsis] + 
            1\/16\^n + \[CenterEllipsis])\)\)]],
  "\n\nUse the formula in Theorem 18 to find the sum of the series.  In this \
example  ",
  Cell[BoxData[
      \(r = 1\/16\)]],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{\(1\/2\), "  ", "+", "   ", 
      RowBox[{\(1\/8\), " ", 
        StyleBox[
          FractionBox[
            StyleBox["1",
              FontSize->12], 
            StyleBox[\(1 - 1\/16\),
              FontSize->12]],
          FontSize->12]}], 
      StyleBox["  ",
        FontSize->12], "+", "   ", 
      RowBox[{\(1\/16\), " ", 
        StyleBox[
          FractionBox[
            StyleBox["1",
              FontSize->12], 
            StyleBox[\(1 - 1\/16\),
              FontSize->12]],
          FontSize->12], 
        StyleBox["  ",
          FontSize->12]}]}]], "Input"],

Cell[BoxData[
    RowBox[{\(1\/2\), "  ", "+", "  ", 
      RowBox[{\(3\/16\), " ", 
        StyleBox[
          FractionBox[
            StyleBox["1",
              FontSize->12], 
            StyleBox[\(1 - 1\/16\),
              FontSize->12]],
          FontSize->12], 
        StyleBox["  ",
          FontSize->12]}]}]], "Input"],

Cell[TextData[{
  "Or we can use the power of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the infinite sum.  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[n, s1, s2];\)\ \ \), "\n", 
    \(\(s1\  = \ 
        1\/2 + 1\/8\ \(\[Sum]\+\(n = 0\)\%\[Infinity] 1\/16\^n\) + 
          1\/16\ \(\[Sum]\+\(n = 0\)\%\[Infinity] 1\/16\^n\);\)\ \ \), "\n", 
    \(\(s2\  = \ 
        1\/2 + 3\/16\ \(\[Sum]\+\(n = 0\)\%\[Infinity] 1\/16\^n\);\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(1\/2\)+\!\(1\/8\) \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\
\)\!\(1\/16\^n\)+\!\(1\/16\) \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(1\/16\^n\
\)  =  \>\"", s1\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(1\/2\)  +  \!\(3\/16\) \!\(\[Sum]\+\(n = 0\)\%\
\[Infinity]\)\!\(1\/16\^n\)  =  \>\"", s2\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 19.  (Big \"O\" Remainders for Series Approximations).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that   \n\n\t",
  Cell[BoxData[
      \(f \((h)\)\  = \ p \((h)\) + \ O \((h\^n)\)\)]],
  "   and   ",
  Cell[BoxData[
      \(g \((h)\)\  = \ q \((h)\) + \ O \((h\^m)\)\)]],
  ",  \nand  \n\t",
  Cell[BoxData[
      \(p\  = \ min {m, n}\)]],
  ".  \nThen\n\t",
  Cell[BoxData[
      \(f \((h)\) + g \((h)\)\  = \ 
        p \((h)\) + q \((h)\)\  + \ O \((h\^p)\)\)]],
  "   \n\t\n\t",
  Cell[BoxData[
      \(f \((h)\)*g \((h)\) = \ p \((h)\)*q \((h)\)\  + \ O \((h\^p)\)\)]],
  " \n\t\n\t",
  Cell[BoxData[
      RowBox[{
        FractionBox[
          StyleBox[\(f \((h)\)\),
            FontSize->12], 
          StyleBox[\(g \((h)\)\),
            FontSize->12]], " ", "=", 
        RowBox[{
          FractionBox[
            StyleBox[\(\(\ \)\(p \((h)\)\)\),
              FontSize->12], 
            StyleBox[\(q \((h)\)\),
              FontSize->12]], " ", "+", " ", \(O \((h\^p)\)\)}]}]]],
  " "
}], "Text",
  CellTags->"Big O Remainders for Series Approximations"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, g, h, m, n, P, Q];\)\ \ \), "\n", 
    \(\(m = 2;\)\ \ \), "\n", 
    \(\(n = 3;\)\ \ \), "\n", 
    \(\(P[h_]\  = \ Series[f[h], {h, 0, m - 1}];\)\ \ \), "\n", 
    \(\(Q[h_]\  = \ Series[g[h], {h, 0, n - 1}];\)\ \ \), "\n", 
    \(\(Print["\<m = \>", m];\)\ \ \), "\n", 
    \(\(Print["\<P[h] = \>", P[h]];\)\ \ \), "\n", 
    \(\(Print["\<n = \>", n];\)\ \ \), "\n", 
    \(\(Print["\<Q[h] = \>", Q[h]];\)\ \ \), "\n", 
    \(\(Print["\<p = min{m,n} = \>", Min[m, n]];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<P[h]+Q[h] = \>", P[h] + Q[h]];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", "\<P[h]*Q[h] = \>", P[h]*Q[h]];\)\ \ \), "\n", 
    \(\(Print["\<\n\>", \*"\"\<    \!\(P[h]\/Q[h]\) = \>\"", 
        P[h]\/Q[h]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 32.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  First find Maclaurin expansions for  ",
  Cell[BoxData[
      \(f \((h)\) = \[ExponentialE]\^h\)]],
  "  and  ",
  Cell[BoxData[
      \(g \((h)\) = cos \((h)\)\)]],
  "  of order  ",
  Cell[BoxData[
      \(n = 5\)]],
  "  and   ",
  Cell[BoxData[
      \(m = 7\)]],
  ",  respectively.\nThen experiment and find the order of approximation for \
their sum, product and quotient.  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 32.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[h, m, n, p, prod, P, Q, quot, sum];\)\ \ \), "\n", 
    \(\(n = 5;\)\ \ \), "\n", 
    \(\(m = 7;\)\ \ \), "\n", 
    \(\(p = Min[n, m];\)\ \ \), "\n", 
    \(\(f[h_] = \[ExponentialE]\^h;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g[h_] = Cos[h];\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[h_]\  = \ 
        Series[\[ExponentialE]\^h, {h, 0, n - 1}];\)\ \ \), "\n", 
    \(\(Q[h_]\  = \ Series[Cos[h], {h, 0, m - 1}];\)\ \ \), "\n", 
    \(\(Print["\<f[h] = \>", f[h]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[h] = \>", P[h]];\)\ \ \), "\n", 
    \(\(Print["\<g[h] = \>", g[h]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Q[h] = \>", Q[h]];\)\ \ \)}], "Input"],

Cell["Then find the series for their sum.  ", "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(sum\  = \ 
        Series[\[ExponentialE]\^h + Cos[h], {h, 0, p - 1}];\)\ \ \), "\n", 
    \(\(Print["\<       P[h] = \>", P[h]];\)\ \ \), "\n", 
    \(\(Print["\<       Q[h] = \>", Q[h]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[h] + Q[h] = \>", P[h] + Q[h]];\)\ \ \), "\n", 
    \(\(Print["\<            = \>", sum];\)\ \ \)}], "Input"],

Cell["Then find the series for their product.  ", "Text",
  Evaluatable->False],

Cell[BoxData[{
    RowBox[{\(prod = Series[\[ExponentialE]\^h\ Cos[h], {h, 0, p - 1}];\), 
      "  "}], "\n", 
    RowBox[{\(Print["\<P[h] \[Times] Q[h] = (\>", P[h], "\<)(\>", 
          Q[h], "\<)\>"];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<P[h] \[Times] Q[h] = (\>", Normal[P[h]], 
          Normal[Q[h]], \*"\"\<) + O[h\!\(\(]\^\(min {5, 7}\)\)\)\>\""];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<P[h] \[Times] Q[h] = (\>\"", 
            ",", \(Expand[Normal[P[h]] Normal[Q[h]]]\), ",", "\"\<) + \!\(
\*InterpretationBox[\(O[h]\^5\),
SeriesData[ h, 0, {}, 0, 5, 1]]\)\>\""}], "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<P[h] \[Times] Q[h] = (\>\"", ",", 
            RowBox[{\(Expand[Normal[P[h]] Normal[Q[h]]]\), "+", 
              InterpretationBox[\(O[h]\^5\),
                SeriesData[ h, 0, {}, 0, 5, 1]]}], ",", "\"\<)\>\""}], "]"}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<P[h] \[Times] Q[h] = \>", P[h]*Q[h]];\), "  "}], "\n", 
  
    RowBox[{\(Print["\<            = \>", prod];\), "  "}]}], "Input"],

Cell["Then find the series for their quotient.  ", "Text",
  Evaluatable->False],

Cell[BoxData[{
    RowBox[{\(quot = Series[\[ExponentialE]\^h\/Cos[h], {h, 0, p - 1}];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P[h]\/Q[h]\) = (\>\"", 
          Normal[P[h]]/
            Normal[Q[h]], \*"\"\<) + O[h\!\(\(]\^\(min {5, 7}\)\)\)\>\""];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(P[h]\/Q[h]\) = (\>\"", 
            ",", \(Expand[Normal[P[h]]/Normal[Q[h]]]\), ",", "\"\<) + \!\(
\*InterpretationBox[\(O[h]\^5\),
SeriesData[ h, 0, {}, 0, 5, 1]]\)\>\""}], "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(P[h]\/Q[h]\) = (\>\"", ",", 
            RowBox[{\(Expand[Normal[P[h]]/Normal[Q[h]]]\), "+", 
              InterpretationBox[\(O[h]\^5\),
                SeriesData[ h, 0, {}, 0, 5, 1]]}], ",", "\"\<)\>\""}], "]"}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P[h]\/Q[h]\) = \>\"", P[h]\/Q[h]];\), 
      "  "}], "\n", 
    RowBox[{\(Print["\<      = \>", quot];\), "  "}]}], "Input"],

Cell[TextData[{
  "Interpret the quotient as the product of  ",
  Cell[BoxData[
      \(P[h]\)]],
  "  and  ",
  Cell[BoxData[
      \(1\/Q[h]\)]],
  "  and see what's happening.  "
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    RowBox[{\(Print[\*"\"\<P[h]\!\(1\/Q[h]\) = (\>\"", 
          Normal[P[h]], "\<)(\>", 
          Normal[1/Q[h]], \*"\"\<) + O[h\!\(\(]\^\(min {5, 7}\)\)\)\>\""];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<P[h]\!\(1\/Q[h]\) = (\>\"", ",", \(Expand[Normal[P[h]]]\), 
            ",", "\"\<)(\>\"", ",", \(Normal[Series[1/Q[h], {h, 0, 7}]]\), 
            ",", "\"\<) + \!\(
\*InterpretationBox[\(O[h]\^5\),
SeriesData[ h, 0, {}, 0, 5, 1]]\)\>\""}], "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<P[h]\!\(1\/Q[h]\) = (\>\"", 
            ",", \(Expand[Normal[P[h]] Normal[Series[1/Q[h], {h, 0, 7}]]]\), 
            ",", "\"\<) + \!\(
\*InterpretationBox[\(O[h]\^5\),
SeriesData[ h, 0, {}, 0, 5, 1]]\)\>\""}], "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<          = \>", quot];\), "  "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 20.  (Taylor's Polynomial with Integral Remainder).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that the function  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  and its derivatives  ",
  Cell[BoxData[
      RowBox[{\(f' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(f'' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", " ", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((n + 1)\),
              Derivative],
            MultilineFunction->None], \((x)\)}]}]]],
  "  are all continuous on  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ".  If  both  ",
  Cell[BoxData[
      \(x\_0\)]],
  "  and  ",
  Cell[BoxData[
      \(x = x\_0 + h\)]],
  "  lie in the interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  then  ",
  Cell[BoxData[
      \(f \((x)\)\  = \ \(P\_n\) \((x)\)\  + \ O \((h\^\(n + 1\))\)\)]],
  ",  where\t\n\n\t",
  Cell[BoxData[
      RowBox[{\(\(P\_n\) \((x)\)\), " ", "=", " ", 
        RowBox[{
          StyleBox[
            UnderoverscriptBox["\[Sum]", 
              StyleBox[\(k = 0\),
                FontSize->10], 
              StyleBox["n",
                FontSize->10]],
            FontSize->18], " ", 
          RowBox[{
            FractionBox[
              StyleBox[
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((k)\),
                      Derivative],
                    MultilineFunction->None], \((x\_0)\)}],
                FontSize->12], 
              StyleBox[\(k!\),
                FontSize->12]], \(\((x - x\_0)\)\^k\)}]}]}]]],
  "  \n\t\nis the n-th degree Taylor polynomial expanded about  ",
  Cell[BoxData[
      \(x\_0\)]],
  ".  \n\n\t",
  Cell[BoxData[
      \(f \((x)\) = \(P\_n\) \((x)\) + \(R\_n\) \((x)\)\)]],
  "\n\nThe integral form of the remainder is  \n\n\t",
  Cell[BoxData[
      RowBox[{\(\(R\_n\) \((x)\)\), "=", 
        RowBox[{\(1\/\(n!\)\), 
          RowBox[{\(\[Integral]\_\(x\_0\)\%x\), 
            RowBox[{\(\((x - t)\)\^n\), 
              SuperscriptBox["f", 
                TagBox[\((n + 1)\),
                  Derivative],
                
                MultilineFunction->
                  None], \((t)\), \(\[DifferentialD]t\)}]}]}]}]]],
  ".  "
}], "Text",
  CellTags->"Taylor's Polynomial with Integral Remainder"],

Cell[TextData[{
  StyleBox["Theorem 21.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Taylor's Polynomial with O(",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(TraditionalForm\`h\^\(n + 1\)\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[")  remainder",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that the function  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  and its derivatives  ",
  Cell[BoxData[
      RowBox[{\(f' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(f'' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", " ", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((n + 1)\),
              Derivative],
            MultilineFunction->None], \((x)\)}]}]]],
  "  are all continuous on  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ".  If  both  ",
  Cell[BoxData[
      \(x\_0\)]],
  "  and  ",
  Cell[BoxData[
      \(x = x\_0 + h\)]],
  "  lie in the interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman"], "b"}], "]"}]]],
  ",  then  \n\t\n\t",
  Cell[BoxData[
      RowBox[{\(\(P\_n\) \((x)\)\), " ", "=", " ", 
        RowBox[{
          StyleBox[
            UnderoverscriptBox["\[Sum]", 
              StyleBox[\(k = 0\),
                FontSize->10], 
              StyleBox["n",
                FontSize->10]],
            FontSize->18], " ", 
          RowBox[{
            FractionBox[
              StyleBox[
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((k)\),
                      Derivative],
                    MultilineFunction->None], \((x\_0)\)}],
                FontSize->12], 
              StyleBox[\(k!\),
                FontSize->12]], \(\((x - x\_0)\)\^k\)}]}]}]]],
  "  \n\t\nis the n-th degree Taylor polynomial expanded about  ",
  Cell[BoxData[
      \(x\_0\)]],
  ".  We write    \n\n\t",
  Cell[BoxData[
      \(f \((x)\)\  = \ \(P\_n\) \((x)\)\  + \ O \((h\^\(n + 1\))\)\)]],
  "\n\nIn the  ",
  Cell[BoxData[
      \(O \((h\^\(n + 1\))\)\)]],
  "  remainder we are using  ",
  Cell[BoxData[
      \(h = x - x\_0\)]],
  " in Lagrange's formula for the remainder. \n\n\t",
  Cell[BoxData[
      RowBox[{\(\(R\_n\) \((x)\)\), "=", 
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((n + 1)\),
                  Derivative],
                
                MultilineFunction->None], \((c)\)}], \(\((n + 
                  1)\)!\)], \(\((x - x\_0)\)\^\(n + 1\)\)}]}]]],
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"=", 
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((n + 1)\),
                    Derivative],
                  
                  MultilineFunction->None], \((c)\)}], \(\((n + 
                    1)\)!\)], \(\((h)\)\^\(n + 1\)\)}]}]}]]],
  Cell[BoxData[
      \(\(\(\ \)\(\(+\ O\) \((h\^\(n + 1\))\)\)\)\)]],
  "\n\nwhere ",
  Cell[BoxData[
      \(c\)]],
  " depends on ",
  Cell[BoxData[
      \(x\)]],
  " and lies somewhere between  ",
  Cell[BoxData[
      RowBox[{\(x\_0\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], "  ", "x"}]]],
  ".  \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Often times ",
  Cell[BoxData[
      FractionBox[
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((n + 1)\),
              Derivative],
            MultilineFunction->None], \((c)\)}], \(\((n + 1)\)!\)]]],
  " is not important and we think of it \"like a constant\" and  ",
  Cell[BoxData[
      \(h\^\(n + 1\)\)]],
  "  is the signal feature in the remainder."
}], "Text",
  CellTags->"Taylor's Polynomial with O(h^n+1) remainder"],

Cell[BoxData[{
    \(\(Clear[f, n, x, X];\)\ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \ \), "\[IndentingNewLine]", 
    \(\(S = Series[f[x], {x, X\_0, n}];\)\ \), "\[IndentingNewLine]", 
    \(\(S = ReplaceAll[S, X \[Rule] x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] \[TildeTilde] \>", S];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Taylor and Maclaurin Polynomial Approximation",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Series/Series.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Taylor and Maclaurin Polynomial Approximation",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Series/Series.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  \nInternet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Maclaurin Polynomials",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/calculus/maclaurin/mpe.htm"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Maclaurin Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/calculus/maclaurin/mpe.htm"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Taylor Polynomials",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/calculus/taylor/tpe.htm"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Taylor Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/calculus/taylor/tpe.htm"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 33.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider  ",
  Cell[BoxData[
      \(f \((x)\) = sin \((x)\)\)]],
  "  and the Taylor polynomials of degree  ",
  Cell[BoxData[
      RowBox[{\(n = 3\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "5", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], 
          StyleBox["  ",
            FontFamily->"Times New Roman"], "7"}]}]]],
  "  expanded about  ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  ".  \n\n\t",
  Cell[BoxData[
      RowBox[{
        StyleBox["Taylor",
          FontFamily->"Times New Roman"], 
        StyleBox["   ",
          FontFamily->"Times New Roman"], 
        RowBox[{
          StyleBox["Polynomial",
            FontFamily->"Times New Roman"], 
          StyleBox[":",
            FontFamily->"Times New Roman"], 
          "                             "}]}]]],
  "\t",
  Cell[BoxData[
      StyleBox[\(Order\ of\ \(\(approximation\)\(:\)\)\),
        FontFamily->"Times New Roman"]]],
  "\n\n\t",
  Cell[BoxData[
      RowBox[{\(\(P\_3\) \((x)\)\), " ", "=", " ", 
        RowBox[{"x", "-", 
          FractionBox[
            StyleBox[\(x\^3\),
              FontSize->12], 
            StyleBox["6",
              FontSize->12]], "                             "}]}]]],
  "\t",
  Cell[BoxData[
      RowBox[{\(O \((x\^5)\)\), 
        StyleBox[" ",
          FontSize->12], "\[TildeTilde]", 
        StyleBox[" ",
          FontSize->12], 
        FractionBox[
          StyleBox[\(x\^5\),
            FontSize->12], 
          StyleBox["120",
            FontSize->12]]}]]],
  "  \n\n\t",
  Cell[BoxData[
      RowBox[{\(\(P\_5\) \((x)\)\), " ", "=", " ", 
        RowBox[{"x", "-", 
          FractionBox[
            StyleBox[\(x\^3\),
              FontSize->12], 
            StyleBox["6",
              FontSize->12]], "+", 
          FractionBox[
            StyleBox[\(x\^5\),
              FontSize->12], 
            StyleBox["120",
              FontSize->12]], "                "}]}]]],
  "\t",
  Cell[BoxData[
      RowBox[{\(O \((x\^7)\)\), " ", 
        StyleBox["\[TildeTilde]",
          FontSize->14], " ", 
        FractionBox[
          StyleBox[\(x\^7\),
            FontSize->12], 
          StyleBox["5040",
            FontSize->12]]}]]],
  "  \n\n\t",
  Cell[BoxData[
      RowBox[{\(\(P\_7\) \((x)\)\), " ", "=", " ", 
        RowBox[{"x", "-", 
          FractionBox[
            StyleBox[\(x\^3\),
              FontSize->12], 
            StyleBox["6",
              FontSize->12]], "+", 
          FractionBox[
            StyleBox[\(x\^5\),
              FontSize->12], 
            StyleBox["120",
              FontSize->12]], "-", 
          FractionBox[
            StyleBox[\(x\^7\),
              FontSize->12], 
            StyleBox["5040",
              FontSize->12]]}]}]]],
  "\t",
  Cell[BoxData[
      RowBox[{\(O \((x\^9)\)\), " ", 
        StyleBox["\[TildeTilde]",
          FontSize->14], " ", 
        FractionBox[
          StyleBox[\(x\^9\),
            FontSize->12], 
          StyleBox["362880",
            FontSize->12]]}]]],
  "  "
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 33.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Solution (i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\t",
    FontColor->RGBColor[1, 0, 1]],
  "\tShow that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[VerticalSeparator]", 
          
          RowBox[{\(sin \((x)\)\  - \ \(P\_3\) \((x)\)\), 
            "\[VerticalSeparator]", 
            RowBox[{"<", 
              RowBox[{"\[VerticalSeparator]", 
                RowBox[{
                  StyleBox[
                    FractionBox[
                      StyleBox[\(x\^5\),
                        FontSize->12], 
                      StyleBox["120",
                        FontSize->12]],
                    FontSize->12], "\[VerticalSeparator]"}]}]}]}]}], " "}]]],
  " over  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(-2\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], "2"}], "]"}]]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(Clear[f, E3, maxerr, P3, x];\)\ \ \), "\n", 
    \(\(f[x_] = Sin[x];\)\ \ \), "\n", 
    \(\(P3[x_] = Normal[Series[f[x], {x, 0, 3}]];\)\ \ \), "\n", 
    \(\(E3[x_] = x\^5\/\(5!\);\)\ \ \), "\n", 
    \(\(maxerr = Abs[f[2.0] - P3[2.0]];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[{Abs[f[x] - P3[x]], Abs[E3[x]]}, {x, \(-2\), 2}, 
        PlotRange \[Rule] {{\(-2\), 2}, {0, \ maxerr}}, 
        PlotStyle \[Rule] {Red, Blue}, AxesLabel \[Rule] {x, "\< \>"}, \n\t
        PlotLabel \[Rule] \*"\"\<y = |f[x]-\!\(P\_3\)(x)|  and  y = |\!\(E\_3\
\)[x]|\>\""];\)\ \ \), "\n", 
    \(\(Print["\<f(x)  = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<f(x)  = \>", Series[f[x], {x, 0, 3}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(P\_3\)(x) = \>\"", P3[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<|sin(x) - \!\(P\_3\)(x)| \[LessEqual] \
|\!\(x\^5\/\(5!\)\)|  over [-2,2],\>\""];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<over [-2,2] use |\!\(x\^5\/\(5!\)\)| \[LessEqual] \
\!\(4\/15\) \[LessEqual] 0.266667 \>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The maximum error over [-2,2] is:  \>", 
        maxerr];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Solution (ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\t",
    FontColor->RGBColor[1, 0, 1]],
  "\tShow that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[VerticalSeparator]", 
          
          RowBox[{\(sin \((x)\)\  - \ \(P\_5\) \((x)\)\), 
            "\[VerticalSeparator]", 
            RowBox[{"<", 
              RowBox[{"\[VerticalSeparator]", 
                RowBox[{
                  StyleBox[
                    FractionBox[
                      StyleBox[\(x\^7\),
                        FontSize->12], 
                      StyleBox["5040",
                        FontSize->12]],
                    FontSize->12], "\[VerticalSeparator]"}]}]}]}]}], " "}]]],
  "   over  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(-2\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], "2"}], "]"}]]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(Clear[f, E5, maxerr, P5, x];\)\), "\n", 
    \(\(f[x_] = Sin[x];\)\), "\n", 
    \(\(P5[x_] = Normal[Series[f[x], {x, 0, 5}]];\)\), "\n", 
    \(\(E5[x_] = x\^7\/\(7!\);\)\), "\n", 
    \(\(maxerr = Abs[f[2.0] - P5[2.0]];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[{Abs[f[x] - P5[x]], Abs[E5[x]]}, {x, \(-2\), 2}, 
        PlotRange \[Rule] {{\(-2\), 2}, {0, maxerr}}, 
        PlotStyle \[Rule] {Red, Blue}, AxesLabel \[Rule] {x, "\< \>"}, \n\t
        PlotLabel \[Rule] \*"\"\<y = |f[x]-\!\(P\_5\)(x)|  and  y = |\!\(E\_5\
\)[x]|\>\""];\)\), "\n", 
    \(\(Print["\<f(x)  = \>", f[x]];\)\), "\n", 
    \(\(Print["\<f(x)  = \>", Series[f[x], {x, 0, 5}]];\)\), "\n", 
    \(\(Print[\*"\"\<\!\(P\_5\)(x) = \>\"", P5[x]];\)\), "\n", 
    \(\(Print[\*"\"\<|sin(x) - \!\(P\_5\)(x)| \[LessEqual] \
|\!\(x\^7\/\(7!\)\)|  over [-2,2],\>\""];\)\), "\n", 
    \(\(Print[\*"\"\<over [-2,2] use |\!\(x\^7\/\(7!\)\)| \[LessEqual] \
\!\(8\/315\) \[LessEqual] 0.025397 \>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The maximum error over [-2,2] is:  \>", 
        maxerr];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Solution (iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\t",
    FontColor->RGBColor[1, 0, 1]],
  "\tShow that   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[VerticalSeparator]", 
          
          RowBox[{\(sin \((x)\)\  - \ \(P\_7\) \((x)\)\), 
            "\[VerticalSeparator]", 
            RowBox[{"<", 
              RowBox[{"\[VerticalSeparator]", 
                RowBox[{
                  StyleBox[
                    FractionBox[
                      StyleBox[\(x\^9\),
                        FontSize->12], 
                      StyleBox["362880",
                        FontSize->12]],
                    FontSize->12], "\[VerticalSeparator]"}]}]}]}]}], " "}]]],
  "   over  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(-2\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], "2"}], "]"}]]],
  ".  "
}], "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(Clear[f, E7, maxerr, P7, x];\)\), "\n", 
    \(\(f[x_] = Sin[x];\)\), "\n", 
    \(\(P7[x_] = Normal[Series[f[x], {x, 0, 7}]];\)\), "\n", 
    \(\(E7[x_] = x\^9\/\(9!\);\)\), "\n", 
    \(\(maxerr = Abs[f[2.0] - P7[2.0]];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[{Abs[f[x] - P7[x]], Abs[E7[x]]}, {x, \(-2\), 2}, 
        PlotRange \[Rule] {{\(-2\), 2}, {0, maxerr}}, 
        PlotStyle \[Rule] {Red, Blue}, AxesLabel \[Rule] {x, "\< \>"}, \n\t
        PlotLabel \[Rule] \*"\"\<y = |f[x]-\!\(P\_7\)(x)|  and  y = |\!\(E\_7\
\)[x]|\>\""];\)\), "\n", 
    \(\(Print["\<f(x)  = \>", f[x]];\)\), "\n", 
    \(\(Print["\<f(x)  = \>", Series[f[x], {x, 0, 7}]];\)\), "\n", 
    \(\(Print[\*"\"\<\!\(P\_7\)(x) = \>\"", P7[x]];\)\), "\n", 
    \(\(Print[\*"\"\<|sin(x) - \!\(P\_7\)(x)| \[LessEqual] \
|\!\(x\^9\/\(9!\)\)|  over [-2,2]9\>\""];\)\), "\n", 
    \(\(Print[\*"\"\<over [-2,2] use |\!\(x\^9\/\(9!\)\)| \[LessEqual] \
\!\(4\/2835\) \[LessEqual] 0.001411 \>\""];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The maximum error over [-2,2] is:  \>", 
        maxerr];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 22.  (The Fundamental Theorem of Algebra).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(P \((x)\)\)]],
  "  is a polynomial of degree  ",
  Cell[BoxData[
      \(n\)]],
  ",  then  ",
  Cell[BoxData[
      \(P \((x)\)\)]],
  "  has at least one zero."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"The Fundamental Theorem of Algebra"],

Cell[TextData[{
  StyleBox["Corollary.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(P \((x)\)\)]],
  "  be a polynomial of degree  ",
  Cell[BoxData[
      \(n\)]],
  ".  Then  ",
  Cell[BoxData[
      \(P \((x)\)\)]],
  "  can be expressed as the product of linear factors.  That is,  \n\n\t",
  Cell[BoxData[
      \(P \((x)\) = \(A \((x - z\_1)\)\ \((x - z\_2)\)\  ... \) \((x - 
              z\_n)\)\)]],
  "  \n\nwhere  ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "...", " ", 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(z\_n\)}]]],
  "  are the zeros of  ",
  Cell[BoxData[
      \(P \((x)\)\)]],
  "  counted according to multiplicity and A is a constant.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 34.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the  ",
  Cell[BoxData[
      \(n\)]],
  "  zeros of the equation  ",
  Cell[BoxData[
      \(x\^n - 1 = 0\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 34.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to illustrate the cases n=1,2,...,8."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[n, P, Q, x];\)\ \), "\[IndentingNewLine]", 
    \(\(n = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^n - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[x_] = Factor[P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[x] \[Equal] 0, x]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<P[x] = \>", Q[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solutions to \>", 
        P[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[MapAll[ComplexExpand, solset]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^n - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[x_] = Factor[P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[x] \[Equal] 0, x]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<P[x] = \>", Q[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solutions to \>", 
        P[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[MapAll[ComplexExpand, solset]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^n - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[x_] = Factor[P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[x] \[Equal] 0, x]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<P[x] = \>", Q[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solutions to \>", 
        P[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[MapAll[ComplexExpand, solset]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 5;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^n - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[x_] = Factor[P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[x] \[Equal] 0, x]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<P[x] = \>", Q[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solutions to \>", 
        P[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[MapAll[ComplexExpand, solset]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 6;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^n - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[x_] = Factor[P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[x] \[Equal] 0, x]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<P[x] = \>", Q[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solutions to \>", 
        P[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[MapAll[ComplexExpand, solset]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 7;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^n - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[x_] = Factor[P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[x] \[Equal] 0, x]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<P[x] = \>", Q[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solutions to \>", 
        P[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[MapAll[ComplexExpand, solset]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 8;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^n - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Q[x_] = Factor[P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[P[x] \[Equal] 0, x]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[P\_n, "\<P[x] = \>", Q[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solutions to \>", 
        P[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[MapAll[ComplexExpand, solset]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 23.  (Linear Approximation).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}]}]]],
  "  is a continuous function with continuous partial derivatives at  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(z\_0\), "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}]}]]],
  ".  The linear approximation to  ",
  Cell[BoxData[
      RowBox[{"f", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman"], "y"}], ")"}]}]]],
  ",  at the point  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  "  is  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}], " ", 
        "\[TildeTilde]", " ", 
        RowBox[{
          RowBox[{"f", 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], " ", 
          "+", " ", 
          RowBox[{\(f\_x\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], 
              ")"}], \((x - x\_0)\), " "}]}]}]]],
  Cell[BoxData[
      RowBox[{\(+\ \ f\_y\), 
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], 
          ")"}], \((y - y\_0)\)}]]],
  ".  \n\nIf we use the increments  ",
  Cell[BoxData[
      \(\[CapitalDelta]x = x - x\_0\)]],
  ",  and  ",
  Cell[BoxData[
      \(\[CapitalDelta]y = y - y\_0\)]],
  ",  then this can be written as  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}], " ", 
        "\[TildeTilde]", " ", 
        RowBox[{
          RowBox[{"f", 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], " ", 
          "+", " ", 
          RowBox[{\(f\_x\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}], 
            "\[CapitalDelta]x", " "}]}]}]]],
  Cell[BoxData[
      RowBox[{\(+\ \ f\_y\), 
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], ")"}], 
        "\[CapitalDelta]y", " "}]]],
  ".  \n\t\nIf we include the increment  ",
  Cell[BoxData[
      \(\[CapitalDelta]z = z - z\_0\)]],
  "  where  ",
  Cell[BoxData[
      RowBox[{\(z\_0\), "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}]}]]],
  " and  ",
  Cell[BoxData[
      RowBox[{\(z\_0\), "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{\(x\_0 + \[CapitalDelta]x\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0 + \[CapitalDelta]y\)}],
             ")"}]}]}]]],
  "  then the this can be written as  \n\n\t",
  Cell[BoxData[
      RowBox[{"\[CapitalDelta]z", " ", "\[TildeTilde]", " ", 
        RowBox[{
          RowBox[{\(f\_x\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}], 
            "\[CapitalDelta]x"}], " ", "+", " ", 
          RowBox[{\(f\_y\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}], 
            "\[CapitalDelta]y"}]}]}]]],
  ".  "
}], "Text",
  CellTags->"Linear Approximation"],

Cell[TextData[{
  StyleBox["Theorem 24 (a).  (First Chain Rule for Several Variables).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}]}]]],
  ",  ",
  Cell[BoxData[
      \(x = g \((t)\)\)]],
  ", and ",
  Cell[BoxData[
      \(y = h \((t)\)\)]],
  "  are all differentiable functions.  \nThen   ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{\(g \((t)\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(h \((t)\)\)}], ")"}]}]}]]],
  "  and the derivative of   ",
  Cell[BoxData[
      \(z\)]],
  "  with respect to  ",
  Cell[BoxData[
      \(t\)]],
  "  is \n\n\t",
  Cell[BoxData[
      \(dz\/dt = \(\[PartialD]z\/\[PartialD]x\) 
            dx\/dt + \(\[PartialD]z\/\[PartialD]y\) dy\/dt\)]],
  "."
}], "Text",
  CellTags->"First Chain Rule for Several Variables"],

Cell[BoxData[{
    \(\(z = f[x, y];\)\ \ \), "\n", 
    \(\(x = g[t];\)\ \ \), "\n", 
    \(\(y = h[t];\)\ \ \), "\n", 
    \(\(Print["\<  z = \>", z\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(dz\/dt\) =  \>\"", \[PartialD]\_t\ 
          z\ \ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Theorem 24 (b).  (Second Chain Rule for Several Variables).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}]}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{"g", 
          RowBox[{"(", 
            RowBox[{"s", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "t"}], ")"}]}]}]]],
  ", and  ",
  Cell[BoxData[
      RowBox[{"y", "=", 
        RowBox[{"h", 
          RowBox[{"(", 
            RowBox[{"s", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "t"}], ")"}]}]}]]],
  "  are all differentiable functions.  \nThen   ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"g", 
                RowBox[{"(", 
                  RowBox[{"s", 
                    StyleBox[",",
                      FontFamily->"Times New Roman"], "t"}], ")"}]}], ",", 
              RowBox[{"h", 
                RowBox[{"(", 
                  RowBox[{"s", 
                    StyleBox[",",
                      FontFamily->"Times New Roman"], "t"}], ")"}]}]}], 
            ")"}]}]}]]],
  "  and the partial derivatives of  ",
  Cell[BoxData[
      \(z\)]],
  "  with respect to  ",
  Cell[BoxData[
      \(s\)]],
  "  and  ",
  Cell[BoxData[
      \(t\)]],
  "  are   \n\n\t",
  Cell[BoxData[
      \(\[PartialD]z\/\[PartialD]s = \(\[PartialD]z\/\[PartialD]x\) \
\[PartialD]x\/\[PartialD]s + \(\[PartialD]z\/\[PartialD]y\) \[PartialD]y\/\
\[PartialD]s\)]],
  ",  \nand\n\t",
  Cell[BoxData[
      \(\[PartialD]z\/\[PartialD]t = \(\[PartialD]z\/\[PartialD]x\) \
\[PartialD]x\/\[PartialD]t + \(\[PartialD]z\/\[PartialD]y\) \[PartialD]y\/\
\[PartialD]t\)]],
  ".  "
}], "Text",
  CellTags->"Second Chain Rule for Several Variables"],

Cell[BoxData[{
    \(\(Clear[x, y, z, f, g, h];\)\ \), "\[IndentingNewLine]", 
    \(\(z = f[x, y];\)\ \ \), "\n", 
    \(\(x = g[s, t];\)\ \ \), "\n", 
    \(\(y = h[s, t];\)\ \ \), "\n", 
    \(\(Print["\<  z = \>", z\ ];\)\ \ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", \*"\"\<\!\(\[PartialD]z\/\[PartialD]s\) =  \>\"", \
\[PartialD]\_s\ z\ \ ];\)\ \ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", \*"\"\<\!\(\[PartialD]z\/\[PartialD]t\) =  \>\"", \
\[PartialD]\_t\ z\ \ ];\)\ \ \ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Theorem 25.  (Taylor's Series for Two Variables).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}]}]]],
  "  is a continuous function with continuous partial derivatives at  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(z\_0\), "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}]}]]],
  ".  The Taylor polynomial approximation of degree  ",
  Cell[BoxData[
      \(n = 2\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{"f", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman"], "y"}], ")"}]}]]],
  ",  at the point  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  "  is  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}], " ", 
        "\[TildeTilde]", " ", 
        RowBox[{
          RowBox[{"f", 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], " ", 
          "+", " ", 
          RowBox[{\(f\_x\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], 
              ")"}], \((x - x\_0)\), " "}]}]}]]],
  Cell[BoxData[
      RowBox[{\(+\ \ f\_y\), 
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], 
          ")"}], \((y - y\_0)\)}]]],
  "\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(+\ \(1\/2\)\), \(f\_xx\), 
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], 
          ")"}], \(\((x - x\_0)\)\^2\)}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(+\ f\_xy\), 
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], 
          ")"}], \((x - x\_0)\), \((y - y\_0)\)}]]],
  " ",
  Cell[BoxData[
      RowBox[{\(+\ \(1\/2\)\), " ", \(f\_yy\), 
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], 
          ")"}], \(\((y - y\_0)\)\^2\)}]]]
}], "Text",
  CellTags->"Taylor's Series for Two Variables"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derivation.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, t, x, y];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(s = 
        Series[f[X\_0 + \[CapitalDelta]x\ \ t, 
            Y\_0 + \[CapitalDelta]y\ t], {t, 0, 
            n}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S = 
        ReplaceAll[Normal[s], t \[Rule] 1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S = 
        ReplaceAll[
          S, {X \[Rule] x, Y \[Rule] y}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Taylor polynomial approximation of degree  n = \>", 
        n\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<f[x,y] \[TildeTilde] \>", 
        S];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S = 
        ReplaceAll[
          S, {\[CapitalDelta]x\  \[Rule] x - x\_0, \[CapitalDelta]y\  \[Rule] 
              y - y\_0}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<f[x,y] \[TildeTilde] \>", S];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Clear[f, t, x, y];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 3;\)\ \ \), "\[IndentingNewLine]", 
    \(\(s = 
        Series[f[X\_0 + \[CapitalDelta]x\ \ t, 
            Y\_0 + \[CapitalDelta]y\ t], {t, 0, 
            n}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S = 
        ReplaceAll[Normal[s], t \[Rule] 1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S = 
        ReplaceAll[
          S, {X \[Rule] x, Y \[Rule] y}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Taylor polynomial approximation of degree  n = \>", 
        n\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<f[x,y] \[TildeTilde] \>", 
        S];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S = 
        ReplaceAll[
          S, {\[CapitalDelta]x\  \[Rule] x - x\_0, \[CapitalDelta]y\  \[Rule] 
              y - y\_0}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<f[x,y] \[TildeTilde] \>", S];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 35.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Taylor polynomial approximation of degree  ",
  Cell[BoxData[
      \(n = 1\)]],
  "  for  ",
  Cell[BoxData[
      \(f \((x, y)\) = 5  x\^2 + x\^4 - 9\ x\^2\ y + 3\ y\^2 + 2\ y\^4\)]],
  "  expanded about  ",
  Cell[BoxData[
      \(\((x\_0, y\_0)\) = \((1, 1)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 35.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, x, y];\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[x_, y_] = 
        5  x\^2 + x\^4 - 9\ x\^2\ y + 3\ y\^2 + 
          2\ y\^4;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \ \)}], "Input"],

Cell["Use the formula in Theorem 25. ", "Text"],

Cell[BoxData[{
    RowBox[{\(x\_0 = 1;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(y\_0 = 1;\), "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"S", "=", 
          RowBox[{\(f[x\_0, y\_0]\), "+", 
            RowBox[{\((y - y\_0)\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((0, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x\_0, y\_0\), "]"}]}], "+",
             
            RowBox[{\(1\/2\), " ", \(\((y - y\_0)\)\^2\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((0, 2)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x\_0, y\_0\), "]"}]}], "+",
             
            RowBox[{\((x - x\_0)\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((1, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x\_0, y\_0\), "]"}]}], "+",
             
            RowBox[{\((x - x\_0)\), " ", \((y - y\_0)\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((1, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x\_0, y\_0\), "]"}]}], "+",
             
            RowBox[{\(1\/2\), " ", \(\((x - x\_0)\)\^2\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x\_0, y\_0\), "]"}]}]}]}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<f[x,y] = \>", f[x, y]\ ];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Taylor polynomial approximation of degree  n = \
2\>"];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<f[x,y] \[TildeTilde] \>", S];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<f[x,y] \[TildeTilde] \>", Expand[S]\ ];\), 
      "  "}]}], "Input"],

Cell[TextData[{
  "Or use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s procedure ",
  StyleBox["Series",
    FontWeight->"Bold"],
  " with caution.  "
}], "Text"],

Cell[BoxData[{
    \(\(n = 2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(S2 = 
        Series[f[1 + \[CapitalDelta]x\ \ t, 1 + \[CapitalDelta]y\ t], {t, 0, 
            n}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S2 = 
        ReplaceAll[Normal[S2], t \[Rule] 1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S2 = Expand[S2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[s];\)\ \ \), "\[IndentingNewLine]", 
    \(\(s[x_, y_] = 
        ReplaceAll[
          S2, {\[CapitalDelta]x\  \[Rule] x - 1, \[CapitalDelta]y\  \[Rule] 
              y - 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Taylor polynomial approximation of degree  n = \>", 
        n\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] \[TildeTilde] \>", 
        s[x, y]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] \[TildeTilde] \>", 
        Expand[s[x, y]]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Observation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  When the given function  ",
  Cell[BoxData[
      \(f[x, y]\)]],
  ", (which is a polynomial of two variables of order n = 4) is expanded in a \
Taylor polynomial of degree n = 4, the result is an equivalent expression  ",
  Cell[BoxData[
      \(f[x, y]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(n = 4;\)\ \ \), "\[IndentingNewLine]", 
    \(\(S2 = 
        Series[f[1 + \[CapitalDelta]x\ \ t, 1 + \[CapitalDelta]y\ t], {t, 0, 
            n}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S2 = 
        ReplaceAll[Normal[S2], t \[Rule] 1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S2 = Expand[S2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Clear[s];\)\ \ \), "\[IndentingNewLine]", 
    \(\(s[x_, y_] = 
        ReplaceAll[
          S2, {\[CapitalDelta]x\  \[Rule] x - 1, \[CapitalDelta]y\  \[Rule] 
              y - 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Taylor polynomial approximation of degree  n = \>", 
        n\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] \[TildeTilde] \>", 
        s[x, y]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x,y] \[TildeTilde] \>", 
        Expand[s[x, y]]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 6.  (Local Extrema for a Function of Two Variables).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  StyleBox["Suppose that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"f", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman"], "y"}], ")"}]}]]],
  StyleBox[" is defined in some disk  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(D\)]],
  StyleBox["  with center  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  ".  ",
  StyleBox["  \n\nThe function ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"f", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman"], "y"}], ")"}]}]]],
  StyleBox[" has a ",
    FontFamily->"Times New Roman"],
  StyleBox["local maximum",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" at ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  " provided that \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}], 
        "\[LessEqual]", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}]}]]],
  " for all ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], ")"}], "\[Element]",
         "D"}]]],
  ". \n\n",
  StyleBox["The function ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x, y)\)\)]],
  StyleBox[" has a ",
    FontFamily->"Times New Roman"],
  StyleBox["local minimum at",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\((x\_0, y\_0)\)\)]],
  " provided that \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}], 
        "\[GreaterEqual]", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}]}]]],
  " for all ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], ")"}], "\[Element]",
         "D"}]]],
  "."
}], "Text",
  CellTags->"Local Extrema for a Function of Two Variables"],

Cell[TextData[{
  StyleBox["Theorem 26.  (Critical Points for a Function of Two Variables).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  If the function  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"f", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman"], "y"}], ")"}]}]]],
  StyleBox["  has a either a local minimum or local maximum at  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  "  and the first-order partial derivatives exist there, then both  \n\n\t\t\
",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_x\), 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "=", 
        "0"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_x\), 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "=", 
        "0"}]]],
  ". \n\nA point  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  "  such that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_x\), 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "=", 
        "0"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_x\), 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "=", 
        "0"}]]],
  ",  or one of the partial derivatives does not exist is called a ",
  StyleBox["critical point",
    FontColor->RGBColor[0, 0, 1]],
  ".  "
}], "Text",
  CellTags->"Critical Points for a Function of Two Variables"],

Cell[TextData[{
  StyleBox["Theorem 27.  (Second Derivative Test for a Function of Two \
Variables).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Suppose  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"f", 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(f\_x\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(f\_y\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(f\_xx\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(f\_xy\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], 
          StyleBox["  ",
            FontFamily->"Times New Roman"], \(f\_yy\)}]}]]],
  "  are all continuous on a disk ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(D\)]],
  StyleBox["  with center ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  ".  Assume that  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  "  is a critical point, i.e.  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_x\), 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "=", 
        "0"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_x\), 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "=", 
        "0"}]]],
  ".  \n\n",
  StyleBox["(i)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(f\_xx\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], 
              ")"}], \(f\_yy\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "-", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{\(f\_xy\), 
                RowBox[{"(", 
                  RowBox[{\(x\_0\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], 
              ")"}], "2"]}], ">", "0"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_xx\), 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], ">", 
        "0"}]]],
  " then ",
  Cell[BoxData[
      RowBox[{"f", 
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}]]],
  " is a local minimum.  \n\n",
  StyleBox["(ii)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(f\_xx\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], 
              ")"}], \(f\_yy\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "-", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{\(f\_xy\), 
                RowBox[{"(", 
                  RowBox[{\(x\_0\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], 
              ")"}], "2"]}], ">", "0"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_xx\), 
          RowBox[{"(", 
            RowBox[{\(x\_0\), 
              StyleBox[",",
                FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "<", 
        "0"}]]],
  " then ",
  Cell[BoxData[
      RowBox[{"f", 
        RowBox[{"(", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}]]],
  " is a local maximum.  \n\n",
  StyleBox["(iii)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(f\_xx\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], 
              ")"}], \(f\_yy\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "-", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{\(f\_xy\), 
                RowBox[{"(", 
                  RowBox[{\(x\_0\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], 
              ")"}], "2"]}], "<", "0"}]]],
  " then ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{"f", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman"], "y"}], ")"}]}]}]]],
  "has a saddle point at ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]]],
  ".  \n\n",
  StyleBox["(iv)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(f\_xx\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], 
              ")"}], \(f\_yy\), 
            RowBox[{"(", 
              RowBox[{\(x\_0\), 
                StyleBox[",",
                  FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], "-", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{\(f\_xy\), 
                RowBox[{"(", 
                  RowBox[{\(x\_0\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman"], \(y\_0\)}], ")"}]}], 
              ")"}], "2"]}], "=", "0"}]]],
  " then a mere computation of the second partials is not helpful in \
determining the nature of the critical point. Theory could be developed for \
investigating this situations and it would involve the fourth order partial \
derivatives.  It is awkward to use and for this reason is not used. "
}], "Text",
  CellTags->"Second Derivative Test for a Function of Two Variables"],

Cell[TextData[{
  StyleBox["Definition 7.  (Limit of a Sequence).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      \(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\ x\_n = x\)]],
  "  means that for any real number  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there corresponds a positive integer  ",
  Cell[BoxData[
      \(N\_\[Epsilon]\)]],
  "  (which depends on  ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  ")  such that  \n\n\t",
  Cell[BoxData[
      \(\(\(|\)\(x - x\_n\)\(|\)\(\(<\)\(\[Element]\)\)\)\)]],
  "  whenever  ",
  Cell[BoxData[
      \(n > N\_\[Epsilon]\)]],
  ".  \n\nInformally, the sequence  ",
  Cell[BoxData[
      \({x\_n}\_1\%\[Infinity]\)]],
  "  has  ",
  Cell[BoxData[
      \(x\)]],
  "  as its limit as  ",
  Cell[BoxData[
      \(n\)]],
  "  approaches infinity, provided the terms  ",
  Cell[BoxData[
      \(x\_n\)]],
  "  can be made as close as we please to  ",
  Cell[BoxData[
      \(x\)]],
  "  by making  ",
  Cell[BoxData[
      \(n\)]],
  "  large enough.  When this happens, we write \n\n\t",
  Cell[BoxData[
      \(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\ x\_n = x\)]],
  "  \nor\n\t",
  Cell[BoxData[
      \(\(\(\ \)\(x\_n \[Rule] \(x\ \ \ as\ \ n\  \[Rule] \
\[Infinity]\)\)\)\)]],
  "  \n\nIf  ",
  Cell[BoxData[
      \(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\ x\_n = x\)]],
  ",  we say that the sequence  ",
  Cell[BoxData[
      \({x\_n}\_1\%\[Infinity]\)]],
  "  ",
  StyleBox["converges",
    FontColor->RGBColor[0, 0, 1]],
  " to  x.  "
}], "Text",
  CellTags->"Limit of a Sequence"],

Cell[TextData[{
  StyleBox["Example 36 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(\(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\) \(2  n\  + \
\ 3\)\/\(n\^2\  + \ 1\)\)]],
  ",  ",
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(\(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\) \(1\  + \ \
2  n\  + \ 3  n\^3\)\/\(4  n\^3\  + \ 5  n\^2\  + \ 6\)\)]],
  ",  ",
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(\(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\) \(n\^3\  + \
\ 1\)\/\(6  n\^2\  + \ 7  n\^2\  + \ 8\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 36 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[n];\)\ \), "\[IndentingNewLine]", 
    \(X\_n_ = \(2  n + 3\)\/\(\(n\^2 + 1\)\(\ \ \)\)\)}], "Input"],

Cell[BoxData[
    \(\(\(Limit[\ X\_n, \ n \[Rule] \[Infinity]]\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 36 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[n];\)\ \), "\[IndentingNewLine]", 
    \(X\_n_ = \(1 + 2  n + 3  n\^3\)\/\(\(4  n\^3 + 5  n\^2 + 6\)\(\ \ \
\)\)\)}], "Input"],

Cell[BoxData[
    \(\(\(Limit[\ X\_n, \ n \[Rule] \[Infinity]]\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 36 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[n];\)\ \), "\[IndentingNewLine]", 
    \(X\_n_ = \(n\^3 + 1\)\/\(\(6  n\^2 + 7  n\^2 + 8\)\(\ \ \)\)\)}], "Input"],

Cell[BoxData[
    \(Limit[\ X\_n, \ n \[Rule] \[Infinity]]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Definition 8.  (Limit of a Series).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The ",
  StyleBox["infinite series",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 1]],
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\[Infinity] x\_k\)]],
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["converges",
    FontColor->RGBColor[0, 0, 1]],
  " to  S if for any real number  ",
  Cell[BoxData[
      \(\[Epsilon] > 0\)]],
  "  there corresponds a positive integer  ",
  Cell[BoxData[
      \(N\_\[Epsilon]\)]],
  "  (which depends on  ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  ")  such that  \n\n\t",
  Cell[BoxData[
      \(\(\(|\)\(S - \[Sum]\+\(k = 1\)\%n \
x\_k\)\(|\)\(\(<\)\(\[Element]\)\)\)\)]],
  "  whenever  ",
  Cell[BoxData[
      \(n > N\_\[Epsilon]\)]],
  ".  \n\nInformally, the ",
  StyleBox["infinite series",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 1]],
  Cell[BoxData[
      \(S = \[Sum]\+\(k = 1\)\%\[Infinity] x\_k\)]],
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["converges",
    FontColor->RGBColor[0, 0, 1]],
  " if the sequence  ",
  Cell[BoxData[
      \({S\_n}\_1\%\[Infinity]\)]],
  "  of partial sums,  ",
  Cell[BoxData[
      \(S\_n = \[Sum]\+\(k = 1\)\%n x\_k\)]],
  ",  has  ",
  Cell[BoxData[
      \(S\)]],
  "  as",
  " its limit.",
  "\n\t\n\tIf  ",
  Cell[BoxData[
      \(S\_n = \[Sum]\+\(k = 1\)\%n x\_k\)]],
  ",  then  ",
  Cell[BoxData[
      \(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\ S\_n\  = \ 
        S\)]],
  ", \nor  \n\t",
  Cell[BoxData[
      \(\(\(\(\ \)\(lim\)\(\ \)\)\+\(n\  \[Rule] \ \[Infinity]\)\) \(\[Sum]\+\
\(k = 1\)\%n x\_k\) = \ \[Sum]\+\(k = 1\)\%\[Infinity] x\_k\)]]
}], "Text",
  CellTags->"Limit of a Series"],

Cell[TextData[{
  StyleBox["Example 37 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^\(n + 1\)\/n\)]],
  ",  ",
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] 2\^n\/\(n!\)\)]],
  ",  ",
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\ \ 2\^\(2  n + \
1\)\)\/\(\((2  n + 1)\)!\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 37 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(\[Sum]\+\(n = 
            1\)\%\[Infinity]\)\(\((\(-1\))\)\^\(n + 1\)\/n\)\(\ \ \)\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 37 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(\[Sum]\+\(n = 
            0\)\%\[Infinity]\)\(2\^n\/\(n!\)\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 37 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\(\(\(\((\(-1\))\)\^n\) 
            2\^\(2  n + 1\)\)\/\(\((2  n + 1)\)!\)\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "The answer is \"well known.\"  But to obtain it we must use ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s simplification command called ",
  StyleBox["FunctionExpand",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(FunctionExpand[\@\[Pi]\ BesselJ[1\/2, 2]]\)], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Calculus",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CalculusBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Calculus",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CalculusBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  \nInternet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The Mean Value Theorem",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/MeanValueTheoremBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Mean Value Theorem",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/MeanValueTheoremBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  \nInternet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The Fundamental Theorem of Calculus",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/FunTheoremCalculusBib.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Fundamental Theorem of Calculus",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/FunTheoremCalculusBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  \nInternet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Maclaurin and Taylor Series",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/TaylorPolyBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Maclaurin and Taylor Series",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/TaylorPolyBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  \nInternet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{892, 589},
WindowMargins->{{18, Automatic}, {Automatic, 7}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Definite Integral as a Limit of a Riemann Sum"->{
    Cell[3429, 111, 1267, 38, 98, "Text",
      CellTags->"Definite Integral as a Limit of a Riemann Sum"]},
  "First Fundamental Theorem of Calculus"->{
    Cell[19894, 498, 1050, 36, 94, "Text",
      CellTags->"First Fundamental Theorem of Calculus"]},
  "Second Fundamental Theorem of Calculus"->{
    Cell[26042, 664, 850, 28, 31, "Text",
      CellTags->"Second Fundamental Theorem of Calculus"]},
  "Rules for Integration"->{
    Cell[30677, 801, 181, 4, 30, "Text",
      Evaluatable->False,
      CellTags->"Rules for Integration"]},
  "Formulas for Integration"->{
    Cell[35667, 923, 190, 4, 30, "Text",
      Evaluatable->False,
      CellTags->"Formulas for Integration"]},
  "Mean Value Theorem for Integrals"->{
    Cell[40269, 1092, 1148, 41, 76, "Text",
      CellTags->"Mean Value Theorem for Integrals"]},
  "Weighted Mean Value Theorem for Integrals"->{
    Cell[45146, 1235, 970, 34, 88, "Text",
      CellTags->"Weighted Mean Value Theorem for Integrals"]},
  "Taylor's Theorem and Lagrange's Remainder"->{
    Cell[49045, 1352, 2714, 87, 258, "Text",
      CellTags->"Taylor's Theorem and Lagrange's Remainder"]},
  "Horner's Method for Polynomial Evaluation"->{
    Cell[53168, 1487, 1241, 38, 182, "Text",
      CellTags->"Horner's Method for Polynomial Evaluation"]},
  "Geometric Series"->{
    Cell[57603, 1614, 1544, 51, 152, "Text",
      CellTags->"Geometric Series"]},
  "Big O Remainders for Series Approximations"->{
    Cell[64004, 1820, 1140, 36, 226, "Text",
      CellTags->"Big O Remainders for Series Approximations"]},
  "Taylor's Polynomial with Integral Remainder"->{
    Cell[71720, 2036, 2683, 84, 253, "Text",
      CellTags->"Taylor's Polynomial with Integral Remainder"]},
  "Taylor's Polynomial with O(h^n+1) remainder"->{
    Cell[74406, 2122, 4203, 139, 342, "Text",
      CellTags->"Taylor's Polynomial with O(h^n+1) remainder"]},
  "The Fundamental Theorem of Algebra"->{
    Cell[91139, 2636, 449, 17, 30, "Text",
      Evaluatable->False,
      CellTags->"The Fundamental Theorem of Algebra"]},
  "Linear Approximation"->{
    Cell[97612, 2803, 4551, 141, 239, "Text",
      CellTags->"Linear Approximation"]},
  "First Chain Rule for Several Variables"->{
    Cell[102166, 2946, 1102, 38, 95, "Text",
      CellTags->"First Chain Rule for Several Variables"]},
  "Second Chain Rule for Several Variables"->{
    Cell[103559, 2994, 2044, 66, 138, "Text",
      CellTags->"Second Chain Rule for Several Variables"]},
  "Taylor's Series for Two Variables"->{
    Cell[106130, 3073, 3014, 96, 112, "Text",
      CellTags->"Taylor's Series for Two Variables"]},
  "Local Extrema for a Function of Two Variables"->{
    Cell[116570, 3371, 3090, 105, 182, "Text",
      CellTags->"Local Extrema for a Function of Two Variables"]},
  "Critical Points for a Function of Two Variables"->{
    Cell[119663, 3478, 2098, 67, 128, "Text",
      CellTags->"Critical Points for a Function of Two Variables"]},
  "Second Derivative Test for a Function of Two Variables"->{
    Cell[121764, 3547, 7262, 225, 223, "Text",
      CellTags->"Second Derivative Test for a Function of Two Variables"]},
  "Limit of a Sequence"->{
    Cell[129029, 3774, 1630, 58, 263, "Text",
      CellTags->"Limit of a Sequence"]},
  "Limit of a Series"->{
    Cell[132548, 3904, 1845, 65, 215, "Text",
      CellTags->"Limit of a Series"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Definite Integral as a Limit of a Riemann Sum", 162955, 4994},
  {"First Fundamental Theorem of Calculus", 163109, 4997},
  {"Second Fundamental Theorem of Calculus", 163257, 5000},
  {"Rules for Integration", 163388, 5003},
  {"Formulas for Integration", 163530, 5007},
  {"Mean Value Theorem for Integrals", 163683, 5011},
  {"Weighted Mean Value Theorem for Integrals", 163830, 5014},
  {"Taylor's Theorem and Lagrange's Remainder", 163985, 5017},
  {"Horner's Method for Polynomial Evaluation", 164142, 5020},
  {"Geometric Series", 164274, 5023},
  {"Big O Remainders for Series Approximations", 164407, 5026},
  {"Taylor's Polynomial with Integral Remainder", 164567, 5029},
  {"Taylor's Polynomial with O(h^n+1) remainder", 164728, 5032},
  {"The Fundamental Theorem of Algebra", 164881, 5035},
  {"Linear Approximation", 165034, 5039},
  {"First Chain Rule for Several Variables", 165168, 5042},
  {"Second Chain Rule for Several Variables", 165320, 5045},
  {"Taylor's Series for Two Variables", 165468, 5048},
  {"Local Extrema for a Function of Two Variables", 165622, 5051},
  {"Critical Points for a Function of Two Variables", 165791, 5054},
  {"Second Derivative Test for a Function of Two Variables", 165968, 5057},
  {"Limit of a Sequence", 166118, 5060},
  {"Limit of a Series", 166230, 5063}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 171, 4, 35, "Text"],
Cell[1950, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3429, 111, 1267, 38, 98, "Text",
  CellTags->"Definite Integral as a Limit of a Riemann Sum"],
Cell[4699, 151, 874, 27, 52, "Text"],
Cell[5576, 180, 316, 12, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5917, 196, 102, 2, 33, "Text"],
Cell[6022, 200, 837, 15, 314, "Input"],
Cell[6862, 217, 729, 12, 254, "Input"],
Cell[7594, 231, 729, 12, 254, "Input"],
Cell[8326, 245, 657, 11, 234, "Input"],
Cell[8986, 258, 1337, 25, 416, "Input"]
}, Closed]],
Cell[10338, 286, 317, 12, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10680, 302, 102, 2, 33, "Text"],
Cell[10785, 306, 840, 15, 314, "Input"],
Cell[11628, 323, 732, 12, 254, "Input"],
Cell[12363, 337, 732, 12, 254, "Input"],
Cell[13098, 351, 660, 11, 234, "Input"],
Cell[13761, 364, 1340, 25, 416, "Input"]
}, Closed]],
Cell[15116, 392, 317, 12, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[15458, 408, 102, 2, 33, "Text"],
Cell[15563, 412, 840, 15, 314, "Input"],
Cell[16406, 429, 732, 12, 254, "Input"],
Cell[17141, 443, 732, 12, 254, "Input"],
Cell[17876, 457, 660, 11, 234, "Input"],
Cell[18539, 470, 1340, 25, 416, "Input"]
}, Closed]],
Cell[19894, 498, 1050, 36, 94, "Text",
  CellTags->"First Fundamental Theorem of Calculus"],
Cell[20947, 536, 1089, 38, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22061, 578, 102, 2, 33, "Text"],
Cell[22166, 582, 474, 9, 165, "Input"],
Cell[22643, 593, 619, 11, 192, "Input"],
Cell[23265, 606, 799, 12, 151, "Input"],
Cell[24067, 620, 167, 6, 33, "Text",
  Evaluatable->False],
Cell[24237, 628, 487, 8, 200, "Input"],
Cell[24727, 638, 1300, 23, 264, "Input"]
}, Closed]],
Cell[26042, 664, 850, 28, 31, "Text",
  CellTags->"Second Fundamental Theorem of Calculus"],
Cell[26895, 694, 254, 4, 103, "Input"],
Cell[27152, 700, 393, 13, 34, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[27570, 717, 102, 2, 33, "Text"],
Cell[27675, 721, 665, 11, 249, "Input"],
Cell[28343, 734, 250, 4, 70, "Input"],
Cell[28596, 740, 185, 3, 50, "Input"]
}, Closed]],
Cell[28796, 746, 408, 14, 40, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[29229, 764, 102, 2, 33, "Text"],
Cell[29334, 768, 866, 19, 218, "Input"],
Cell[30203, 789, 260, 4, 70, "Input"],
Cell[30466, 795, 196, 3, 50, "Input"]
}, Closed]],
Cell[30677, 801, 181, 4, 30, "Text",
  Evaluatable->False,
  CellTags->"Rules for Integration"],
Cell[30861, 807, 2920, 68, 337, "Print"],

Cell[CellGroupData[{
Cell[33806, 879, 132, 2, 33, "Text"],
Cell[33941, 883, 1689, 35, 417, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[35667, 923, 190, 4, 30, "Text",
  Evaluatable->False,
  CellTags->"Formulas for Integration"],
Cell[35860, 929, 164, 6, 33, "Text"],
Cell[36027, 937, 139, 2, 45, "Input"],
Cell[36169, 941, 166, 7, 71, "Text"],
Cell[36338, 950, 122, 2, 42, "Input"],
Cell[36463, 954, 148, 2, 41, "Input"],
Cell[36614, 958, 130, 2, 45, "Input"],
Cell[36747, 962, 127, 2, 41, "Input"],
Cell[36877, 966, 116, 2, 41, "Input"],
Cell[36996, 970, 121, 2, 41, "Input"],
Cell[37120, 974, 184, 3, 41, "Input"],
Cell[37307, 979, 173, 6, 33, "Text"],
Cell[37483, 987, 149, 2, 41, "Input"],
Cell[37635, 991, 134, 5, 33, "Text"],
Cell[37772, 998, 132, 2, 41, "Input"],
Cell[37907, 1002, 153, 3, 41, "Input"],
Cell[38063, 1007, 148, 3, 41, "Input"],
Cell[38214, 1012, 123, 2, 41, "Input"],
Cell[38340, 1016, 124, 2, 41, "Input"],
Cell[38467, 1020, 158, 2, 48, "Input"],
Cell[38628, 1024, 156, 6, 45, "Text"],
Cell[38787, 1032, 164, 3, 42, "Input"],
Cell[38954, 1037, 222, 7, 36, "Text"],
Cell[39179, 1046, 153, 6, 45, "Text"],
Cell[39335, 1054, 163, 3, 42, "Input"],
Cell[39501, 1059, 183, 6, 45, "Text"],
Cell[39687, 1067, 198, 6, 45, "Text"],
Cell[39888, 1075, 197, 6, 45, "Text"],
Cell[40088, 1083, 166, 6, 45, "Text"]
}, Closed]],
Cell[40269, 1092, 1148, 41, 76, "Text",
  CellTags->"Mean Value Theorem for Integrals"],
Cell[41420, 1135, 1104, 40, 82, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[42549, 1179, 102, 2, 33, "Text"],
Cell[42654, 1183, 362, 6, 138, "Input"],
Cell[43019, 1191, 788, 15, 294, "Input"],
Cell[43810, 1208, 1321, 24, 285, "Input"]
}, Closed]],
Cell[45146, 1235, 970, 34, 88, "Text",
  CellTags->"Weighted Mean Value Theorem for Integrals"],
Cell[46119, 1271, 921, 33, 75, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[47065, 1308, 102, 2, 33, "Text"],
Cell[47170, 1312, 341, 6, 130, "Input"],
Cell[47514, 1320, 965, 18, 369, "Input"],
Cell[48482, 1340, 548, 9, 124, "Input"]
}, Closed]],
Cell[49045, 1352, 2714, 87, 258, "Text",
  CellTags->"Taylor's Theorem and Lagrange's Remainder"],
Cell[51762, 1441, 414, 18, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[52201, 1463, 102, 2, 33, "Text"],
Cell[52306, 1467, 354, 7, 150, "Input"],
Cell[52663, 1476, 490, 8, 130, "Input"]
}, Closed]],
Cell[53168, 1487, 1241, 38, 182, "Text",
  CellTags->"Horner's Method for Polynomial Evaluation"],
Cell[54412, 1527, 325, 12, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[54762, 1543, 102, 2, 33, "Text"],
Cell[54867, 1547, 130, 5, 33, "Text"],
Cell[55000, 1554, 1108, 22, 230, "Input"],
Cell[56111, 1578, 601, 12, 170, "Input"],
Cell[56715, 1592, 149, 4, 33, "Text",
  Evaluatable->False],
Cell[56867, 1598, 721, 13, 190, "Input"]
}, Closed]],
Cell[57603, 1614, 1544, 51, 152, "Text",
  CellTags->"Geometric Series"],
Cell[59150, 1667, 339, 10, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[59514, 1681, 102, 2, 33, "Text"],
Cell[59619, 1685, 1084, 22, 321, "Input"],
Cell[60706, 1709, 150, 5, 33, "Text",
  Evaluatable->False],
Cell[60859, 1716, 257, 4, 114, "Input"]
}, Closed]],
Cell[61131, 1723, 259, 9, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[61415, 1736, 102, 2, 33, "Text"],
Cell[61520, 1740, 706, 20, 156, "Text"],
Cell[62229, 1762, 614, 21, 51, "Input"],
Cell[62846, 1785, 335, 11, 51, "Input"],
Cell[63184, 1798, 145, 5, 33, "Text"],
Cell[63332, 1805, 657, 12, 200, "Input"]
}, Closed]],
Cell[64004, 1820, 1140, 36, 226, "Text",
  CellTags->"Big O Remainders for Series Approximations"],

Cell[CellGroupData[{
Cell[65169, 1860, 101, 2, 33, "Text"],
Cell[65273, 1864, 768, 14, 285, "Input"]
}, Closed]],
Cell[66056, 1881, 522, 19, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[66603, 1904, 102, 2, 33, "Text"],
Cell[66708, 1908, 708, 13, 251, "Input"],
Cell[67419, 1923, 75, 1, 33, "Text",
  Evaluatable->False],
Cell[67497, 1926, 372, 6, 111, "Input"],
Cell[67872, 1934, 79, 1, 33, "Text",
  Evaluatable->False],
Cell[67954, 1937, 1251, 27, 154, "Input"],
Cell[69208, 1966, 80, 1, 33, "Text",
  Evaluatable->False],
Cell[69291, 1969, 1155, 26, 213, "Input"],
Cell[70449, 1997, 215, 9, 38, "Text",
  Evaluatable->False],
Cell[70667, 2008, 1038, 25, 158, "Input"]
}, Closed]],
Cell[71720, 2036, 2683, 84, 253, "Text",
  CellTags->"Taylor's Polynomial with Integral Remainder"],
Cell[74406, 2122, 4203, 139, 342, "Text",
  CellTags->"Taylor's Polynomial with O(h^n+1) remainder"],
Cell[78612, 2263, 327, 5, 110, "Input"],
Cell[78942, 2270, 824, 24, 52, "Text"],
Cell[79769, 2296, 746, 23, 33, "Text"],
Cell[80518, 2321, 727, 22, 33, "Text"],
Cell[81248, 2345, 3347, 117, 203, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[84620, 2466, 102, 2, 33, "Text"],
Cell[84725, 2470, 947, 31, 39, "Text",
  Evaluatable->False],
Cell[85675, 2503, 1212, 20, 361, "Input"],
Cell[86890, 2525, 951, 31, 39, "Text",
  Evaluatable->False],
Cell[87844, 2558, 1159, 20, 361, "Input"],
Cell[89006, 2580, 955, 31, 39, "Text",
  Evaluatable->False],
Cell[89964, 2613, 1160, 20, 361, "Input"]
}, Closed]],
Cell[91139, 2636, 449, 17, 30, "Text",
  Evaluatable->False,
  CellTags->"The Fundamental Theorem of Algebra"],
Cell[91591, 2655, 940, 32, 109, "Text",
  Evaluatable->False],
Cell[92534, 2689, 289, 13, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[92848, 2706, 102, 2, 33, "Text"],
Cell[92953, 2710, 134, 5, 33, "Text"],
Cell[93090, 2717, 691, 11, 210, "Input"],
Cell[93784, 2730, 633, 10, 190, "Input"],
Cell[94420, 2742, 633, 10, 190, "Input"],
Cell[95056, 2754, 633, 10, 190, "Input"],
Cell[95692, 2766, 633, 10, 190, "Input"],
Cell[96328, 2778, 633, 10, 190, "Input"],
Cell[96964, 2790, 633, 10, 190, "Input"]
}, Closed]],
Cell[97612, 2803, 4551, 141, 239, "Text",
  CellTags->"Linear Approximation"],
Cell[102166, 2946, 1102, 38, 95, "Text",
  CellTags->"First Chain Rule for Several Variables"],
Cell[103271, 2986, 285, 6, 123, "Input"],
Cell[103559, 2994, 2044, 66, 138, "Text",
  CellTags->"Second Chain Rule for Several Variables"],
Cell[105606, 3062, 521, 9, 177, "Input"],
Cell[106130, 3073, 3014, 96, 112, "Text",
  CellTags->"Taylor's Series for Two Variables"],

Cell[CellGroupData[{
Cell[109169, 3173, 101, 2, 33, "Text"],
Cell[109273, 3177, 944, 20, 190, "Input"],
Cell[110220, 3199, 944, 20, 190, "Input"]
}, Closed]],
Cell[111179, 3222, 403, 14, 49, "Text"],

Cell[CellGroupData[{
Cell[111607, 3240, 102, 2, 33, "Text"],
Cell[111712, 3244, 254, 5, 70, "Input"],
Cell[111969, 3251, 47, 0, 33, "Text"],
Cell[112019, 3253, 2044, 49, 198, "Input"],
Cell[114066, 3304, 178, 8, 33, "Text"],
Cell[114247, 3314, 959, 19, 210, "Input"],
Cell[115209, 3335, 384, 12, 52, "Text"],
Cell[115596, 3349, 959, 19, 210, "Input"]
}, Closed]],
Cell[116570, 3371, 3090, 105, 182, "Text",
  CellTags->"Local Extrema for a Function of Two Variables"],
Cell[119663, 3478, 2098, 67, 128, "Text",
  CellTags->"Critical Points for a Function of Two Variables"],
Cell[121764, 3547, 7262, 225, 223, "Text",
  CellTags->"Second Derivative Test for a Function of Two Variables"],
Cell[129029, 3774, 1630, 58, 263, "Text",
  CellTags->"Limit of a Sequence"],
Cell[130662, 3834, 763, 25, 41, "Text"],

Cell[CellGroupData[{
Cell[131450, 3863, 106, 2, 33, "Text"],
Cell[131559, 3867, 130, 2, 63, "Input"],
Cell[131692, 3871, 87, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[131816, 3877, 106, 2, 30, "Text"],
Cell[131925, 3881, 155, 3, 66, "Input"],
Cell[132083, 3886, 87, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[132207, 3892, 106, 2, 30, "Text"],
Cell[132316, 3896, 143, 2, 66, "Input"],
Cell[132462, 3900, 71, 1, 30, "Input"]
}, Closed]],
Cell[132548, 3904, 1845, 65, 215, "Text",
  CellTags->"Limit of a Series"],
Cell[134396, 3971, 620, 23, 40, "Text"],

Cell[CellGroupData[{
Cell[135041, 3998, 106, 2, 33, "Text"],
Cell[135150, 4002, 124, 3, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[135311, 4010, 106, 2, 30, "Text"],
Cell[135420, 4014, 108, 2, 49, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[135565, 4021, 106, 2, 30, "Text"],
Cell[135674, 4025, 156, 2, 59, "Input"],
Cell[135833, 4029, 244, 8, 33, "Text"],
Cell[136080, 4039, 74, 1, 42, "Input"]
}, Closed]],
Cell[136169, 4043, 158, 3, 32, "Text"],
Cell[136330, 4048, 532, 16, 52, "Text"],
Cell[136865, 4066, 592, 18, 52, "Text"],
Cell[137460, 4086, 617, 18, 52, "Text"],
Cell[138080, 4106, 576, 16, 52, "Text"],
Cell[138659, 4124, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

