(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25621,        813]*)
(*NotebookOutlinePosition[     26872,        852]*)
(*  CellTagsIndexPosition[     26828,        848]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Bisection Method",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The bisection method is one of the bracketing methods for finding roots \
of equations.\n",
  StyleBox["Implementation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given a function f(x) and an interval which might contain a root, \
perform a predetermined number of iterations using the bisection method. \n",
  StyleBox["Limitations.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Investigate the result of applying the bisection method over an interval \
where there is a discontinuity.  Apply the bisection method for a function \
using an interval where there are distinct roots.  Apply the bisection method \
over a \"large\" interval.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Bisection Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Bisection.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " Assume that  ",
  Cell[BoxData[
      RowBox[{"f", "\[Element]", 
        RowBox[{
          StyleBox["C",
            FontWeight->"Bold"], "[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  " and that there exists a number ",
  Cell[BoxData[
      RowBox[{"r", "\[Element]", 
        RowBox[{"[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  " such that ",
  Cell[BoxData[
      \(f \((r)\) = 0\)]],
  ".  \nIf  ",
  Cell[BoxData[
      RowBox[{"f", \((a)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "f", \((b)\)}]]],
  " have opposite signs, and ",
  Cell[BoxData[
      \({c\_n}\)]],
  " represents the sequence of midpoints generated by the bisection process, \
then\n\n\t\t",
  Cell[BoxData[
      \(\(\(|\)\(r - 
          c\_n\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\(b\  - \ 
                a\)\/2\^\(n + 1\)\)\)\)\)]],
  "   for   ",
  Cell[BoxData[
      RowBox[{\(n = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  ",\n\nand the sequence ",
  Cell[BoxData[
      \({c\_n}\)]],
  " converges to the zero  ",
  Cell[BoxData[
      \(x = r\)]],
  ".  \n\nThat is,  \t",
  Cell[BoxData[
      \(lim\+\(k\  \[Rule] \ \[Infinity]\)\ c\_n\  = \ r\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/BisectionProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BisectionProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/BisectionProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BisectionProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Bisection Method).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(Bisection[a0_, b0_, 
        m_]\)\(\ \)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \
\[IndentingNewLine]a\  = \ N[a0]; \ \ \[IndentingNewLine]b\  = \ 
          N[b0]; \ \ \[IndentingNewLine]c\  = \ \(a\  + \ b\)\/2; \ \
\[IndentingNewLine]k\  = \ 
          0; \ \[IndentingNewLine]output = {{k, a, c, b, 
              f[c]}}; \ \[IndentingNewLine]While[
          k\  < \ m, \[IndentingNewLine]If[\ 
            Sign[f[b]]\  \[Equal] \ \ Sign[
                f[c]], \ \[IndentingNewLine]b\  = \ 
              c, \ \(a\  = \ 
                c;\)\ ]; \ \[IndentingNewLine]c\  = \ \(a\  + \ b\)\/2; \ \
\[IndentingNewLine]k\  = \ k + 1; \ \[IndentingNewLine]output = 
            Append[output, {k, a, c, b, 
                f[c]}];\ ]; \ \[IndentingNewLine]Print[
          NumberForm[
            TableForm[
              output, \[IndentingNewLine]TableHeadings \[Rule] {None, \
{"\<k\>", \*"\"\<\!\(a\_k\)\>\"", \*"\"\<\!\(c\_k\)\>\"", \*"\"\<\!\(b\_k\)\>\
\"", \*"\"\<f[\!\(c\_k\)]\>\""}}], 
            16]]; \ \[IndentingNewLine]Print["\<  c  = \>", 
          NumberForm[c, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]c  = \
\[PlusMinus]\>", \(b - a\)\/2]; \ \[IndentingNewLine]Print["\<f[c] = \>", 
          NumberForm[f[c], 16]\ ];\ ]\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Find all the real solutions to the cubic equation  ",
  Cell[BoxData[
      \(x\^3 + 4\ x\^2 - 10 = 0\)],
    AspectRatioFixed->False],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 + 4\ x\^2 - 10;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input",
  AspectRatioFixed->False],

Cell["Plot the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-4\), 2}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
There appears to be only one real root which lies in the interval \
[1,2]. \
\>", "Text"],

Cell[BoxData[{
    \(\(Plot[f[x], {x, 1, 2}, 
        PlotStyle \[Rule] Magenta];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Call the Bisection subroutine on the interval [1,2] using 10 \
iterations\
\>", "Text"],

Cell[BoxData[
    \(\(\(Bisection[1, 2, 10];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell["\<\
After 10 iterations, the interval has been reduced to [a,b] where \
\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<a = \>", 
        NumberForm[a, 16]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<b = \>", 
        NumberForm[b, 16]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<[a, b] = [\>", a, "\<, \>", b, "\<]\>"];\)\ \ \ \)}], "Input"],

Cell["\<\
The root lies somewhere in the interval [a,b] the width of which is \
\
\>", "Text"],

Cell[BoxData[
    \(\(\(Print["\<b-a = \>", NumberForm[b - a, 16]\ ];\)\(\ \)\)\)], "Input"],

Cell["The reported root is alleged to be ", "Text"],

Cell[BoxData[
    \(\(\(Print["\<c = \>", NumberForm[c, 16]\ ];\)\(\ \)\)\)], "Input"],

Cell["\<\
The accuracy we can guarantee is one half of the interval \
width.\
\>", "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(\(b - a\)\/2\) = \>\"", 
        NumberForm[\(b - a\)\/2, 16]\ ];\)\(\ \)\)\)], "Input"],

Cell["\<\
Is this the desired accuracy you want ?  If not, more iterations \
are required.\
\>", "Text"],

Cell[BoxData[
    \(\(\(Bisection[1, 2, 20];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Compare our result with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in root finder."
}], "Text"],

Cell[BoxData[
    \(\(\(\(solset = NSolve[f[x] \[Equal] 0, x];\)\ \[IndentingNewLine]
    NumberForm[TableForm[solset], 16]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Question.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Why is ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s answer different ?\nHow many bisections would it take to reduce the \
interval width to ",
  Cell[BoxData[
      \(10\^\(-16\)\)]],
  " ? "
}], "Text"],

Cell[BoxData[
    \(\(\(Bisection[1, 2, 50];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Remember.",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The bisection method can only be used to find a real root in an interval \
[a,b] in which f[x] changes sign."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Use the cubic equation  ",
  Cell[BoxData[
      \(x\^3 + 4\ x\^2 - 10 = 0\)],
    AspectRatioFixed->False],
  "  in Example 1 and perform the following call to the bisection method. \n\n\
",
  StyleBox["Bisection[0,1,30];",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(Bisection[0, 1, 30];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Caution.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " You must be able to explain what the output means.  Would you give it to \
your boss ?"
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Reduce the volume of printout.\n\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "After you have debugged you program and it is working properly, delete the \
unnecessary print statements. "
}], "Text"],

Cell[TextData[StyleBox["Concise Program for the Bisection Method",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(Bisection[a0_, b0_, 
          m_]\  := \[IndentingNewLine]Module[{a\  = \ N[a0], 
            b\  = \ N[
                b0]}, \[IndentingNewLine]c\  = \ \(a\  + \ b\)\/2; \ \
\[IndentingNewLine]k\  = \ 0; \ \[IndentingNewLine]While[
            k\  < \ m, \[IndentingNewLine]If[\ 
              Sign[f[b]]\  \[Equal] \ \ Sign[
                  f[c]], \ \[IndentingNewLine]b\  = \ 
                c, \ \(a\  = \ 
                  c;\)\ ]; \ \[IndentingNewLine]c\  = \ \(a\  + \ b\)\/2; \ \
\[IndentingNewLine]k\  = \ 
              k + 1;\ \ ]; \ \[IndentingNewLine]Print["\<  c  = \>", 
            NumberForm[c, 
              16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]c  = \
\[PlusMinus]\>", \(b - a\)\/2]; \ \[IndentingNewLine]Print["\<f[c] = \>", 
            NumberForm[f[c], 16]\ ];\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell["\<\
Now test the example to see if it still works. Use the last case in \
Example 1 given above and compare with the previous results.\
\>", "Text"],

Cell[BoxData[
    \(\(\(Bisection[1, 2, 30];\)\(\ \)\)\)], "Input"],

Cell[TextData[StyleBox["Reducing the Computational Load for the Bisection \
Method",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
The following program uses fewer computations in the bisection \
method and is the traditional way to do it.  Can you determine how many fewer \
functional evaluations are used ?\
\>", "Text"],

Cell[BoxData[
    \(\(\(Bisection[a0_, b0_, 
        m_]\)\(\ \)\(:=\)\(\n\)\(Module[{a\  = \ N[a0], 
          b\  = \ N[
              b0]}, \[IndentingNewLine]c\  = \ \(a\  + \ b\)\/2; \ \
\[IndentingNewLine]Yb\  = \ f[b]; \ \[IndentingNewLine]Yc\  = \ 
          f[c]; \ \[IndentingNewLine]k\  = \ 0; \ \[IndentingNewLine]While[
          k\  < \ m, \[IndentingNewLine]If[\ 
            Sign[Yb]\  \[Equal] \ \ Sign[Yc], \ \[IndentingNewLine]b\  = \ 
              c; \ \[IndentingNewLine]Yb\  = \ 
              Yc, \ \[IndentingNewLine]\(a\  = \ 
                c;\)\ ]; \ \[IndentingNewLine]c\  = \ \(a\  + \ b\)\/2; \ \
\[IndentingNewLine]Yc\  = \ f[c]; \ \[IndentingNewLine]k\  = \ 
            k + 1;\ \ ]; \ \n\ \ Print["\<  c  = \>", 
          NumberForm[c, 
            16]\ ]; \ \n\ \ Print["\< \[CapitalDelta]c  = \[PlusMinus]\>", \
\(b - a\)\/2]; \ \n\ \ Print["\<f[c] = \>", 
          NumberForm[Yc, 16]\ ];\ ]\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Various Scenarios and Animations for the Bisection \
Method.",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(Bisection[a0_, b0_, 
        m_]\)\(\ \)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \
\[IndentingNewLine]a\  = \ N[a0]; \ \ \[IndentingNewLine]b\  = \ 
          N[b0]; \ \ \[IndentingNewLine]c\  = \ \(a\  + \ b\)\/2; \ \
\[IndentingNewLine]k\  = \ 
          0; \ \[IndentingNewLine]output = {{k, a, c, b, 
              f[c]}}; \ \[IndentingNewLine]While[
          k\  < \ m, \[IndentingNewLine]If[\ 
            Sign[f[b]]\  \[Equal] \ \ Sign[
                f[c]], \ \[IndentingNewLine]b\  = \ 
              c, \ \(a\  = \ 
                c;\)\ ]; \ \[IndentingNewLine]c\  = \ \(a\  + \ b\)\/2; \ \
\[IndentingNewLine]k\  = \ k + 1; \ \[IndentingNewLine]output = 
            Append[output, {k, a, c, b, 
                f[c]}];\ ]; \ \[IndentingNewLine]Print[
          NumberForm[
            TableForm[
              output, \[IndentingNewLine]TableHeadings \[Rule] {None, \
{"\<k\>", \*"\"\<\!\(a\_k\)\>\"", \*"\"\<\!\(c\_k\)\>\"", \*"\"\<\!\(b\_k\)\>\
\"", \*"\"\<f[\!\(c\_k\)]\>\""}}], 
            16]]; \ \[IndentingNewLine]Print["\<  c  = \>", 
          NumberForm[c, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]c  = \
\[PlusMinus]\>", \(b - a\)\/2]; \ \[IndentingNewLine]Print["\<f[c] = \>", 
          NumberForm[f[c], 16]\ ];\ ]\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 3.  ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Convergence",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Find the solution to the cubic equation  ",
  Cell[BoxData[
      \(x\^3 + 4\ x\^2 - 10 = 0\)],
    AspectRatioFixed->False],
  ".  Use the starting interval  ",
  Cell[BoxData[
      \(\([a, b]\) = \([\(-1\), 2]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = x\^3 + 4\ x\^2 - 10;\)\ \), "\[IndentingNewLine]", 
    \(\(a = \(-1.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 2.0;\)\), "\[IndentingNewLine]", 
    \(\(Bisection[a, b, 30];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-1.05\), 2.05}, 
        PlotRange \[Rule] {{\(-1.05\), 2.05}, {\(-10\), 15}}, 
        PlotStyle \[Rule] Magenta];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/RootFinding/\
BisectionMethod/Bisectionaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/RootFinding/\
BisectionMethod/Bisectionaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.  ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Not a root located",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Find the solution to the equation  ",
  Cell[BoxData[
      \(Tan[x] = 0\)],
    AspectRatioFixed->False],
  ".  Use the starting interval  ",
  Cell[BoxData[
      \(\([a, b]\) = \([0, 2]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = Tan[x];\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 2.0;\)\), "\[IndentingNewLine]", 
    \(\(Bisection[a, b, 15];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-0.05\), 2.05}, 
        PlotRange \[Rule] {{\(-0.05\), 2.05}, {\(-15\), 15}}, 
        PlotStyle \[Rule] Magenta];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  " The bisection method located a pole of  ",
  Cell[BoxData[
      \(f[x] = Tan[x]\)]],
  ".  This is where the graph has a vertical asymptote."
}], "Text"],

Cell[BoxData[
    \(Solve[1/f[x]\  \[Equal] \ 0, x]\)], "Input"],

Cell[TextData[{
  StyleBox["Animation 2.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/RootFinding/\
BisectionMethod/Bisectionbb.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/RootFinding/\
BisectionMethod/Bisectionbb.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/RootFinding/\
BisectionMethod/BisectionMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/RootFinding/\
BisectionMethod/BisectionMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/bi.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/bi.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/BisectionBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " ",
  StyleBox[ButtonBox["Bisection Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BisectionBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  ",
  "Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 173, 4, 35, "Text"],
Cell[1952, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3431, 111, 801, 18, 87, "Text"],
Cell[4235, 131, 3210, 103, 169, "Text"],
Cell[7448, 236, 607, 20, 33, "Text"],
Cell[8058, 258, 593, 19, 33, "Text"],
Cell[8654, 279, 146, 2, 33, "Text"],
Cell[8803, 283, 1346, 26, 416, "Input"],
Cell[10152, 311, 348, 13, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10525, 328, 101, 2, 33, "Text"],
Cell[10629, 332, 165, 3, 50, "Input"],
Cell[10797, 337, 34, 0, 33, "Text"],
Cell[10834, 339, 273, 5, 70, "Input"],
Cell[11110, 346, 99, 3, 33, "Text"],
Cell[11212, 351, 200, 4, 50, "Input"],
Cell[11415, 357, 97, 3, 33, "Text"],
Cell[11515, 362, 94, 2, 30, "Input"],
Cell[11612, 366, 92, 3, 33, "Text"],
Cell[11707, 371, 324, 6, 90, "Input"],
Cell[12034, 379, 94, 3, 33, "Text"],
Cell[12131, 384, 92, 1, 30, "Input"],
Cell[12226, 387, 51, 0, 33, "Text"],
Cell[12280, 389, 86, 1, 30, "Input"],
Cell[12369, 392, 90, 3, 33, "Text"],
Cell[12462, 397, 129, 2, 42, "Input"],
Cell[12594, 401, 104, 3, 33, "Text"],
Cell[12701, 406, 67, 1, 30, "Input"],
Cell[12771, 409, 138, 5, 33, "Text"],
Cell[12912, 416, 146, 2, 50, "Input"],
Cell[13061, 420, 323, 12, 52, "Text"],
Cell[13387, 434, 67, 1, 30, "Input"],
Cell[13457, 437, 242, 7, 35, "Text"]
}, Closed]],
Cell[13714, 447, 491, 18, 69, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14230, 469, 101, 2, 33, "Text"],
Cell[14334, 473, 67, 1, 30, "Input"],
Cell[14404, 476, 201, 6, 33, "Text"]
}, Closed]],
Cell[14620, 485, 265, 7, 72, "Text"],
Cell[14888, 494, 182, 4, 35, "Text"],
Cell[15073, 500, 883, 17, 296, "Input"],
Cell[15959, 519, 154, 3, 33, "Text"],
Cell[16116, 524, 67, 1, 30, "Input"],
Cell[16186, 527, 200, 5, 35, "Text"],
Cell[16389, 534, 202, 4, 33, "Text"],
Cell[16594, 540, 982, 18, 396, "Input"],
Cell[17579, 560, 166, 4, 35, "Text"],
Cell[17748, 566, 1346, 26, 416, "Input"],
Cell[19097, 594, 431, 15, 33, "Text"],

Cell[CellGroupData[{
Cell[19553, 613, 101, 2, 33, "Text"],
Cell[19657, 617, 472, 8, 130, "Input"],
Cell[20132, 627, 791, 26, 33, "Text"]
}, Closed]],
Cell[20938, 656, 414, 15, 30, "Text"],

Cell[CellGroupData[{
Cell[21377, 675, 101, 2, 33, "Text"],
Cell[21481, 679, 452, 8, 130, "Input"],
Cell[21936, 689, 253, 8, 33, "Text"],
Cell[22192, 699, 64, 1, 30, "Input"],
Cell[22259, 702, 791, 26, 33, "Text"]
}, Closed]],
Cell[23065, 731, 798, 24, 30, "Text"],
Cell[23866, 757, 695, 20, 33, "Text"],
Cell[24564, 779, 158, 3, 35, "Text"],
Cell[24725, 784, 596, 19, 33, "Text"],
Cell[25324, 805, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

