(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21656,        671]*)
(*NotebookOutlinePosition[     22536,        700]*)
(*  CellTagsIndexPosition[     22492,        696]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Regula Falsi Method",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The Regula Falsi method is one of the bracketing methods for finding \
roots of equations.\n",
  StyleBox["Implementation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given a function f(x) and an interval which might contain a root, \
perform a predetermined number of iterations using the Regula Falsi method. \n\
",
  StyleBox["Limitations.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Investigate the result of applying the Regula Falsi method over an \
interval where there is a discontinuity.  Apply the Regula Falsi method for a \
function using an interval where there are distinct roots.  Apply the Regula \
Falsi method over a \"large\" interval.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Regula Falsi Theorem).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " Assume that  ",
  Cell[BoxData[
      RowBox[{"f", "\[Element]", 
        RowBox[{
          StyleBox["C",
            FontWeight->"Bold"], "[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  " and that there exists a number ",
  Cell[BoxData[
      RowBox[{"r", "\[Element]", 
        RowBox[{"[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  " such that ",
  Cell[BoxData[
      \(f \((r)\) = 0\)]],
  ".  \nIf  ",
  Cell[BoxData[
      RowBox[{"f", \((a)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "f", \((b)\)}]]],
  " have opposite signs, and \n\n\t",
  Cell[BoxData[
      \(c\_n\  = \ \(a\_n\ f \((b\_n)\)\  - \ b\_n\ f \((a\_n)\)\)\/\(f \
\((b\_n)\)\  - \ f \((a\_n)\)\)\)]],
  "  \n\nrepresents the sequence of points generated by the Regula Falsi \
process, then the sequence ",
  Cell[BoxData[
      \({c\_n}\)]],
  " converges to the zero  ",
  Cell[BoxData[
      \(x = r\)]],
  ".  \n\nThat is,  \t",
  Cell[BoxData[
      \(lim\+\(k\  \[Rule] \ \[Infinity]\)\ c\_n\  = \ r\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["False Position or Regula Falsi Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/RegulaFalsiProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["False Position or Regula Falsi Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/RegulaFalsiProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["False Position or Regula Falsi Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/RegulaFalsiProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["False Position or Regula Falsi Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/RegulaFalsiProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Regula Falsi Method).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(RegulaFalsi[a0_, b0_, 
        m_]\)\(\ \)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \
\[IndentingNewLine]a\  = \ N[a0]; \ \[IndentingNewLine]b\  = \ 
          N[b0]; \ \[IndentingNewLine]c\  = \ \(a\ f[b] - b\ f[a]\)\/\(f[b] - \
f[a]\); \ \[IndentingNewLine]k\  = \ 
          0; \ \[IndentingNewLine]output = {{k, a, c, b, 
              f[c]}}; \ \ \[IndentingNewLine]While[
          k\  < \ m, \[IndentingNewLine]If[\ 
            Sign[f[b]]\  \[Equal] \ \ Sign[
                f[c]], \ \[IndentingNewLine]b\  = \ 
              c, \ \(a\  = \ 
                c;\)\ ]; \ \[IndentingNewLine]c\  = \ \(a\ f[b] - b\ f[a]\)\/\
\(f[b] - f[a]\); \ \[IndentingNewLine]k\  = \ 
            k + 1; \ \[IndentingNewLine]output = 
            Append[output, {k, a, c, b, 
                f[c]}];\ ]; \ \[IndentingNewLine]Print[
          NumberForm[
            TableForm[
              output, \[IndentingNewLine]TableHeadings \[Rule] {None, \
{"\<k\>", \*"\"\<\!\(a\_k\)\>\"", \*"\"\<\!\(c\_k\)\>\"", \*"\"\<\!\(b\_k\)\>\
\"", \*"\"\<f[\!\(c\_k\)]\>\""}}], 
            16]\ ]; \ \[IndentingNewLine]Print["\<  c  = \>", 
          NumberForm[c, 16]\ ]; \ \[IndentingNewLine]Print["\<f[c] = \>", 
          NumberForm[f[c], 16]\ ];\ ]\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Find all the real solutions to the cubic equation  ",
  Cell[BoxData[
      \(x\^3 + 4\ x\^2 - 10 = 0\)],
    AspectRatioFixed->False],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 + 4\ x\^2 - 10;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input",
  AspectRatioFixed->False],

Cell["Plot the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-4\), 2}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
There appears to be only one real root which lies in the interval \
[1,2]. \
\>", "Text"],

Cell[BoxData[{
    \(\(Plot[f[x], {x, 1, 2}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Call the Regula Falsi subroutine on the interval [1,2] using 10 \
iterations\
\>", "Text"],

Cell[BoxData[
    \(\(\(RegulaFalsi[1, 2, 10];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell["\<\
After 10 iterations, the interval has been reduced to [a,b] where \
\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<a = \>", 
        NumberForm[a, 16]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<b = \>", NumberForm[b, 16]\ ];\)\ \)}], "Input"],

Cell["\<\
The root lies somewhere in the interval [a,b] width of which is \
\
\>", "Text"],

Cell[BoxData[
    \(\(\(NumberForm[b - a, 16]\)\(\ \)\)\)], "Input"],

Cell["The reported root is alleged to be ", "Text"],

Cell[BoxData[
    \(\(\(NumberForm[c, 16]\)\(\ \)\)\)], "Input"],

Cell["\<\
The estimate of \"how things are going\" is the distance between  c \
 and the nearest endpoint to the interval.\
\>", "Text"],

Cell[BoxData[
    \(\(\(NumberForm[Min[c - a, b - c], 16]\)\(\ \)\)\)], "Input"],

Cell["\<\
Is this the desired accuracy you want ?  If not, more iterations \
are required.\
\>", "Text"],

Cell[BoxData[
    \(\(\(RegulaFalsi[1, 2, 30];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Compare our result with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in root finder."
}], "Text"],

Cell[BoxData[{
    \(\(solset = NSolve[f[x] \[Equal] 0, x];\)\ \), "\[IndentingNewLine]", 
    \(NumberForm[TableForm[solset], 11]\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remember.",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The ",
  "Regula Falsi",
  " method can only be used to find a real root in an interval [a,b] in which \
f[x] changes sign."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Use the cubic equation  ",
  Cell[BoxData[
      \(x\^3 + 4\ x\^2 - 10 = 0\)],
    AspectRatioFixed->False],
  "  in Example 1 and perform the following call to the ",
  "Regula Falsi subroutine",
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 + 4\ x\^2 - 10;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[BoxData[
    \(\(\(RegulaFalsi[0, 1, 30];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Caution.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " What is the interval [a,b]?"
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<a = \>", NumberForm[a, 16]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<b = \>", NumberForm[b, 16]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<[a,b] = [\>", NumberForm[a, 16], "\< , \>", 
        NumberForm[b, 16], "\<]\>"];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Reduce the volume of printout.\n\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "After you have debugged you program and it is working properly, delete the \
unnecessary print statements."
}], "Text"],

Cell[TextData[StyleBox["Concise Program for the Regula Falsi",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(RegulaFalsi[a0_, b0_, 
        m_]\)\(\ \)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \
\[IndentingNewLine]a\  = \ N[a0]; \ \[IndentingNewLine]b\  = \ 
          N[b0]; \ \[IndentingNewLine]c\  = \ \(a\ f[b] - b\ f[a]\)\/\(f[b] - \
f[a]\); \ \[IndentingNewLine]k\  = \ 0; \ \[IndentingNewLine]While[
          k\  < \ m, \[IndentingNewLine]If[\ 
            Sign[f[b]]\  \[Equal] \ \ Sign[
                f[c]], \ \[IndentingNewLine]b\  = \ 
              c, \ \(a\  = \ 
                c;\)\ ]; \ \[IndentingNewLine]c\  = \ \(a\ f[b] - b\ f[a]\)\/\
\(f[b] - f[a]\); \ \[IndentingNewLine]k\  = \ 
            k + 1;\ \ ]; \ \[IndentingNewLine]Print["\<  c  = \>", 
          NumberForm[c, 16]\ ]; \ \[IndentingNewLine]Print["\<f[c] = \>", 
          NumberForm[f[c], 16]\ ];\ ]\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell["\<\
Now test the example to see if it still works. Use the last case in \
Example 1 given above and compare with the previous results.\
\>", "Text"],

Cell[BoxData[
    \(\(\(RegulaFalsi[1, 2, 30];\)\(\ \)\)\)], "Input"],

Cell[TextData[StyleBox["Reducing the Computational Load for the Regula Falsi \
Method",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
The following program uses fewer computations in the Regula Falsi \
method and is the traditional way to do it.  Can you determine how many fewer \
functional evaluations are used ?\
\>", "Text"],

Cell[BoxData[
    \(\(\(RegulaFalsi[a0_, b0_, 
        m_]\)\(\ \)\(:=\)\(\n\)\(Module[{}, \[IndentingNewLine]a\  = \ 
          N[a0]; \ \[IndentingNewLine]b\  = \ 
          N[b0]; \ \[IndentingNewLine]Ya\  = \ 
          f[a]; \ \[IndentingNewLine]Yb\  = \ 
          f[b]; \ \[IndentingNewLine]c\  = \ \(a\ Yb - b\ Ya\)\/\(Yb - Ya\); \
\ \[IndentingNewLine]Yc\  = \ f[c]; \ \[IndentingNewLine]k\  = \ 
          0; \ \[IndentingNewLine]While[
          k\  < \ m, \[IndentingNewLine]If[\ 
            Sign[Yb]\  \[Equal] \ \ Sign[Yc]\ , \ \[IndentingNewLine]b\  = \ 
              c; \ \[IndentingNewLine]Yb\  = \ 
              Yc, \ \[IndentingNewLine]a\  = \ 
              c; \ \[IndentingNewLine]Ya\  = \ 
              Yc;\ ]; \ \[IndentingNewLine]c\  = \ \(a\ Yb - b\ Ya\)\/\(Yb - \
Ya\); \ \[IndentingNewLine]Yc\  = \ f[c]; \ \[IndentingNewLine]k\  = \ 
            k + 1;\ \ ]; \ \n\ \ Print["\<  c  = \>", 
          NumberForm[c, 11]\ ]; \ \n\ \ Print["\<f[c] = \>", 
          NumberForm[Yc, 11]\ ];\ ]\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Various Scenarios and Animations for ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Regula Falsi Method",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[".",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[
    \(\(\(RegulaFalsi[a0_, b0_, 
        m_]\)\(\ \)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \
\[IndentingNewLine]a\  = \ N[a0]; \ \[IndentingNewLine]b\  = \ 
          N[b0]; \ \[IndentingNewLine]c\  = \ \(a\ f[b]\  - \ b\ \
f[a]\)\/\(f[b] - f[a]\); \ \[IndentingNewLine]k\  = \ 
          0; \ \[IndentingNewLine]output = {{k, a, c, b, 
              f[c]}}; \ \ \[IndentingNewLine]While[
          k\  < \ m, \[IndentingNewLine]If[\ 
            Sign[f[b]]\  \[Equal] \ \ Sign[
                f[c]], \ \[IndentingNewLine]b\  = \ 
              c, \ \(a\  = \ 
                c;\)\ ]; \ \[IndentingNewLine]c\  = \ \(a\ f[b] - b\ f[a]\)\/\
\(f[b] - f[a]\); \ \[IndentingNewLine]k\  = \ 
            k + 1; \ \[IndentingNewLine]output = 
            Append[output, {k, a, c, b, 
                f[c]}];\ ]; \ \[IndentingNewLine]Print[
          NumberForm[
            TableForm[
              output, \[IndentingNewLine]TableHeadings \[Rule] {None, \
{"\<k\>", \*"\"\<\!\(a\_k\)\>\"", \*"\"\<\!\(c\_k\)\>\"", \*"\"\<\!\(b\_k\)\>\
\"", \*"\"\<f[\!\(c\_k\)]\>\""}}], 
            16]\ ]; \ \[IndentingNewLine]Print["\<  c  = \>", 
          NumberForm[c, 16]\ ]; \ \[IndentingNewLine]Print["\<f[c] = \>", 
          NumberForm[f[c], 16]\ ];\ ]\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 3.  ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Convergence",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Find the solution to the cubic equation  ",
  Cell[BoxData[
      \(x\^3 + 4\ x\^2 - 10 = 0\)],
    AspectRatioFixed->False],
  ".  Use the starting interval  ",
  Cell[BoxData[
      \(\([a, b]\) = \([\(-1\), 2]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = x\^3 + 4\ x\^2 - 10;\)\ \), "\[IndentingNewLine]", 
    \(\(a = \(-1.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 2.0;\)\), "\[IndentingNewLine]", 
    \(\(RegulaFalsi[a, b, 15];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-1.05\), 2.05}, 
        PlotRange \[Rule] {{\(-1.05\), 2.05}, {\(-10\), 15}}, 
        PlotStyle \[Rule] Magenta];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " (",
  StyleBox[ButtonBox["Regula Falsi  Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/RootFinding/\
RegulaFalsi/RegulaFalsiaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Regula Falsi  Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/RootFinding/\
RegulaFalsi/RegulaFalsiaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Regula Falsi  Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/RootFinding/\
RegulaFalsi/RegulaFalsi.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Regula Falsi  Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/RootFinding/\
RegulaFalsi/RegulaFalsi.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Regula Falsi Method",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/RegulaFalsiBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Regula Falsi Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/RegulaFalsiBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 176, 4, 35, "Text"],
Cell[1955, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3434, 111, 818, 19, 87, "Text"],
Cell[4255, 132, 2011, 63, 171, "Text"],
Cell[6269, 197, 660, 21, 33, "Text"],
Cell[6932, 220, 646, 20, 33, "Text"],
Cell[7581, 242, 149, 2, 33, "Text"],
Cell[7733, 246, 1305, 25, 386, "Input"],
Cell[9041, 273, 348, 13, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[9414, 290, 101, 2, 33, "Text"],
Cell[9518, 294, 165, 3, 50, "Input"],
Cell[9686, 299, 34, 0, 33, "Text"],
Cell[9723, 301, 273, 5, 70, "Input"],
Cell[9999, 308, 99, 3, 33, "Text"],
Cell[10101, 313, 198, 4, 50, "Input"],
Cell[10302, 319, 100, 3, 33, "Text"],
Cell[10405, 324, 96, 2, 30, "Input"],
Cell[10504, 328, 92, 3, 33, "Text"],
Cell[10599, 333, 168, 3, 50, "Input"],
Cell[10770, 338, 90, 3, 33, "Text"],
Cell[10863, 343, 68, 1, 30, "Input"],
Cell[10934, 346, 51, 0, 33, "Text"],
Cell[10988, 348, 64, 1, 30, "Input"],
Cell[11055, 351, 136, 3, 33, "Text"],
Cell[11194, 356, 80, 1, 30, "Input"],
Cell[11277, 359, 104, 3, 33, "Text"],
Cell[11384, 364, 69, 1, 30, "Input"],
Cell[11456, 367, 138, 5, 33, "Text"],
Cell[11597, 374, 146, 2, 50, "Input"]
}, Closed]],
Cell[11758, 379, 257, 9, 32, "Text"],
Cell[12018, 390, 407, 15, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12450, 409, 101, 2, 33, "Text"],
Cell[12554, 413, 138, 2, 50, "Input"],
Cell[12695, 417, 69, 1, 30, "Input"],
Cell[12767, 420, 142, 5, 33, "Text"],
Cell[12912, 427, 339, 5, 90, "Input"]
}, Closed]],
Cell[13266, 435, 264, 7, 72, "Text"],
Cell[13533, 444, 178, 4, 35, "Text"],
Cell[13714, 450, 851, 15, 306, "Input"],
Cell[14568, 467, 154, 3, 33, "Text"],
Cell[14725, 472, 69, 1, 30, "Input"],
Cell[14797, 475, 203, 5, 35, "Text"],
Cell[15003, 482, 205, 4, 33, "Text"],
Cell[15211, 488, 1068, 19, 442, "Input"],
Cell[16282, 509, 397, 14, 35, "Text"],
Cell[16682, 525, 1309, 25, 386, "Input"],
Cell[17994, 552, 431, 15, 33, "Text"],

Cell[CellGroupData[{
Cell[18450, 571, 101, 2, 33, "Text"],
Cell[18554, 575, 474, 8, 130, "Input"],
Cell[19031, 585, 796, 26, 33, "Text"]
}, Closed]],
Cell[19842, 614, 790, 24, 30, "Text"],
Cell[20635, 640, 158, 3, 35, "Text"],
Cell[20796, 645, 560, 16, 33, "Text"],
Cell[21359, 663, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

