(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27192,        878]*)
(*NotebookOutlinePosition[     28171,        908]*)
(*  CellTagsIndexPosition[     28127,        904]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Muller's Method",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  ButtonBox["Muller\[CloseCurlyQuote]s method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MullersMethod.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" is a generalization of the secant method, in the sense that it \
does not require the derivative of the function. It is an iterative method \
that requires three starting points  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(p\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(f \((p\_0)\)\)}], ")"}]]],
  StyleBox[", ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(p\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(f \((p\_1)\)\)}], ")"}]]],
  StyleBox[", and ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(p\_2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(f \((p\_2)\)\)}], ")"}]]],
  StyleBox[".   A parabola is constructed that passes through the three \
points; then the quadratic formula is used to find a root of the quadratic \
for the next approximation.  It has been proved that near a simple root \
Muller\[CloseCurlyQuote]s method converges faster than the secant method and \
almost as fast as Newton\[CloseCurlyQuote]s method.  The method can be used \
to find real or complex zeros of a function and can be programmed to use \
complex arithmetic. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Muller's Method",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/MullersMethodProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Muller's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/MullersMethodProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Muller's Method",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/MullersMethodProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Muller's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/MullersMethodProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Newton-Raphson Iteration).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[x0_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \[IndentingNewLine]k\
\  = \ 0; \ \[IndentingNewLine]p0\  = \ 
          N[x0]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {16, 16}], \*"\"\<,   f[\!\(p\_0\)] = \>\"", 
          NumberForm[f[p0], 16]\ ]; \ \[IndentingNewLine]p1\  = \ 
          p0; \ \[IndentingNewLine]While[\ 
          k < max, \[IndentingNewLine]p0\  = \ 
            p1; \ \[IndentingNewLine]p1\  = \ 
            p0\  - \ f[p0]\/\(f'\)[p0]; \ \[IndentingNewLine]k\  = \ 
            k + 1; \ \ \[IndentingNewLine]Print["\<p\>"\_k, "\< = \>", 
            PaddedForm[p1, {16, 16}], "\<,   f[\>", "\<p\>"\_k, "\<] = \>", 
            NumberForm[f[p1], 
              16]\ ];\ ]; \ \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p1, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", Abs[p1 - p0]\ ]; \ \[IndentingNewLine]Print["\<f[p] = \>", 
          NumberForm[f[p1], 16]\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[StyleBox["Mathematica Subroutine (Muller's Method).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(Muller[x0_, x1_, x2_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{a, b, c, det, k, 
          Z}, \[IndentingNewLine]p0 = N[x0]; \ \[IndentingNewLine]Y0 = 
          f[p0]; \ \[IndentingNewLine]p1 = N[x1]; \ \[IndentingNewLine]Y1 = 
          f[p1]; \ \[IndentingNewLine]p2 = N[x2]; \ \[IndentingNewLine]Y2 = 
          f[p2]; \ \[IndentingNewLine]k = 
          2; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {16, 16}], \*"\"\<,   f[\!\(p\_0\)] = \>\"", 
          NumberForm[Y0, 
            16]\ ]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_1\) = \>\"", 
          PaddedForm[p1, {16, 16}], \*"\"\<,   f[\!\(p\_1\)] = \>\"", 
          NumberForm[Y1, 
            16]\ ]; \ \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_2\) = \>\"", 
          PaddedForm[p2, {16, 16}], \*"\"\<,   f[\!\(p\_2\)] = \>\"", 
          NumberForm[Y2, 16]\ ]; \ \ \[IndentingNewLine]While[
          k < max, \[IndentingNewLine]h0 = p0 - p2; \ \[IndentingNewLine]h1 = 
            p1 - p2; \ \[IndentingNewLine]c = Y2; \ \[IndentingNewLine]e0 = 
            Y0 - c; \ \[IndentingNewLine]e1 = 
            Y1 - c; \ \[IndentingNewLine]det = 
            h0\ h1\ \((h0 - 
                  h1)\); \ \[IndentingNewLine]a = \(e0\ h1 - h0\ e1\)\/det; \ \
\[IndentingNewLine]b = \(h0\ h0\ e1 - h1\ h1\ e0\)\/det; \ \
\[IndentingNewLine]If[b\ b > 4\ a\ c, disc = \@\(b\ b - 4\ a\ c\), 
            disc = 0]; \ \[IndentingNewLine]If[b < 0, 
            disc = \(-disc\)]; \ \[IndentingNewLine]Z = \(-\(\(2\ c\)\/\(b + 
                    disc\)\)\); \ \[IndentingNewLine]p3 = 
            p2 + Z; \ \[IndentingNewLine]If[Abs[p3 - p1] < Abs[p3 - p0], 
            U = p1; p1 = p0; p0 = U; V = Y1; Y1 = Y0; 
            Y0 = V;]; \ \[IndentingNewLine]If[Abs[p3 - p2] < Abs[p3 - p1], 
            U = p2; p2 = p1; p1 = U; V = Y2; Y2 = Y1; 
            Y1 = V;]; \ \[IndentingNewLine]p2 = p3; \ \[IndentingNewLine]Y2 = 
            f[p2]; \ \[IndentingNewLine]Print["\<p\>"\_\(k + 1\), "\< = \>", 
            PaddedForm[
              p2, {16, 16}], "\<,   f[\>", "\<p\>"\_\(k + 1\), "\<] = \>", 
            NumberForm[Y2, 16]\ ]; \ \[IndentingNewLine]k = 
            k + 1;\ ]; \[IndentingNewLine]Print["\< \>"]; \ \
\[IndentingNewLine]Print["\<The function is f[x] = \>", 
          f[
            x]]; \ \[IndentingNewLine]Print["\<A root of f[x] is:\>"]; \
\[IndentingNewLine]Print["\<  p  = \>", 
          N[p2]]; \ \[IndentingNewLine]Print["\<f[p] = \>", 
          N[Y2]]; \[IndentingNewLine]Print["\<|dp| \[LessEqual] \>", 
          N[Abs[Z]]];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method and Muller's method to find numerical approximations \
to the multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  of the function  ",
  Cell[BoxData[
      \(f[x] = x\^3 - 3\ x + 2\)]],
  ".  \nShow details of the computations for the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1\)]],
  ".  Compare the number of iterations for the two methods."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(f[x_] = x\^3 - 3\ x + 2\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-2.6\), 2.0}, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 2\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[2.0, 8];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve procedure to determine some of the roots."
}], "Text"],

Cell[BoxData[{
    \(\(eqn = f[x] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqn, x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \)}], "Input"],

Cell[TextData[{
  "For Newton's method, how far away is the eighth iteration  ",
  Cell[BoxData[
      \(p\_8\)],
    AspectRatioFixed->False],
  "  from the root  ",
  Cell[BoxData[
      \(p = 1\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_1\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<1-\!\(p\_8\) = \>\"", 1 - p1];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 2.2\)]],
  ", ",
  Cell[BoxData[
      \(p\_0 = 2.1\)]],
  ", and ",
  Cell[BoxData[
      \(p\_2 = 2.0\)]],
  ", use Muller's method to find a numerical approximation to the root. "
}], "Text"],

Cell[BoxData[
    \(\(Muller[2.2, 2.1, 2.0, 10];\)\)], "Input"],

Cell[TextData[{
  "For Muller's method, how far away is the ",
  "eighth",
  " iteration from the root  ",
  Cell[BoxData[
      \(p = 1\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_2\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(Print[\*"\"\<1 - \!\(p\_2\) = \>\"", 1 - p2];\)\)], "Input"],

Cell[TextData[{
  "This is closer than  ",
  Cell[BoxData[
      InterpretationBox[\("1-\!\(p\_8\) = \
"\[InvisibleSpace]\(-0.005094741093277788`\)\),
        SequenceForm[ "1-\!\(p\_8\) = ", -.0050947410932777881],
        Editable->False]]],
  "  which was obtained with Newton's method."
}], "Text"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Compare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in routine."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset = FindRoot[f[x] == 0, {x, 1.2}];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s answer is not so good, need to adjust the number of iterations and the \
working precision."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[f[x] == 0, {x, 1.2}, MaxIterations \[Rule] 50, 
          WorkingPrecision \[Rule] 20];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[f[x] == 0, {x, 1.2}, MaxIterations \[Rule] 50, 
          WorkingPrecision \[Rule] 30];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method and Muller's method to find numerical approximations \
to the multiple root  ",
  Cell[BoxData[
      \(p = \@2\)]],
  "  of the function  ",
  Cell[BoxData[
      \(f[x] = Sin[x\^2 - 2] \((x\^2 - 2)\)\)]],
  ".  \nShow details of the computations for the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1\)]],
  ".  Compare the number of iterations for the two methods."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x\^2 - 2] \((x\^2 - 2)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-1.4\), 2.3}, 
        PlotRange \[Rule] {{\(-1.4\), 2.3}, {0, 2}}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[1.0, 8];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve procedure to determine some of the roots."
}], "Text"],

Cell[BoxData[{
    \(\(eqn = f[x] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqn, x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \)}], "Input"],

Cell[TextData[{
  "For Newton's method, how far away is the ",
  "eighth",
  " iteration  ",
  Cell[BoxData[
      \(p\_8\)],
    AspectRatioFixed->False],
  "  from the root  ",
  Cell[BoxData[
      \(p = \@2\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_1\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(\@2\)-\!\(p\_8\) = \>\"", \@2 - 
          p1];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 0.8\)]],
  ", ",
  Cell[BoxData[
      \(p\_0 = 0.9\)]],
  ", and ",
  Cell[BoxData[
      \(p\_2 = 1.0\)]],
  ", use Muller's method to find a numerical approximation to the root. "
}], "Text"],

Cell[BoxData[
    \(\(Muller[0.8, 0.9, 1.0, 10];\)\)], "Input"],

Cell[TextData[{
  "For Muller's method, how far away is the ",
  "eighth",
  " iteration from the root  ",
  Cell[BoxData[
      \(p = \@2\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_2\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(\@2\) - \!\(p\_2\) = \>\"", \@2 - p2];\)\)], "Input"],

Cell[TextData[{
  "This is closer than  ",
  Cell[BoxData[
      InterpretationBox[\("\!\(\@2\)-\!\(p\_8\) = \
"\[InvisibleSpace]0.0007749324363364174`\),
        SequenceForm[ "\!\(\@2\)-\!\(p\_8\) = ", .0007749324363364174],
        Editable->False]]],
  "  which was obtained with Newton's method."
}], "Text"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Compare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in routine."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset = FindRoot[f[x] == 0, {x, 1.0}];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s answer is not so good, need to adjust the number of iterations and the \
working precision."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[f[x] == 0, {x, 1.0}, MaxIterations \[Rule] 50, 
          WorkingPrecision \[Rule] 20];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[f[x] == 0, {x, 1.0}, MaxIterations \[Rule] 50, 
          WorkingPrecision \[Rule] 30];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method and Muller's method to find numerical approximations \
to the multiple root near  x = 2  of the function  ",
  Cell[BoxData[
      \(f[x] = x\^6 - 7\ x\^4 + 15\ x\^2 - 9\)]],
  ".  \nShow details of the computations for the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.5\)]],
  ".  Compare the number of iterations for the two methods."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        x\^6 - \ 7\ x\^4 + \ 15\ x\^2\  - \ 9;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2.3}, PlotRange \[Rule] {{0, 2.3}, {\(-1\), 2}}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1.5\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[1.5, 8];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve procedure to determine some of the roots."
}], "Text"],

Cell[BoxData[{
    \(\(eqn = f[x] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqn, x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \)}], "Input"],

Cell[TextData[{
  "For Newton's method, how far away is the ",
  "eighth",
  " iteration  ",
  Cell[BoxData[
      \(p\_8\)],
    AspectRatioFixed->False],
  "  from the root  ",
  Cell[BoxData[
      \(p = \@3\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_1\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(\@3\)-\!\(p\_8\) = \>\"", \@3 - 
          p1];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1.3\)]],
  ", ",
  Cell[BoxData[
      \(p\_1 = 1.4\)]],
  ", and ",
  Cell[BoxData[
      \(p\_2 = 1.5\)]],
  ", use Muller's method to find a numerical approximation to the root. "
}], "Text"],

Cell[BoxData[
    \(\(Muller[1.3, 1.4, 1.5, 10];\)\)], "Input"],

Cell[TextData[{
  "For Muller's method, how far away is the ",
  "eighth",
  " iteration from the root  ",
  Cell[BoxData[
      \(p = \@3\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_2\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(\@3\) - \!\(p\_2\) = \>\"", \@3 - p2];\)\)], "Input"],

Cell[TextData[{
  "This is closer than  ",
  Cell[BoxData[
      InterpretationBox[\("\!\(\@3\)-\!\(p\_8\) = \
"\[InvisibleSpace]0.0003667737826091866`\),
        SequenceForm[ "\!\(\@3\)-\!\(p\_8\) = ", .00036677378260918658],
        Editable->False]]],
  "  which was obtained with Newton's method."
}], "Text"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Compare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in routine."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset = FindRoot[f[x] == 0, {x, 1.5}];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s answer is not so good, need to adjust the number of iterations and the \
working precision."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[f[x] == 0, {x, 1.5}, MaxIterations \[Rule] 50, 
          WorkingPrecision \[Rule] 20];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[f[x] == 0, {x, 1.5}, MaxIterations \[Rule] 50, 
          WorkingPrecision \[Rule] 30];\)\), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\n", 
    \(\(Print[solset];\)\), "\n", 
    \(\(Print["\<   p = \>", p];\)\), "\n", 
    \(\(Print["\<f[p] = \>", f[p]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Muller's Method",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/MullersMethodBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Muller's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/MullersMethodBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
SpellingDictionaries->{"CorrectWords"->{
  "Mathews", "Bartlett", "Sudbury", "Tele.", "mkt", "jbpub", "com", "mathews",
     "edu", "westmont", "Raphson", "solset", "Steffensen's", "Steffensen", 
    "Aitken's", "Aitken", "eqn"}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 168, 4, 35, "Text"],
Cell[1947, 59, 1464, 49, 96, "Text"]
}, Closed]],
Cell[3426, 111, 2372, 61, 125, "Text"],
Cell[5801, 174, 609, 20, 33, "Text"],
Cell[6413, 196, 595, 19, 33, "Text"],
Cell[7011, 217, 154, 2, 33, "Text"],
Cell[7168, 221, 1069, 18, 310, "Input"],
Cell[8240, 241, 145, 2, 33, "Text"],
Cell[8388, 245, 2619, 43, 799, "Input"],
Cell[11010, 290, 543, 17, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11578, 311, 101, 2, 33, "Text"],
Cell[11682, 315, 146, 2, 50, "Input"],
Cell[11831, 319, 35, 0, 33, "Text"],
Cell[11869, 321, 243, 4, 70, "Input"],
Cell[12115, 327, 173, 6, 33, "Text"],
Cell[12291, 335, 69, 1, 30, "Input"],
Cell[12363, 338, 151, 5, 33, "Text"],
Cell[12517, 345, 231, 4, 90, "Input"],
Cell[12751, 351, 391, 16, 52, "Text"],
Cell[13145, 369, 90, 1, 30, "Input"],
Cell[13238, 372, 263, 11, 33, "Text"],
Cell[13504, 385, 63, 1, 30, "Input"],
Cell[13570, 388, 331, 14, 52, "Text"],
Cell[13904, 404, 82, 1, 30, "Input"],
Cell[13989, 407, 302, 8, 33, "Text"],
Cell[14294, 417, 349, 14, 71, "Text",
  Evaluatable->False],
Cell[14646, 433, 312, 7, 110, "Input"],
Cell[14961, 442, 226, 7, 33, "Text",
  Evaluatable->False],
Cell[15190, 451, 391, 9, 110, "Input"],
Cell[15584, 462, 391, 9, 110, "Input"]
}, Closed]],
Cell[15990, 474, 558, 17, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[16573, 495, 101, 2, 33, "Text"],
Cell[16677, 499, 147, 2, 51, "Input"],
Cell[16827, 503, 35, 0, 33, "Text"],
Cell[16865, 505, 299, 5, 70, "Input"],
Cell[17167, 512, 173, 6, 33, "Text"],
Cell[17343, 520, 69, 1, 30, "Input"],
Cell[17415, 523, 151, 5, 33, "Text"],
Cell[17569, 530, 231, 4, 90, "Input"],
Cell[17803, 536, 405, 18, 52, "Text"],
Cell[18211, 556, 111, 2, 33, "Input"],
Cell[18325, 560, 263, 11, 33, "Text"],
Cell[18591, 573, 63, 1, 30, "Input"],
Cell[18657, 576, 333, 14, 52, "Text"],
Cell[18993, 592, 92, 1, 33, "Input"],
Cell[19088, 595, 313, 8, 33, "Text"],
Cell[19404, 605, 349, 14, 71, "Text",
  Evaluatable->False],
Cell[19756, 621, 312, 7, 110, "Input"],
Cell[20071, 630, 226, 7, 33, "Text",
  Evaluatable->False],
Cell[20300, 639, 391, 9, 110, "Input"],
Cell[20694, 650, 391, 9, 110, "Input"]
}, Closed]],
Cell[21100, 662, 528, 14, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[21653, 680, 101, 2, 33, "Text"],
Cell[21757, 684, 161, 3, 50, "Input"],
Cell[21921, 689, 35, 0, 33, "Text"],
Cell[21959, 691, 281, 4, 70, "Input"],
Cell[22243, 697, 175, 6, 33, "Text"],
Cell[22421, 705, 69, 1, 30, "Input"],
Cell[22493, 708, 151, 5, 33, "Text"],
Cell[22647, 715, 231, 4, 90, "Input"],
Cell[22881, 721, 405, 18, 52, "Text"],
Cell[23289, 741, 111, 2, 33, "Input"],
Cell[23403, 745, 263, 11, 33, "Text"],
Cell[23669, 758, 63, 1, 30, "Input"],
Cell[23735, 761, 333, 14, 52, "Text"],
Cell[24071, 777, 92, 1, 33, "Input"],
Cell[24166, 780, 314, 8, 33, "Text"],
Cell[24483, 790, 349, 14, 71, "Text",
  Evaluatable->False],
Cell[24835, 806, 312, 7, 110, "Input"],
Cell[25150, 815, 226, 7, 33, "Text",
  Evaluatable->False],
Cell[25379, 824, 391, 9, 110, "Input"],
Cell[25773, 835, 391, 9, 110, "Input"]
}, Closed]],
Cell[26179, 847, 158, 3, 32, "Text"],
Cell[26340, 852, 552, 16, 33, "Text"],
Cell[26895, 870, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

