(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     41947,       1346]*)
(*NotebookOutlinePosition[     42926,       1376]*)
(*  CellTagsIndexPosition[     42882,       1372]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Module for Aitken's ",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(\[CapitalDelta]\^2\)],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" Process and Steffensen's Acceleration Method",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background for Aitken\[CloseCurlyQuote]s Process",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["\n\tWe have seen that Newton\[CloseCurlyQuote]s method converges \
slowly at a multiple root and the sequence of iterates  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({p\_n}\)]],
  StyleBox["  exhibits linear convergence.  A technique called ",
    FontFamily->"Times New Roman"],
  "Aitken's  ",
  Cell[BoxData[
      \(\[CapitalDelta]\^2\)]],
  " process ",
  StyleBox["can be used to speed up convergence of any sequence that is \
linearly convergent.  In order to proceed, we will need a definition.  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Forward Difference).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Given the sequence ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({p\_n}\_\(n = 0\)\%\[Infinity]\)]],
  StyleBox[",  define the forward difference  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\[CapitalDelta]\ p\_n\)]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["by\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\[CapitalDelta]\ p\_n\  = \ p\_\(n + 1\)\  - \ p\_n\)]],
  StyleBox["    for   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(n = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ".  ",
  StyleBox["\n\nHigher powers  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\[CapitalDelta]\^k\ p\_n\)]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["are defined recursively by  \n\n\t",
    FontFamily->"Times New Roman"],
  "\t",
  Cell[BoxData[
      \(\[CapitalDelta]\^k\ p\_n\  = \ \(\[CapitalDelta]\^\(k - 
                1\)\) \((\[CapitalDelta]\ p\_n)\)\)]],
  StyleBox["    for   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(k \[GreaterEqual] 2\)]],
  ".  \n\nWhen  ",
  StyleBox["k=2",
    FontFamily->"Courier New"],
  "  we have the useful formula  ",
  Cell[BoxData[
      \(\[CapitalDelta]\^2\ p\_n\ \  = \ \(\[CapitalDelta] \((\[CapitalDelta]\
\ p\_n)\)\  = \((p\_\(n + 2\)\  - \ 
                p\_\(n - 1\))\)\  - \ \((p\_\(n + 1\)\  - \ p\_n)\)\)\)]],
  "  which simplifies to be:  \n\t\t\n\t",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \)\(\[CapitalDelta]\^2\ p\_n\ \  = \ \ \
p\_\(n + 2\)\  - \ 2  p\_\(n - 1\)\  + \ \ p\_n\)\)\)]],
  StyleBox["    for   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(n = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Aitken\[CloseCurlyQuote]s Acceleration).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that the sequence  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({p\_n}\_\(n = 0\)\%\[Infinity]\)]],
  StyleBox["  converges linearly to the limit ",
    FontFamily->"Times New Roman"],
  StyleBox["p",
    FontFamily->"Courier New"],
  StyleBox[" and that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(p\_n \[NotEqual] p\)]],
  StyleBox["  for all  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(n \[GreaterEqual] 0\)]],
  ".  ",
  StyleBox[" If there exists a real number ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Courier New"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(A\)\(|\)\(\(<\)\(1\)\)\)\)]],
  StyleBox["   such that  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ \(p - p\_\(n + 1\)\)\/\(p - p\_n\)\  \
= \ A\)]],
  StyleBox["  \n\nthen the sequence  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({q\_n}\_\(n = 0\)\%\[Infinity]\)]],
  StyleBox["  defined by  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(q\_n\ \  = \ \ \(p\_n\  - \ \((\[CapitalDelta]p\_n)\)\^2\/\(\(\
\[CapitalDelta]\^2\) p\_n\)\ \  = \ \ p\_n\  - \ \((p\_\(n + 1\)\  - \ \
p\_n)\)\^2\/\(p\_\(n + 2\)\  - \ 2  p\_\(n + 1\)\  + \ p\_n\)\)\)]],
  "  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["converges to ",
    FontFamily->"Times New Roman"],
  StyleBox["p",
    FontFamily->"Courier New"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["faster than  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({p\_n}\_\(n = 0\)\%\[Infinity]\)]],
  StyleBox[",  in the sense that  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(lim\+\(n \[Rule] \[Infinity]\)\ \(\(|\)\(\(p - q\_n\)\/\(p - 
                  p\_n\)\)\(|\)\)\ \  = \ \ 0\)]],
  ".",
  StyleBox["  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Aitken's & Steffensen's acceleration",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/AitkenSteffensenProof.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Aitken's & Steffensen's acceleration",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/AitkenSteffensenProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Steffensen's Acceleration",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["\n\tWhen Aitken's process is combined with the fixed point \
iteration in Newton\[CloseCurlyQuote]s method, the result is called \
Steffensen's acceleration.  Starting with ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(p\_0\)],
    AspectRatioFixed->False],
  StyleBox[", two steps of Newton's method are used to compute  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(p\_1 = p\_0 - \(f \((p\_0)\)\)\/\(f' \((p\_0)\)\)\)],
    AspectRatioFixed->False],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(p\_2 = p\_1 - \(f \((p\_1)\)\)\/\(f' \((p\_1)\)\)\)],
    AspectRatioFixed->False],
  StyleBox[",  then ",
    FontFamily->"Times New Roman"],
  "Aitken's  ",
  Cell[BoxData[
      \(\[CapitalDelta]\^2\)]],
  " process",
  StyleBox[" is used to compute  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(q\_0 = 
        p\_0 - \((\[CapitalDelta]p\_0)\)\^2\/\(\(\[CapitalDelta]\^2\) \
p\_0\)\)]],
  ".   To continue the iteration set ",
  Cell[BoxData[
      \(p\_0 = q\_0\)]],
  " and repeat the previous steps.  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Aitken's & Steffensen's acceleration",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/AitkenSteffensenProof.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Aitken's & Steffensen's acceleration",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/AitkenSteffensenProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Aitken's & Steffensen's acceleration",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/AitkenSteffensenProg.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Aitken's & Steffensen's acceleration",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/AitkenSteffensenProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Newton-Raphson Iteration).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[x0_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \[IndentingNewLine]k\
\  = \ 0; \ \[IndentingNewLine]p0\  = \ 
          N[x0]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {16, 16}], \*"\"\<,   f[\!\(p\_0\)] = \>\"", 
          NumberForm[f[p0], 16]\ ]; \ \[IndentingNewLine]p1\  = \ 
          p0; \ \[IndentingNewLine]While[\ 
          k < max, \[IndentingNewLine]p0\  = \ 
            p1; \ \[IndentingNewLine]p1\  = \ 
            p0\  - \ f[p0]\/\(f'\)[p0]; \ \[IndentingNewLine]k\  = \ 
            k + 1; \ \ \[IndentingNewLine]Print["\<p\>"\_k, "\< = \>", 
            PaddedForm[p1, {16, 16}], "\<,   f[\>", "\<p\>"\_k, "\<] = \>", 
            NumberForm[f[p1], 
              16]\ ];\ ]; \ \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p1, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", Abs[p1 - p0]\ ]; \ \[IndentingNewLine]Print["\<f[p] = \>", 
          NumberForm[f[p1], 16]\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[StyleBox["Mathematica Subroutine (Steffensen's Method).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(Steffensen[x0_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \[IndentingNewLine]p\
\_0\  = \ N[x0]; \ \[IndentingNewLine]p\_3\  = \ 
          p\_0; \ \[IndentingNewLine]k\  = \ 
          0; \ \[IndentingNewLine]Print["\<p\>"\_\(k, 0\), "\< = \>", 
          PaddedForm[
            p\_0, {16, 16}], "\<,   f[\>", "\<p\>"\_\(0, 0\), "\<] = \>", 
          NumberForm[f[p\_0], 16]\ ]; \ \[IndentingNewLine]While[
          k < max, \[IndentingNewLine]p\_0\  = \ 
            p\_3; \ \[IndentingNewLine]p\_1\  = \ 
            p\_0\  - \ 
              f[p\_0]\/\(f'\)[p\_0]; \ \[IndentingNewLine]Print["\<p\>"\_\(k, \
1\), "\< = \>", 
            PaddedForm[
              p\_1, {16, 16}], "\<,   f[\>", "\<p\>"\_\(k, 1\), "\<] = \>", 
            NumberForm[f[p\_1], 16]\ ]; \ \[IndentingNewLine]p\_2\  = \ 
            p\_1\  - \ 
              f[p\_1]\/\(f'\)[p\_1]; \ \[IndentingNewLine]Print["\<p\>"\_\(k, \
2\), "\< = \>", 
            PaddedForm[
              p\_2, {16, 16}], "\<,   f[\>", "\<p\>"\_\(k, 2\), "\<] = \>", 
            NumberForm[f[p\_2], 
              16]\ ]; \ \[IndentingNewLine]Print["\< \>"]; \ \
\[IndentingNewLine]p\_3\  = \ 
            p\_0\  - \ \((p\_1 - p\_0)\)\^2\/\(p\_2\  - \ 2\ p\_1\  + \ \
p\_0\); \ \[IndentingNewLine]Print["\<p\>"\_\(k + 1, 0\), "\< = \>", 
            PaddedForm[
              p\_3, {16, 
                16}], "\<,   f[\>", "\<p\>"\_\(k + 1, 0\), "\<] = \>", 
            NumberForm[f[p\_3]]\ ]; \ \[IndentingNewLine]k\  = \ 
            k + 1;\ ]; \ \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p\_3, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", 
          NumberForm[Abs[p\_3 - p\_2], 
            16]\ ]; \ \[IndentingNewLine]Print["\<f[p] = \>", 
          NumberForm[f[p\_3], 16]\ ];\ \ ]\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Use Newton's method to construct a linearly convergent sequence  ",
  Cell[BoxData[
      \({p\_n}\)]],
  "  which converges slowly to the multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  of  ",
  Cell[BoxData[
      \(f[x] = x\^3 - 3\ x + 2\)]],
  ".  \nThen use the Aitken  ",
  Cell[BoxData[
      \(\[CapitalDelta]\^2\)]],
  " process to construct  ",
  Cell[BoxData[
      \({q\_n}\)]],
  "   which converges faster to the root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 - 3\ x + 2;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-2.6\), 2.0}, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 2\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 - 3\ x + 2;\)\), "\n", 
    \(\(g[x_]\  = \ x\ \  - \ f[x]\/\(f'\)[x];\)\ \), "\[IndentingNewLine]", 
    \(\(m = 15;\)\), "\[IndentingNewLine]", 
    \(\(P = NestList[g, 2.0, m];\)\ \), "\n", 
    \(\(ns = Table[i, {i, 0, m}];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ns, P}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \
\!\(p\_n\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  "Since we know the root is   ",
  Cell[BoxData[
      \(p = \@2\)]],
  ",  we can determine the error for each iteration."
}], "Text"],

Cell[BoxData[{
    \(\(dP = P - 1;\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ns, P, dP}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(p\_n\)\>\"", \
\*"\"\<  \!\(p\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  "Newton's method is converging linearly (or slowly), the error at each step \
is being reduced by approximately one-half.  Let us apply Aitken's \
acceleration process to a sequence  ",
  Cell[BoxData[
      \({p\_n}\)],
    AspectRatioFixed->False],
  "  of iterations generated by Newton's method."
}], "Text"],

Cell[BoxData[{
    \(\(Q\  = \ Table[0, {i, m - 2}];\)\ \), "\[IndentingNewLine]", 
    \(\(For[n = 1, 
        n \[LessEqual] 
          m - 2, \(n++\), \
\[IndentingNewLine]\(Q\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\
\)\)\  = \ 
            P\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\  - \
\((\ P\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\) - \
P\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\))\)\^2\/\(P\_\(\(\
\[LeftDoubleBracket]\)\(n + 2\)\(\[RightDoubleBracket]\)\) - 2  P\_\(\(\
\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\) + P\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\);\)\ ];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(ms = Table[i, {i, 0, m - 3}];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Q}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \
\!\(q\_n\)\>\""}}], 11]];\)\)}], "Input"],

Cell["Again, we can determine the error for each term.", "Text"],

Cell[BoxData[{
    \(\(dQ = Q - 1;\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Q, dQ}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(q\_n\)\>\"", \
\*"\"\<  \!\(q\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  " The sequence  ",
  Cell[BoxData[
      \({q\_n}\)],
    AspectRatioFixed->False],
  "  is converging to  p  faster than the sequence  ",
  Cell[BoxData[
      \({p\_n}\)],
    AspectRatioFixed->False],
  "  converges to  p.  "
}], "Text"],

Cell[BoxData[
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Take[P, m - 2], Take[dP, m - 2], Q, dQ}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(p\_n\)\>\"", \
\*"\"\<  \!\(p\_n\) - \!\(\@2\)\>\"", \*"\"\<  \!\(q\_n\)\>\"", \*"\"\<  \
\!\(q\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method and Steffensen's acceleration method to find \
numerical approximations to the multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  of the function  ",
  Cell[BoxData[
      \(f[x] = x\^3 - 3\ x + 2\)]],
  ".  \nShow details of the computations for the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1\)]],
  ".  Compare the number of iterations for the two methods."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(f[x_] = x\^3 - 3\ x + 2\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-2.6\), 2.0}, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 2\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[2.0, 9];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve procedure to determine some of the roots."
}], "Text"],

Cell[BoxData[{
    \(\(eqn = f[x] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqn, x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \)}], "Input"],

Cell[TextData[{
  "For Newton's method, how far away is the ",
  "ninth",
  " iteration  ",
  Cell[BoxData[
      \(p\_9\)],
    AspectRatioFixed->False],
  "  from the root  ",
  Cell[BoxData[
      \(p = 1\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_1\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<1-\!\(p\_9\) = \>\"", 1 - p1];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 2\)]],
  ", use Steffensen's acceleration method to find a numerical approximation \
to the root. "
}], "Text"],

Cell[BoxData[
    \(\(\(Steffensen[2.0, 3];\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "For Steffensen's acceleration method, how far away is the ",
  "ninth",
  " iteration from the root  ",
  Cell[BoxData[
      \(p = 1\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_3\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(Print[\*"\"\<1 - \!\(p\_3\) = \>\"", 1 - p\_3];\)\)], "Input"],

Cell[TextData[{
  "This is closer than   ",
  Cell[BoxData[
      InterpretationBox[\("1-\!\(p\_9\) = \
"\[InvisibleSpace]\(-0.0025495280828193856`\)\),
        SequenceForm[ "1-\!\(p\_9\) = ", -.0025495280828193856],
        Editable->False]]],
  "  which was obtained with Newton's method."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method to construct a linearly convergent sequence  ",
  Cell[BoxData[
      \({p\_n}\)]],
  "  which converges slowly to the multiple root  ",
  Cell[BoxData[
      \(p = \@2\)]],
  "  of  ",
  Cell[BoxData[
      \(f[x] = Sin[x\^2 - 2] \((x\^2 - 2)\)\)]],
  ".  \nThen use the Aitken  ",
  Cell[BoxData[
      \(\[CapitalDelta]\^2\)]],
  " process to construct  ",
  Cell[BoxData[
      \({q\_n}\)]],
  "   which converges faster to the root  ",
  Cell[BoxData[
      \(p = \@2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x\^2 - 2] \((x\^2 - 2)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-1.4\), 2.3}, 
        PlotRange \[Rule] {{\(-1.4\), 2.3}, {0, 2}}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x\^2 - 2] \((x\^2 - 2)\);\)\ \), "\n", 
    \(\(g[x_]\  = \ x\ \  - \ f[x]\/\(f'\)[x];\)\ \), "\[IndentingNewLine]", 
    \(\(m = 15;\)\), "\[IndentingNewLine]", 
    \(\(P = NestList[g, 1.0, m];\)\ \), "\n", 
    \(\(ns = Table[i, {i, 0, m}];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ns, P}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \
\!\(p\_n\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  "Since we know the root is   ",
  Cell[BoxData[
      \(p = \@2\)]],
  ",  we can determine the error for each iteration."
}], "Text"],

Cell[BoxData[{
    \(\(dP = P - \@2;\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ns, P, dP}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(p\_n\)\>\"", \
\*"\"\<  \!\(p\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  "Newton's method is converging linearly (or slowly), the error at each step \
is being reduced by approximately one-half.  Let us apply Aitken's \
acceleration process to a sequence  ",
  Cell[BoxData[
      \({p\_n}\)],
    AspectRatioFixed->False],
  "  of iterations generated by Newton's method."
}], "Text"],

Cell[BoxData[{
    \(\(Q\  = \ Table[0, {i, m - 2}];\)\ \), "\[IndentingNewLine]", 
    \(\(For[n = 1, 
        n \[LessEqual] 
          m - 2, \(n++\), \
\[IndentingNewLine]\(Q\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\
\)\)\  = \ 
            P\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\  - \
\((\ P\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\) - \
P\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\))\)\^2\/\(P\_\(\(\
\[LeftDoubleBracket]\)\(n + 2\)\(\[RightDoubleBracket]\)\) - 2  P\_\(\(\
\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\) + P\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\);\)\ ];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(ms = Table[i, {i, 0, m - 3}];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Q}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \
\!\(q\_n\)\>\""}}], 11]];\)\)}], "Input"],

Cell["Again, we can determine the error for each term.", "Text"],

Cell[BoxData[{
    \(\(dQ = Q - \@2;\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Q, dQ}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(q\_n\)\>\"", \
\*"\"\<  \!\(q\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  " The sequence  ",
  Cell[BoxData[
      \({q\_n}\)],
    AspectRatioFixed->False],
  "  is converging to  p  faster than the sequence  ",
  Cell[BoxData[
      \({p\_n}\)],
    AspectRatioFixed->False],
  "  converges to  p.  "
}], "Text"],

Cell[BoxData[
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Take[P, m - 2], Take[dP, m - 2], Q, dQ}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(p\_n\)\>\"", \
\*"\"\<  \!\(p\_n\) - \!\(\@2\)\>\"", \*"\"\<  \!\(q\_n\)\>\"", \*"\"\<  \
\!\(q\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method and Steffensen's acceleration method to find \
numerical approximations to the multiple root  ",
  Cell[BoxData[
      \(p = \@2\)]],
  "  of the function  ",
  Cell[BoxData[
      \(f[x] = Sin[x\^2 - 2] \((x\^2 - 2)\)\)]],
  ".  \nShow details of the computations for the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1\)]],
  ".  Compare the number of iterations for the two methods."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x\^2 - 2] \((x\^2 - 2)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-1.4\), 2.3}, 
        PlotRange \[Rule] {{\(-1.4\), 2.3}, {0, 2}}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[1.0, 9];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve procedure to determine some of the roots."
}], "Text"],

Cell[BoxData[{
    \(\(eqn = f[x] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqn, x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \)}], "Input"],

Cell[TextData[{
  "For Newton's method, how far away is the ",
  "ninth",
  " iteration  ",
  Cell[BoxData[
      \(p\_9\)],
    AspectRatioFixed->False],
  "  from the root  ",
  Cell[BoxData[
      \(p = \@2\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_1\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(\@2\)-\!\(p\_9\) = \>\"", \@2 - 
          p1];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1\)]],
  ", use Steffensen's acceleration method to find a numerical approximation \
to the root. "
}], "Text"],

Cell[BoxData[
    \(\(\(Steffensen[1.0, 3];\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "For Steffensen's acceleration method, how far away is the ",
  "ninth",
  " iteration from the root  ",
  Cell[BoxData[
      \(p = \@2\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_3\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(\@2\) - \!\(p\_3\) = \>\"", \@2 - 
          p\_3];\)\)], "Input"],

Cell[TextData[{
  "This is closer than   ",
  Cell[BoxData[
      InterpretationBox[\("\!\(\@2\)-\!\(p\_10\) = \
"\[InvisibleSpace]0.00038735969181824537`\),
        SequenceForm[ "\!\(\@2\)-\!\(p\_10\) = ", .00038735969181824537],
        Editable->False]]],
  "  which was obtained with Newton's method."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method to construct a linearly convergent sequence  ",
  Cell[BoxData[
      \({p\_n}\)]],
  "  which converges slowly to the multiple root  ",
  Cell[BoxData[
      \(p = \@3\)]],
  "  of  ",
  Cell[BoxData[
      \(f[x] = x\^6 - 7\ x\^4 + 15\ x\^2 - 9\)]],
  ".  \nThen use the Aitken  ",
  Cell[BoxData[
      \(\[CapitalDelta]\^2\)]],
  " process to construct  ",
  Cell[BoxData[
      \({q\_n}\)]],
  "   which converges faster to the root  ",
  Cell[BoxData[
      \(p = \@3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        x\^6 - \ 7\ x\^4 + \ 15\ x\^2\  - \ 9;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2.3}, PlotRange \[Rule] {{0, 2.3}, {\(-1\), 2}}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1.5\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^6 - \ 7\ x\^4 + \ 15\ x\^2\  - \ 9;\)\ \), "\n", 
    \(\(g[x_]\  = \ x\ \  - \ f[x]\/\(f'\)[x];\)\ \), "\[IndentingNewLine]", 
    \(\(m = 15;\)\), "\[IndentingNewLine]", 
    \(\(P = NestList[g, 1.5, m];\)\ \), "\n", 
    \(\(ns = Table[i, {i, 0, m}];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ns, P}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \
\!\(p\_n\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  "Since we know the root is   ",
  Cell[BoxData[
      \(p = \@2\)]],
  ",  we can determine the error for each iteration."
}], "Text"],

Cell[BoxData[{
    \(\(dP = P - \@3;\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ns, P, dP}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(p\_n\)\>\"", \
\*"\"\<  \!\(p\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  "Newton's method is converging linearly (or slowly), the error at each step \
is being reduced by approximately one-half.  Let us apply Aitken's \
acceleration process to a sequence  ",
  Cell[BoxData[
      \({p\_n}\)],
    AspectRatioFixed->False],
  "  of iterations generated by Newton's method."
}], "Text"],

Cell[BoxData[{
    \(\(Q\  = \ Table[0, {i, m - 2}];\)\ \), "\[IndentingNewLine]", 
    \(\(For[n = 1, 
        n \[LessEqual] 
          m - 2, \(n++\), \
\[IndentingNewLine]\(Q\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\
\)\)\  = \ 
            P\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\  - \
\((\ P\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\) - \
P\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\))\)\^2\/\(P\_\(\(\
\[LeftDoubleBracket]\)\(n + 2\)\(\[RightDoubleBracket]\)\) - 2  P\_\(\(\
\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\) + P\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\);\)\ ];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(ms = Table[i, {i, 0, m - 3}];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Q}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \
\!\(q\_n\)\>\""}}], 11]];\)\)}], "Input"],

Cell["Again, we can determine the error for each term.", "Text"],

Cell[BoxData[{
    \(\(dQ = Q - \@3;\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Q, dQ}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(q\_n\)\>\"", \
\*"\"\<  \!\(q\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)}], "Input"],

Cell[TextData[{
  " The sequence  ",
  Cell[BoxData[
      \({q\_n}\)],
    AspectRatioFixed->False],
  "  is converging to  p  faster than the sequence  ",
  Cell[BoxData[
      \({p\_n}\)],
    AspectRatioFixed->False],
  "  converges to  p.  "
}], "Text"],

Cell[BoxData[
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{ms, Take[P, m - 2], Take[dP, m - 2], Q, dQ}], 
            TableHeadings \[Rule] {None, {"\< \>", \*"\"\<  \!\(p\_n\)\>\"", \
\*"\"\<  \!\(p\_n\) - \!\(\@2\)\>\"", \*"\"\<  \!\(q\_n\)\>\"", \*"\"\<  \
\!\(q\_n\) - \!\(\@2\)\>\""}}], 11]];\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method and Steffensen's acceleration method to find \
numerical approximations to the multiple root near  x = 2  of the function  \
",
  Cell[BoxData[
      \(f[x] = x\^6 - 7\ x\^4 + 15\ x\^2 - 9\)]],
  ".  \nShow details of the computations for the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.5\)]],
  ".  Compare the number of iterations for the two methods."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        x\^6 - \ 7\ x\^4 + \ 15\ x\^2\  - \ 9;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2.3}, PlotRange \[Rule] {{0, 2.3}, {\(-1\), 2}}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1.5\)]],
  ", use the Newton-Raphson method to find a numerical approximation to the \
root. "
}], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[1.5, 9];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve procedure to determine some of the roots."
}], "Text"],

Cell[BoxData[{
    \(\(eqn = f[x] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqn, x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \)}], "Input"],

Cell[TextData[{
  "For Newton's method, how far away is the ",
  "ninth",
  " iteration  ",
  Cell[BoxData[
      \(p\_9\)],
    AspectRatioFixed->False],
  "  from the root  ",
  Cell[BoxData[
      \(p = \@3\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_1\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(Print[\*"\"\<\!\(\@3\)-\!\(p\_9\) = \>\"", \@3 - 
          p1];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  " Starting with  ",
  Cell[BoxData[
      \(p\_0 = 1.5\)]],
  ", use Steffensen's acceleration method to find a numerical approximation \
to the root. "
}], "Text"],

Cell[BoxData[
    \(\(\(Steffensen[1.5, 3];\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "For Steffensen's acceleration method, how far away is the ",
  "ninth",
  " iteration from the root  ",
  Cell[BoxData[
      \(p = \@3\)]],
  " ?\n",
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The last iteration is actually stored in  ",
  Cell[BoxData[
      \(p\_3\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(\@3\) - \!\(p\_3\) = \>\"", \@3 - 
          p\_3];\)\)], "Input"],

Cell[TextData[{
  "This is closer than  ",
  Cell[BoxData[
      InterpretationBox[\("\!\(\@3\)-\!\(p\_10\) = \
"\[InvisibleSpace]0.00018330916491215987`\),
        SequenceForm[ "\!\(\@3\)-\!\(p\_10\) = ", .00018330916491215987],
        Editable->False]]],
  "  which was obtained with Newton's method."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Aitken's Method and Steffensen's Acceleration",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/AitkenSteffensenBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Aitken's Method and Steffensen's Acceleration",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/AitkenSteffensenBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
SpellingDictionaries->{"CorrectWords"->{
  "Mathews", "Bartlett", "Sudbury", "Tele.", "mkt", "jbpub", "com", "mathews",
     "edu", "westmont", "Raphson", "solset", "Steffensen's", "Steffensen", 
    "Aitken's", "Aitken", "eqn"}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 475, 16, 35, "Text"],
Cell[2254, 71, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3733, 123, 835, 22, 87, "Text"],
Cell[4571, 147, 3295, 99, 223, "Text"],
Cell[7869, 248, 2361, 73, 262, "Text"],
Cell[10233, 323, 670, 22, 33, "Text"],
Cell[10906, 347, 1364, 42, 136, "Text"],
Cell[12273, 391, 670, 22, 33, "Text"],
Cell[12946, 415, 656, 21, 33, "Text"],
Cell[13605, 438, 154, 2, 33, "Text"],
Cell[13762, 442, 1069, 18, 310, "Input"],
Cell[14834, 462, 149, 2, 33, "Text"],
Cell[14986, 466, 1907, 38, 450, "Input"],
Cell[16896, 506, 654, 25, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[17575, 535, 101, 2, 33, "Text"],
Cell[17679, 539, 132, 2, 50, "Input"],
Cell[17814, 543, 35, 0, 33, "Text"],
Cell[17852, 545, 243, 4, 70, "Input"],
Cell[18098, 551, 173, 6, 33, "Text"],
Cell[18274, 559, 472, 10, 146, "Input"],
Cell[18749, 571, 152, 5, 33, "Text"],
Cell[18904, 578, 285, 6, 53, "Input"],
Cell[19192, 586, 330, 8, 33, "Text"],
Cell[19525, 596, 971, 19, 135, "Input"],
Cell[20499, 617, 64, 0, 33, "Text"],
Cell[20566, 619, 285, 6, 53, "Input"],
Cell[20854, 627, 258, 10, 33, "Text"],
Cell[21115, 639, 333, 6, 33, "Input"]
}, Closed]],
Cell[21463, 648, 560, 17, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22048, 669, 101, 2, 33, "Text"],
Cell[22152, 673, 146, 2, 50, "Input"],
Cell[22301, 677, 35, 0, 33, "Text"],
Cell[22339, 679, 243, 4, 70, "Input"],
Cell[22585, 685, 173, 6, 33, "Text"],
Cell[22761, 693, 69, 1, 30, "Input"],
Cell[22833, 696, 151, 5, 33, "Text"],
Cell[22987, 703, 231, 4, 90, "Input"],
Cell[23221, 709, 402, 18, 52, "Text"],
Cell[23626, 729, 90, 1, 30, "Input"],
Cell[23719, 732, 180, 6, 33, "Text"],
Cell[23902, 740, 68, 1, 30, "Input"],
Cell[23973, 743, 347, 14, 52, "Text"],
Cell[24323, 759, 84, 1, 30, "Input"],
Cell[24410, 762, 304, 8, 33, "Text"]
}, Closed]],
Cell[24729, 773, 670, 25, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[25424, 802, 101, 2, 33, "Text"],
Cell[25528, 806, 147, 2, 51, "Input"],
Cell[25678, 810, 35, 0, 33, "Text"],
Cell[25716, 812, 299, 5, 70, "Input"],
Cell[26018, 819, 173, 6, 33, "Text"],
Cell[26194, 827, 487, 10, 147, "Input"],
Cell[26684, 839, 152, 5, 33, "Text"],
Cell[26839, 846, 287, 6, 55, "Input"],
Cell[27129, 854, 330, 8, 52, "Text"],
Cell[27462, 864, 971, 19, 135, "Input"],
Cell[28436, 885, 64, 0, 33, "Text"],
Cell[28503, 887, 287, 6, 55, "Input"],
Cell[28793, 895, 258, 10, 33, "Text"],
Cell[29054, 907, 333, 6, 54, "Input"]
}, Closed]],
Cell[29402, 916, 575, 17, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[30002, 937, 101, 2, 33, "Text"],
Cell[30106, 941, 147, 2, 51, "Input"],
Cell[30256, 945, 35, 0, 33, "Text"],
Cell[30294, 947, 299, 5, 70, "Input"],
Cell[30596, 954, 173, 6, 33, "Text"],
Cell[30772, 962, 69, 1, 30, "Input"],
Cell[30844, 965, 151, 5, 33, "Text"],
Cell[30998, 972, 231, 4, 90, "Input"],
Cell[31232, 978, 404, 18, 52, "Text"],
Cell[31639, 998, 111, 2, 33, "Input"],
Cell[31753, 1002, 180, 6, 33, "Text"],
Cell[31936, 1010, 68, 1, 30, "Input"],
Cell[32007, 1013, 349, 14, 52, "Text"],
Cell[32359, 1029, 105, 2, 33, "Input"],
Cell[32467, 1033, 318, 8, 33, "Text"]
}, Closed]],
Cell[32800, 1044, 671, 25, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[33496, 1073, 101, 2, 33, "Text"],
Cell[33600, 1077, 161, 3, 50, "Input"],
Cell[33764, 1082, 35, 0, 33, "Text"],
Cell[33802, 1084, 281, 4, 70, "Input"],
Cell[34086, 1090, 175, 6, 33, "Text"],
Cell[34264, 1098, 496, 10, 146, "Input"],
Cell[34763, 1110, 152, 5, 33, "Text"],
Cell[34918, 1117, 287, 6, 55, "Input"],
Cell[35208, 1125, 330, 8, 33, "Text"],
Cell[35541, 1135, 971, 19, 135, "Input"],
Cell[36515, 1156, 64, 0, 33, "Text"],
Cell[36582, 1158, 287, 6, 55, "Input"],
Cell[36872, 1166, 258, 10, 33, "Text"],
Cell[37133, 1178, 333, 6, 33, "Input"]
}, Closed]],
Cell[37481, 1187, 547, 15, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[38053, 1206, 101, 2, 33, "Text"],
Cell[38157, 1210, 161, 3, 50, "Input"],
Cell[38321, 1215, 35, 0, 33, "Text"],
Cell[38359, 1217, 281, 4, 70, "Input"],
Cell[38643, 1223, 175, 6, 33, "Text"],
Cell[38821, 1231, 69, 1, 30, "Input"],
Cell[38893, 1234, 151, 5, 33, "Text"],
Cell[39047, 1241, 231, 4, 90, "Input"],
Cell[39281, 1247, 404, 18, 52, "Text"],
Cell[39688, 1267, 111, 2, 33, "Input"],
Cell[39802, 1271, 182, 6, 33, "Text"],
Cell[39987, 1279, 68, 1, 30, "Input"],
Cell[40058, 1282, 349, 14, 52, "Text"],
Cell[40410, 1298, 105, 2, 33, "Input"],
Cell[40518, 1302, 317, 8, 33, "Text"]
}, Closed]],
Cell[40850, 1313, 158, 3, 32, "Text"],
Cell[41011, 1318, 636, 18, 33, "Text"],
Cell[41650, 1338, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

