(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     73137,       2350]*)
(*NotebookOutlinePosition[     74052,       2379]*)
(*  CellTagsIndexPosition[     74008,       2375]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Accelerated and Modified Newton \
Methods",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["\tNewton's method is commonly used to find the root of an \
equation.  If the root is simple then the extension to Halley's method will \
increase the order of convergence from quadratic to cubic.  At a multiple \
root it can be speed up with the accelerated Newton-Raphson and modified \
Newton-Raphson methods.  ",
    FontFamily->"Times New Roman"],
  "\n\t\n",
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Newton-Raphson Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NewtonsMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that ",
  Cell[BoxData[
      RowBox[{"f", "\[Element]", 
        RowBox[{
          StyleBox[\(C\^2\),
            FontWeight->"Bold"], "[", \(a, b\), "]"}]}]]],
  " and there exists a number ",
  Cell[BoxData[
      \(p \[Element] \([a, b]\)\)]],
  ", where ",
  Cell[BoxData[
      \(f \((p)\) = 0\)]],
  ".  If   ",
  Cell[BoxData[
      \(f' \((p)\) \[NotEqual] 0\)]],
  ", then there exists a ",
  Cell[BoxData[
      \(\[Delta] > 0\)]],
  " such that the sequence ",
  Cell[BoxData[
      \({p\_k}\_\(k = 0\)\%\[Infinity]\)]],
  " defined by the iteration  \n\n\t",
  Cell[BoxData[
      RowBox[{\(p\_\(k + 1\)\), " ", "=", " ", 
        RowBox[{\(g \((p\_k)\)\), " ", "=", "  ", 
          RowBox[{\(p\_k\), " ", "-", 
            StyleBox[
              FractionBox[
                StyleBox[\(f \((p\_k)\)\),
                  FontSize->12], 
                StyleBox[\(f' \((p\_k)\)\),
                  FontSize->12]],
              FontSize->12]}]}]}]]],
  "    for    ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  "  \n\nwill converge to ",
  Cell[BoxData[
      \(p\)]],
  " for any initial approximation  ",
  Cell[BoxData[
      \(p\_0 \[Element] \([p - \[Delta], p + \[Delta]]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Newton-Raphson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Newton'sMethodProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Newton-Raphson Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/Newton'sMethodProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Order of a Root)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  f(x)  and its derivatives  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(f' \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(f\^\((m)\)\) \((x)\)\)}]]],
  "  ",
  StyleBox["are defined and continuous on an interval about  x = p.  We say \
that  f(x) = 0  has a root of order  ",
    FontFamily->"Times New Roman"],
  "m",
  StyleBox["  at   x = p  if and only if  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(f \((p)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(f' \((p)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(f'' \((p)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(f\^\((m - 1)\)\) \((p)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(f\^\((m)\)\) \((p)\) \[NotEqual] 
          0\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["A root of order  ",
    FontFamily->"Times New Roman"],
  "m",
  StyleBox[" = 1  is often called a ",
    FontFamily->"Times New Roman"],
  StyleBox["simple root",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", and if  ",
    FontFamily->"Times New Roman"],
  "m",
  StyleBox[" > 1  it is called a ",
    FontFamily->"Times New Roman"],
  StyleBox["multiple root",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  A root of order  ",
    FontFamily->"Times New Roman"],
  "m",
  StyleBox[" = 2  is sometimes called a ",
    FontFamily->"Times New Roman"],
  StyleBox["double root",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", and so on.  The next result will illuminate these concepts.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Order of Convergence)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(p\_n\)]],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["converges to  p,  and set  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(E\_n\  = \ p\  - \ p\_n\ \ for\ \ n \[GreaterEqual] 0\)]],
  StyleBox[".    If two positive constants  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(A \[NotEqual] 0\ \ and\ \ R > 0\)]],
  StyleBox["  exist, and  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(lim\+\(n\  \[Rule] \ \[Infinity]\)\ \(\(|\)\(p\  - \ p\_\(n + 1\)\
\)\(|\)\)\/\(\(|\)\(p\  - \ p\_n\)\( | \^R\)\) = \ \(lim\+\(n\  \[Rule] \ \
\[Infinity]\)\ \(\(|\)\(E\_\(n + 1\)\)\(|\)\)\/\(\(|\)\(E\_n\)\( | \^R\)\)\  \
= \ A\)\)\(,\)\)\)]],
  "\n",
  StyleBox["\nthen the sequence is said to converge to  p  with ",
    FontFamily->"Times New Roman"],
  StyleBox["order of convergence R",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  The number  A  is called the ",
    FontFamily->"Times New Roman"],
  StyleBox["asymptotic error constant",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  The cases  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(R = 1, 2\)]],
  StyleBox["  are given special  consideration.\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["(i)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(R = 1\)]],
  StyleBox[", the convergence of  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({p\_k}\_\(k = 0\)\%\[Infinity]\)]],
  StyleBox["  is called ",
    FontFamily->"Times New Roman"],
  StyleBox["linear",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["(ii)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(R = 2\)]],
  StyleBox[", the convergence of  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({p\_k}\_\(k = 0\)\%\[Infinity]\)]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["is called ",
    FontFamily->"Times New Roman"],
  StyleBox["quadratic",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Convergence Rate for Newton-Raphson Iteration)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that Newton-Raphson iteration produces a sequence  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({p\_k}\_\(k = 0\)\%\[Infinity]\)]],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["that converges to the root  p  of the function",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  ".  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox["If  p  is a simple root, then convergence is quadratic and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 
              1\)\)\(|\)\(\ \)\(\(\[TildeTilde]\)\(\ \)\(\(\(\(|\)\(f'' \((p)\
\)\)\(|\)\)\/\(2 | f' \((p)\) | \)\) \((\(|\)\(E\_k\)\(|\))\)\^2\)\)\)\)]],
  "  for  k  ",
  StyleBox["sufficiently large. \n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox["If  p  is a multiple root of order  ",
    FontFamily->"Times New Roman"],
  "m",
  StyleBox[",  then convergence is linear and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 
              1\)\)\(|\)\(\ \)\(\(\[TildeTilde]\)\(\ \)\(\(m - 
                1\)\/m\)\)\(|\)\(E\_k\)\(|\)\)\)]],
  "  ",
  StyleBox["for  k  sufficiently large.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Newton-Raphson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Newton'sMethodProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Newton-Raphson Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/Newton'sMethodProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Newton-Raphson Iteration",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To find ",
    FontFamily->"New Century Schlbk"],
  "a root of  ",
  Cell[BoxData[
      \(f \((x)\) = 0\)]],
  "  given an initial approximation  ",
  Cell[BoxData[
      \(p\_\(\(0\)\(\ \)\)\)]],
  "  using the iteration  \n\n\t",
  Cell[BoxData[
      RowBox[{\(p\_\(k + 1\)\), " ", "=", " ", 
        RowBox[{\(p\_k\), "-", 
          StyleBox[
            FractionBox[
              StyleBox[\(f \((p\_k)\)\),
                FontSize->12], 
              StyleBox[\(f' \((p\_k)\)\),
                FontSize->12]],
            FontSize->12]}]}]]],
  "   for    ",
  Cell[BoxData[
      \(\(\(k\  = \ 
        0\)\(,\)\(1\)\(,\)\(\[CenterEllipsis]\)\(\ \)\(,\)\(m\)\(\ \)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Newton-Raphson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Newton'sMethodProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Newton-Raphson Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Newton'sMethodProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Newton-Raphson Iteration).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[x0_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \[IndentingNewLine]k\
\  = \ 0; \ \[IndentingNewLine]p0\  = \ 
          N[x0]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {16, 16}], \*"\"\<,   f[\!\(p\_0\)] = \>\"", 
          NumberForm[f[p0], 16]\ ]; \ \[IndentingNewLine]p1\  = \ 
          p0; \ \[IndentingNewLine]While[\ 
          k < max, \[IndentingNewLine]p0\  = \ 
            p1; \ \[IndentingNewLine]p1\  = \ 
            p0\  - \ f[p0]\/\(f'\)[p0]; \ \[IndentingNewLine]k\  = \ 
            k + 1; \ \ \[IndentingNewLine]Print["\<p\>"\_k, "\< = \>", 
            PaddedForm[p1, {16, 16}], "\<,   f[\>", "\<p\>"\_k, "\<] = \>", 
            NumberForm[f[p1], 
              16]\ ];\ ]; \ \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p1, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", Abs[p1 - p0]\ ]; \ \[IndentingNewLine]Print["\<f[p] = \>", 
          NumberForm[f[p1], 16]\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method to find the roots of the cubic polynomial  ",
  Cell[BoxData[
      \(f \((x)\)\  = \ x\^3 - 3\ x + 2\)],
    AspectRatioFixed->False],
  ".  \n",
  StyleBox["1 (a) Fast Convergence.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Investigate quadratic convergence at the simple root  ",
  Cell[BoxData[
      \(p = \(-2\)\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = \(-2.4\)\)]],
  "\n",
  StyleBox["1 (b) Slow Convergence.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Investigate linear convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 - 3\ x + 2;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-3\), 3}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-3\), \(-1\)}, 
        PlotRange \[Rule] {{\(-3\), \(-1\)}, {\(-10\), 5}}, 
        Ticks \[Rule] {Range[\(-3\), \(-1\), 1], Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[" The Newton-Raphson iteration formula  g[x]  is", "Text"],

Cell[BoxData[{
    \(\(g[x_]\  = \ x - f[x]\/\(f'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate quadratic convergence at the simple root  ",
  Cell[BoxData[
      \(p = \(-2\)\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = \(-2.4\)\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = \(-2.4\)\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell[BoxData[
    \(p4 = g[p3]\)], "Input"],

Cell[BoxData[
    \(p5 = g[p4]\)], "Input"],

Cell[BoxData[
    \(p6 = g[p5]\)], "Input"],

Cell[TextData[{
  "Notice that convergence is fast and the sequence is converging to the \
simple root  ",
  Cell[BoxData[
      \(p = \(-2\)\)]],
  "  "
}], "Text"],

Cell[BoxData[
    \(\(NewtonRaphson[\(-2.4\), 7];\)\)], "Input"],

Cell[TextData[{
  "At the simple root  ",
  Cell[BoxData[
      \(p = \(-2\)\)]],
  "  we can explore the relationship",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 
              1\)\)\(|\)\(\ \)\(\(\[TildeTilde]\)\(\ \)\(\(\(\(|\)\(f'' \((p)\
\)\)\(|\)\)\/\(2 | f' \((p)\) | \)\) \((\(|\)\(E\_k\)\(|\))\)\^2\)\)\)\)]],
  "  for  k  ",
  StyleBox["sufficiently large. ",
    FontFamily->"Times New Roman"],
  " \n\nThis will be done by investigating the ratio",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\  \
\[TildeTilde] \ \(\(|\)\(f'' \((p)\)\)\(|\)\)\/\(2 | f' \((p)\) | \)\)]],
  "  for  k  ",
  StyleBox["sufficiently large. ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 4;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, \(-2.4\), Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = \(-2\) - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell[TextData[{
  "Evaluate the quantity  ",
  Cell[BoxData[
      \(\(\(|\)\(f'' \((p)\)\)\(|\)\)\/\(2 | f' \((p)\) | \)\)]],
  " at the root  ",
  Cell[BoxData[
      \(p = \(-2\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(\(\(|\)\(\(f''\)[\(-2\)]\)\(|\)\)\/\(2 | \(f'\)[\(-2\
\)] | \)\) = \>\"", 
        Abs[\(f''\)[\(-2\)]]\/\(2  Abs[\(f'\)[\(-2\)]]\)];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\(\(|\)\(\(f''\)[\(-2\)]\)\(|\)\)\/\(2 | \(f'\)[\(-2\
\)] | \)\) = \>\"", 
        N[Abs[\(f''\)[\(-2\)]]\/\(2  Abs[\(f'\)[\(-2\)]]\)]];\)\)}], "Input"],

Cell[TextData[{
  "Which is close to the computed value  ",
  Cell[BoxData[
      \(\(\(|\)\(E\_3\)\(|\)\)\/\((\(|\)\(E\_3\)\(|\))\)\^2\  = \ 
        0.666654809469126\)]],
  "  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 - 3\ x + 2;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-3\), 3}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2}, {0, 5}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-10\), 10, 1]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[" The Newton-Raphson iteration formula  g[x]  is", "Text"],

Cell[BoxData[{
    \(\(g[x_]\  = \ x - f[x]\/\(f'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate linear convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 1.2\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell[BoxData[
    \(p4 = g[p3]\)], "Input"],

Cell[BoxData[
    \(p5 = g[p4]\)], "Input"],

Cell[BoxData[
    \(p6 = g[p5]\)], "Input"],

Cell[TextData[{
  "Notice that convergence is slow, but the sequence is converging to  the \
double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  "
}], "Text"],

Cell[BoxData[
    \(\(NewtonRaphson[1.2, 25];\)\)], "Input"],

Cell[TextData[{
  "At the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  we can explore the relationship",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 
              1\)\)\(|\)\(\ \)\(\(\[TildeTilde]\)\(\ \
\)\(1\/2\)\)\(|\)\(E\_k\)\(|\)\)\)]],
  "  for  k  ",
  StyleBox["sufficiently large. ",
    FontFamily->"Times New Roman"],
  " \n\nThis will be done by investigating the ratio",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\(\(|\)\(E\_k\)\(|\)\)\  \
\[TildeTilde] \ 1\/2\)]],
  "  for  k  ",
  StyleBox["sufficiently large. ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 24;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 1.2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 1 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Abs[Ek], Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\(\(|\)\(E\_k\)\(|\)\)\)\>\""}}, TableSpacing \[Rule] {3, 1}], 
      15]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem (Acceleration of Newton-Raphson Iteration)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Given that the Newton-Raphson algorithm produces a sequence \
that converges linearly to the root  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x = p\)]],
  StyleBox["  of order   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(m > 1\)]],
  StyleBox[".  Then the accelerated Newton-Raphson formula \n\n",
    FontFamily->"Times New Roman"],
  "\t",
  Cell[BoxData[
      RowBox[{\(p\_\(k + 1\)\), " ", "=", " ", 
        RowBox[{\(g \((p\_k)\)\), " ", "=", "  ", 
          RowBox[{\(p\_k\), "  ", "-", " ", 
            RowBox[{"m", 
              StyleBox[
                FractionBox[
                  StyleBox[\(f \((p\_k)\)\),
                    FontSize->12], 
                  StyleBox[\(f' \((p\_k)\)\),
                    FontSize->12]],
                FontSize->12]}]}]}]}]]],
  "    for    ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  "  \n\nwill produce a sequence ",
  Cell[BoxData[
      \({p\_k}\)]],
  " that converges quadratically to  ",
  StyleBox["p",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Accelerated & Modified Newton-Raphson",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/n2003/NewtonAccelerateProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Accelerated & Modified Newton-Raphson",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NewtonAccelerateProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Accelerated & Modified Newton-Raphson",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/n2003/NewtonAccelerateProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Accelerated & Modified Newton-Raphson",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NewtonAccelerateProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Accelerated Newton-Raphson \
Iteration).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphsonAccelerate[x0_, m_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \[IndentingNewLine]k\
\  = \ 0; \ \[IndentingNewLine]p0\  = \ 
          N[x0]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {16, 16}], \*"\"\<,   f[\!\(p\_0\)] = \>\"", 
          NumberForm[f[p0], 16]\ ]; \ \[IndentingNewLine]p1\  = \ 
          p0; \ \[IndentingNewLine]While[\ 
          k < max, \[IndentingNewLine]p0\  = \ 
            p1; \ \[IndentingNewLine]p1\  = \ 
            p0\  - m\ f[p0]\/\(f'\)[p0]; \ \[IndentingNewLine]k\  = \ 
            k + 1; \ \ \[IndentingNewLine]Print["\<p\>"\_k, "\< = \>", 
            PaddedForm[p1, {16, 16}], "\<,   f[\>", "\<p\>"\_k, "\<] = \>", 
            NumberForm[f[p1], 
              16]\ ];\ ]; \ \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p1, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", Abs[p1 - p0]\ ]; \ \[IndentingNewLine]Print["\<f[p] = \>", 
          NumberForm[f[p1], 16]\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the accelerated Newton's method to find the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  of the cubic polynomial  ",
  Cell[BoxData[
      \(f \((x)\)\  = \ x\^3 - 3\ x + 2\)],
    AspectRatioFixed->False],
  ".  Use the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 - 3\ x + 2;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-3\), 3}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2}, {0, 5}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-10\), 10, 1]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Since the  double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  has order  double root  ",
  Cell[BoxData[
      \(m = 2\)]],
  ",  the accelerated Newton-Raphson iteration formula  g[x]  is"
}], "Text"],

Cell[BoxData[{
    \(\(g[x_]\  = \ x - 2  f[x]\/\(f'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate quadratic convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 1.2\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell["\<\
Notice that convergence is much faster than the standard \
Newton-Raphson iteration. \
\>", "Text"],

Cell[BoxData[
    \(\(NewtonRaphsonAccelerate[1.2, 2, 5];\)\)], "Input"],

Cell[BoxData[
    \(\(NewtonRaphsonAccelerate[1.2, 2, 6];\)\)], "Input"],

Cell[TextData[{
  "At the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  we can explore the ratio ",
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 3;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 1.2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 1 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell["\<\
Therefore, the accelerated Newton-Raphson iteration is converging \
quadratically. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the accelerated Newton's method to find the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  and triple root   ",
  Cell[BoxData[
      \(p = 2\)]],
  ",  of the cubic polynomial  ",
  Cell[BoxData[
      \(f \((x)\)\  = x\^5 - 8\ x\^4 + 25\ x\^3 - 38\ x\^2 + 28\ x - 8\)],
    AspectRatioFixed->False],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        x\^5 - 8\ x\^4 + 25\ x\^3 - 38\ x\^2 + 28\ x - 
          8;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2.4}, 
        PlotRange \[Rule] {{0, 2.4}, {\(-0.1\), 0.1}}, 
        Ticks \[Rule] {Range[0, 3, 1], Automatic}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Since the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  has order  ",
  Cell[BoxData[
      \(m = 2\)]],
  ",  the accelerated Newton-Raphson iteration formula  ",
  StyleBox["g[x]",
    FontFamily->"Courier New"],
  "  is"
}], "Text"],

Cell[BoxData[{
    \(\(g[x_]\  = \ x - 2  f[x]\/\(f'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate quadratic convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 1.2\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell["\<\
Notice that convergence is much faster than the standard \
Newton-Raphson iteration. \
\>", "Text"],

Cell[BoxData[
    \(\(NewtonRaphsonAccelerate[1.2, 2, 5];\)\)], "Input"],

Cell[TextData[{
  "At the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  we can explore the ratio ",
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 5;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 1.2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 1 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell["\<\
Therefore, the accelerated Newton-Raphson iteration is converging \
quadratically. \
\>", "Text"],

Cell[TextData[{
  "Now investigate the other root.\nSince the triple root  ",
  Cell[BoxData[
      \(p = 2\)]],
  "  has order  ",
  Cell[BoxData[
      \(m = 3\)]],
  ",  the accelerated Newton-Raphson iteration formula  ",
  StyleBox["g[x]",
    FontFamily->"Courier New"],
  "  is"
}], "Text"],

Cell[BoxData[{
    \(\(g[x_]\  = \ x - 3  f[x]\/\(f'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate quadratic convergence at the triple root  ",
  Cell[BoxData[
      \(p = 2\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 2.3\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 2.3\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell["\<\
Notice that convergence is much faster than the standard \
Newton-Raphson iteration. \
\>", "Text"],

Cell[BoxData[
    \(\(NewtonRaphsonAccelerate[2.3, 3, 4];\)\)], "Input"],

Cell[TextData[{
  "At the triple root  ",
  Cell[BoxData[
      \(p = 2\)]],
  "  we can explore the ratio ",
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 4;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 2.3, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 2 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell["\<\
Therefore, the accelerated Newton-Raphson iteration is converging \
quadratically. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["More Background\n",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\tIf  ",
    FontFamily->"Times New Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox["  has a root of multiplicity   ",
    FontFamily->"Times New Roman"],
  StyleBox["m",
    FontFamily->"Courier New"],
  StyleBox["   at  ",
    FontFamily->"Times New Roman"],
  StyleBox["x=p",
    FontFamily->"Courier New"],
  StyleBox["  , then  ",
    FontFamily->"Times New Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox["  can be expressed in the form \n\t \n\t\t ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\) = \(\((x - p)\)\^m\) q \((x)\)\)]],
  " \n\nwhere  ",
  Cell[BoxData[
      \(q \((p)\) \[NotEqual] 0\)]],
  ".  In this situation, the function  ",
  StyleBox["h(x)",
    FontFamily->"Courier New"],
  "  is defined by\n\n\t\t",
  Cell[BoxData[
      \(h \((x)\) = \(f \((x)\)\)\/\(f' \((x)\)\)\)]],
  " ",
  StyleBox["\n\nand it is easy to prove that  ",
    FontFamily->"Times New Roman"],
  StyleBox["h(x)",
    FontFamily->"Courier New"],
  StyleBox["  has a simple root at  ",
    FontFamily->"Times New Roman"],
  StyleBox["x=p",
    FontFamily->"Courier New"],
  StyleBox[".  When Newton's method is applied for finding the root  ",
    FontFamily->"Times New Roman"],
  StyleBox["x=p",
    FontFamily->"Courier New"],
  StyleBox["  of  ",
    FontFamily->"Times New Roman"],
  StyleBox["h(x)",
    FontFamily->"Courier New"],
  StyleBox["  we obtain the following result. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Modified Newton-Raphson Iteration)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Given that the Newton-Raphson algorithm produces a sequence \
that converges linearly to the root  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x = p\)]],
  StyleBox["  of multiplicity   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(m > 1\)]],
  StyleBox[".  Then the modified Newton-Raphson formula \n\n",
    FontFamily->"Times New Roman"],
  "\t",
  Cell[BoxData[
      \(p\_\(k + 1\)\  = \ \(g \((p\_k)\)\  = \ 
          p\_k\  - \ \(f \((p\_k)\)\)\/\(f' \((p\_k)\)\ \((1 - \(f \((p\_k)\)\
\ f'' \((p\_k)\)\)\/\((f' \((p\_k)\))\)\^2)\)\)\)\)]],
  "     \n\t\nwhich can be simplified as \n\n\t",
  Cell[BoxData[
      \(p\_\(k + 1\)\  = \ \(g \((p\_k)\)\  = \ 
          p\_k\ \  - \ \(f \((p\_k)\)\ f' \((p\_k)\)\)\/\(f \((p\_k)\)\ f'' \
\((p\_k)\) - \((f' \((p\_k)\))\)\^2\)\)\)]],
  "    for    ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  "  \n\nwill produce a sequence ",
  Cell[BoxData[
      \({p\_k}\)]],
  " that converges quadratically to  ",
  StyleBox["p",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Accelerated & Modified Newton-Raphson",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/n2003/NewtonAccelerateProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Accelerated & Modified Newton-Raphson",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NewtonAccelerateProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Accelerated & Modified Newton-Raphson",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/n2003/NewtonAccelerateProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Accelerated & Modified Newton-Raphson",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NewtonAccelerateProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Modified Newton-Raphson \
Iteration).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphsonModified[x0_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \[IndentingNewLine]h[
            x_] = f[x]\/\(f'\)[x]; \ \[IndentingNewLine]g[x_]\  = 
          Simplify[\ x - h[x]\/\(h'\)[x]]; \[IndentingNewLine]k\  = \ 
          0; \ \[IndentingNewLine]p0\  = \ 
          N[x0]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {16, 16}], \*"\"\<,   f[\!\(p\_0\)] = \>\"", 
          NumberForm[f[p0], 16]\ ]; \ \[IndentingNewLine]p1\  = \ 
          p0; \ \[IndentingNewLine]While[\ 
          k < max, \[IndentingNewLine]p0\  = \ 
            p1; \ \[IndentingNewLine]p1\  = \ 
            g[p0]; \ \[IndentingNewLine]k\  = \ 
            k + 1; \ \ \[IndentingNewLine]Print["\<p\>"\_k, "\< = \>", 
            PaddedForm[p1, {16, 16}], "\<,   f[\>", "\<p\>"\_k, "\<] = \>", 
            NumberForm[f[p1], 
              16]\ ];\ ]; \ \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p1, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", Abs[p1 - p0]\ ]; \ \[IndentingNewLine]Print["\<f[p] = \>", 
          NumberForm[f[p1], 16]\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the modified Newton's method to find the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  of the cubic polynomial  ",
  Cell[BoxData[
      \(f \((x)\)\  = \ x\^3 - 3\ x + 2\)],
    AspectRatioFixed->False],
  ".  Use the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^3 - 3\ x + 2;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-3\), 3}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-10\), 10}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-10\), 10, 5]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2}, {0, 5}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-10\), 10, 1]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The modified Newton-Raphson iteration formula  ",
  StyleBox["g[x]",
    FontFamily->"Courier New"],
  "  is found."
}], "Text"],

Cell[BoxData[{
    \(\(h[x_] = f[x]\/\(f'\)[x];\)\ \), "\[IndentingNewLine]", 
    \(\(g[x_]\  = \ x - h[x]\/\(h'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<h[x] = \>", h[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate quadratic convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 1.2\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell["\<\
Notice that convergence is much faster than the standard \
Newton-Raphson iteration. \
\>", "Text"],

Cell[BoxData[
    \(\(NewtonRaphsonModified[1.2, 7];\)\)], "Input"],

Cell[TextData[{
  "At the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  we can explore the ratio ",
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 3;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 1.2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 1 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell["\<\
Therefore, the modified Newton-Raphson iteration is converging \
quadratically. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the modified Newton's method to find the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  and triple root   ",
  Cell[BoxData[
      \(p = 2\)]],
  ",  of the cubic polynomial  ",
  Cell[BoxData[
      \(f \((x)\)\  = x\^5 - 8\ x\^4 + 25\ x\^3 - 38\ x\^2 + 28\ x - 8\)],
    AspectRatioFixed->False],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        x\^5 - 8\ x\^4 + 25\ x\^3 - 38\ x\^2 + 28\ x - 
          8;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2.4}, 
        PlotRange \[Rule] {{0, 2.4}, {\(-0.1\), 0.1}}, 
        Ticks \[Rule] {Range[0, 3, 1], Automatic}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The modified Newton-Raphson iteration formula  ",
  StyleBox["g[x]",
    FontFamily->"Courier New"],
  "  is found."
}], "Text"],

Cell[BoxData[{
    \(\(h[x_] = f[x]\/\(f'\)[x];\)\ \), "\[IndentingNewLine]", 
    \(\(g[x_]\  = \ x - h[x]\/\(h'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<h[x] = \>", h[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate quadratic convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 1.2\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell["\<\
Notice that convergence is much faster than the standard \
Newton-Raphson iteration. \
\>", "Text"],

Cell[BoxData[
    \(\(NewtonRaphsonModified[1.2, 5];\)\)], "Input"],

Cell[TextData[{
  "At the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  we can explore the ratio ",
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 5;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 1.2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 1 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell["\<\
Therefore, the modified Newton-Raphson iteration is converging \
quadratically. \
\>", "Text"],

Cell[TextData[{
  "Now investigate the other root.",
  "\nInvestigate quadratic convergence at the triple root  ",
  Cell[BoxData[
      \(p = 2\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 2.3\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 2.3\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell["\<\
Notice that convergence is much faster than the standard \
Newton-Raphson iteration. \
\>", "Text"],

Cell[BoxData[
    \(\(NewtonRaphsonModified[2.3, 5];\)\)], "Input"],

Cell[TextData[{
  "At the triple root  ",
  Cell[BoxData[
      \(p = 2\)]],
  "  we can explore the ratio ",
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 4;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 2.3, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 2 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell["\<\
Therefore, the modified Newton-Raphson iteration is converging \
quadratically. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the function  ",
  Cell[BoxData[
      \(f \((x)\) = \(-\ x\^7\) + 8\ x\^6 - 27\ x\^5 + 50\ x\^4 - 55\ x\^3 + 
          36\ x\^2 - 13\ x\  + 2\)]],
  ".  \n",
  StyleBox["6 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method to find the multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ".  \n",
  StyleBox["6 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the accelerated Newton's method to find the multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ".  \n",
  StyleBox["6 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the modified Newton's method to find the multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(-\ x\^7\) + 8\ x\^6 - 27\ x\^5 + 50\ x\^4 - 55\ x\^3 + 
          36\ x\^2 - 13\ x\  + 2;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2}, {0, 0.5}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 1, 0.1]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0.9, 1.1}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0.992, 1.008}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Blue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0.994, 1.006}, 
        PlotRange \[Rule] {All, {\(-2\)*10\^\(-14\), 4*10\^\(-14\)}}, 
        PlotStyle \[Rule] Red];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "It appears that round off error in the calculation of ",
  StyleBox["f[x]",
    FontFamily->"Courier New"],
  " is introducing quite a bit of round-off error or noise.\nLet's see what \
happens!"
}], "Text"],

Cell[TextData[{
  " The Newton-Raphson iteration formula  ",
  StyleBox["g[x]",
    FontFamily->"Courier New"],
  "  is"
}], "Text"],

Cell[BoxData[{
    \(\(g[x_]\  = \ x - f[x]\/\(f'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate linear convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 1.2\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell[BoxData[
    \(p4 = g[p3]\)], "Input"],

Cell[BoxData[
    \(p5 = g[p4]\)], "Input"],

Cell[BoxData[
    \(p6 = g[p5]\)], "Input"],

Cell[TextData[{
  "Notice that convergence is slow, but the sequence is converging to the \
multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(NewtonRaphson[1.2, 50];\)\)], "Input"],

Cell[TextData[{
  StyleBox["Observe.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The function value is very close to zero, and the approximation ",
  Cell[BoxData[
      \(p\_50\  = \ 0.9960767463913650\)]],
  "  is a long way from the root !\n\nAt the multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  we can explore the relationship",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 
              1\)\)\(|\)\(\ \)\(\(\[TildeTilde]\)\(\ \
\)\(1\/2\)\)\(|\)\(E\_k\)\(|\)\)\)]],
  "  for  k  ",
  StyleBox["sufficiently large. ",
    FontFamily->"Times New Roman"],
  " \n\nThis will be done by investigating the ratio",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\(\(|\)\(E\_k\)\(|\)\)\  \
\[TildeTilde] \ 1\/2\)]],
  "  for  k  ",
  StyleBox["sufficiently large. ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 10;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 1.2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 1 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Abs[Ek], Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\(\(|\)\(E\_k\)\(|\)\)\)\>\""}}, TableSpacing \[Rule] {3, 1}], 
      15]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(-\ x\^7\) + 8\ x\^6 - 27\ x\^5 + 50\ x\^4 - 55\ x\^3 + 
          36\ x\^2 - 13\ x\  + 2;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2}, {0, 1}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 1, 0.2]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "How would we determine the order of the root ?\nIn practice, this must be \
known in advance. \nFor this example, the function was  ",
  Cell[BoxData[
      \(f[x] = \(\((x - 1)\)\^6\) \((2 - x)\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<(x-1\!\(\()\^6\)\)(2-x) = \>\"", \ 
        Expand[\(\((x - 1)\)\^6\) \((2 - x)\)]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<       f[x] = \>", f[x]];\)\)}], "Input"],

Cell[TextData[{
  "Since the multiple root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  has order  double root  ",
  Cell[BoxData[
      \(m = 6\)]],
  ",  the accelerated Newton-Raphson iteration formula  g[x]  is"
}], "Text"],

Cell[BoxData[{
    \(\(g[x_]\  = \ x - 6  f[x]\/\(f'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate quadratic convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 1.2\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell["\<\
Notice that convergence is much faster than the standard \
Newton-Raphson iteration. \
\>", "Text"],

Cell[BoxData[
    \(\(NewtonRaphsonAccelerate[1.2, 6, 5];\)\)], "Input"],

Cell[TextData[{
  "At the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  we can explore the ratio ",
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 3;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 1.2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 1 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell["\<\
Therefore, the accelerated Newton-Raphson iteration is converging \
quadratically. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(-\ x\^7\) + 8\ x\^6 - 27\ x\^5 + 50\ x\^4 - 55\ x\^3 + 
          36\ x\^2 - 13\ x\  + 2;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input",
  AspectRatioFixed->False],

Cell["Graph the function.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2}, {0, 1}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 1, 0.2]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The modified Newton-Raphson iteration formula  ",
  StyleBox["g[x]",
    FontFamily->"Courier New"],
  "  is found."
}], "Text"],

Cell[BoxData[{
    \(\(h[x_] = f[x]\/\(f'\)[x];\)\ \), "\[IndentingNewLine]", 
    \(\(g[x_]\  = \ x - h[x]\/\(h'\)[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<h[x] = \>", h[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = \ Simplify[\ g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Investigate quadratic convergence at the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  ",  using the starting value  ",
  Cell[BoxData[
      \(p\_0 = 1.2\)]],
  "\n\nFirst, do the iteration one step at a time.  \nType each of the \
following commands in a separate cell and execute them one at a time."
}], "Text"],

Cell[BoxData[
    \(p0 = 1.2\)], "Input"],

Cell[BoxData[
    \(p1 = g[p0]\)], "Input"],

Cell[BoxData[
    \(p2 = g[p1]\)], "Input"],

Cell[BoxData[
    \(p3 = g[p2]\)], "Input"],

Cell["\<\
Notice that convergence is much faster than the standard \
Newton-Raphson iteration. \
\>", "Text"],

Cell[BoxData[
    \(\(NewtonRaphsonModified[1.2, 4];\)\)], "Input"],

Cell[TextData[{
  "At the double root  ",
  Cell[BoxData[
      \(p = 1\)]],
  "  we can explore the ratio ",
  Cell[BoxData[
      \(\(\(|\)\(E\_\(k + 1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Nk = 3;\)\), "\[IndentingNewLine]", 
    \(\(Pk = NestList[g, 1.2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Vk = Table[i - 1, {i, 1, Nk + 1}];\)\), "\[IndentingNewLine]", 
    \(\(Ek = 1 - Pk;\)\), "\[IndentingNewLine]", 
    \(\(Qk = 
        Take[Abs[Ek], \(-Nk\)]/\ 
          Take[Ek\^2, Nk];\)\), "\[IndentingNewLine]", 
    \(\(Qk = Append[Qk, "\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Tvals = Transpose[{Vk, Pk, Ek, Qk}];\)\), "\[IndentingNewLine]", 
    \(NumberForm[
      TableForm[Tvals, 
        TableHeadings \[Rule] {None, {"\<k\>", \*"\"\<\!\(p\_k\)\>\"", \
\*"\"\<\!\(E\_k\)=p-\!\(p\_k\)\>\"", \*"\"\<\!\(\(\(|\)\(E\_\(k + \
1\)\)\(|\)\)\/\((\(|\)\(E\_k\)\(|\))\)\^2\)\>\""}}, 
        TableSpacing \[Rule] {3, 1}], 15]\)}], "Input"],

Cell["\<\
Therefore, the modified Newton-Raphson iteration is converging \
quadratically. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " ",
  StyleBox[ButtonBox["Newton's Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/RootFinding/\
NewtonMethod/NewtonMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Newton's Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/RootFinding/\
NewtonMethod/NewtonMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " ",
  StyleBox[ButtonBox["Newton's Method",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/nr.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Newton's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/nr.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Newton-Raphson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Newton'sMethodBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Newton-Raphson Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Newton'sMethodBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  ",
  "Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
SpellingDictionaries->{"CorrectWords"->{
  "Mathews", "Bartlett", "Sudbury", "Tele.", "mkt", "jbpub", "com", "mathews",
     "edu", "westmont", "Raphson", "solset"}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 198, 5, 35, "Text"],
Cell[1977, 60, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3456, 112, 2654, 83, 226, "Text"],
Cell[6113, 197, 641, 22, 33, "Text"],
Cell[6757, 221, 2665, 76, 90, "Text"],
Cell[9425, 299, 947, 30, 52, "Text"],
Cell[10375, 331, 2900, 91, 190, "Text"],
Cell[13278, 424, 1651, 49, 130, "Text"],
Cell[14932, 475, 641, 22, 33, "Text"],
Cell[15576, 499, 1109, 36, 77, "Text"],
Cell[16688, 537, 620, 20, 33, "Text"],
Cell[17311, 559, 154, 2, 33, "Text"],
Cell[17468, 563, 1069, 18, 310, "Input"],
Cell[18540, 583, 883, 30, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19448, 617, 105, 2, 33, "Text"],
Cell[19556, 621, 157, 3, 50, "Input"],
Cell[19716, 626, 35, 0, 33, "Text"],
Cell[19754, 628, 369, 6, 70, "Input"],
Cell[20126, 636, 383, 6, 70, "Input"],
Cell[20512, 644, 63, 0, 33, "Text"],
Cell[20578, 646, 272, 4, 105, "Input"],
Cell[20853, 652, 351, 9, 90, "Text"],
Cell[21207, 663, 46, 1, 30, "Input"],
Cell[21256, 666, 43, 1, 30, "Input"],
Cell[21302, 669, 43, 1, 30, "Input"],
Cell[21348, 672, 43, 1, 30, "Input"],
Cell[21394, 675, 43, 1, 30, "Input"],
Cell[21440, 678, 43, 1, 30, "Input"],
Cell[21486, 681, 43, 1, 30, "Input"],
Cell[21532, 684, 165, 6, 33, "Text"],
Cell[21700, 692, 64, 1, 30, "Input"],
Cell[21767, 695, 833, 24, 82, "Text"],
Cell[22603, 721, 788, 15, 186, "Input"],
Cell[23394, 738, 204, 8, 38, "Text"],
Cell[23601, 748, 382, 7, 80, "Input"],
Cell[23986, 757, 192, 6, 39, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[24215, 768, 105, 2, 30, "Text"],
Cell[24323, 772, 157, 3, 50, "Input"],
Cell[24483, 777, 35, 0, 33, "Text"],
Cell[24521, 779, 369, 6, 70, "Input"],
Cell[24893, 787, 343, 5, 70, "Input"],
Cell[25239, 794, 63, 0, 33, "Text"],
Cell[25305, 796, 272, 4, 105, "Input"],
Cell[25580, 802, 338, 9, 90, "Text"],
Cell[25921, 813, 41, 1, 30, "Input"],
Cell[25965, 816, 43, 1, 30, "Input"],
Cell[26011, 819, 43, 1, 30, "Input"],
Cell[26057, 822, 43, 1, 30, "Input"],
Cell[26103, 825, 43, 1, 30, "Input"],
Cell[26149, 828, 43, 1, 30, "Input"],
Cell[26195, 831, 43, 1, 30, "Input"],
Cell[26241, 834, 162, 6, 33, "Text"],
Cell[26406, 842, 60, 1, 30, "Input"],
Cell[26469, 845, 713, 24, 80, "Text"],
Cell[27185, 871, 774, 15, 185, "Input"]
}, Closed]],
Cell[27974, 889, 1801, 55, 131, "Text"],
Cell[29778, 946, 673, 22, 33, "Text"],
Cell[30454, 970, 659, 21, 33, "Text"],
Cell[31116, 993, 168, 3, 33, "Text"],
Cell[31287, 998, 1084, 18, 310, "Input"],
Cell[32374, 1018, 459, 16, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32858, 1038, 101, 2, 33, "Text"],
Cell[32962, 1042, 157, 3, 50, "Input"],
Cell[33122, 1047, 35, 0, 33, "Text"],
Cell[33160, 1049, 369, 6, 70, "Input"],
Cell[33532, 1057, 343, 5, 70, "Input"],
Cell[33878, 1064, 225, 8, 33, "Text"],
Cell[34106, 1074, 275, 4, 105, "Input"],
Cell[34384, 1080, 341, 9, 90, "Text"],
Cell[34728, 1091, 41, 1, 30, "Input"],
Cell[34772, 1094, 43, 1, 30, "Input"],
Cell[34818, 1097, 43, 1, 30, "Input"],
Cell[34864, 1100, 43, 1, 30, "Input"],
Cell[34910, 1103, 109, 3, 33, "Text"],
Cell[35022, 1108, 72, 1, 30, "Input"],
Cell[35097, 1111, 72, 1, 30, "Input"],
Cell[35172, 1114, 269, 10, 39, "Text"],
Cell[35444, 1126, 778, 15, 186, "Input"],
Cell[36225, 1143, 107, 3, 33, "Text"]
}, Closed]],
Cell[36347, 1149, 488, 17, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[36860, 1170, 101, 2, 33, "Text"],
Cell[36964, 1174, 210, 5, 50, "Input"],
Cell[37177, 1181, 35, 0, 33, "Text"],
Cell[37215, 1183, 348, 6, 70, "Input"],
Cell[37566, 1191, 264, 11, 33, "Text"],
Cell[37833, 1204, 275, 4, 105, "Input"],
Cell[38111, 1210, 341, 9, 90, "Text"],
Cell[38455, 1221, 41, 1, 30, "Input"],
Cell[38499, 1224, 43, 1, 30, "Input"],
Cell[38545, 1227, 43, 1, 30, "Input"],
Cell[38591, 1230, 43, 1, 30, "Input"],
Cell[38637, 1233, 109, 3, 33, "Text"],
Cell[38749, 1238, 72, 1, 30, "Input"],
Cell[38824, 1241, 269, 10, 39, "Text"],
Cell[39096, 1253, 778, 15, 186, "Input"],
Cell[39877, 1270, 107, 3, 33, "Text"],
Cell[39987, 1275, 297, 11, 52, "Text"],
Cell[40287, 1288, 275, 4, 105, "Input"],
Cell[40565, 1294, 341, 9, 90, "Text"],
Cell[40909, 1305, 41, 1, 30, "Input"],
Cell[40953, 1308, 43, 1, 30, "Input"],
Cell[40999, 1311, 43, 1, 30, "Input"],
Cell[41045, 1314, 43, 1, 30, "Input"],
Cell[41091, 1317, 109, 3, 33, "Text"],
Cell[41203, 1322, 72, 1, 30, "Input"],
Cell[41278, 1325, 269, 10, 39, "Text"],
Cell[41550, 1337, 778, 15, 186, "Input"],
Cell[42331, 1354, 107, 3, 33, "Text"]
}, Closed]],
Cell[42453, 1360, 1659, 53, 225, "Text"],
Cell[44115, 1415, 1792, 52, 230, "Text"],
Cell[45910, 1469, 673, 22, 33, "Text"],
Cell[46586, 1493, 659, 21, 33, "Text"],
Cell[47248, 1516, 165, 3, 33, "Text"],
Cell[47416, 1521, 1197, 20, 364, "Input"],
Cell[48616, 1543, 456, 16, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[49097, 1563, 101, 2, 33, "Text"],
Cell[49201, 1567, 157, 3, 50, "Input"],
Cell[49361, 1572, 35, 0, 33, "Text"],
Cell[49399, 1574, 369, 6, 70, "Input"],
Cell[49771, 1582, 343, 5, 70, "Input"],
Cell[50117, 1589, 147, 5, 33, "Text"],
Cell[50267, 1596, 403, 6, 161, "Input"],
Cell[50673, 1604, 341, 9, 90, "Text"],
Cell[51017, 1615, 41, 1, 30, "Input"],
Cell[51061, 1618, 43, 1, 30, "Input"],
Cell[51107, 1621, 43, 1, 30, "Input"],
Cell[51153, 1624, 43, 1, 30, "Input"],
Cell[51199, 1627, 109, 3, 33, "Text"],
Cell[51311, 1632, 67, 1, 30, "Input"],
Cell[51381, 1635, 269, 10, 39, "Text"],
Cell[51653, 1647, 778, 15, 186, "Input"],
Cell[52434, 1664, 104, 3, 33, "Text"]
}, Closed]],
Cell[52553, 1670, 485, 17, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[53063, 1691, 101, 2, 33, "Text"],
Cell[53167, 1695, 210, 5, 50, "Input"],
Cell[53380, 1702, 35, 0, 33, "Text"],
Cell[53418, 1704, 348, 6, 70, "Input"],
Cell[53769, 1712, 147, 5, 33, "Text"],
Cell[53919, 1719, 403, 6, 161, "Input"],
Cell[54325, 1727, 341, 9, 90, "Text"],
Cell[54669, 1738, 41, 1, 30, "Input"],
Cell[54713, 1741, 43, 1, 30, "Input"],
Cell[54759, 1744, 43, 1, 30, "Input"],
Cell[54805, 1747, 43, 1, 30, "Input"],
Cell[54851, 1750, 109, 3, 33, "Text"],
Cell[54963, 1755, 67, 1, 30, "Input"],
Cell[55033, 1758, 269, 10, 39, "Text"],
Cell[55305, 1770, 778, 15, 186, "Input"],
Cell[56086, 1787, 104, 3, 33, "Text"],
Cell[56193, 1792, 380, 10, 109, "Text"],
Cell[56576, 1804, 41, 1, 30, "Input"],
Cell[56620, 1807, 43, 1, 30, "Input"],
Cell[56666, 1810, 43, 1, 30, "Input"],
Cell[56712, 1813, 43, 1, 30, "Input"],
Cell[56758, 1816, 109, 3, 33, "Text"],
Cell[56870, 1821, 67, 1, 30, "Input"],
Cell[56940, 1824, 269, 10, 39, "Text"],
Cell[57212, 1836, 778, 15, 186, "Input"],
Cell[57993, 1853, 104, 3, 33, "Text"]
}, Closed]],
Cell[58112, 1859, 902, 32, 87, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[59039, 1895, 105, 2, 33, "Text"],
Cell[59147, 1899, 232, 4, 50, "Input"],
Cell[59382, 1905, 35, 0, 33, "Text"],
Cell[59420, 1907, 337, 5, 70, "Input"],
Cell[59760, 1914, 263, 4, 70, "Input"],
Cell[60026, 1920, 266, 4, 70, "Input"],
Cell[60295, 1926, 313, 5, 71, "Input"],
Cell[60611, 1933, 226, 6, 52, "Text"],
Cell[60840, 1941, 132, 5, 33, "Text"],
Cell[60975, 1948, 272, 4, 105, "Input"],
Cell[61250, 1954, 338, 9, 90, "Text"],
Cell[61591, 1965, 41, 1, 30, "Input"],
Cell[61635, 1968, 43, 1, 30, "Input"],
Cell[61681, 1971, 43, 1, 30, "Input"],
Cell[61727, 1974, 43, 1, 30, "Input"],
Cell[61773, 1977, 43, 1, 30, "Input"],
Cell[61819, 1980, 43, 1, 30, "Input"],
Cell[61865, 1983, 43, 1, 30, "Input"],
Cell[61911, 1986, 164, 6, 33, "Text"],
Cell[62078, 1994, 60, 1, 30, "Input"],
Cell[62141, 1997, 964, 30, 118, "Text"],
Cell[63108, 2029, 774, 15, 185, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[63919, 2049, 105, 2, 30, "Text"],
Cell[64027, 2053, 232, 4, 50, "Input"],
Cell[64262, 2059, 35, 0, 33, "Text"],
Cell[64300, 2061, 335, 5, 70, "Input"],
Cell[64638, 2068, 238, 6, 71, "Text"],
Cell[64879, 2076, 208, 3, 51, "Input"],
Cell[65090, 2081, 226, 8, 33, "Text"],
Cell[65319, 2091, 275, 4, 105, "Input"],
Cell[65597, 2097, 341, 9, 90, "Text"],
Cell[65941, 2108, 41, 1, 30, "Input"],
Cell[65985, 2111, 43, 1, 30, "Input"],
Cell[66031, 2114, 43, 1, 30, "Input"],
Cell[66077, 2117, 43, 1, 30, "Input"],
Cell[66123, 2120, 109, 3, 33, "Text"],
Cell[66235, 2125, 72, 1, 30, "Input"],
Cell[66310, 2128, 269, 10, 39, "Text"],
Cell[66582, 2140, 778, 15, 186, "Input"],
Cell[67363, 2157, 107, 3, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[67507, 2165, 105, 2, 30, "Text"],
Cell[67615, 2169, 232, 4, 50, "Input"],
Cell[67850, 2175, 35, 0, 33, "Text"],
Cell[67888, 2177, 335, 5, 70, "Input"],
Cell[68226, 2184, 147, 5, 33, "Text"],
Cell[68376, 2191, 403, 6, 161, "Input"],
Cell[68782, 2199, 341, 9, 90, "Text"],
Cell[69126, 2210, 41, 1, 30, "Input"],
Cell[69170, 2213, 43, 1, 30, "Input"],
Cell[69216, 2216, 43, 1, 30, "Input"],
Cell[69262, 2219, 43, 1, 30, "Input"],
Cell[69308, 2222, 109, 3, 33, "Text"],
Cell[69420, 2227, 67, 1, 30, "Input"],
Cell[69490, 2230, 269, 10, 39, "Text"],
Cell[69762, 2242, 778, 15, 186, "Input"],
Cell[70543, 2259, 104, 3, 33, "Text"]
}, Closed]],
Cell[70662, 2265, 762, 26, 30, "Text"],
Cell[71427, 2293, 663, 22, 33, "Text"],
Cell[72093, 2317, 158, 3, 35, "Text"],
Cell[72254, 2322, 583, 18, 33, "Text"],
Cell[72840, 2342, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

