(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    162115,       4705]*)
(*NotebookOutlinePosition[    162809,       4729]*)
(*  CellTagsIndexPosition[    162765,       4725]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Fixed Point Iteration and Newton's Method \
in 2D and 3D",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tIterative techniques will now be introduced that extend the \
fixed point and Newton methods for finding a root of an equation.  We desire \
to have a method for finding a solution for the system of nonlinear equations \
\n\t\n\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "0"}]]],
  "  \n\t(1)\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "0"}]]],
  ".  ",
  StyleBox["\n\t\nEach equation in (1) implicitly defines a curve in the \
plane and we want to find their points of intersection.  Our first method \
will be be fixed point iteration and the second one will be Newton's method. \
",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Jacobian Matrix).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(f\_1\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], "  ", \(f\_2\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  StyleBox[" are functions of the independent variables ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"x", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], " ", "y"}]]],
  StyleBox[", then their ",
    FontFamily->"Times New Roman"],
  ButtonBox["Jacobian matrix",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Jacobian.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " ",
  StyleBox["is  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\[PartialD]f\_1\/\[PartialD]x\), \(\[PartialD]f\_1\/\
\[PartialD]y\)},
              {\(\[PartialD]f\_2\/\[PartialD]x\), \(\[PartialD]f\_2\/\
\[PartialD]y\)}
              }], ")"}]}]]],
  ".  \n\t\nSimilarly, if",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}], 
          StyleBox[
            RowBox[{" ", 
              StyleBox[" ",
                FontFamily->"Times New Roman"]}]], 
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", \(f\_3\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}]}]]],
  StyleBox[" are functions of the independent variables  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"x", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"y", " ", 
          StyleBox["and",
            FontFamily->"Times New Roman"], " ", "z"}]}]]],
  StyleBox[", then their ",
    FontFamily->"Times New Roman"],
  ButtonBox["Jacobian matrix",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Jacobian.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "z"}], ")"}]}]]],
  " ",
  StyleBox["is  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\[PartialD]f\_1\/\[PartialD]x\), \(\[PartialD]f\_1\/\
\[PartialD]y\), \(\[PartialD]f\_1\/\[PartialD]z\)},
              {\(\[PartialD]f\_2\/\[PartialD]x\), \(\[PartialD]f\_2\/\
\[PartialD]y\), \(\[PartialD]f\_2\/\[PartialD]z\)},
              {\(\[PartialD]f\_3\/\[PartialD]x\), \(\[PartialD]f\_3\/\
\[PartialD]y\), \(\[PartialD]f\_3\/\[PartialD]z\)}
              }], ")"}]}]]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Generalized Differential",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tFor a function of several variables, the differential is used to \
show how changes of the independent variables affect the change in the \
dependent variables. Suppose that we have  \n\t\n\t\t",
  Cell[BoxData[
      \(u\  = \ \(f\_1\) \((x, y, z)\)\)]],
  "\n\t\t\n\t\t",
  Cell[BoxData[
      \(v\  = \ \(f\_2\) \((x, y, z)\)\)]],
  "\n\t\t\n\t\t",
  Cell[BoxData[
      \(w\  = \ \(f\_3\) \((x, y, z)\)\)]],
  "\n\t\nSuppose that the values of these functions in are known at the point \
",
  Cell[BoxData[
      \(\((x\_0, y\_0, z\_0)\)\)]],
  " and we wish to predict their value at a nearby point ",
  Cell[BoxData[
      \(\((x, y, z)\)\)]],
  ".  Let  ",
  Cell[BoxData[
      RowBox[{"du", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{"dv", "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", "dw"}]}]]],
  ",  denote differential changes in the dependent variables and , and    ",
  Cell[BoxData[
      RowBox[{"dx", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{"dy", "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", "dz"}]}]]],
  "  denote differential changes in the independent variables. These changes \
obey the relationships  \n\n\t\t",
  Cell[BoxData[
      \(du\  = \(\[PartialD]\/\[PartialD]x\) \(f\_1\) \((x\_0, y\_0, z\_0)\) 
            dx + \(\[PartialD]\/\[PartialD]z\) \(f\_1\) \((x\_0, y\_0, 
              z\_0)\) dy + \(\[PartialD]\/\[PartialD]z\) \(f\_1\) \((x\_0, 
              y\_0, z\_0)\) dz\)]],
  ", \n\t\t\n\t\t",
  Cell[BoxData[
      \(dv\  = \(\[PartialD]\/\[PartialD]x\) \(f\_2\) \((x\_0, y\_0, z\_0)\) 
            dx + \(\[PartialD]\/\[PartialD]z\) \(f\_2\) \((x\_0, y\_0, 
              z\_0)\) 
            dy + \(\[PartialD]\/\[PartialD]z\) \(f\_2\) \((x\_0, y\_0, 
              z\_0)\) dz\)]],
  ", \n\t\t\n\t\t",
  Cell[BoxData[
      \(dw\  = \(\[PartialD]\/\[PartialD]x\) \(f\_3\) \((x\_0, y\_0, z\_0)\) 
            dx + \(\[PartialD]\/\[PartialD]z\) \(f\_3\) \((x\_0, y\_0, 
              z\_0)\) dy + \(\[PartialD]\/\[PartialD]z\) \(f\_3\) \((x\_0, 
              y\_0, z\_0)\) dz\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["If vector notation is used, then this can be compactly written by \
using the Jacobian matrix. The function changes are  ",
    FontFamily->"Times New Roman"],
  StyleBox["d",
    FontFamily->"Courier New"],
  StyleBox["F",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  and the changes in the variables are denoted  ",
    FontFamily->"Times New Roman"],
  StyleBox["d",
    FontFamily->"Courier New"],
  StyleBox["X",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[".  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", GridBox[{
              {"du"},
              {"dv"},
              {"dw"}
              }], ")"}], " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[PartialD]f\_1\/\[PartialD]x\), \(\[PartialD]f\_1\/\
\[PartialD]y\), \(\[PartialD]f\_1\/\[PartialD]z\)},
                {\(\[PartialD]f\_2\/\[PartialD]x\), \(\[PartialD]f\_2\/\
\[PartialD]y\), \(\[PartialD]f\_2\/\[PartialD]z\)},
                {\(\[PartialD]f\_3\/\[PartialD]x\), \(\[PartialD]f\_3\/\
\[PartialD]y\), \(\[PartialD]f\_3\/\[PartialD]z\)}
                }], ")"}], " ", 
          RowBox[{"(", GridBox[{
                {"dx"},
                {"dy"},
                {"dz"}
                }], ")"}]}]}]]],
  StyleBox["  \n\tor\t\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{"d", 
            StyleBox["F",
              FontWeight->"Bold"]}]], " ", "=", " ", 
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], \((x\_0, y\_0, z\_0)\), 
          StyleBox[
            RowBox[{"d", 
              StyleBox["X",
                FontWeight->"Bold"]}]]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Convergence near a Fixed Point",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\tIn solving for solutions of a system of equations, \
iteration is used.  We now turn to the study of sufficient conditions which \
will guarantee convergence.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Fixed Point).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  A ",
    FontFamily->"Times New Roman"],
  ButtonBox["fixed point",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MapFixedPoint.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" for the system of two equations\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"x", " ", "=", 
        RowBox[{\(g\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  ",    \n\t\t",
  Cell[BoxData[
      RowBox[{"y", " ", "=", 
        RowBox[{\(g\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  ".  \n\nis a point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q"}], ")"}]]],
  " such that ",
  Cell[BoxData[
      RowBox[{"p", " ", "=", 
        RowBox[{
          RowBox[{\(g\_1\), 
            RowBox[{"(", 
              RowBox[{"p", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "q"}], ")"}], " ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", "q"}], " ", "=", 
          RowBox[{\(g\_2\), 
            RowBox[{"(", 
              RowBox[{"p", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "q"}], ")"}]}]}]}]]],
  ".  Similarly, in three dimensions a",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  ButtonBox["fixed point",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MapFixedPoint.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" for the system of three equations\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"x", " ", "=", 
        RowBox[{\(g\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}]}]]],
  ",  \n\t\t",
  Cell[BoxData[
      RowBox[{"y", " ", "=", 
        RowBox[{\(g\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}]}]]],
  ",  \n\t\t",
  Cell[BoxData[
      RowBox[{"z", " ", "=", 
        RowBox[{\(g\_3\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}]}]]],
  ".  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->9],
  "is a point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "r"}], ")"}]]],
  " such that ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"p", " ", "=", 
          RowBox[{\(g\_1\), 
            RowBox[{"(", 
              RowBox[{"p", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "q", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "r"}], ")"}]}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"q", " ", "=", 
          RowBox[{
            RowBox[{\(g\_2\), 
              RowBox[{"(", 
                RowBox[{"p", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "q", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "r"}], ")"}], " ", 
              StyleBox["and",
                FontFamily->"Times New Roman"], "  ", "r"}], " ", "=", 
            RowBox[{\(g\_3\), 
              RowBox[{"(", 
                RowBox[{"p", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "q", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "r"}], ")"}]}]}]}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Fixed Point Iteration).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  For a system of two equations, ",
    FontFamily->"Times New Roman"],
  StyleBox["fixed point iteration",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" is  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(p\_\(k + 1\)\), " ", "=", 
        RowBox[{\(g\_1\), 
          RowBox[{"(", 
            RowBox[{\(p\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(q\_k\)}], ")"}]}]}]]],
  ",  and  \n\t\t",
  Cell[BoxData[
      RowBox[{\(q\_\(k + 1\)\), " ", "=", 
        RowBox[{\(g\_2\), 
          RowBox[{"(", 
            RowBox[{\(p\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(q\_k\)}], ")"}]}]}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman"], "  ", "k"}], "=", "0"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n\n",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox["Similarly, for a system of three equations, ",
    FontFamily->"Times New Roman"],
  StyleBox["fixed point iteration",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" is\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(p\_\(k + 1\)\), " ", "=", 
          RowBox[{\(g\_1\), 
            RowBox[{"(", 
              RowBox[{\(p\_k\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(q\_k\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(r\_k\)}], ")"}]}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "   \n\t\t",
  Cell[BoxData[
      RowBox[{\(q\_\(k + 1\)\), " ", "=", 
        RowBox[{\(g\_2\), 
          RowBox[{"(", 
            RowBox[{\(p\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(q\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(r\_k\)}], ")"}]}]}]]],
  ",  and \n\t\t",
  Cell[BoxData[
      RowBox[{\(r\_\(k + 1\)\), " ", "=", 
        RowBox[{\(g\_3\), 
          RowBox[{"(", 
            RowBox[{\(p\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(q\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " ", \(r\_k\)}], ")"}]}]}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman"], "  ", "k"}], "=", "0"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Fixed-Point Iteration).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that all the functions and their first partial \
derivatives are continuous on a region that contains the fixed point ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q"}], ")"}]]],
  StyleBox[" or ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "r"}], ")"}]]],
  StyleBox[", respectively.  If the starting point is chosen sufficiently \
close to the fixed point, then one of the following cases apply.\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox["Case (i)  Two dimensions.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   If ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(p\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(q\_0\)}], ")"}]]],
  " ",
  StyleBox["is sufficiently close to ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q"}], ")"}]]],
  " ",
  StyleBox["and if  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(f\_1\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  StyleBox["\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_1\/\[PartialD]x\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q"}], ")"}]}], "|", " ", 
        RowBox[{"+", " ", 
          RowBox[{"|", 
            RowBox[{\(\[PartialD]g\_1\/\[PartialD]y\), 
              RowBox[{"(", 
                RowBox[{"p", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "q"}], ")"}]}], "|", 
            " ", \(\(<\)\(\ \)\(1\)\)}]}]}]]],
  ",  ",
  StyleBox["\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_2\/\[PartialD]x\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q"}], ")"}]}], "|", " ", 
        RowBox[{"+", " ", 
          RowBox[{"|", " ", 
            RowBox[{\(\[PartialD]g\_2\/\[PartialD]y\), 
              RowBox[{"(", 
                RowBox[{"p", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "q"}], ")"}]}], "|", 
            " ", \(\(<\)\(\ \)\(1\)\)}]}]}]]],
  ",  \n\nthen fixed point iteration will converge to the fixed point",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q"}], ")"}]]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["Case (ii)  Three dimensions.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   If ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(p\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(q\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(r\_0\)}], ")"}]]],
  " ",
  StyleBox["is sufficiently close to ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "r"}], ")"}]]],
  " ",
  StyleBox["and if  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_1\/\[PartialD]x\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " + ",
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_1\/\[PartialD]y\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " + ",
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_1\/\[PartialD]y\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " < 1,  ",
  StyleBox["\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_2\/\[PartialD]x\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " + ",
  Cell[BoxData[
      RowBox[{"|", " ", 
        RowBox[{\(\[PartialD]g\_2\/\[PartialD]y\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " + ",
  Cell[BoxData[
      RowBox[{"|", " ", 
        RowBox[{\(\[PartialD]g\_2\/\[PartialD]y\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " < 1,  \n\n\t\t",
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_3\/\[PartialD]x\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " + ",
  Cell[BoxData[
      RowBox[{"|", " ", 
        RowBox[{\(\[PartialD]g\_3\/\[PartialD]y\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " + ",
  Cell[BoxData[
      RowBox[{"|", " ", 
        RowBox[{\(\[PartialD]g\_3\/\[PartialD]y\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}], "|"}]]],
  " < 1,  \n\nthen fixed point iteration will converge to the fixed point",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "r"}], ")"}]]],
  StyleBox[".  \n\n\tIf these conditions are not met, the iteration might \
diverge, which is usually the case.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/NewtonSystemProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonSystemProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (Fixed Point Iteration for Non-Linear Systems)",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" ",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " In two dimensions, solve the non-linear fixed point system  \n\t\t",
  Cell[BoxData[{
      RowBox[{"x", " ", "=", " ", 
        RowBox[{\(g\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}], "\n", 
      RowBox[{"y", " ", "=", " ", 
        RowBox[{\(g\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]}]],
  "  \ngiven one initial approximation ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", 
        RowBox[{"(", 
          RowBox[{\(p\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(q\_0\)}], ")"}]}]]],
  ", and generating a sequence ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "k"], "}"}], "=", 
        RowBox[{"{", 
          RowBox[{"(", 
            RowBox[{\(p\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(q\_k\)}], ")"}], "}"}]}]]],
  " which converges to the solution  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "=", 
        RowBox[{"(", 
          RowBox[{"p", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "q"}], ")"}]}]]],
  ",  i.e.   \t\t\n\t\t",
  Cell[BoxData[{
      RowBox[{"p", "=", 
        RowBox[{\(g\_1\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q"}], ")"}]}]}], 
    "\[IndentingNewLine]", 
      RowBox[{"q", "=", 
        RowBox[{\(g\_2\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q"}], ")"}]}]}]}]],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (Fixed Point Iteration for Non-Linear Systems)",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "In three dimensions, solve the non-linear fixed point system  \n\t\t",
  Cell[BoxData[{
      RowBox[{"x", " ", "=", " ", 
        RowBox[{\(g\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}]}], "\n", 
      RowBox[{"y", " ", "=", " ", 
        RowBox[{\(g\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}]}], "\n", 
      RowBox[{"z", " ", "=", " ", 
        RowBox[{\(g\_3\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "z"}], ")"}]}]}]}]],
  "\t \ngiven one initial approximation ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", 
        RowBox[{"(", 
          RowBox[{\(p\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(q\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(r\_0\)}], ")"}]}]]],
  ", and generating a sequence ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "k"], "}"}], "=", 
        RowBox[{"{", 
          RowBox[{"(", 
            RowBox[{\(p\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(q\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(r\_k\)}], ")"}], "}"}]}]]],
  " which converges to the solution  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "=", 
        RowBox[{"(", 
          RowBox[{"p", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "q", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "r"}], ")"}]}]]],
  ",  i.e.   \n\t\t",
  Cell[BoxData[{
      RowBox[{"p", "=", 
        RowBox[{\(g\_1\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}]}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"q", "=", 
          RowBox[{\(g\_2\), 
            RowBox[{"(", 
              RowBox[{"p", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "q", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "r"}], ")"}]}]}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{"r", "=", 
        RowBox[{\(g\_3\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "r"}], ")"}]}]}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (Fixed Point Iteration for Non-Linear Systems)",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  S",
    FontFamily->"Times New Roman"],
  "olve the non-linear fixed point system  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(X\&\[RightVector]\),
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", " ", 
        RowBox[{
          StyleBox[
            OverscriptBox[
              StyleBox["G",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], 
          RowBox[{"(", 
            StyleBox[\(X\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}]}]]],
  ",  \n\ngiven one initial approximation ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "0"]]],
  ", and generating a sequence ",
  Cell[BoxData[
      RowBox[{"{", 
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "k"], "}"}]]],
  " which converges to the solution  ",
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["P",
            FontWeight->"Bold"], "\[RightVector]"],
        FontWeight->"Bold"]]],
  ",  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            OverscriptBox[
              StyleBox["G",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], 
          RowBox[{"(", 
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], ")"}]}], "=", " ", 
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"]}]]],
  ".  \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " First we give a subroutine for performing fixed point iteration. "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/NewtonSystemProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonSystemProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Fixed Point Iteration in \
n-Dimensions).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(FixPoint[P0_, \[Epsilon]_, max_]\), ":=", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            RowBox[{\({dist = 1, k = 0, P}\), ",", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], " ", "=", " ", "P0"}], ";", 
                " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", ",", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"]}], "]"}], ";", " ", 
                "\[IndentingNewLine]", 
                RowBox[{"While", "[", " ", 
                  
                  RowBox[{\(And[\ k \[LessEqual] max\ , 
                      dist > \[Epsilon]\ ]\), ",", "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], " ", "=", " ", 
                        RowBox[{\(G\&\[RightVector]\), "[", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "0"], "]"}]}], ";", " ", 
                      "\[IndentingNewLine]", 
                      RowBox[{"Print", "[", 
                        RowBox[{
                          SubscriptBox["\"\<\!\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\>\"", \(k + 1\)], ",", "\"\< = \>\"", ",", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "1"]}], "]"}], ";", "  ", 
                      "\[IndentingNewLine]", 
                      RowBox[{"dist", " ", "=", " ", 
                        SqrtBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"]}], ")"}], ".", 
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"]}], ")"}]}]]}], 
                      ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], " ", "=", " ", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"]}], ";", " ", 
                      "\[IndentingNewLine]", \(k\  = \ k + 1\), ";"}]}], "  ",
                   "]"}], ";", "  ", "\[IndentingNewLine]", 
                RowBox[{"Return", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}], ";"}]}], " ", "]"}]}],
         ";"}], "  "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use fixed point iteration to find a solution to the nonlinear system  \n\
\n\t\t",
  Cell[BoxData[{
      RowBox[{"x", " ", "=", " ", 
        RowBox[{
          RowBox[{\(g\_1\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(\(2  x\^2\  - \ 2  y\^3\  + \ 1\)\/4\)}]}], "\n", 
      RowBox[{"y", " ", "=", " ", 
        RowBox[{
          RowBox[{\(g\_2\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(\(\(-\ x\^4\)\  - \ 4\ y\^4\  + \ 8\ y\  + \ 
                4\)\/12\)}]}]}]],
  "   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{\(g\_1\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(g\_2\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ", and vector function ",
  Cell[BoxData[
      StyleBox["G",
        FontWeight->"Bold"]]],
  " into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(g\_1[{x_, y_}]\  = \ \(2  x\^2 - 2  y\^3 + 1\)\/4;\)\ \ \), "\n", 
    \(\(g\_2[{x_, 
            y_}]\  = \ \(\(-\ x\^4\) - 4\ y\^4 + 8\ y + 4\)\/12;\)\ \ \), "\n\
", 
    \(\(G\&\[RightVector][{x_, y_}]\  = \ {\ g\_1[{x, y}], 
          g\_2[{x, y}]\ };\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(G\&\[RightVector]\)[{x,y}] = \>\"", 
        G\&\[RightVector][{x, y}]\ ];\)\ \ \ \)}], "Input"],

Cell[TextData[{
  "Second, graph the curves ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(g\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{
          RowBox[{"x", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(g\_2\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", "y"}]}]]],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  \nThe points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[{g\_1[{x, y}] \[Equal] x, 
          g\_2[{x, y}] \[Equal] y}, {x, \ \(-2\), \ 2}, {y, \ \(-2\), \ 1}, 
        PlotStyle \[Rule] \ {Red, Blue}];\)\ \)}], "Input"],

Cell[TextData[{
  "How many points of intersection are there ?  \nUse fixed point iteration \
to find a numerical approximation to the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0.1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0.7"}], ")"}]],
    AspectRatioFixed->False],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(P\&\[RightVector]\), "=", 
          RowBox[{"FixPoint", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-8\)\), ",", 
              "100"}], "]"}]}], ";"}], " "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "A fixed point satisfies the equation  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\&\[RightVector]\),
          FontWeight->"Bold"], "=", 
        RowBox[{
          StyleBox[\(G\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{"(", 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}]}]]],
  ".  Our last approximation is stored in  ",
  Cell[BoxData[
      \(P\&\[RightVector]\)],
    AspectRatioFixed->False,
    FontWeight->"Bold"],
  ",  check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(G\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", G\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell["Do you think that iteration produced the solution ? Why ?  ", "Text"],

Cell["\<\
Accuracy is determined by the tolerance and number of iterations.  How \
accurate was the solution \"really\"? \
\>", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        NumberForm[P\&\[RightVector], 12]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(G\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[G\&\[RightVector][P\&\[RightVector]], 12]];\)\ \)}], "Input"],

Cell[TextData[{
  "Since our tolerance was only  ",
  Cell[BoxData[
      \(10\^\(-8\)\)],
    AspectRatioFixed->False],
  ",  the accuracy is what we should expect. "
}], "Text"],

Cell[TextData[{
  "Use fixed point iteration to attempt finding a numerical approximation to \
the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"1.5", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(-0.5\)}], ")"}]],
    AspectRatioFixed->False],
  ".  \nBut this time attempt only 10 iterations !  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.5, \(-0.5\)}\)}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(P\&\[RightVector]\), "=", 
          RowBox[{"FixPoint", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-8\)\), ",", "10"}],
             "]"}]}], ";"}], " "}]}], "Input"],

Cell[TextData[{
  "A fixed point satisfies the equation  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\&\[RightVector]\),
          FontWeight->"Bold"], "=", 
        RowBox[{
          StyleBox[\(G\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{"(", 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}]}]]],
  ".  Our last approximation is stored in  ",
  Cell[BoxData[
      \(P\&\[RightVector]\)],
    FontWeight->"Bold"],
  ",  check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(G\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", G\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell[TextData[{
  "Did iteration find the desired solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"1.5", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(-0.5\)}], ")"}]],
    AspectRatioFixed->False],
  "?  Why ?  "
}], "Text"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find that solution  near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"1.5", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(-0.5\)}], ")"}]],
    AspectRatioFixed->False],
  ".  \nThis time use the procedure  ",
  StyleBox["NSolve",
    FontWeight->"Bold"],
  "  (if you use ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " you might be unhappy). "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<The system to solve is\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[{g\_1[{x, y}] \[Equal] x, \ 
          g\_2[{x, y}] \[Equal] y}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(TableForm[
      NSolve[{g\_1[{x, y}] \[Equal] x, g\_2[{x, y}] \[Equal] y}, {x, 
          y}]]\ \ \)}], "Input"],

Cell["\<\
Where did all those complex number come from ?  Thought we were looking at \
curves in the plane ? \
\>", "Text"],

Cell["\<\
Try solving the first equation for x then substituting one of the solutions \
in for x is the second equation.  \
\>", "Text"],

Cell[BoxData[
    \(\(\(Solve[g\_1[{x, y}] \[Equal] x, x]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(eqn\)\(=\)\(ExpandAll[
        g\_2[{1\/2\ \((2 + \@2\ \@\(1 + 2\ y\^3\))\), y}] \[Equal] 
          y]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(eqn\)\(=\)\(Thread[
        eqn - y + \@\(1 + 2\ y\^3\)\/\(2\ \@2\) + \(y\^3\ \@\(1 + 2\ y\^3\)\)\
\/\(3\ \@2\), Equal]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(eqn\)\(=\)\(Thread[eqn\^2, Equal]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(eqn\)\(=\)\(ExpandAll[eqn]\)\(\ \)\)\)], "Input"],

Cell["\<\
So we can solve for y, in a single polynomial equation of degree 12  which is \
known to have 12 roots, some of which are complex.\
\>", "Text"],

Cell[BoxData[
    \(\(\(TableForm[NSolve[eqn, y]]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "For our course, we don't want the complex solutions because we usually \
work with real numbers and our iteration schemes produces more real numbers. \
\nHowever, you should be convinced that the second solution we seek is \n\n",
  StyleBox["{x \[Rule] 1.5560974843220556, y \[Rule] -0.5756507696188449}",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell["\<\
Do you think we should have started closer to the solution and that fixed \
point iteration should then work ?   
If so, try the following iteration.  \
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"FixPoint", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                StyleBox["1.556097",
                  FontFamily->"Courier New",
                  FontWeight->"Bold"], ",", \(-0.575651\)}], "}"}], 
            ",", \(10\^\(-8\)\), ",", "20"}], "]"}], ";"}], " "}]], "Input"],

Cell[TextData[{
  "Is iteration converging to the desired solution ",
  StyleBox["{1.5560974843220556",
    FontFamily->"Courier New"],
  ",",
  StyleBox[" -0.5756507696188449}",
    FontFamily->"Courier New"],
  "  ?  \n\nOur goal is to obtain this second solution.  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(P\&\[RightVector]\), "=", 
          StyleBox[\({1.5560974843220556, \ \(-0.5756507696188449\)}\),
            FontFamily->"Courier New"]}], 
        StyleBox[";",
          FontFamily->"Courier New"]}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
          NumberForm[P\&\[RightVector], 13]];\), " "}], "\[IndentingNewLine]",
   
    RowBox[{\(Print[\*"\"\<\!\(G\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[G\&\[RightVector][P\&\[RightVector]], 13]];\), 
      " "}]}], "Input"],

Cell[TextData[{
  "Theoretically, if we know the fixed point and look at the partial \
derivatives of the equations then the row sum should be small. \n\n",
  StyleBox["Case (i)  Two dimensions.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  If ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(p\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(q\_0\)}], ")"}]]],
  " ",
  StyleBox["is sufficiently close to ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q"}], ")"}]]],
  " ",
  StyleBox["and if  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_1\/\[PartialD]x\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q"}], ")"}]}], "|", " ", 
        RowBox[{"+", " ", 
          RowBox[{"|", 
            RowBox[{\(\[PartialD]g\_1\/\[PartialD]y\), 
              RowBox[{"(", 
                RowBox[{"p", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "q"}], ")"}]}], "|", 
            " ", \(\(<\)\(\ \)\(1\)\)}]}]}]]],
  ",  ",
  StyleBox["\n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{\(\[PartialD]g\_2\/\[PartialD]x\), 
          RowBox[{"(", 
            RowBox[{"p", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "q"}], ")"}]}], "|", " ", 
        RowBox[{"+", " ", 
          RowBox[{"|", " ", 
            RowBox[{\(\[PartialD]g\_2\/\[PartialD]y\), 
              RowBox[{"(", 
                RowBox[{"p", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "q"}], ")"}]}], "|", 
            " ", \(\(<\)\(\ \)\(1\)\)}]}]}]]],
  ",  \n\nthen fixed point iteration will converge to the fixed point",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"p", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "q"}], ")"}]]],
  StyleBox[".  \n\nConsider the first inequality for our problem. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\ \(g1\_x[{x_, y_}] = \[PartialD]\_x\ g\_1[{x, y}];\)\ \ \), "\n", 
    \(\ \(g1\_y[{x_, y_}] = \[PartialD]\_y\ 
          g\_1[{x, y}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<g1[{x,y}] = \>", 
        g1[{x, y}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_x\) \!\(g\_1\)[{x,y}] = \>\"", 
        g1\_x[{x, y}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_y\) \!\(g\_1\)[{x,y}] = \>\"", 
        g1\_y[{x, y}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(P\&\[RightVector]\)  = {p,q} = \>\"", 
        P\&\[RightVector]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_x\) \!\(g\_1\)[\!\(P\&\[RightVector]\)] \
= \!\(\[PartialD]\_x\) \!\(g\_1\)[\>\"", P\&\[RightVector], "\<] = \>", 
        g1\_x[P\&\[RightVector]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_y\) \!\(g\_1\)[\!\(P\&\[RightVector]\)] \
= \!\(\[PartialD]\_y\) \!\(g\_1\)[\>\"", P\&\[RightVector], "\<] = \>", 
        g1\_y[P\&\[RightVector]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(\[PartialD]\_x\) \
\!\(g\_1\)[\!\(P\&\[RightVector]\)]|+|\!\(\[PartialD]\_y\) \!\(g\_1\)[\!\(P\&\
\[RightVector]\)]| = \>\"", 
        Abs[g1\_x[P\&\[RightVector]]] + 
          Abs[g1\_y[P\&\[RightVector]]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Is this larger than 1.\>"];\)\ \ \)}], "Input"],

Cell["\<\
The sum of the absolute values of the partial derivatives is too big, so we \
should not have expected that iteration would converge. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Newton\[CloseCurlyQuote]s Method for Nonlinear Systems",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["We now outline the derivation of Newton\[CloseCurlyQuote]s method \
in two dimensions.  Newton\[CloseCurlyQuote]s method can easily be extended \
to higher dimensions.  Consider the system\n\n",
    FontFamily->"Times New Roman"],
  "\t\t",
  Cell[BoxData[
      \(u\  = \ \(f\_1\) \((x, y)\)\)]],
  "\t\t\n(1)\n\t\t",
  Cell[BoxData[
      \(v\  = \ \(f\_2\) \((x, y)\)\)]],
  StyleBox["\n\nwhich can be considered a transformation from the  xy-plane \
to the uv-plane.  We are interested in the behavior of this transformation \
near the point ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\((x\_0, y\_0)\)\)]],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["whose image is the point ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\((u\_0, v\_0)\)\)]],
  StyleBox[".  If the two functions have continuous partial derivatives, then \
the differential can be used to write a system of linear approximations that \
is valid near the point ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\((x\_0, y\_0)\)\)]],
  StyleBox[":\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", GridBox[{
              {"du"},
              {"dv"}
              }], ")"}], " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[PartialD]f\_1\/\[PartialD]x\), \(\[PartialD]f\_1\/\
\[PartialD]y\)},
                {\(\[PartialD]f\_2\/\[PartialD]x\), \(\[PartialD]f\_2\/\
\[PartialD]y\)}
                }], ")"}], " ", 
          RowBox[{"(", GridBox[{
                {"dx"},
                {"dy"}
                }], ")"}]}]}]]],
  StyleBox["  \n\nthen substitute the changes ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\[CapitalDelta]x = x - x\_0, \[CapitalDelta]y = 
        y - y\_0, \[CapitalDelta]u = u - u\_0, \[CapitalDelta]v = 
        v - v\_0\)]],
  "  for  ",
  Cell[BoxData[
      \(dx, dy, du, dv\)]],
  ",  respectively.  Then we will have\n\n",
  StyleBox["\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", GridBox[{
              {"\[CapitalDelta]u"},
              {"\[CapitalDelta]v"}
              }], ")"}], " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[PartialD]f\_1\/\[PartialD]x\), \(\[PartialD]f\_1\/\
\[PartialD]y\)},
                {\(\[PartialD]f\_2\/\[PartialD]x\), \(\[PartialD]f\_2\/\
\[PartialD]y\)}
                }], ")"}], " ", 
          RowBox[{"(", GridBox[{
                {"\[CapitalDelta]x"},
                {"\[CapitalDelta]y"}
                }], ")"}]}]}]]],
  StyleBox["  or  \n(2)\t\t\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalDelta]", 
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"]}], " ", "=", " ", 
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], \((x\_0, y\_0)\), "\[CapitalDelta]", 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["\tConsider the system (1) with u and v set equal to zero, \n\n",
    FontFamily->"Times New Roman"],
  "\t\t",
  Cell[BoxData[
      \(0\  = \ \(f\_1\) \((x, y)\)\)]],
  "\t\t\n(3)\n\t\t",
  Cell[BoxData[
      \(0\  = \ \(f\_2\) \((x, y)\)\)]],
  "\n\nSuppose we are trying to find the solution ",
  Cell[BoxData[
      \(\((p, q)\)\)]],
  " and we start iteration at the nearby point ",
  Cell[BoxData[
      \(\((p\_0, q\_0)\)\)]],
  ", then we can apply (2) and write \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(f\_1\) \((p, q)\) - \(f\_1\) \((p\_0, q\_0)\)\)},
              {\(\(f\_2\) \((p, q)\) - \(f\_2\) \((p\_0, q\_0)\)\)}
              }], ")"}], " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[PartialD]f\_1\/\[PartialD]x\), \(\[PartialD]f\_1\/\
\[PartialD]y\)},
                {\(\[PartialD]f\_2\/\[PartialD]x\), \(\[PartialD]f\_2\/\
\[PartialD]y\)}
                }], ")"}], " ", 
          RowBox[{"(", GridBox[{
                {"\[CapitalDelta]p"},
                {"\[CapitalDelta]q"}
                }], ")"}]}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(\(f\_1\) \((p, q)\) = 0, \ and\ \ \(f\_2\) \((p, q)\) = 0\)]],
  ", this becomes  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", GridBox[{
                {\(\(f\_1\) \((p\_0, q\_0)\)\)},
                {\(\(f\_2\) \((p\_0, q\_0)\)\)}
                }], ")"}]}], " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[PartialD]f\_1\/\[PartialD]x\), \(\[PartialD]f\_1\/\
\[PartialD]y\)},
                {\(\[PartialD]f\_2\/\[PartialD]x\), \(\[PartialD]f\_2\/\
\[PartialD]y\)}
                }], ")"}], " ", 
          RowBox[{"(", GridBox[{
                {"\[CapitalDelta]p"},
                {"\[CapitalDelta]q"}
                }], ")"}]}]}]]],
  ",\nor  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"-", " ", 
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"]}], \((p\_0, q\_0)\)}], " ", "=", "  ", 
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], \((p\_0, q\_0)\), "\[CapitalDelta]", 
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWhen we solve this latter equation for  ",
  Cell[BoxData[
      RowBox[{"\[CapitalDelta]", 
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"]}]]],
  "  we get  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalDelta]", 
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"]}], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", " ", 
        RowBox[{
          RowBox[{"-", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["J",
                    FontWeight->"Bold"], \((p\_0, q\_0)\)}], ")"}], \(-1\)]}],
           " ", 
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], \((p\_0, q\_0)\)}]}]]],
  " and the next approximation ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "1"], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "+", 
          RowBox[{"\[CapitalDelta]", 
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"]}]}]}]]],
  " is \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "1"], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "  ", "-", " ", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["J",
                    FontWeight->"Bold"], 
                  RowBox[{"(", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"], ")"}]}], ")"}], \(-1\)], 
            " ", 
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ")"}]}]}]}]]],
  "\n"
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" (Newton-Raphson Method for 2-dimensional Systems).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  To solve the non-linear system  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(X\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ",  \n\ngiven one initial approximation ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "0"]]],
  ", and generating a sequence ",
  Cell[BoxData[
      RowBox[{"{", 
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "k"], "}"}]]],
  StyleBox[" which converges to the solution ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["P",
            FontWeight->"Bold"], "\[RightVector]"],
        FontWeight->"Bold"]]],
  ",  i.e.",
  StyleBox["  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  \n\nSuppose that  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "k"]]],
  " has been obtained, use the following steps to obtain ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], \(k + 1\)]]],
  ".  \n\nStep 1.\t Evaluate the function   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"], "k"],
              FontWeight->"Bold"], ")"}]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(f\_1\) \((p\_k, q\_k)\)\)},
              {\(\(f\_2\) \((p\_k, q\_k)\)\)}
              }], ")"}]}]]],
  ".\n\nStep 2.  Evaluate the Jacobian   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"], "k"],
              FontWeight->"Bold"], ")"}]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(\[PartialD]\/\[PartialD]x\) \(f\_1\) \((p\_k, 
                    
                    q\_k)\)\), \(\(\[PartialD]\/\[PartialD]y\) \(f\_1\) \
\((p\_k, q\_k)\)\)},
              {\(\(\[PartialD]\/\[PartialD]x\) \(f\_2\) \((p\_k, 
                    q\_k)\)\), \(\(\[PartialD]\/\[PartialD]y\) \(f\_2\) \
\((p\_k, q\_k)\)\)}
              }], ")"}]}]]],
  ".  \n\nStep 3.  Solve the linear system   ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            StyleBox["J",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              StyleBox[
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"], "k"],
                FontWeight->"Bold"], ")"}], "\[CapitalDelta]", 
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"]}], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox[\(-\ F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"], "k"],
                FontWeight->"Bold"], ")"}]}]}]}]]],
  "   for   ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"\[CapitalDelta]", 
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"]}]}]]],
  ".  \n\nStep 4.  Compute the next approximation   ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], \(k + 1\)], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "k"], " ", "+", 
          RowBox[{"\[CapitalDelta]", 
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/NewtonSystemProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonSystemProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/NewtonSystemProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonSystemProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Newton's Method for Systems \
in n-Dimensions).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(NewtonSystem[P0_, \[Epsilon]_, max_]\), ":=", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({dist = 1, F0, J0, k = 0, P}\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], " ", "=", " ", "P0"}], ";", 
                " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", ",", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"]}], "]"}], ";", " ", 
                "\[IndentingNewLine]", 
                RowBox[{"While", "[", " ", 
                  
                  RowBox[{\(And[\ k < max, dist > \[Epsilon]\ ]\), ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], " ", "=", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "0"], " ", "-", " ", 
                          RowBox[{
                            RowBox[{"Inverse", "[", 
                              RowBox[{"J", "[", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"], "]"}], "]"}], 
                            ".", 
                            RowBox[{\(F\&\[RightVector]\), "[", 
                              SubscriptBox[
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["P",
                                      FontWeight->"Bold"], "\[RightVector]"],
                                  FontWeight->"Bold"], "0"], "]"}]}]}]}], ";",
                       " ", "\[IndentingNewLine]", 
                      RowBox[{"Print", "[", 
                        RowBox[{
                          SubscriptBox["\"\<\!\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\>\"", \(k + 1\)], ",", "\"\< = \>\"", ",", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "1"]}], "]"}], ";", "  ", 
                      "\[IndentingNewLine]", 
                      RowBox[{"dist", " ", "=", " ", 
                        SqrtBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"]}], ")"}], ".", 
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"]}], ")"}]}]]}], 
                      ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], " ", "=", " ", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"]}], ";", " ", 
                      "\[IndentingNewLine]", \(k\  = \ k + 1\), ";"}]}], "  ",
                   "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Return", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}], ";"}]}], " ", "]"}]}],
         ";"}], " "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method to solve the nonlinear system  \n\n\t\t",
  Cell[BoxData[{
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_1\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(1 - 4\ x + 2\ x\^2 - 2\ y\^3\)}]}], "\n", 
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_2\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(\(-\ 4\) + x\^4 + 
            4\ y + \(\(4\)\(\ \)\(y\^4\)\(\ \)\)\)}]}]}]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(f\_2\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}]}]],
    AspectRatioFixed->False],
  " and construct the vector function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  " using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{x_, y_}] = 1 - 4\ x + 2\ x\^2 - 2\ y\^3;\)\ \ \), "\n", 
    \(\(f\_2[{x_, y_}] = \(-4\) + x\^4 + 4\ y + 4\ y\^4;\)\ \ \), "\n", 
    \(\(F\&\[RightVector][{x_, y_}] = {f\_1[{x, y}], 
          f\_2[{x, y}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_}] = 
        Transpose[{\[PartialD]\_x\ F\&\[RightVector][{x, y}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y}]}];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", 
        f\_1[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", 
        f\_2[{x, y}]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<    J(x,y) = \>", MatrixForm[J[{x, y}]]];\)\ \ \)}], "Input",\

  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the curves ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[{f\_1[{x, y}] \[Equal] 0, 
          f\_2[{x, y}] \[Equal] 0}, {x, \ \(-2\), \ 2}, {y, \ \(-2\), \ 1}, 
        PlotStyle \[Rule] \ {Red, Blue}];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Use the Newton-Raphson method to find a numerical approximation to the \
solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0.1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0.7"}], ")"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(P\&\[RightVector]\), "=", 
          RowBox[{"NewtonSystem", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-8\)\), " ", ",", 
              "100"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "A solution to the system satisfies ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Our last approximation is stored in ",
  Cell[BoxData[
      StyleBox[\(P\&\[RightVector]\),
        FontWeight->"Bold"]]],
  ", check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell["\<\
Accuracy is determined by the tolerance and number of iterations.  How \
accurate was the solution \"really\"? \
\>", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        NumberForm[P\&\[RightVector], 17]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[F\&\[RightVector][P\&\[RightVector]], 17]];\)\ \)}], "Input"],

Cell["Do you think that iteration produced the solution ? Why ?  ", "Text"],

Cell[TextData[{
  "Compare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in routine."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[{f\_1[{x, y}] \[Equal] 0, f\_2[{x, y}] \[Equal] 0}, {x, 
            0.1}, {y, 0.7}];\)\ \ \), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(q = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(Print[solset];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = {\>\"", p, "\<, \>", 
        q, "\<}\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][{p, q}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Whose answer is best, ours or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ?  How can this be ?  Find out how to increase the number of iterations \
in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine."
}], "Text"],

Cell[BoxData[
    \(\(\(Options[FindRoot]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Use the Newton-Raphson method to find a numerical approximation to the \
solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"1.5", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(-0.5\)}], ")"}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "=", " ", \({1.5, \(-0.5\)}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(P\&\[RightVector]\), "=", 
          RowBox[{"NewtonSystem", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-8\)\), " ", ",", 
              "100"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "A solution to the system satisfies ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Our last approximation is stored in ",
  Cell[BoxData[
      \(P\&\[RightVector]\)],
    FontWeight->"Bold"],
  ", check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell["Do you think that iteration produced the solution ? Why ?  ", "Text"],

Cell[TextData[{
  "Compare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in routine."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[{f\_1[{x, y}] \[Equal] 0, f\_2[{x, y}] \[Equal] 0}, {x, 
            1.5}, {y, \(-0.5\)}];\)\ \ \), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(q = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(Print[solset];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = {\>\"", p, "\<, \>", 
        q, "\<}\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][{p, q}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Whose answer is best, ours or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ?  How can this be ?  Find out how to increase the number of iterations \
in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine."
}], "Text"],

Cell[BoxData[
    \(\(\(Options[FindRoot]\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the systems in examples 1 and 2 are equivalent.  The system  \n\
\n\t\t",
  Cell[BoxData[{
      \(x\  = \ \(2  x\^2\  - \ 2  y\^3\  + \ 1\)\/4\), "\n", 
      \(y\  = \ \(\(-\ x\^4\)\  - \ 4\ y\^4\  + \ 8\ y\  + \ 4\)\/12\)}]],
  "  \n\t\nis equivalent to the system  \n\n\t\t",
  Cell[BoxData[{
      \(0\  = \ \ \ 1 - 4\ x + 2\ x\^2 - 2\ y\^3\), "\n", 
      \(0\  = \ \(-\ 4\) + x\^4 + 4\ y + \(\(4\)\(\ \)\(y\^4\)\(\ \)\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "You can do this by hand or you can try a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " derivation.  "
}], "Text"],

Cell["Change the second equation.  ", "Text"],

Cell[BoxData[
    \(eq1 = \(\(\(2  x\^2 - 2  y\^3 + 
              1\)\/4\)\(\[Equal]\)\(x\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(eq1\)\(=\)\(Thread[4\ eq1, Equal]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Thread[eq1 - 4  x, Equal]\)\(\ \ \)\)\)], "Input"],

Cell["Change the second equation.  ", "Text"],

Cell[BoxData[
    \(eq2 = \(\(y\)\(\[Equal]\)\(\(\(-x\^4\) - 4\ y\^4 + 8\ y + 
              4\)\/12\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(eq2\)\(=\)\(Thread[12\ eq2, Equal]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Thread[\ eq2 - 12  y, Equal]\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show how Newton's method is in reality a fixed point iteration scheme.  \
Use the system    \n\n\t\t",
  Cell[BoxData[{
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_1\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(1 - 4\ x + 2\ x\^2 - 2\ y\^3\)}]}], "\n", 
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_2\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", 
          "=", \(\(-\ 4\) + x\^4 + 
            4\ y + \(\(4\)\(\ \)\(y\^4\)\(\ \)\)\)}]}]}]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(f\_2\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}]}]],
    AspectRatioFixed->False],
  " and construct the vector function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  " using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{x_, y_}] = 1 - 4\ x + 2\ x\^2 - 2\ y\^3;\)\ \ \), "\n", 
    \(\(f\_2[{x_, y_}] = \(-\ 4\) + x\^4 + 4\ y + 4\ y\^4;\)\ \ \), "\n", 
    \(\(F\&\[RightVector][{x_, y_}] = {f\_1[{x, y}], 
          f\_2[{x, y}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_}] = 
        Transpose[{\[PartialD]\_x\ F\&\[RightVector][{x, y}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y}]}];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", 
        f\_1[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", 
        f\_2[{x, y}]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<    J(x,y) = \>", MatrixForm[J[{x, y}]]];\)\ \ \)}], "Input",\

  AspectRatioFixed->False],

Cell[TextData[{
  "Construct the Newton-Raphson fixed point function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(G\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(G\&\[RightVector][{x_, y_}]\  = \ {x, y}\  - \ 
          Inverse[J[{x, y}]] . 
            F\&\[RightVector][{x, y}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(G\&\[RightVector]\)[{x,y}] = \>\"", 
        G\&\[RightVector][{x, y}]\ ];\)\ \ \ \)}], "Input"],

Cell[TextData[{
  "Use fixed point iteration and the above fixed point function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(G\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  " to find a numerical approximation to the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0.1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0.7"}], ")"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(P\&\[RightVector]\), " ", "=", " ", 
          RowBox[{"FixPoint", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-8\)\), ",", 
              "100"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "A fixed point satisfies the equation  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\&\[RightVector]\),
          FontWeight->"Bold"], "=", 
        RowBox[{
          StyleBox[\(G\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{"(", 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}]}]]],
  ".  Our last approximation is stored in  ",
  Cell[BoxData[
      \(P\&\[RightVector]\)],
    AspectRatioFixed->False,
    FontWeight->"Bold"],
  ",  check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(G\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", G\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell["\<\
Accuracy is determined by the tolerance and number of iterations.  How \
accurate was the solution? \
\>", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        NumberForm[P\&\[RightVector], 15]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(G\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[G\&\[RightVector][P\&\[RightVector]], 15]];\)\ \)}], "Input"],

Cell[TextData[{
  "Compare these values with those obtained with the Newton-Raphson method \
for finding a numerical approximation to the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0.1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0.7"}], ")"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(P\&\[RightVector]\  = \ 
          NewtonSystem[{0.1, 0.7}, 10\^\(-8\)\ , 100];\), "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "A solution to the system satisfies ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Our last approximation is stored in ",
  Cell[BoxData[
      StyleBox[\(P\&\[RightVector]\),
        FontWeight->"Bold"]]],
  ", check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell["\<\
Accuracy is determined by the tolerance and number of iterations.  How \
accurate was the solution? \
\>", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        NumberForm[P\&\[RightVector], 17]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[F\&\[RightVector][P\&\[RightVector]], 17]];\)\ \)}], "Input"],

Cell["\<\
This Newton-Raphson solution is the same as the one obtained using fixed \
point iteration.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Use fixed point iteration and the above fixed point function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(G\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  " to find a numerical approximation to the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"1.5", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(-0.5\)}], ")"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.5, \(-0.5\)}\)}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(P\&\[RightVector]\), " ", "=", " ", 
          RowBox[{"FixPoint", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-8\)\), ",", 
              "100"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "A fixed point satisfies the equation  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\&\[RightVector]\),
          FontWeight->"Bold"], "=", 
        RowBox[{
          StyleBox[\(G\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{"(", 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}]}]]],
  ".  Our last approximation is stored in  ",
  Cell[BoxData[
      \(P\&\[RightVector]\)],
    AspectRatioFixed->False,
    FontWeight->"Bold"],
  ",  check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        NumberForm[P\&\[RightVector], 15]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(G\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[G\&\[RightVector][P\&\[RightVector]], 15]];\)\ \)}], "Input"],

Cell[TextData[{
  "Compare these values with those obtained with the Newton-Raphson method \
for finding a numerical approximation to the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"1.5", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(-0.5\)}], ")"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.5, \(-0.5\)}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(P\&\[RightVector]\), " ", "=", " ", 
          RowBox[{"NewtonSystem", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-8\)\), " ", ",", 
              "100"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "A solution to the system satisfies ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Our last approximation is stored in ",
  Cell[BoxData[
      StyleBox[\(P\&\[RightVector]\),
        FontWeight->"Bold"]]],
  ", check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        NumberForm[P\&\[RightVector], 17]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[F\&\[RightVector][P\&\[RightVector]], 17]];\)\ \)}], "Input"],

Cell["\<\
This Newton-Raphson solution is the same as the one obtained using fixed \
point iteration.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Observe that the subroutine ",
  StyleBox["NewtonSystem",
    FontWeight->"Bold"],
  " involves vector functions and is not dependent on the dimension. \nUse \
the subroutine NewtonSystem to solve the nonlinear system in 3D space:  \n\n\t\
\t",
  Cell[BoxData[
      \(0\  = \ 9\ x\^2 + 36  y\^2 + 4  z\^2 - 36\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - 2\ y\^2 - 20  z\)],
    AspectRatioFixed->False],
  "  \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - y\^2 + z\^2\)],
    AspectRatioFixed->False],
  "  \n\t\n",
  StyleBox["Hint.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There are four solutions.  Good starting vectors are ",
  Cell[BoxData[
      RowBox[{
        StyleBox["P0",
          FontWeight->"Bold"], 
        "=", \({\(\[PlusMinus]1\), \(\[PlusMinus]1\), 0}\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{\(f\_2\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], "  ",
           
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], 
          RowBox[{\(f\_2\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], 
            "]"}]}]}]],
    AspectRatioFixed->False],
  " and construct the vector function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  " using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{x_, y_, z_}] = 
        9\ x\^2 + 36  y\^2 + 4  z\^2 - 36;\)\ \ \ \), "\n", 
    \(\(f\_2[{x_, y_, z_}] = x\^2 - 2\ y\^2 - 20  z;\)\ \ \ \), "\n", 
    \(\(f\_3[{x_, y_, z_}] = 
        x\^2 - y\^2 + z\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(F\&\[RightVector][{x_, y_, z_}] = {f\_1[{x, y, z}], f\_2[{x, y, z}], 
          f\_3[{x, y, z}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_, z_}] = 
        Transpose[{\[PartialD]\_x\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_z\ 
              F\&\[RightVector][{x, y, 
                  z}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<    J(x,y,z) = \>", 
        MatrixForm[J[{x, y, z}]]];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the curves ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ContourPlot3D`\>"];\)\ \ \), "\[IndentingNewLine]", \

    \(\(graph1 = 
        ContourPlot3D[
          9\ x\^2 + 36  y\^2 + 4  z\^2 - 36, {x, \(-1.2\), 
            1.2}, {y, \(-1.2\), 1.2}, {z, \(-1.2\), 1.2}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ContourPlot3D[
          x\^2 - 2\ y\^2 - 20  z, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ContourPlot3D[
          x\^2 - y\^2 + z\^2, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Use the Newton-Raphson method to find a numerical approximation to the \
solution near ",
  Cell[BoxData[
      \(\((1.0, 1.0, 0.0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(P0 = {1.0, 1.0, 0.0};\)\ \ \), "\[IndentingNewLine]", 
    \(\(P\&\[RightVector] = 
        NewtonSystem[P0, 10\^\(-8\)\ , 100];\)\ \ \)}], "Input"],

Cell[TextData[{
  "A solution to the system satisfies ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Our last approximation is stored in ",
  Cell[BoxData[
      StyleBox[\(P\&\[RightVector]\),
        FontWeight->"Bold"]]],
  ", check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell[TextData[{
  "Use the Newton-Raphson method to find a numerical approximation to the \
solution near ",
  Cell[BoxData[
      \(\((1.0, \(-1.0\), 0.0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(P0 = {1.0, \(-1.0\), 0.0};\)\ \ \), "\[IndentingNewLine]", 
    \(\(P\&\[RightVector] = 
        NewtonSystem[P0, 10\^\(-8\)\ , 100];\)\ \ \)}], "Input"],

Cell[TextData[{
  "A solution to the system satisfies ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Our last approximation is stored in ",
  Cell[BoxData[
      StyleBox[\(P\&\[RightVector]\),
        FontWeight->"Bold"]]],
  ", check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell[TextData[{
  "Use the Newton-Raphson method to find a numerical approximation to the \
solution near ",
  Cell[BoxData[
      \(\((\(-1.0\), 1.0, 0.0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(P0 = {\(-1.0\), 1.0, 0.0};\)\ \ \), "\[IndentingNewLine]", 
    \(\(P\&\[RightVector] = 
        NewtonSystem[P0, 10\^\(-8\)\ , 100];\)\ \ \)}], "Input"],

Cell[TextData[{
  "A solution to the system satisfies ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Our last approximation is stored in ",
  Cell[BoxData[
      StyleBox[\(P\&\[RightVector]\),
        FontWeight->"Bold"]]],
  ", check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell[TextData[{
  "Use the Newton-Raphson method to find a numerical approximation to the \
solution near ",
  Cell[BoxData[
      \(\((\(-1.0\), \(-1.0\), 0.0)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(P0 = {\(-1.0\), \(-1.0\), 0.0};\)\ \ \), "\[IndentingNewLine]", 
    \(\(P\&\[RightVector] = 
        NewtonSystem[P0, 10\^\(-8\)\ , 100];\)\ \ \)}], "Input"],

Cell[TextData[{
  "A solution to the system satisfies ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Our last approximation is stored in ",
  Cell[BoxData[
      StyleBox[\(P\&\[RightVector]\),
        FontWeight->"Bold"]]],
  ", check it out.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = \>\"", 
        P\&\[RightVector]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", F\&\[RightVector][P\&\[RightVector]]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " solve the system analytically.  There is a surprise."
}], "Text"],

Cell[BoxData[{
    \(\(eqns = {f\_1[{x, y, z}] \[Equal] 0, f\_2[{x, y, z}] \[Equal] 0, 
          f\_3[{x, y, z}] \[Equal] 0};\)\), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqns, {x, y, z}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of equations\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[N[solset]]];\)\)}], "Input"],

Cell[TextData[{
  "Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " performs its solution using complex number arithmetic, the first four \
solutions are extraneous. \nThe solutions that we seek are the latter four \
solutions where x, y, and z are real numbers.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Non-Linear Systems",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/n2.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Non-Linear Systems",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/n2.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Non-Linear Systems",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/NewtonSystemBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Non-Linear Systems",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonSystemBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 209, 5, 35, "Text"],
Cell[1988, 60, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3467, 112, 1678, 45, 220, "Text"],
Cell[5148, 159, 8460, 239, 243, "Text"],
Cell[13611, 400, 2374, 61, 365, "Text"],
Cell[15988, 463, 1809, 55, 172, "Text"],
Cell[17800, 520, 382, 9, 71, "Text"],
Cell[18185, 531, 9188, 254, 239, "Text"],
Cell[27376, 787, 6588, 189, 217, "Text"],
Cell[33967, 978, 15879, 444, 473, "Text"],
Cell[49849, 1424, 611, 20, 33, "Text"],
Cell[50463, 1446, 4136, 118, 124, "Text"],
Cell[54602, 1566, 7955, 216, 162, "Text"],
Cell[62560, 1784, 2231, 71, 185, "Text"],
Cell[64794, 1857, 597, 19, 33, "Text"],
Cell[65394, 1878, 169, 3, 33, "Text"],
Cell[65566, 1883, 5835, 122, 267, "Input"],
Cell[71404, 2007, 1421, 39, 104, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[72850, 2050, 101, 2, 33, "Text"],
Cell[72954, 2054, 1288, 40, 33, "Text"],
Cell[74245, 2096, 433, 8, 126, "Input"],
Cell[74681, 2106, 1705, 47, 52, "Text"],
Cell[76389, 2155, 349, 5, 70, "Input"],
Cell[76741, 2162, 608, 18, 52, "Text",
  Evaluatable->False],
Cell[77352, 2182, 800, 23, 53, "Input"],
Cell[78155, 2207, 557, 18, 33, "Text"],
Cell[78715, 2227, 252, 4, 55, "Input"],
Cell[78970, 2233, 75, 0, 33, "Text"],
Cell[79048, 2235, 135, 3, 33, "Text"],
Cell[79186, 2240, 286, 4, 55, "Input"],
Cell[79475, 2246, 179, 6, 33, "Text"],
Cell[79657, 2254, 573, 16, 52, "Text"],
Cell[80233, 2272, 775, 22, 53, "Input"],
Cell[81011, 2296, 528, 17, 33, "Text"],
Cell[81542, 2315, 252, 4, 55, "Input"],
Cell[81797, 2321, 485, 15, 33, "Text"],
Cell[82285, 2338, 696, 24, 52, "Text"],
Cell[82984, 2364, 394, 7, 90, "Input"],
Cell[83381, 2373, 123, 3, 33, "Text"],
Cell[83507, 2378, 136, 3, 33, "Text"],
Cell[83646, 2383, 82, 1, 30, "Input"],
Cell[83731, 2386, 152, 3, 42, "Input"],
Cell[83886, 2391, 168, 3, 54, "Input"],
Cell[84057, 2396, 82, 1, 31, "Input"],
Cell[84142, 2399, 73, 1, 30, "Input"],
Cell[84218, 2402, 154, 3, 33, "Text"],
Cell[84375, 2407, 74, 1, 30, "Input"],
Cell[84452, 2410, 399, 8, 91, "Text"],
Cell[84854, 2420, 175, 4, 52, "Text"],
Cell[85032, 2426, 371, 10, 31, "Input"],
Cell[85406, 2438, 281, 8, 71, "Text"],
Cell[85690, 2448, 612, 13, 76, "Input"],
Cell[86305, 2463, 4008, 110, 233, "Text"],
Cell[90316, 2575, 1551, 25, 262, "Input"],
Cell[91870, 2602, 158, 3, 33, "Text"]
}, Closed]],
Cell[92043, 2608, 3376, 98, 421, "Text"],
Cell[95422, 2708, 1172, 34, 219, "Text"],
Cell[96597, 2744, 1293, 39, 162, "Text"],
Cell[97893, 2785, 3041, 92, 90, "Text"],
Cell[100937, 2879, 6212, 190, 375, "Text"],
Cell[107152, 3071, 611, 20, 33, "Text"],
Cell[107766, 3093, 597, 19, 33, "Text"],
Cell[108366, 3114, 175, 3, 33, "Text"],
Cell[108544, 3119, 6800, 142, 269, "Input"],
Cell[115347, 3263, 1395, 38, 88, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[116767, 3305, 101, 2, 33, "Text"],
Cell[116871, 3309, 2168, 66, 33, "Text"],
Cell[119042, 3377, 814, 16, 193, "Input"],
Cell[119859, 3395, 1159, 35, 33, "Text"],
Cell[121021, 3432, 351, 5, 70, "Input"],
Cell[121375, 3439, 536, 17, 33, "Text",
  Evaluatable->False],
Cell[121914, 3458, 811, 23, 53, "Input"],
Cell[122728, 3483, 595, 19, 33, "Text"],
Cell[123326, 3504, 252, 4, 55, "Input"],
Cell[123581, 3510, 135, 3, 33, "Text"],
Cell[123719, 3515, 286, 4, 55, "Input"],
Cell[124008, 3521, 75, 0, 33, "Text"],
Cell[124086, 3523, 171, 7, 33, "Text",
  Evaluatable->False],
Cell[124260, 3532, 652, 14, 135, "Input"],
Cell[124915, 3548, 272, 9, 33, "Text"],
Cell[125190, 3559, 66, 1, 30, "Input"],
Cell[125259, 3562, 491, 15, 33, "Text"],
Cell[125753, 3579, 828, 23, 53, "Input"],
Cell[126584, 3604, 581, 19, 33, "Text"],
Cell[127168, 3625, 252, 4, 55, "Input"],
Cell[127423, 3631, 75, 0, 33, "Text"],
Cell[127501, 3633, 171, 7, 33, "Text",
  Evaluatable->False],
Cell[127675, 3642, 657, 14, 135, "Input"],
Cell[128335, 3658, 272, 9, 33, "Text"],
Cell[128610, 3669, 66, 1, 30, "Input"]
}, Closed]],
Cell[128691, 3673, 566, 14, 194, "Text"],

Cell[CellGroupData[{
Cell[129282, 3691, 101, 2, 33, "Text"],
Cell[129386, 3695, 145, 5, 33, "Text"],
Cell[129534, 3702, 45, 0, 33, "Text"],
Cell[129582, 3704, 115, 2, 45, "Input"],
Cell[129700, 3708, 82, 1, 30, "Input"],
Cell[129785, 3711, 74, 1, 30, "Input"],
Cell[129862, 3714, 45, 0, 33, "Text"],
Cell[129910, 3716, 123, 2, 45, "Input"],
Cell[130036, 3720, 81, 1, 30, "Input"],
Cell[130120, 3723, 75, 1, 30, "Input"]
}, Closed]],
Cell[130210, 3727, 1431, 39, 85, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[131666, 3770, 101, 2, 33, "Text"],
Cell[131770, 3774, 2168, 66, 33, "Text"],
Cell[133941, 3842, 816, 16, 193, "Input"],
Cell[134760, 3860, 355, 12, 33, "Text"],
Cell[135118, 3874, 296, 5, 53, "Input"],
Cell[135417, 3881, 837, 26, 33, "Text",
  Evaluatable->False],
Cell[136257, 3909, 811, 23, 53, "Input"],
Cell[137071, 3934, 557, 18, 33, "Text"],
Cell[137631, 3954, 252, 4, 55, "Input"],
Cell[137886, 3960, 124, 3, 33, "Text"],
Cell[138013, 3965, 286, 4, 55, "Input"],
Cell[138302, 3971, 582, 17, 33, "Text",
  Evaluatable->False],
Cell[138887, 3990, 475, 13, 53, "Input"],
Cell[139365, 4005, 595, 19, 33, "Text"],
Cell[139963, 4026, 252, 4, 55, "Input"],
Cell[140218, 4032, 124, 3, 33, "Text"],
Cell[140345, 4037, 286, 4, 55, "Input"],
Cell[140634, 4043, 163, 5, 33, "Text",
  Evaluatable->False],
Cell[140800, 4050, 840, 26, 33, "Text",
  Evaluatable->False],
Cell[141643, 4078, 816, 23, 53, "Input"],
Cell[142462, 4103, 557, 18, 33, "Text"],
Cell[143022, 4123, 286, 4, 55, "Input"],
Cell[143311, 4129, 585, 17, 33, "Text",
  Evaluatable->False],
Cell[143899, 4148, 826, 23, 53, "Input"],
Cell[144728, 4173, 595, 19, 33, "Text"],
Cell[145326, 4194, 286, 4, 55, "Input"],
Cell[145615, 4200, 163, 5, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[145793, 4208, 1025, 34, 163, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[146843, 4246, 101, 2, 33, "Text"],
Cell[146947, 4250, 3623, 106, 33, "Text"],
Cell[150573, 4358, 1148, 23, 213, "Input"],
Cell[151724, 4383, 1159, 35, 33, "Text"],
Cell[152886, 4420, 1259, 27, 173, "Input"],
Cell[154148, 4449, 225, 8, 33, "Text",
  Evaluatable->False],
Cell[154376, 4459, 171, 3, 52, "Input"],
Cell[154550, 4464, 595, 19, 33, "Text"],
Cell[155148, 4485, 252, 4, 55, "Input"],
Cell[155403, 4491, 230, 8, 33, "Text",
  Evaluatable->False],
Cell[155636, 4501, 176, 3, 52, "Input"],
Cell[155815, 4506, 595, 19, 33, "Text"],
Cell[156413, 4527, 252, 4, 55, "Input"],
Cell[156668, 4533, 230, 8, 33, "Text",
  Evaluatable->False],
Cell[156901, 4543, 176, 3, 52, "Input"],
Cell[157080, 4548, 595, 19, 33, "Text"],
Cell[157678, 4569, 252, 4, 55, "Input"],
Cell[157933, 4575, 235, 8, 33, "Text",
  Evaluatable->False],
Cell[158171, 4585, 181, 3, 52, "Input"],
Cell[158355, 4590, 595, 19, 33, "Text"],
Cell[158953, 4611, 252, 4, 55, "Input"],
Cell[159208, 4617, 334, 12, 71, "Text"],
Cell[159545, 4631, 540, 9, 150, "Input"],
Cell[160088, 4642, 293, 7, 52, "Text"]
}, Closed]],
Cell[160396, 4652, 699, 20, 30, "Text"],
Cell[161098, 4674, 158, 3, 35, "Text"],
Cell[161259, 4679, 556, 16, 33, "Text"],
Cell[161818, 4697, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

