(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    301476,       8372]*)
(*NotebookOutlinePosition[    302143,       8395]*)
(*  CellTagsIndexPosition[    302099,       8391]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Broyden's Method",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  StyleBox["Numerical Methods Using Mathematica \nComplementary Supplement \n\
for ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Numerical Analysis - Numerical Methods",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" \n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["(c) ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2005",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  TextAlignment->Center]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tNewton's method can be used to solve systems of nonlinear equations. \
"
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" (Newton-Raphson Method for 2-dimensional Systems).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  To solve the non-linear system  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(X\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ",  given one initial approximation  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "0"]]],
  ",  and generating a sequence  ",
  Cell[BoxData[
      RowBox[{"{", 
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "k"], "}"}]]],
  StyleBox["  which converges to the solution  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["P",
            FontWeight->"Bold"], "\[RightVector]"],
        FontWeight->"Bold"]]],
  ",  i.e.",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".   Suppose that  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "k"]]],
  "  has been obtained, use the following steps to obtain  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], \(k + 1\)]]],
  ".  \n\n",
  StyleBox["Step 1.",
    FontColor->RGBColor[0, 0, 1]],
  "\t Evaluate the function   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"], "k"],
              FontWeight->"Bold"], ")"}]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(f\_1\) \((p\_k, q\_k)\)\)},
              {\(\(f\_2\) \((p\_k, q\_k)\)\)}
              }], ")"}]}]]],
  ".\n\n",
  StyleBox["Step 2.",
    FontColor->RGBColor[0, 0, 1]],
  "  Evaluate the Jacobian   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"], "k"],
              FontWeight->"Bold"], ")"}]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(\[PartialD]\/\[PartialD]x\) \(f\_1\) \((p\_k, 
                    q\_k)\)\), \(\(\[PartialD]\/\[PartialD]y\) \(f\_1\) \
\((p\_k, q\_k)\)\)},
              {\(\(\[PartialD]\/\[PartialD]x\) \(f\_2\) \((p\_k, 
                    q\_k)\)\), \(\(\[PartialD]\/\[PartialD]y\) \(f\_2\) \
\((p\_k, q\_k)\)\)}
              }], ")"}]}]]],
  ".  \n\n",
  StyleBox["Step 3.",
    FontColor->RGBColor[0, 0, 1]],
  "  Solve the linear system   ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            StyleBox["J",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              StyleBox[
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"], "k"],
                FontWeight->"Bold"], ")"}], "\[CapitalDelta]", 
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"]}], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox[\(-\ F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"], "k"],
                FontWeight->"Bold"], ")"}]}]}]}]]],
  "   for   ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"\[CapitalDelta]", 
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"]}]}]]],
  ".  \n\n",
  StyleBox["Step 4.",
    FontColor->RGBColor[0, 0, 1]],
  "  Compute the next approximation   ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], \(k + 1\)], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "k"], " ", "+", 
          RowBox[{"\[CapitalDelta]", 
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " ",
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonSystemProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Nonlinear Systems",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonSystemProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Newton's Method for Systems \
in n-Dimensions).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(NewtonSystem[P0_, \[Epsilon]_, max_]\), ":=", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            RowBox[{\({dist = 1, k = 0, P}\), ",", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], " ", "=", " ", "P0"}], ";", 
                " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"While", "[", " ", 
                  
                  RowBox[{\(And[\ k < max, dist > \[Epsilon]\ ]\), ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      
                      RowBox[{\(\[CapitalDelta]P\&\[RightVector]\), " ", "=", 
                        " ", 
                        RowBox[{"LinearSolve", "[", " ", 
                          RowBox[{
                            RowBox[{"J", "[", 
                              SubscriptBox[
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["P",
                                      FontWeight->"Bold"], "\[RightVector]"],
                                  FontWeight->"Bold"], "0"], "]"}], " ", ",", 
                            
                            RowBox[{"-", " ", 
                              RowBox[{\(F\&\[RightVector]\), "[", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"], "]"}]}]}], 
                          "]"}]}], ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], " ", "=", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "0"], " ", "+", 
                          " ", \(\[CapitalDelta]P\&\[RightVector]\)}]}], ";", 
                      " ", "\[IndentingNewLine]", 
                      RowBox[{"Print", "[", 
                        RowBox[{
                          SubscriptBox["\"\<\!\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\>\"", \(k + 1\)], ",", "\"\< = \>\"", ",", 
                          RowBox[{"NumberForm", "[", 
                            RowBox[{
                              SubscriptBox[
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["P",
                                      FontWeight->"Bold"], "\[RightVector]"],
                                  FontWeight->"Bold"], "1"], ",", "17"}], 
                            "]"}]}], "]"}], ";", "  ", "\[IndentingNewLine]", 
                      
                      RowBox[{"dist", " ", "=", " ", 
                        SqrtBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"]}], ")"}], ".", 
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"]}], ")"}]}]]}], 
                      ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], " ", "=", " ", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"]}], ";", " ", 
                      "\[IndentingNewLine]", \(k\  = \ k + 1\), ";"}]}], "  ",
                   "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "2"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{x,y}] = \>\"", MatrixForm[F\&\[RightVector][{x, y}]]]\)}], 
                  " ", "]"}], ";", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "3"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{x,y,z}] = \>\"", 
                      MatrixForm[F\&\[RightVector][{x, y, z}]]]\)}], "  ", 
                  "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "4"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{w,x,y,z}] = \>\"", 
                      MatrixForm[F\&\[RightVector][{w, x, y, z}]]]\)}], "  ", 
                  "]"}], ";", " ", 
                "\[IndentingNewLine]", \(Print["\<The Newton-Raphson solution \
to \>", \*"\"\<\!\(F\&\[RightVector]\)[{x,y}] = \!\(0\&\[RightVector]\)\>\"", \
"\< is\>"]\), ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<  \!\(P\&\[RightVector]\)  = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{
                  "\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        RowBox[{\(F\&\[RightVector]\), "[", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "0"], "]"}], ",", "17"}], 
                      "]"}]}], " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Return", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}], ";"}]}], " ", "]"}]}],
         ";"}], " "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Newton's method to solve the nonlinear system  \n\n\t\t",
  Cell[BoxData[{
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_1\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(1 - 4\ x + 2\ x\^2 - 2\ y\^3\)}]}], "\n", 
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_2\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(\(-\ 4\) + x\^4 + 
            4\ y + \(\(4\)\(\ \)\(y\^4\)\(\ \)\)\)}]}]}]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(f\_2\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}]}]],
    AspectRatioFixed->False],
  " and construct the vector function  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  "  using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{x_, y_}] = 1 - 4\ x + 2\ x\^2 - 2\ y\^3;\)\ \ \), "\n", 
    \(\(f\_2[{x_, y_}] = \(-4\) + x\^4 + 4\ y + 4\ y\^4;\)\ \ \), "\n", 
    \(\(F\&\[RightVector][{x_, y_}] = {f\_1[{x, y}], 
          f\_2[{x, y}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_}] = 
        Transpose[{\[PartialD]\_x\ F\&\[RightVector][{x, y}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y}]}];\)\ \ \), "\n", 
    \(\(Print["\<Solve\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", 
        f\_1[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", 
        f\_2[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[{x,y}] = \>\"", 
        MatrixForm[
          F\&\[RightVector][{x, y}]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<  J(x,y) = \>", MatrixForm[J[{x, y}]]\ ];\)\ \ \)}], "Input",\

  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the curves  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  "  using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[{f\_1[{x, y}] \[Equal] 0, 
          f\_2[{x, y}] \[Equal] 0}, {x, \ \(-2\), \ 2}, {y, \ \(-2\), \ 1}, 
        PlotStyle \[Rule] \ {Red, Blue}, 
        Ticks \[Rule] {Range[\(-1.5\), 2.0, 0.5], 
            Range[\(-1.0\), 1.0, 0.5]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", 
        f\_1[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", 
        f\_2[{x, y}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Newton-Raphson method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", 
        RowBox[{"(", 
          RowBox[{"0.1", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "0.7"}], ")"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Accuracy is determined by the tolerance and number of iterations.  How \
accurate was the solution \"really\"? \
\>", "Text"],

Cell["Do you think that iteration produced the solution ? Why ?  ", "Text"],

Cell[TextData[{
  "Compare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in routine."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[{f\_1[{x, y}] \[Equal] 0, f\_2[{x, y}] \[Equal] 0}, {x, 
            0.1}, {y, 0.7}];\)\ \ \), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(q = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(Print["\<  \>", NumberForm[solset, 17]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = {\>\"", 
        NumberForm[p, 17], "\<, \>", 
        NumberForm[q, 17], "\<}\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[F\&\[RightVector][{p, q}], 17]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Whose answer is best, ours or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ?  How can this be ?  Find out how to increase the number of iterations \
in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine."
}], "Text"],

Cell[BoxData[
    \(\(\(Options[FindRoot]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(?AccuracyGoal\)\)], "Input"],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[{f\_1[{x, y}] \[Equal] 0, f\_2[{x, y}] \[Equal] 0}, {x, 
            0.1}, {y, 0.7}, AccuracyGoal \[Rule] 17];\)\ \ \), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(q = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(Print["\<  \>", NumberForm[solset, 17]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = {\>\"", 
        NumberForm[p, 17], "\<, \>", 
        NumberForm[q, 17], "\<}\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[F\&\[RightVector][{p, q}], 17]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Newton-Raphson method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], " ", "=", " ", 
        RowBox[{"(", 
          RowBox[{"1.5", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(-0.5\)}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "=", " ", \({1.5, \(-0.5\)}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell["Do you think that iteration produced the solution ? Why ?  ", "Text"],

Cell[TextData[{
  "Compare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in routine."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ 
        FindRoot[{f\_1[{x, y}] \[Equal] 0, f\_2[{x, y}] \[Equal] 0}, {x, 
            1.5}, {y, \(-0.5\)}, AccuracyGoal \[Rule] 16];\)\ \ \), "\n", 
    \(\(p = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(q = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\n", 
    \(\(Print["\<  \>", NumberForm[solset, 17]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<  \!\(P\&\[RightVector]\)  = {\>\"", 
        NumberForm[p, 17], "\<, \>", 
        NumberForm[q, 17], "\<}\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", NumberForm[F\&\[RightVector][{p, q}], 17]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Observe that the subroutine ",
  StyleBox["NewtonSystem",
    FontWeight->"Bold"],
  " involves vector functions and is not dependent on the dimension. \nUse \
the subroutine NewtonSystem to solve the nonlinear system in 3D space:  \n\n\t\
\t",
  Cell[BoxData[
      \(0\  = \ 9\ x\^2 + 36  y\^2 + 4  z\^2 - 36\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - 2\ y\^2 - 20  z\)],
    AspectRatioFixed->False],
  "  \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - y\^2 + z\^2\)],
    AspectRatioFixed->False],
  "  \n\t\n",
  StyleBox["Hint.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There are four solutions.  Good starting vectors are  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"], "0"],
          FontWeight->"Bold"], 
        "=", \({\(\[PlusMinus]1\), \(\[PlusMinus]1\), 0}\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{\(f\_2\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], "  ",
           
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], 
          RowBox[{\(f\_2\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], 
            "]"}]}]}]],
    AspectRatioFixed->False],
  " and construct the vector function  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  "  using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{x_, y_, z_}] = 
        9\ x\^2 + 36  y\^2 + 4  z\^2 - 36;\)\ \ \ \), "\n", 
    \(\(f\_2[{x_, y_, z_}] = x\^2 - 2\ y\^2 - 20  z;\)\ \ \ \), "\n", 
    \(\(f\_3[{x_, y_, z_}] = 
        x\^2 - y\^2 + z\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(F\&\[RightVector][{x_, y_, z_}] = {f\_1[{x, y, z}], f\_2[{x, y, z}], 
          f\_3[{x, y, z}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_, z_}] = 
        Transpose[{\[PartialD]\_x\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_z\ 
              F\&\[RightVector][{x, y, 
                  z}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<    J(x,y,z) = \>", 
        MatrixForm[J[{x, y, z}]]];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the surfaces  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  ",  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_3\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  "  using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ContourPlot3D`\>"];\)\ \ \), "\[IndentingNewLine]", \

    \(\(graph1 = 
        ContourPlot3D[
          9\ x\^2 + 36  y\^2 + 4  z\^2 - 36, {x, \(-1.2\), 
            1.2}, {y, \(-1.2\), 1.2}, {z, \(-1.2\), 1.2}, 
          Lighting \[Rule] False, ContourStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ContourPlot3D[
          x\^2 - 2\ y\^2 - 20  z, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, Lighting \[Rule] False, 
          ContourStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ContourPlot3D[
          x\^2 - y\^2 + z\^2, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, Lighting \[Rule] False, 
          ContourStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Newton-Raphson method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((1.0, 1.0, 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, 1.0, 0.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Newton-Raphson method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((1.0, \(-1.0\), 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, \(-1.0\), 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Newton-Raphson method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((\(-1.0\), 1.0, 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), 1.0, 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(iv)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Newton-Raphson method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], 
        "=", \((\(-1.0\), \(-1.0\), 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), \(-1.0\), 0.0}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " solve the system analytically.  There is a surprise."
}], "Text"],

Cell[BoxData[{
    \(\(eqns = {f\_1[{x, y, z}] \[Equal] 0, f\_2[{x, y, z}] \[Equal] 0, 
          f\_3[{x, y, z}] \[Equal] 0};\)\), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqns, {x, y, z}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of equations\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[N[solset]]];\)\)}], "Input"],

Cell[TextData[{
  "Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " performs its solution using complex number arithmetic, the first four \
solutions are extraneous. \nThe solutions that we seek are the latter four \
solutions where x, y, and z are real numbers.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["More Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tA drawback of Newton's method is the requirement that the Jacobian \
matrix be computed, which requires the calculation of  ",
  Cell[BoxData[
      \(n\^2\)]],
  "  partial derivatives per iteration.  One obvious improvement is to use a \
finite difference approximation for the Jacobian matrix.  For two dimensions \
this is \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            SubscriptBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"], "k"], ")"}]}], 
        StyleBox[" ",
          FontWeight->"Plain"], "\[TildeTilde]", " ", 
        TagBox[
          RowBox[{
            RowBox[{
              StyleBox["M",
                FontWeight->"Bold"], 
              RowBox[{"(", 
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"], "k"], ")"}]}], 
            StyleBox[" ",
              FontWeight->"Plain"], "=", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(\(\(f\_1\) \((p\_k + h, q\_k)\) - \(f\_1\) \((p\_k - h, 
                              q\_k)\)\)\/\(2\ h\)\), \(\(\(f\_1\) \((p\_k, 
                              q\_k + h)\) - \(f\_1\) \((p\_k, 
                              q\_k - h)\)\)\/\(2\ h\)\)},
                  {\(\(\(f\_2\) \((p\_k + h, q\_k)\) - \(f\_2\) \((p\_k - h, 
                              q\_k)\)\)\/\(2\ h\)\), \(\(\(f\_2\) \((p\_k, 
                              q\_k + h)\) - \(f\_2\) \((p\_k, 
                              q\_k - h)\)\)\/\(2\ h\)\)}
                  }], "\[NoBreak]", ")"}]}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], 
        StyleBox[" ",
          FontWeight->"Plain"]}]]],
  "\nwhere ",
  StyleBox["h",
    FontFamily->"Courier New"],
  " is small.  Notice that this will require",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(2  n\^2\)]],
  "  function evaluations.  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (PseudoNewton's Method for \
Systems in n-Dimensions).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(PseudoNewtonSystem[P0_, \[Epsilon]_, max_]\), ":=", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            RowBox[{\({dist = 1, k = 0, P}\), ",", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], " ", "=", " ", "P0"}], ";", 
                " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"While", "[", " ", 
                  
                  RowBox[{\(And[\ k < max, dist > \[Epsilon]\ ]\), ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      
                      RowBox[{\(\[CapitalDelta]P\&\[RightVector]\), " ", "=", 
                        " ", 
                        RowBox[{"LinearSolve", "[", " ", 
                          RowBox[{
                            RowBox[{"M", "[", 
                              SubscriptBox[
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["P",
                                      FontWeight->"Bold"], "\[RightVector]"],
                                  FontWeight->"Bold"], "0"], "]"}], " ", ",", 
                            
                            RowBox[{"-", " ", 
                              RowBox[{\(F\&\[RightVector]\), "[", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"], "]"}]}]}], 
                          "]"}]}], ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], " ", "=", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "0"], " ", "+", 
                          " ", \(\[CapitalDelta]P\&\[RightVector]\)}]}], ";", 
                      " ", "\[IndentingNewLine]", 
                      RowBox[{"Print", "[", 
                        RowBox[{
                          SubscriptBox["\"\<\!\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\>\"", \(k + 1\)], ",", "\"\< = \>\"", ",", 
                          RowBox[{"NumberForm", "[", 
                            RowBox[{
                              SubscriptBox[
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["P",
                                      FontWeight->"Bold"], "\[RightVector]"],
                                  FontWeight->"Bold"], "1"], ",", "17"}], 
                            "]"}]}], "]"}], ";", "  ", "\[IndentingNewLine]", 
                      
                      RowBox[{"dist", " ", "=", " ", 
                        SqrtBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"]}], ")"}], ".", 
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "0"]}], ")"}]}]]}], 
                      ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], " ", "=", " ", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"]}], ";", " ", 
                      "\[IndentingNewLine]", \(k\  = \ k + 1\), ";"}]}], "  ",
                   "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "2"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{x,y}] = \>\"", MatrixForm[F\&\[RightVector][{x, y}]]]\)}], 
                  " ", "]"}], ";", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "3"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{x,y,z}] = \>\"", 
                      MatrixForm[F\&\[RightVector][{x, y, z}]]]\)}], "  ", 
                  "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "4"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{w,x,y,z}] = \>\"", 
                      MatrixForm[F\&\[RightVector][{w, x, y, z}]]]\)}], "  ", 
                  "]"}], ";", " ", 
                "\[IndentingNewLine]", \(Print["\<The Pseudo-Newton solution \
to \>", \*"\"\<\!\(F\&\[RightVector]\)[{x,y}] = \!\(0\&\[RightVector]\)\>\"", \
"\< is\>"]\), ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<  \!\(P\&\[RightVector]\)  = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{
                  "\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        RowBox[{\(F\&\[RightVector]\), "[", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "0"], "]"}], ",", "17"}], 
                      "]"}]}], " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Return", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}], ";"}]}], " ", "]"}]}],
         ";"}], " "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the ",
  "Pseudo",
  "-Newton's method to solve the nonlinear system  \n\n\t\t",
  Cell[BoxData[{
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_1\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(1 - 4\ x + 2\ x\^2 - 2\ y\^3\)}]}], "\n", 
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_2\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(\(-\ 4\) + x\^4 + 
            4\ y + \(\(4\)\(\ \)\(y\^4\)\(\ \)\)\)}]}]}]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(f\_2\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}]}]],
    AspectRatioFixed->False],
  " and construct the vector function  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  "  using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ",  and approximate Jacobian ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(\(f\_1[{x_, y_}] = 1 - 4\ x + 2\ x\^2 - 2\ y\^3;\)\ \ \), "\n", 
    \(\(f\_2[{x_, y_}] = \(-4\) + x\^4 + 4\ y + 4\ y\^4;\)\ \ \), "\n", 
    \(\(F\&\[RightVector][{x_, y_}] = {f\_1[{x, y}], 
          f\_2[{x, y}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_}] = 
        Transpose[{\[PartialD]\_x\ F\&\[RightVector][{x, y}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y}]}];\)\ \ \), "\n", 
    \(\(M[{x_, y_}] = 
        Transpose[{\(F\&\[RightVector][{x + h, y}] - F\&\[RightVector][{x - \
h, y}]\)\/\(2  h\), \(F\&\[RightVector][{x, y + h}] - F\&\[RightVector][{x, y \
- h}]\)\/\(2  h\)}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", 
        f\_1[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", 
        f\_2[{x, y}]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[{x,y}] = \>\"", 
        MatrixForm[
          F\&\[RightVector][{x, y}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<  J(x,y) = \>", 
        MatrixForm[J[{x, y}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<  M(x,y) = \>", 
        MatrixForm[M[{x, y}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(h = 0.001;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use  h = \>", h];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<M(x,y) = \>", MatrixForm[M[{x, y}]]];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the curves ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ImplicitPlot[{f\_1[{x, y}] \[Equal] 0, 
          f\_2[{x, y}] \[Equal] 0}, {x, \ \(-2\), \ 2}, {y, \ \(-2\), \ 1}, 
        PlotStyle \[Rule] \ {Red, Blue}, 
        Ticks \[Rule] {Range[\(-1.5\), 2.0, 0.5], 
            Range[\(-1.0\), 1.0, 0.5]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", 
        f\_1[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", 
        f\_2[{x, y}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the ",
  "Pseudo",
  "-Newton method to find a numerical approximation to the solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", 
        RowBox[{"(", 
          RowBox[{"0.1", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "0.7"}], ")"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "n"], " ", "=", " ", 
          RowBox[{"PseudoNewtonSystem", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
              "10"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell["Compare with the Newton-Raphson method.  ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "n"], " ", "=", " ", 
          RowBox[{"NewtonSystem", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
              "10"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Observation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  The results for the subroutines NewtonSystem and ",
  "Pseudo",
  "NewtonSystem are very close.  Obviously, the Jacobian and its \
approximation agree to several significant digits. "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<  J[\>\"", ",", \(P\&\[RightVector]\), ",", "\"\<] = \>\"", 
            ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  RowBox[{"J", "[", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "n"], "]"}], "]"}], ",", "17"}], 
              "]"}]}], " ", "]"}], ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<  M[\>\"", ",", \(P\&\[RightVector]\), ",", "\"\<] = \>\"", 
            ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  RowBox[{"M", "[", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "n"], "]"}], "]"}], ",", "17"}], 
              "]"}]}], " ", "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Pseudo-Newton method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], " ", "=", " ", 
        RowBox[{"(", 
          RowBox[{"1.5", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(-0.5\)}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "=", " ", \({1.5, \(-0.5\)}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "n"], " ", "=", " ", 
          RowBox[{"PseudoNewtonSystem", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
              "10"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell["Compare with the Newton-Raphson method.  ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "=", " ", \({1.5, \(-0.5\)}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "n"], " ", "=", " ", 
          RowBox[{"NewtonSystem", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
              "10"}], "]"}]}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Observation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  The results for the subroutines NewtonSystem and ",
  "Pseudo",
  "NewtonSystem are very close.  Obviously, the Jacobian and its \
approximation agree to several significant digits. "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<  J[\>\"", ",", \(P\&\[RightVector]\), ",", "\"\<] = \>\"", 
            ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  RowBox[{"J", "[", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "n"], "]"}], "]"}], ",", "17"}], 
              "]"}]}], " ", "]"}], ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<  M[\>\"", ",", \(P\&\[RightVector]\), ",", "\"\<] = \>\"", 
            ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  RowBox[{"M", "[", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "n"], "]"}], "]"}], ",", "17"}], 
              "]"}]}], " ", "]"}], ";"}], "  "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Observe that the subroutine ",
  StyleBox["PseudoNewtonSystem",
    FontWeight->"Bold"],
  " involves vector functions and is not dependent on the dimension. \nUse \
the subroutine NewtonSystem to solve the nonlinear system in 3D space:  \n\n\t\
\t",
  Cell[BoxData[
      \(0\  = \ 9\ x\^2 + 36  y\^2 + 4  z\^2 - 36\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - 2\ y\^2 - 20  z\)],
    AspectRatioFixed->False],
  "  \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - y\^2 + z\^2\)],
    AspectRatioFixed->False],
  "  \n\t\n",
  StyleBox["Hint.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There are four solutions.  Good starting vectors are  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"], "0"],
          FontWeight->"Bold"], 
        "=", \({\(\[PlusMinus]1\), \(\[PlusMinus]1\), 0}\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{\(f\_2\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], "  ",
           
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], 
          RowBox[{\(f\_3\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], 
            "]"}]}]}]],
    AspectRatioFixed->False],
  " and construct the vector function  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  "  using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}]]],
  ",  and approximate Jacobian ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ".    "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(\(f\_1[{x_, y_, z_}] = 
        9\ x\^2 + 36  y\^2 + 4  z\^2 - 36;\)\ \ \ \), "\n", 
    \(\(f\_2[{x_, y_, z_}] = x\^2 - 2\ y\^2 - 20  z;\)\ \ \ \), "\n", 
    \(\(f\_3[{x_, y_, z_}] = 
        x\^2 - y\^2 + z\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(F\&\[RightVector][{x_, y_, z_}] = {f\_1[{x, y, z}], f\_2[{x, y, z}], 
          f\_3[{x, y, z}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_, z_}] = 
        Transpose[{\[PartialD]\_x\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_z\ 
              F\&\[RightVector][{x, y, 
                  z}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(M[{x_, y_, z_}] = 
        Transpose[{\(F\&\[RightVector][{x + h, y, z}] - F\&\[RightVector][{x \
- h, y, z}]\)\/\(2  h\), \(F\&\[RightVector][{x, y + h, z}] - F\&\
\[RightVector][{x, y - h, z}]\)\/\(2  h\), \(F\&\[RightVector][{x, y, z + h}] \
- F\&\[RightVector][{x, y, z - h}]\)\/\(2  h\)}];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<J(x,y,z) = \>", 
        MatrixForm[J[{x, y, z}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<M(x,y,z) = \>", 
        MatrixForm[M[{x, y, z}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(h = 0.001;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use  h = \>", h];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<M(x,y,z) = \>", MatrixForm[M[{x, y, z}]]];\)\ \ \)}], "Input",\

  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the surfaces  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  ",  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_3\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  "  using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ContourPlot3D`\>"];\)\ \ \), "\[IndentingNewLine]", \

    \(\(graph1 = 
        ContourPlot3D[
          9\ x\^2 + 36  y\^2 + 4  z\^2 - 36, {x, \(-1.2\), 
            1.2}, {y, \(-1.2\), 1.2}, {z, \(-1.2\), 1.2}, 
          Lighting \[Rule] False, ContourStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ContourPlot3D[
          x\^2 - 2\ y\^2 - 20  z, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, Lighting \[Rule] False, 
          ContourStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ContourPlot3D[
          x\^2 - y\^2 + z\^2, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, Lighting \[Rule] False, 
          ContourStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Pseudo-Newton method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((1.0, 1.0, 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, 1.0, 0.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"PseudoNewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell["\<\
Compare the Pseudo-Newton result with Newton-Raphson's result.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, 1.0, 0.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Pseudo-Newton method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((1.0, \(-1.0\), 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, \(-1.0\), 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"PseudoNewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell["\<\
Compare the Pseudo-Newton result with Newton-Raphson's result.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, \(-1.0\), 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Pseudo-Newton method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((\(-1.0\), 1.0, 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), 1.0, 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"PseudoNewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell["\<\
Compare the Pseudo-Newton result with Newton-Raphson's result.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), 1.0, 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(iv)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Pseudo-Newton method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], 
        "=", \((\(-1.0\), \(-1.0\), 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), \(-1.0\), 0.0}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"PseudoNewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell["\<\
Compare the Pseudo-Newton result with Newton-Raphson's result.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), \(-1.0\), 0.0}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " solve the system analytically.  There is a surprise."
}], "Text"],

Cell[BoxData[{
    \(\(eqns = {f\_1[{x, y, z}] \[Equal] 0, f\_2[{x, y, z}] \[Equal] 0, 
          f\_3[{x, y, z}] \[Equal] 0};\)\), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqns, {x, y, z}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of equations\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[N[solset]]];\)\)}], "Input"],

Cell[TextData[{
  "Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " performs its solution using complex number arithmetic, the first four \
solutions are extraneous. \nThe solutions that we seek are the latter four \
solutions where x, y, and z are real numbers.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Broyden\[CloseCurlyQuote]s Method",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tCalculation of the Jacobian matrix requires  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(n\^2\)]],
  "  partial derivative evaluations and the",
  StyleBox[" approximate Jacobian matrix requires ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(2  n\^2\)]],
  " function evaluations.  Hence, a more computationally efficient method is \
desired.  Broyden's method is a least change secant update method or \
quasi-Newton method.  Recall ",
  StyleBox["the one-dimensional case of Newton's method for solving  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\) = 0\)]],
  ". ",
  StyleBox[" The secant method replaces the derivative  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f' \((p\_k)\)\)]],
  StyleBox["  with the difference quotient  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f' \((p\_k)\)\  = \ \(f \((p\_k)\) - f \((p\_\(k - 1\))\)\)\/\(p\_k - \
p\_\(k - 1\)\)\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(f' \((p\_k)\) \((p\_k - p\_\(k - 1\))\)\  = \ 
        f \((p\_k)\) - f \((p\_\(k - 1\))\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["The extension to higher dimensions is made by using the basic \
property of the Jacobian",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            StyleBox["J",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              StyleBox[\(X\&\[RightVector]\),
                FontWeight->"Bold"], ")"}], "\[CapitalDelta]", 
            StyleBox[\(X\&\[RightVector]\),
              FontWeight->"Bold"]}], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["\[TildeTilde]",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["\[CapitalDelta]",
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(X\&\[RightVector]\),
                FontWeight->"Bold"], ")"}]}]}]}]]],
  "  to write the equation ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  "\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "k"], ")"}], 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "k"], "-", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], \(k - 1\)]}], ")"}]}], " ", "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "k"], ")"}]}], "-", 
          RowBox[{
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], \(k - 1\)], ")"}]}]}]}]]],
  ".  ",
  StyleBox["\n\nBroyden's method starts initially with the Jacobian matrix  ",
    
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\_0\),
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ")"}]}]}]]],
  ".  Then in successive iterations uses an ",
  StyleBox["update the approximate Jacobian with the matrix  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(A\_k\),
        FontWeight->"Bold"]]],
  ":  ",
  StyleBox["\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(A\_k\),
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "k"], "-", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], \(k - 1\)]}], ")"}]}], " ", "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "k"], ")"}]}], "-", 
          RowBox[{
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], \(k - 1\)], ")"}]}]}]}]]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(k = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  ".  \n\nThis equation is known as the quasi-Newton condition or secant \
condition.  Recall that two initial two values  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "1"]}]]],
  "  are necessary to start the secant method.  In practice we are given one \
starting value ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "0"]]],
  " and compute the Jacobian  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["  ",
          FontFamily->"Times New Roman"], 
        RowBox[{
          StyleBox[\(A\_0\),
            FontWeight->"Bold"], " ", "=", " ", 
          RowBox[{
            StyleBox["J",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ")"}]}]}]}]]],
  "  and use Newton's method to get the first approximation  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "1"]]],
  ".  ",
  "The following result gives the details of Broyden's method."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" (Broyden's Method for 2-dimensional Systems).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  To solve the non-linear system  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(X\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ",  given one initial approximation  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "0"]]],
  ",  and generating a sequence  ",
  Cell[BoxData[
      RowBox[{"{", 
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "k"], "}"}]]],
  StyleBox["  which converges to the solution  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["P",
            FontWeight->"Bold"], "\[RightVector]"],
        FontWeight->"Bold"]]],
  ",  i.e.",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  \n\n",
  StyleBox["Step 0.",
    FontColor->RGBColor[0, 0, 1]],
  "\t Compute the ",
  StyleBox["initial Jacobian matrix  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\_0\),
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ")"}]}]}]]],
  ".  \n\nUse it to compute the first approximation using Newton's method  \n\
\n\t\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "1"], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "-", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                StyleBox[\(A\_0\),
                  FontWeight->"Bold"], ")"}], \(-1\)], 
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ")"}]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["For  ",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(k \[GreaterEqual] 1\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose that  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "k"]]],
  "  has been obtained, use the following steps to obtain  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], \(k + 1\)]]],
  ".  \n\n",
  StyleBox["Step 1.",
    FontColor->RGBColor[0, 0, 1]],
  "\t Evaluate the function   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"], "k"],
              FontWeight->"Bold"], ")"}]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(f\_1\) \((p\_k, q\_k)\)\)},
              {\(\(f\_2\) \((p\_k, q\_k)\)\)}
              }], ")"}]}]]],
  ".\n\n",
  StyleBox["Step 2.",
    FontColor->RGBColor[0, 0, 1]],
  "  U",
  StyleBox["pdate the approximate Jacobian using   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(S\&\[RightVector]\),
          FontWeight->"Bold"], "=", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "k"], "-", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], \(k - 1\)]}]}]]],
  StyleBox["  and   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Y\&\[RightVector]\),
          FontWeight->"Bold"], "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", " ", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "k"], ")"}]}], "-", 
          RowBox[{
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], \(k - 1\)], ")"}]}]}]}]]],
  "\n\n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\_k\),
          FontWeight->"Bold"], "  ", "=", "  ", 
        RowBox[{
          StyleBox[\(A\_\(k - 1\)\),
            FontWeight->"Bold"], "  ", "+", " ", 
          RowBox[{
            FractionBox["1", 
              StyleBox[\(\(S\&\[RightVector]\^T\) S\&\[RightVector]\),
                FontWeight->"Bold"]], 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(Y\&\[RightVector]\),
                  FontWeight->"Bold"], " ", "-", " ", 
                StyleBox[\(\(A\_\(k - 1\)\) S\&\[RightVector]\),
                  FontWeight->"Bold"]}], ")"}], 
            StyleBox[\(S\&\[RightVector]\^T\),
              FontWeight->"Bold"]}]}]}]]],
  "  \n\n",
  StyleBox["Step 3.",
    FontColor->RGBColor[0, 0, 1]],
  "  Solve the linear system   ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            StyleBox[\(A\_k\),
              FontWeight->"Bold"], "\[CapitalDelta]", 
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"]}], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox[\(-\ F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"], "k"],
                FontWeight->"Bold"], ")"}]}]}]}]]],
  "   for   ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"\[CapitalDelta]", 
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"]}]}]]],
  ".  \n\n",
  StyleBox["Step 4.",
    FontColor->RGBColor[0, 0, 1]],
  "  Compute the next approximation   ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], \(k + 1\)], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "k"], " ", "+", 
          RowBox[{"\[CapitalDelta]", 
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " ",
  StyleBox[ButtonBox["Broyden's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BroydenMethodProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Broyden's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BroydenMethodProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Broyden's Method for Systems \
in n-Dimensions).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(Broyden[P0_, \[Epsilon]_, max_]\), ":=", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            RowBox[{\({dist = 1, k = 1, P}\), ",", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], " ", "=", " ", "P0"}], ";", 
                " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{\(A\_0\), " ", "=", " ", 
                  RowBox[{"J", "[", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"], "]"}]}], ";", " ", 
                "\[IndentingNewLine]", 
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["F",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], " ", "=", " ", 
                  RowBox[{\(F\&\[RightVector]\), "[", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"], "]"}]}], ";", " ", 
                "\[IndentingNewLine]", 
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], " ", "=", " ", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"], " ", "-", " ", 
                    RowBox[{\(Inverse[A\_0]\), ".", 
                      RowBox[{\(F\&\[RightVector]\), "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}]}]}]}], ";", " ", 
                "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"While", "[", " ", 
                  
                  RowBox[{\(And[\ k < max, dist > \[Epsilon]\ ]\), ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{\(S\&\[RightVector]\), " ", "=", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "1"], "-", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "0"]}]}], ";", 
                      "\[IndentingNewLine]", \(d = 
                        S\&\[RightVector] . S\&\[RightVector]\), ";", 
                      "\[IndentingNewLine]", \(S\&\[RightVector]\  = \ 
                        Partition[S\&\[RightVector]\ , 1]\), ";", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["F",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], " ", "=", " ", 
                        RowBox[{\(F\&\[RightVector]\), "[", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "1"], "]"}]}], " ", ";", 
                      "\[IndentingNewLine]", 
                      RowBox[{\(Y\&\[RightVector]\), " ", "=", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox[\(F\&\[RightVector]\),
                              FontWeight->"Bold"], "1"], "-", 
                          SubscriptBox[
                            StyleBox[\(F\&\[RightVector]\),
                              FontWeight->"Bold"], "0"]}]}], ";", 
                      "\[IndentingNewLine]", \(A\_1\  = \ 
                        A\_0 + \(1\/d\) \((Y\&\[RightVector]\  - 
                                  A\_0 . S\&\[RightVector])\) . 
                              Transpose[S\&\[RightVector]]\), ";", 
                      "\[IndentingNewLine]", 
                      
                      RowBox[{\(\[CapitalDelta]P\&\[RightVector]\), " ", "=", 
                        " ", 
                        RowBox[{"LinearSolve", "[", " ", 
                          RowBox[{\(A\_1\), ",", 
                            RowBox[{"-", " ", 
                              SubscriptBox[
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["F",
                                      FontWeight->"Bold"], "\[RightVector]"],
                                  FontWeight->"Bold"], "1"]}]}], " ", "]"}]}],
                       ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "2"], " ", "=", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "1"], " ", "+", 
                          " ", \(\[CapitalDelta]P\&\[RightVector]\)}]}], ";", 
                      " ", "\[IndentingNewLine]", 
                      RowBox[{"Print", "[", 
                        RowBox[{
                          SubscriptBox["\"\<\!\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\>\"", \(k + 1\)], ",", "\"\< = \>\"", ",", 
                          RowBox[{"NumberForm", "[", 
                            RowBox[{
                              SubscriptBox[
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["P",
                                      FontWeight->"Bold"], "\[RightVector]"],
                                  FontWeight->"Bold"], "2"], ",", "17"}], 
                            "]"}]}], "]"}], ";", "  ", "\[IndentingNewLine]", 
                      
                      RowBox[{"dist", " ", "=", " ", 
                        SqrtBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "2"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"]}], ")"}], ".", 
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "2"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"]}], ")"}]}]]}], 
                      ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], " ", "=", " ", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"]}], ";", " ", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], " ", "=", " ", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "2"]}], ";", " ", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["F",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], " ", "=", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["F",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"]}], ";", 
                      "\[IndentingNewLine]", \(A\_0 = A\_1\), ";", 
                      "\[IndentingNewLine]", \(k\  = \ k + 1\), ";"}]}], "  ",
                   "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "2"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{x,y}] = \>\"", MatrixForm[F\&\[RightVector][{x, y}]]]\)}], 
                  " ", "]"}], ";", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "3"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{x,y,z}] = \>\"", 
                      MatrixForm[F\&\[RightVector][{x, y, z}]]]\)}], "  ", 
                  "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "4"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{w,x,y,z}] = \>\"", 
                      MatrixForm[F\&\[RightVector][{w, x, y, z}]]]\)}], "  ", 
                  "]"}], ";", " ", 
                "\[IndentingNewLine]", \(Print["\<The Broyden's solution to \
\>", \*"\"\<\!\(F\&\[RightVector]\)[\!\(X\&\[RightVector]\)] = \!\(0\&\
\[RightVector]\)\>\"", "\< is\>"]\), ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<  \!\(P\&\[RightVector]\)  = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "2"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{
                  "\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        RowBox[{\(F\&\[RightVector]\), "[", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "2"], "]"}], ",", "17"}], 
                      "]"}]}], " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Return", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "2"], "]"}], ";"}]}], " ", "]"}]}],
         ";"}], " "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Broyden's method to solve the nonlinear system  \n\n\t\t",
  Cell[BoxData[{
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_1\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(1 - 4\ x + 2\ x\^2 - 2\ y\^3\)}]}], "\n", 
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_2\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(\(-\ 4\) + x\^4 + 
            4\ y + \(\(4\)\(\ \)\(y\^4\)\(\ \)\)\)}]}]}]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(f\_2\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}]}]],
    AspectRatioFixed->False],
  " and construct the vector function  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  "  using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(\(f\_1[{x_, y_}] = 1 - 4\ x + 2\ x\^2 - 2\ y\^3;\)\ \ \), "\n", 
    \(\(f\_2[{x_, y_}] = \(-4\) + x\^4 + 4\ y + 4\ y\^4;\)\ \ \), "\n", 
    \(\(F\&\[RightVector][{x_, y_}] = {f\_1[{x, y}], 
          f\_2[{x, y}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_}] = 
        Transpose[{\[PartialD]\_x\ F\&\[RightVector][{x, y}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y}]}];\)\ \ \), "\n", 
    \(\(Print["\<Solve\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", 
        f\_1[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", 
        f\_2[{x, y}]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[{x,y}] = \>\"", 
        MatrixForm[
          F\&\[RightVector][{x, y}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<  J(x,y) = \>", MatrixForm[J[{x, y}]]];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the curves ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), "  "}], "\[IndentingNewLine]",
   
    RowBox[{
      RowBox[{
        RowBox[{"ImplicitPlot", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{\(f\_1\), "[", 
                    RowBox[{"(", GridBox[{
                          {"x"},
                          {"y"}
                          }], ")"}], "]"}], "\[Equal]", "0"}], ",", 
                RowBox[{
                  RowBox[{\(f\_2\), "[", 
                    RowBox[{"(", GridBox[{
                          {"x"},
                          {"y"}
                          }], ")"}], "]"}], "\[Equal]", "0"}]}], "}"}], 
            ",", \({x, \ \(-2\), \ 2}\), ",", \({y, \ \(-2\), \ 1}\), 
            ",", \(PlotStyle \[Rule] \ {Red, Blue}\), 
            ",", \(Ticks \[Rule] {Range[\(-1.5\), 2.0, 0.5], 
                Range[\(-1.0\), 1.0, 0.5]}\)}], "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", f\_1[{x, y}]];\), 
      "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", f\_2[{x, y}]];\), 
      "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Broyden's method to find a numerical approximation to the solution \
near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", 
        RowBox[{"(", 
          RowBox[{"0.1", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "0.7"}], ")"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(A\_0\), " ", "=", " ", 
        RowBox[{"J", "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<       \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)  = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(A\_0\) = J[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)] = \>\"", ",", \(MatrixForm[A\_0]\)}], " ", 
          "]"}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<       \!\(A\_0\%\(-1\)\) = \>\"", 
          MatrixForm[Inverse[A\_0]]\ ];\), " "}]}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], " ", "=", " ", 
        RowBox[{\(F\&\[RightVector]\), "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], " ", "=", " ", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], " ", "-", " ", 
            RowBox[{\(Inverse[A\_0]\), ".", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "0"], "]"}]}]}]}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", "\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) =  \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) - \
\!\(A\_0\%\(-1\)\).\!\(F\&\[RightVector]\)[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)]\>\"", " ", "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], "]"}], ",", "\"\< - \>\"", 
            ",", \(MatrixForm[Inverse[A\_0]]\), ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "0"], "]"}], "]"}]}], " ", "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], "]"}], ",", "\"\< - \>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(Inverse[A\_0]\), ".", 
                RowBox[{\(F\&\[RightVector]\), "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], "]"}]}], "]"}]}], " ", "]"}],
         ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}]}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(S\&\[RightVector]\), " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], "-", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"]}]}], 
      ";"}], "\[IndentingNewLine]", \(d = 
        S\&\[RightVector] . 
          S\&\[RightVector];\), "\[IndentingNewLine]", \(S\&\[RightVector]\  \
= \ Partition[S\&\[RightVector]\ , 1];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "1"], " ", "=", " ", 
        RowBox[{\(F\&\[RightVector]\), "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], "]"}]}], " ", 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(Y\&\[RightVector]\), " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], "1"], "-", 
          SubscriptBox[
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], "0"]}]}], 
      ";"}], "\[IndentingNewLine]", \(A\_1\  = \ 
        A\_0 + \(1\/d\) \((Y\&\[RightVector]\  - 
                  A\_0 . S\&\[RightVector])\) . 
              Transpose[S\&\[RightVector]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\< \!\(S\&\[RightVector]\) = \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) - \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", 
          ",", \(MatrixForm[S\&\[RightVector]]\)}], " ", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\< \!\(Y\&\[RightVector]\) = \!\(\(\*
StyleBox[\(F\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\_1\) - \!\(\(\*
StyleBox[\(F\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\_0\) = \>\"", 
          ",", \(MatrixForm[Y\&\[RightVector]]\)}], " ", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , MatrixForm[Y\&\[RightVector]], "\< - \>", 
          MatrixForm[A\_0], MatrixForm[S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , MatrixForm[Y\&\[RightVector]], "\< - \>", 
          MatrixForm[A\_0 . S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , 
          MatrixForm[Y\&\[RightVector]\  - \ A\_0 . S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", \(Print[\*"\"\<         d = \!\(S\&\
\[RightVector]\).\!\(S\&\[RightVector]\) = \>\"", 
        d];\), "\[IndentingNewLine]", \(Print[\*"\"\<        \!\(1\/d\) = \
\>\"", 1\/d];\), "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \!\(A\_0\) + \!\(1\/d\)(\!\(Y\&\
\[RightVector]\) - \
\!\(A\_0\).\!\(S\&\[RightVector]\)).\!\(S\&\[RightVector]\^T\)\>\""\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          1\/d, MatrixForm[Y\&\[RightVector]\  - \ A\_0 . S\&\[RightVector]], 
          Flatten[S\&\[RightVector]\ ]];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          1\/d, MatrixForm[\((Y\&\[RightVector]\  - \ 
                  A\_0 . S\&\[RightVector])\) . 
              Transpose[S\&\[RightVector]]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          MatrixForm[\(1\/d\) \((Y\&\[RightVector]\  - \ 
                    A\_0 . S\&\[RightVector])\) . 
                Transpose[S\&\[RightVector]]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_1]\ ];\), 
      " "}]}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "2"], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], " ", "-", " ", 
          RowBox[{\(Inverse[A\_1]\), ".", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["F",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "1"]}]}]}], ";"}], "\[IndentingNewLine]",
   
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", "\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) =  \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) - \
\!\(A\_1\%\(-1\)\).\!\(F\&\[RightVector]\)[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\)]\>\"", " ", "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "1"], "]"}], ",", "\"\< - \>\"", 
            ",", \(MatrixForm[Inverse[A\_1]]\), ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "1"], "]"}], "]"}]}], " ", "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "1"], "]"}], ",", "\"\< - \>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(Inverse[A\_1]\), ".", 
                RowBox[{\(F\&\[RightVector]\), "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}]}], "]"}]}], " ", "]"}],
         ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "2"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}]}], "Input"],

Cell["Use the subroutine to get the answer. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell["Compare with the Newton-Raphson method.  ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Broyden's method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", 
        RowBox[{"(", 
          RowBox[{"1.5", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(-0.5\)}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "=", " ", \({1.5, \(-0.5\)}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input",
  AspectRatioFixed->False],

Cell["Compare with the Newton-Raphson method.  ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "=", " ", \({1.5, \(-0.5\)}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Observe that the subroutine ",
  StyleBox["Broyden",
    FontWeight->"Bold"],
  " involves vector functions and is not dependent on the dimension. \nUse \
the subroutine ",
  StyleBox["Broyden",
    FontWeight->"Bold"],
  " to solve the nonlinear system in 3D space:  \n\n\t\t",
  Cell[BoxData[
      \(0\  = \ 9\ x\^2 + 36  y\^2 + 4  z\^2 - 36\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - 2\ y\^2 - 20  z\)],
    AspectRatioFixed->False],
  "  \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - y\^2 + z\^2\)],
    AspectRatioFixed->False],
  "  \n\t\n",
  StyleBox["Hint.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There are four solutions.  Good starting vectors are  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"], "0"],
          FontWeight->"Bold"], 
        "=", \({\(\[PlusMinus]1\), \(\[PlusMinus]1\), 0}\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{\(f\_2\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], "  ",
           
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], 
          RowBox[{\(f\_3\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], 
            "]"}]}]}]],
    AspectRatioFixed->False],
  " and construct the vector function  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  "  using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix  ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{x_, y_, z_}] = 
        9\ x\^2 + 36  y\^2 + 4  z\^2 - 36;\)\ \ \ \), "\n", 
    \(\(f\_2[{x_, y_, z_}] = x\^2 - 2\ y\^2 - 20  z;\)\ \ \ \), "\n", 
    \(\(f\_3[{x_, y_, z_}] = 
        x\^2 - y\^2 + z\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(F\&\[RightVector][{x_, y_, z_}] = {f\_1[{x, y, z}], f\_2[{x, y, z}], 
          f\_3[{x, y, z}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_, z_}] = 
        Transpose[{\[PartialD]\_x\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_z\ 
              F\&\[RightVector][{x, y, 
                  z}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the vector function\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[{x,y,z}] = \>\"", 
        MatrixForm[
          F\&\[RightVector][{x, y, z}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Jacobian matrix is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<J(x,y,z) = \>", MatrixForm[J[{x, y, z}]]];\)\ \ \)}], "Input",\

  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the surfaces  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  ",  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_3\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  "  using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ContourPlot3D`\>"];\)\ \ \), "\[IndentingNewLine]", \

    \(\(graph1 = 
        ContourPlot3D[
          9\ x\^2 + 36  y\^2 + 4  z\^2 - 36, {x, \(-1.2\), 
            1.2}, {y, \(-1.2\), 1.2}, {z, \(-1.2\), 1.2}, 
          Lighting \[Rule] False, ContourStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ContourPlot3D[
          x\^2 - 2\ y\^2 - 20  z, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, Lighting \[Rule] False, 
          ContourStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ContourPlot3D[
          x\^2 - y\^2 + z\^2, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, Lighting \[Rule] False, 
          ContourStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Broyden's method to find a numerical approximation to the solution \
near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((1.0, 1.0, 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, 1.0, 0.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(A\_0\), " ", "=", " ", 
        RowBox[{"J", "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<       \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)  = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(A\_0\) = J[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)] = \>\"", ",", \(MatrixForm[A\_0]\)}], " ", 
          "]"}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<       \!\(A\_0\%\(-1\)\) = \>\"", 
          MatrixForm[Inverse[A\_0]]\ ];\), " "}]}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], " ", "=", " ", 
        RowBox[{\(F\&\[RightVector]\), "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], " ", "=", " ", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], " ", "-", " ", 
            RowBox[{\(Inverse[A\_0]\), ".", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "0"], "]"}]}]}]}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", "\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) =  \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) - \
\!\(A\_0\%\(-1\)\).\!\(F\&\[RightVector]\)[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)]\>\"", " ", "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], "]"}], ",", "\"\< - \>\"", 
            ",", \(MatrixForm[Inverse[A\_0]]\), ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "0"], "]"}], "]"}]}], " ", "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], "]"}], ",", "\"\< - \>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(Inverse[A\_0]\), ".", 
                RowBox[{\(F\&\[RightVector]\), "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], "]"}]}], "]"}]}], " ", "]"}],
         ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}]}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(S\&\[RightVector]\), " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], "-", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"]}]}], 
      ";"}], "\[IndentingNewLine]", \(d = 
        S\&\[RightVector] . 
          S\&\[RightVector];\), "\[IndentingNewLine]", \(S\&\[RightVector]\  \
= \ Partition[S\&\[RightVector]\ , 1];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "1"], " ", "=", " ", 
        RowBox[{\(F\&\[RightVector]\), "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], "]"}]}], " ", 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(Y\&\[RightVector]\), " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], "1"], "-", 
          SubscriptBox[
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], "0"]}]}], 
      ";"}], "\[IndentingNewLine]", \(A\_1\  = \ 
        A\_0 + \(1\/d\) \((Y\&\[RightVector]\  - 
                  A\_0 . S\&\[RightVector])\) . 
              Transpose[S\&\[RightVector]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\< \!\(S\&\[RightVector]\) = \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) - \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", 
          ",", \(MatrixForm[S\&\[RightVector]]\)}], " ", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\< \!\(Y\&\[RightVector]\) = \!\(\(\*
StyleBox[\(F\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\_1\) - \!\(\(\*
StyleBox[\(F\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\_0\) = \>\"", 
          ",", \(MatrixForm[Y\&\[RightVector]]\)}], " ", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , MatrixForm[Y\&\[RightVector]], "\< - \>", 
          MatrixForm[A\_0], MatrixForm[S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , MatrixForm[Y\&\[RightVector]], "\< - \>", 
          MatrixForm[A\_0 . S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , 
          MatrixForm[Y\&\[RightVector]\  - \ A\_0 . S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", \(Print[\*"\"\<         d = \!\(S\&\
\[RightVector]\).\!\(S\&\[RightVector]\) = \>\"", 
        d];\), "\[IndentingNewLine]", \(Print[\*"\"\<        \!\(1\/d\) = \
\>\"", 1\/d];\), "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \!\(A\_0\) + \!\(1\/d\)(\!\(Y\&\
\[RightVector]\) - \
\!\(A\_0\).\!\(S\&\[RightVector]\)).\!\(S\&\[RightVector]\^T\)\>\""\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          1\/d, MatrixForm[Y\&\[RightVector]\  - \ A\_0 . S\&\[RightVector]], 
          Flatten[S\&\[RightVector]\ ]];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          1\/d, MatrixForm[\((Y\&\[RightVector]\  - \ 
                  A\_0 . S\&\[RightVector])\) . 
              Transpose[S\&\[RightVector]]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          MatrixForm[\(1\/d\) \((Y\&\[RightVector]\  - \ 
                    A\_0 . S\&\[RightVector])\) . 
                Transpose[S\&\[RightVector]]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_1]\ ];\), 
      " "}]}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "2"], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], " ", "-", " ", 
          RowBox[{\(Inverse[A\_1]\), ".", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["F",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "1"]}]}]}], ";"}], "\[IndentingNewLine]",
   
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", "\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) =  \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) - \
\!\(A\_1\%\(-1\)\).\!\(F\&\[RightVector]\)[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\)]\>\"", " ", "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "1"], "]"}], ",", "\"\< - \>\"", 
            ",", \(MatrixForm[Inverse[A\_1]]\), ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "1"], "]"}], "]"}]}], " ", "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "1"], "]"}], ",", "\"\< - \>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(Inverse[A\_1]\), ".", 
                RowBox[{\(F\&\[RightVector]\), "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}]}], "]"}]}], " ", "]"}],
         ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "2"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}]}], "Input"],

Cell["Use the subroutine to get the answer. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, 1.0, 0.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{"Broyden", "[", 
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
      "]"}]}], "Input"],

Cell["Compare Broyden's result with Newton-Raphson's result.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, 1.0, 0.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"NewtonSystem", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Broyden's method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((1.0, \(-1.0\), 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, \(-1.0\), 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell["Compare Broyden's result with Newton-Raphson's result.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, \(-1.0\), 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"NewtonSystem", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell[TextData[{
  StyleBox["(iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Newton-Raphson method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((\(-1.0\), 1.0, 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), 1.0, 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell["Compare Broyden's result with Newton-Raphson's result.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), 1.0, 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"NewtonSystem", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell[TextData[{
  StyleBox["(iv)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Newton-Raphson method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], 
        "=", \((\(-1.0\), \(-1.0\), 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), \(-1.0\), 0.0}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell["Compare Broyden's result with Newton-Raphson's result.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), \(-1.0\), 0.0}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"NewtonSystem", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Observe that the subroutine ",
  StyleBox["Broyden",
    FontWeight->"Bold"],
  " involves vector functions and is not dependent on the dimension. \nUse \
the subroutine ",
  StyleBox["Broyden",
    FontWeight->"Bold"],
  " to solve the nonlinear system in 4D space:  \n\n\t\t",
  Cell[BoxData[
      \(0\  = \ w\^2 + x\^2 + 3  y\^2 - z\^3 - 5\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ w + x\^3 - 2\ y\^2 - 10  z\)],
    AspectRatioFixed->False],
  "  \n\t\t",
  Cell[BoxData[
      \(0\  = \ 20 - w + x\^2 + y\^3 + z\^2\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ w\^3 + x - y\^3 + z - 10\)],
    AspectRatioFixed->False],
  "  \n\t\n",
  StyleBox["Hint.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There is one real solutions.  A good starting vectors is  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"], "0"],
          FontWeight->"Bold"], "=", \({\(-4.0\), 4.0, \(-4.0\), 4.0}\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"w", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(f\_2\), "[", 
          RowBox[{"{", 
            RowBox[{"w", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{\(f\_3\), "[", 
            RowBox[{"{", 
              RowBox[{"w", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], "  ",
           
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], 
          RowBox[{\(f\_4\), "[", 
            RowBox[{"{", 
              RowBox[{"w", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], 
            "]"}]}]}]],
    AspectRatioFixed->False],
  " and construct the vector function  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  "  using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"w", ",", "x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{w_, x_, y_, z_}] = 
        w\^2 + x\^2 + 3  y\^2 - z\^3 - 5;\)\ \ \ \), "\n", 
    \(\(f\_2[{w_, x_, y_, z_}] = 
        w + x\^3 - 2\ y\^2 - 10  z;\)\ \ \ \), "\n", 
    \(\(f\_3[{w_, x_, y_, z_}] = 
        20 - w + x\^2 + y\^3 + z\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(f\_4[{w_, x_, y_, z_}] = 
        w\^3 + x - y\^3 + z - 10;\)\ \), "\[IndentingNewLine]", 
    \(\(F\&\[RightVector][{w_, x_, y_, z_}] = {f\_1[{w, x, y, z}], 
          f\_2[{w, x, y, z}], f\_3[{w, x, y, z}], 
          f\_4[{w, x, y, z}]};\)\ \ \), "\n", 
    \(\(J[{w_, x_, y_, z_}] = 
        Transpose[{\[PartialD]\_w\ 
              F\&\[RightVector][{w, x, y, z}], \[PartialD]\_x\ 
              F\&\[RightVector][{w, x, y, z}], \[PartialD]\_y\ 
              F\&\[RightVector][{w, x, y, z}], \[PartialD]\_z\ 
              F\&\[RightVector][{w, x, y, 
                  z}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(w,x,y,z) = \>\"", 
        f\_1[{w, x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(w,x,y,z) = \>\"", 
        f\_2[{w, x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(w,x,y,z) = \>\"", 
        f\_3[{w, x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_4\)(w,x,y,z) = \>\"", 
        f\_4[{w, x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the vector function\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[{w,x,y,z}] = \>\"", 
        MatrixForm[
          F\&\[RightVector][{w, x, y, z}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Jacobian matrix is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<J(w,x,y,z) = \>", 
        MatrixForm[J[{w, x, y, z}]]];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use Broyden's method to find a numerical approximation to the solution \
near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], 
        "=", \((\(-4.0\), 4.0, \(-4.0\), 4.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], 
          "=", \({\(-4.0\), 4.0, \(-4.0\), 4.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(A\_0\), " ", "=", " ", 
        RowBox[{"J", "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<       \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)  = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(A\_0\) = J[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)] = \>\"", ",", \(MatrixForm[A\_0]\)}], " ", 
          "]"}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<       \!\(A\_0\%\(-1\)\) = \>\"", 
          MatrixForm[Inverse[A\_0]]\ ];\), " "}]}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], " ", "=", " ", 
        RowBox[{\(F\&\[RightVector]\), "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], " ", "=", " ", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], " ", "-", " ", 
            RowBox[{\(Inverse[A\_0]\), ".", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "0"], "]"}]}]}]}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", "\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) =  \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) - \
\!\(A\_0\%\(-1\)\).\!\(F\&\[RightVector]\)[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\)]\>\"", " ", "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], "]"}], ",", "\"\< - \>\"", 
            ",", \(MatrixForm[Inverse[A\_0]]\), ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "0"], "]"}], "]"}]}], " ", "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], "]"}], ",", "\"\< - \>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(Inverse[A\_0]\), ".", 
                RowBox[{\(F\&\[RightVector]\), "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], "]"}]}], "]"}]}], " ", "]"}],
         ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}]}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(S\&\[RightVector]\), " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], "-", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"]}]}], 
      ";"}], "\[IndentingNewLine]", \(d = 
        S\&\[RightVector] . 
          S\&\[RightVector];\), "\[IndentingNewLine]", \(S\&\[RightVector]\  \
= \ Partition[S\&\[RightVector]\ , 1];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "1"], " ", "=", " ", 
        RowBox[{\(F\&\[RightVector]\), "[", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], "]"}]}], " ", 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(Y\&\[RightVector]\), " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], "1"], "-", 
          SubscriptBox[
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], "0"]}]}], 
      ";"}], "\[IndentingNewLine]", \(A\_1\  = \ 
        A\_0 + \(1\/d\) \((Y\&\[RightVector]\  - 
                  A\_0 . S\&\[RightVector])\) . 
              Transpose[S\&\[RightVector]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\< \!\(S\&\[RightVector]\) = \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) - \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", 
          ",", \(MatrixForm[S\&\[RightVector]]\)}], " ", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\< \!\(Y\&\[RightVector]\) = \!\(\(\*
StyleBox[\(F\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\_1\) - \!\(\(\*
StyleBox[\(F\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\_0\) = \>\"", 
          ",", \(MatrixForm[Y\&\[RightVector]]\)}], " ", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , MatrixForm[Y\&\[RightVector]], "\< - \>", 
          MatrixForm[A\_0], MatrixForm[S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , MatrixForm[Y\&\[RightVector]], "\< - \>", 
          MatrixForm[A\_0 . S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<(\!\(Y\&\[RightVector]\) - \!\(A\_0\).\!\(S\&\
\[RightVector]\)) = \>\""\ , 
          MatrixForm[Y\&\[RightVector]\  - \ A\_0 . S\&\[RightVector]]\ ];\), 
      " "}], "\[IndentingNewLine]", \(Print[\*"\"\<         d = \!\(S\&\
\[RightVector]\).\!\(S\&\[RightVector]\) = \>\"", 
        d];\), "\[IndentingNewLine]", \(Print[\*"\"\<        \!\(1\/d\) = \
\>\"", 1\/d];\), "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \!\(A\_0\) + \!\(1\/d\)(\!\(Y\&\
\[RightVector]\) - \
\!\(A\_0\).\!\(S\&\[RightVector]\)).\!\(S\&\[RightVector]\^T\)\>\""\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          1\/d, MatrixForm[Y\&\[RightVector]\  - \ A\_0 . S\&\[RightVector]], 
          Flatten[S\&\[RightVector]\ ]];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          1\/d, MatrixForm[\((Y\&\[RightVector]\  - \ 
                  A\_0 . S\&\[RightVector])\) . 
              Transpose[S\&\[RightVector]]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_0], "\< + \>", 
          MatrixForm[\(1\/d\) \((Y\&\[RightVector]\  - \ 
                    A\_0 . S\&\[RightVector])\) . 
                Transpose[S\&\[RightVector]]]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(A\_1\) = \>\"", MatrixForm[A\_1]\ ];\), 
      " "}]}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "2"], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "1"], " ", "-", " ", 
          RowBox[{\(Inverse[A\_1]\), ".", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["F",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "1"]}]}]}], ";"}], "\[IndentingNewLine]",
   
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", "\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) =  \!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) - \
\!\(A\_1\%\(-1\)\).\!\(F\&\[RightVector]\)[\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\)]\>\"", " ", "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "1"], "]"}], ",", "\"\< - \>\"", 
            ",", \(MatrixForm[Inverse[A\_1]]\), ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(F\&\[RightVector]\), "[", 
                SubscriptBox[
                  StyleBox[
                    OverscriptBox[
                      StyleBox["P",
                        FontWeight->"Bold"], "\[RightVector]"],
                    FontWeight->"Bold"], "1"], "]"}], "]"}]}], " ", "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "1"], "]"}], ",", "\"\< - \>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{\(Inverse[A\_1]\), ".", 
                RowBox[{\(F\&\[RightVector]\), "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], "]"}]}], "]"}]}], " ", "]"}],
         ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_2\) = \>\"", ",", 
            RowBox[{"NumberForm", "[", 
              RowBox[{
                RowBox[{"MatrixForm", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "2"], "]"}], ",", "17"}], "]"}]}], 
          " ", "]"}], ";"}], " "}]}], "Input"],

Cell["Use the subroutine to get the answer. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], 
          "=", \({\(-4.0\), 4.0, \(-4.0\), 4.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell[TextData[{
  "Do you think that there might be other solutions ?  We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to explore the situation. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(eqns = {f\_1[{w, x, y, z}] \[Equal] 0, f\_2[{w, x, y, z}] \[Equal] 0, 
          f\_3[{w, x, y, z}] \[Equal] 0, 
          f\_4[{w, x, y, z}] \[Equal] 0};\)\), "\[IndentingNewLine]", 
    \(\(solset = NSolve[eqns, {w, x, y, z}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equations\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[
            solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
], 17]];\)\ \)}], "Input"],

Cell["Do we dare look at all of the solutions? ", "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Dare",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print["\<Solve the equations\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get one real solution\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[
            solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
], 17]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<\n\>", "\<There are many complex solution\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[TableForm[Take[solset, 1 - Length[solset]]], 
          6]];\)\ \)}], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[TextData[{
  StyleBox["Improving Broyden's Method",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tMatrix inversion requires  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold"], \((n\^3)\)}]]],
  "  calculations.  Thus we seek a way to avoid this time consuming step each \
time an iteration is performed.  A matrix inversion formula of Sherman and \
Morrison can facilitate in making a more efficient algorithm.  Except for ",
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          StyleBox[
            SubscriptBox["A", 
              StyleBox["0",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], ")"}], \(-1\)]]],
  ", no matrix inverse or solution of a linear system computation is \
performed in the general step.  This is efficient when ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is large.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Sherman-Morrison Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Sherman-MorrisonFormula.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["A",
          FontWeight->"Bold"], \(-1\)]]],
  "  is a nonsingular matrix and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(U\&\[RightVector]\),
          FontWeight->"Bold"], " ", ",", 
        StyleBox[\(V\&\[RightVector]\),
          FontWeight->"Bold"], " "}]]],
  "  are vectors such that  ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{\(v\^T\), 
            SuperscriptBox[
              StyleBox["A",
                FontWeight->"Bold"], \(-1\)], "u"}], "\[NotEqual]", 
          " ", \(-1\)}]}]]],
  ",  then  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], " ", "+", " ", 
              RowBox[{
                StyleBox[\(U\&\[RightVector]\),
                  FontWeight->"Bold"], " ", 
                StyleBox[\(V\&\[RightVector]\^T\),
                  FontWeight->"Bold"]}]}], ")"}], 
          StyleBox[\(-1\),
            FontWeight->"Bold"]], "  ", "=", "  ", 
        RowBox[{
          SuperscriptBox[
            StyleBox["A",
              FontWeight->"Bold"], 
            StyleBox[\(-1\),
              FontWeight->"Bold"]], " ", "-", " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["A",
                    FontWeight->"Bold"], 
                  StyleBox[\(-1\),
                    FontWeight->"Bold"]], 
                StyleBox[\(U\&\[RightVector]\),
                  FontWeight->"Bold"], " ", 
                StyleBox[\(V\&\[RightVector]\^T\),
                  FontWeight->"Bold"], 
                SuperscriptBox[
                  StyleBox["A",
                    FontWeight->"Bold"], 
                  StyleBox[\(-1\),
                    FontWeight->"Bold"]]}], ")"}], "/", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  StyleBox[\(V\&\[RightVector]\^T\),
                    FontWeight->"Bold"], 
                  SuperscriptBox[
                    StyleBox["A",
                      FontWeight->"Bold"], 
                    StyleBox[\(-1\),
                      FontWeight->"Bold"]], 
                  StyleBox[\(U\&\[RightVector]\),
                    FontWeight->"Bold"]}]}], ")"}]}]}]}]]],
  "  \n\tor\n\t\t",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], " ", "+", " ", 
              RowBox[{
                StyleBox[\(U\&\[RightVector]\),
                  FontWeight->"Bold"], " ", 
                StyleBox[\(V\&\[RightVector]\^T\),
                  FontWeight->"Bold"]}]}], ")"}], 
          StyleBox[\(-1\),
            FontWeight->"Bold"]], "  ", "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox["(",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["I",
                FontWeight->"Bold"], " ", "-", " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["A",
                        FontWeight->"Bold"], \(-1\)], 
                    StyleBox[\(U\&\[RightVector]\),
                      FontWeight->"Bold"]}], ")"}], 
                RowBox[{
                  StyleBox[\(V\&\[RightVector]\^T\),
                    FontWeight->"Bold"], "/", 
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      RowBox[{
                        StyleBox[\(V\&\[RightVector]\^T\),
                          FontWeight->"Bold"], 
                        SuperscriptBox[
                          StyleBox["A",
                            FontWeight->"Bold"], \(-1\)], 
                        StyleBox[\(U\&\[RightVector]\),
                          FontWeight->"Bold"]}]}], ")"}]}]}]}], 
            StyleBox[")",
              FontWeight->"Bold"]}], 
          SuperscriptBox[
            StyleBox["A",
              FontWeight->"Bold"], 
            StyleBox[\(-1\),
              FontWeight->"Bold"]]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" (Broyden's Method for n-dimensional Systems).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  To solve the non-linear system  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(X\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ",  given one initial approximation  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "0"]]],
  ",  and generating a sequence  ",
  Cell[BoxData[
      RowBox[{"{", 
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "k"], "}"}]]],
  StyleBox["  which converges to the solution  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["P",
            FontWeight->"Bold"], "\[RightVector]"],
        FontWeight->"Bold"]]],
  ",  i.e.",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], ")"}]}], "=", 
        StyleBox[\(0\&\[RightVector]\),
          FontWeight->"Bold"]}]]],
  ".  Compute the ",
  StyleBox["initial Jacobian matrix  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox["A", 
            StyleBox["0",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          StyleBox["J",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ")"}]}]}]]],
  ".  \n\nUse it to compute the first approximation using Newton's method  \n\
\n\t\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "1"], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "-", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                StyleBox[
                  SubscriptBox["A", 
                    StyleBox["0",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ")"}], \(-1\)], 
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{"(", 
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"],
                  FontWeight->"Bold"], "0"], ")"}]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "For  ",
  Cell[BoxData[
      \(k \[GreaterEqual] 1\)]],
  ".  Suppose that  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "k"]]],
  "  has been obtained, use the following steps to obtain  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          OverscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], \(k + 1\)]]],
  ".  \n\n",
  StyleBox["Step 1.",
    FontColor->RGBColor[0, 0, 1]],
  "\t Evaluate the function  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[\(F\&\[RightVector]\), 
            StyleBox["k",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          StyleBox[\(F\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{"(", " ", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "k"], ")"}]}]}]]],
  ".  \n\n",
  StyleBox["Step 2.",
    FontColor->RGBColor[0, 0, 1]],
  "  U",
  StyleBox["pdate the approximate Jacobian using  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(V\&\[RightVector]\),
          FontWeight->"Bold"], "=", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "k"], "-", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], \(k - 1\)]}]}]]],
  ",  and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(U\&\[RightVector]\),
          FontWeight->"Bold"], "=", 
        RowBox[{
          FractionBox["1", 
            StyleBox[\(\(V\&\[RightVector]\^T\) V\&\[RightVector]\),
              FontWeight->"Bold"]], 
          RowBox[{"(", 
            RowBox[{
              StyleBox[
                SubscriptBox[\(F\&\[RightVector]\), 
                  StyleBox["k",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], 
              StyleBox["-",
                FontWeight->"Bold"], 
              StyleBox[
                SubscriptBox[\(F\&\[RightVector]\), 
                  StyleBox[\(k - 1\),
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], "-", 
              StyleBox[
                RowBox[{
                  SubscriptBox["A", 
                    StyleBox[\(k - 1\),
                      FontWeight->"Plain"]], \(V\&\[RightVector]\)}],
                FontWeight->"Bold"]}], ")"}]}]}]],
    AspectRatioFixed->False],
  "\n\n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox["A", 
            StyleBox["k",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          StyleBox[
            SubscriptBox["A", 
              StyleBox[\(k - 1\),
                FontWeight->"Plain"]],
            FontWeight->"Bold"], " ", "+", " ", 
          StyleBox[\(\(U\&\[RightVector]\) V\&\[RightVector]\^T\),
            FontWeight->"Bold"]}]}]]],
  ".   \n\n",
  StyleBox["Step 3.",
    FontColor->RGBColor[0, 0, 1]],
  "  Compute  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox["B", 
            StyleBox["k",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], " ", "=", " ", 
        SubsuperscriptBox[
          StyleBox["A",
            FontWeight->"Bold"], "k", 
          StyleBox[\(-1\),
            FontWeight->"Bold"]]}]]],
  "  using the Sherman-Morrison formula\n\n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox["B", 
            StyleBox["k",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          SubsuperscriptBox[
            StyleBox["A",
              FontWeight->"Bold"], "k", 
            StyleBox[\(-1\),
              FontWeight->"Bold"]], " ", "=", " ", 
          RowBox[{
            RowBox[{
              StyleBox["(",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["I",
                  FontWeight->"Bold"], " ", "-", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      SubsuperscriptBox[
                        StyleBox["A",
                          FontWeight->"Bold"], \(k - 1\), 
                        StyleBox[\(-1\),
                          FontWeight->"Bold"]], 
                      StyleBox[\(U\&\[RightVector]\),
                        FontWeight->"Bold"]}], ")"}], 
                  RowBox[{
                    StyleBox[\(V\&\[RightVector]\^T\),
                      FontWeight->"Bold"], "/", 
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        RowBox[{
                          StyleBox[\(V\&\[RightVector]\^T\),
                            FontWeight->"Bold"], 
                          SuperscriptBox[
                            StyleBox["A",
                              FontWeight->"Bold"], 
                            StyleBox[\(-1\),
                              FontWeight->"Bold"]], 
                          StyleBox[\(U\&\[RightVector]\),
                            FontWeight->"Bold"]}]}], ")"}]}]}]}], 
              StyleBox[")",
                FontWeight->"Bold"]}], 
            SubsuperscriptBox[
              StyleBox["A",
                FontWeight->"Bold"], \(k - 1\), 
              StyleBox[\(-1\),
                FontWeight->"Bold"]]}]}]}]]],
  "  \n\n",
  StyleBox["Step 4.",
    FontColor->RGBColor[0, 0, 1]],
  "  Compute the next approximation   \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], \(k + 1\)], " ", "=", " ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "k"], " ", "-", " ", 
          RowBox[{
            StyleBox[
              SubscriptBox["B", 
                StyleBox["k",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[\(F\&\[RightVector]\),
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["P",
                      FontWeight->"Bold"], "\[RightVector]"], "k"],
                FontWeight->"Bold"], ")"}]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " ",
  StyleBox[ButtonBox["Broyden's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BroydenMethodProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Improved Broyden's Method for \
Systems in n-Dimensions).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(ImprovedBroyden[P0_, \[Epsilon]_, max_]\), ":=", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({dist = 1, k = 1, n = Length[P0], P}\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], " ", "=", " ", "P0"}], ";", 
                " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_0\) = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{\(A\_0\), " ", "=", " ", 
                  RowBox[{"J", "[", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"], "]"}]}], ";", " ", 
                "\[IndentingNewLine]", \(B\_0 = \ Inverse[A\_0]\), ";", " ", 
                "\[IndentingNewLine]", 
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["F",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "0"], " ", "=", " ", 
                  RowBox[{\(F\&\[RightVector]\), "[", 
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"], "]"}]}], ";", " ", 
                "\[IndentingNewLine]", 
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "1"], " ", "=", " ", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox[
                        OverscriptBox[
                          StyleBox["P",
                            FontWeight->"Bold"], "\[RightVector]"],
                        FontWeight->"Bold"], "0"], " ", "-", " ", 
                    RowBox[{\(B\_0\), ".", 
                      RowBox[{\(F\&\[RightVector]\), "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}]}]}]}], ";", " ", 
                "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<\!\(\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\_1\) = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", 
                "\[IndentingNewLine]", \(B\_0 = \ Inverse[A\_0]\), ";", 
                "\[IndentingNewLine]", 
                RowBox[{"While", "[", " ", 
                  
                  RowBox[{\(And[\ k < max, dist > \[Epsilon]\ ]\), ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["F",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], " ", "=", " ", 
                        RowBox[{\(F\&\[RightVector]\), "[", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "1"], "]"}]}], " ", ";", 
                      " ", "\[IndentingNewLine]", 
                      RowBox[{
                        StyleBox[\(V\&\[RightVector]\),
                          FontWeight->"Bold"], " ", "=", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "1"], "-", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "0"]}]}], ";", " ", 
                      "\[IndentingNewLine]", \(d\  = \ 
                        V\&\[RightVector] . V\&\[RightVector]\), ";", " ", 
                      "\[IndentingNewLine]", 
                      RowBox[{\(U\&\[RightVector]\), " ", "=", " ", 
                        RowBox[{\(1\/d\), 
                          RowBox[{"(", 
                            RowBox[{
                              SubscriptBox[
                                StyleBox[\(F\&\[RightVector]\),
                                  FontWeight->"Bold"], "1"], "-", 
                              SubscriptBox[
                                StyleBox[\(F\&\[RightVector]\),
                                  FontWeight->"Bold"], "0"], " ", "-", 
                              RowBox[{"Flatten", "[", " ", 
                                RowBox[{\(A\_\(k - 1\)\), ".", 
                                  RowBox[{"Transpose", "[", 
                                    RowBox[{"{", 
                                      StyleBox[\(V\&\[RightVector]\),
                                        FontWeight->"Bold"], 
                                      StyleBox["}",
                                        FontWeight->"Bold"]}], 
                                    StyleBox["]",
                                      FontWeight->"Bold"]}]}], 
                                StyleBox["]",
                                  FontWeight->"Bold"]}]}], ")"}]}]}], ";", 
                      " ", "\[IndentingNewLine]", \(W\&\[RightVector]\  = \ 
                        B\_\(k - 1\) . 
                            U\&\[RightVector]\ /\((1\  + \ 
                              V\&\[RightVector] . B\_\(k - 1\) . 
                                U\&\[RightVector])\)\), ";", " ", 
                      "\[IndentingNewLine]", 
                      RowBox[{\(A\_k\), " ", "=", " ", 
                        RowBox[{\(A\_\(k - 1\)\), "+", 
                          RowBox[{\(Partition[U\&\[RightVector], 1]\), ".", 
                            RowBox[{"{", 
                              StyleBox[\(V\&\[RightVector]\),
                                FontWeight->"Bold"], "}"}]}]}]}], ";", " ", 
                      "\[IndentingNewLine]", \(B\_k\  = \ \((IdentityMatrix[
                                n]\  - \ 
                              Partition[W\&\[RightVector], 
                                  1] . {V\&\[RightVector]})\) . 
                          B\_\(k - 1\)\), ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "2"], " ", "=", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "1"], " ", "-", " ", 
                          RowBox[{\(B\_k\), ".", 
                            SubscriptBox[
                              StyleBox[
                                OverscriptBox[
                                  StyleBox["F",
                                    FontWeight->"Bold"], "\[RightVector]"],
                                FontWeight->"Bold"], "1"]}]}]}], ";", " ", 
                      "\[IndentingNewLine]", 
                      RowBox[{"Print", "[", 
                        RowBox[{
                          SubscriptBox["\"\<\!\(\*
StyleBox[
OverscriptBox[
StyleBox[\"P\",\nFontWeight->\"Bold\"], \"\[RightVector]\"],\n\
FontWeight->\"Bold\"]\)\>\"", \(k + 1\)], ",", "\"\< = \>\"", ",", 
                          RowBox[{"NumberForm", "[", 
                            RowBox[{
                              SubscriptBox[
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["P",
                                      FontWeight->"Bold"], "\[RightVector]"],
                                  FontWeight->"Bold"], "2"], ",", "17"}], 
                            "]"}]}], "]"}], ";", "  ", "\[IndentingNewLine]", 
                      
                      RowBox[{"dist", " ", "=", " ", 
                        SqrtBox[
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "2"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"]}], ")"}], ".", 
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "2"], "-", 
                                SubscriptBox[
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["P",
                                        FontWeight->"Bold"], 
                                      "\[RightVector]"],
                                    FontWeight->"Bold"], "1"]}], ")"}]}]]}], 
                      ";", " ", "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], " ", "=", " ", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"]}], ";", " ", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"], " ", "=", " ", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "2"]}], ";", " ", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["F",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], " ", "=", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["F",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "1"]}], ";", 
                      "\[IndentingNewLine]", \(k\  = \ k + 1\), ";"}]}], "  ",
                   "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "2"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{x,y}] = \>\"", MatrixForm[F\&\[RightVector][{x, y}]]]\)}], 
                  " ", "]"}], ";", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "3"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{x,y,z}] = \>\"", 
                      MatrixForm[F\&\[RightVector][{x, y, z}]]]\)}], "  ", 
                  "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Length", "[", 
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "0"], "]"}], "\[Equal]", 
                      "4"}], ",", \(Print["\<\n\>", \*"\"\<\!\(F\&\
\[RightVector]\)[{w,x,y,z}] = \>\"", 
                      MatrixForm[F\&\[RightVector][{w, x, y, z}]]]\)}], "  ", 
                  "]"}], ";", " ", 
                "\[IndentingNewLine]", \(Print["\<The Improved Broyden's \
solution to \>", \*"\"\<\!\(F\&\[RightVector]\)[\!\(X\&\[RightVector]\)] = \!\
\(0\&\[RightVector]\)\>\"", "\< is\>"]\), ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{"\"\<  \!\(P\&\[RightVector]\)  = \>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox[
                            OverscriptBox[
                              StyleBox["P",
                                FontWeight->"Bold"], "\[RightVector]"],
                            FontWeight->"Bold"], "2"], ",", "17"}], "]"}]}], 
                  " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                  RowBox[{
                  "\"\<\!\(F\&\[RightVector]\)[\!\(P\&\[RightVector]\)] = \
\>\"", ",", 
                    RowBox[{"NumberForm", "[", 
                      RowBox[{
                        RowBox[{\(F\&\[RightVector]\), "[", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["P",
                                  FontWeight->"Bold"], "\[RightVector]"],
                              FontWeight->"Bold"], "2"], "]"}], ",", "17"}], 
                      "]"}]}], " ", "]"}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Return", "[", 
                  SubscriptBox[
                    StyleBox[
                      OverscriptBox[
                        StyleBox["P",
                          FontWeight->"Bold"], "\[RightVector]"],
                      FontWeight->"Bold"], "2"], "]"}], ";"}]}], " ", "]"}]}],
         ";"}], " "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the improved Broyden's method to solve the nonlinear system  \n\n\t\t\
",
  Cell[BoxData[{
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_1\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(1 - 4\ x + 2\ x\^2 - 2\ y\^3\)}]}], "\n", 
      RowBox[{"0", "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(f\_2\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(\(-\ 4\) + x\^4 + 
            4\ y + \(\(4\)\(\ \)\(y\^4\)\(\ \)\)\)}]}]}]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(f\_2\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], "}"}], "]"}]}]],
    AspectRatioFixed->False],
  " and construct the vector function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  " using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the approximate Jacobian ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"M", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(\(f\_1[{x_, y_}] = 1 - 4\ x + 2\ x\^2 - 2\ y\^3;\)\ \ \), "\n", 
    \(\(f\_2[{x_, y_}] = \(-4\) + x\^4 + 4\ y + 4\ y\^4;\)\ \ \), "\n", 
    \(\(F\&\[RightVector][{x_, y_}] = {f\_1[{x, y}], 
          f\_2[{x, y}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_}] = 
        Transpose[{\[PartialD]\_x\ F\&\[RightVector][{x, y}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y}]}];\)\ \ \), "\n", 
    \(\(Print["\<Solve\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", 
        f\_1[{x, y}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", 
        f\_2[{x, y}]];\)\ \ \), "\n", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[{x,y}] = \>\"", 
        MatrixForm[
          F\&\[RightVector][{x, y}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<  J(x,y) = \>", MatrixForm[J[{x, y}]]];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the curves ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "0"}]],
    AspectRatioFixed->False],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), "  "}], "\[IndentingNewLine]",
   
    RowBox[{
      RowBox[{
        RowBox[{"ImplicitPlot", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{\(f\_1\), "[", 
                    RowBox[{"(", GridBox[{
                          {"x"},
                          {"y"}
                          }], ")"}], "]"}], "\[Equal]", "0"}], ",", 
                RowBox[{
                  RowBox[{\(f\_2\), "[", 
                    RowBox[{"(", GridBox[{
                          {"x"},
                          {"y"}
                          }], ")"}], "]"}], "\[Equal]", "0"}]}], "}"}], 
            ",", \({x, \ \(-2\), \ 2}\), ",", \({y, \ \(-2\), \ 1}\), 
            ",", \(PlotStyle \[Rule] \ {Red, Blue}\), 
            ",", \(Ticks \[Rule] {Range[\(-1.5\), 2.0, 0.5], 
                Range[\(-1.0\), 1.0, 0.5]}\)}], "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<0 = \!\(f\_1\)(x,y) = \>\"", f\_1[{x, y}]];\), 
      "  "}], "\n", 
    RowBox[{\(Print[\*"\"\<0 = \!\(f\_2\)(x,y) = \>\"", f\_2[{x, y}]];\), 
      "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the improved Broyden's method to find a numerical approximation to \
the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0.1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0.7"}], ")"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"ImprovedBroyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell[TextData[{
  "Compare with the standard Broyden's method to find a numerical \
approximation to the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0.1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0.7"}], ")"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({0.1, 0.7}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Broyden", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the improved Broyden's method to find a numerical approximation to \
the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"1.5", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(-0.5\)}], ")"}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "=", " ", \({1.5, \(-0.5\)}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"ImprovedBroyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Compare with the standard Broyden's method to find a numerical \
approximation to the solution near ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"1.5", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(-0.5\)}], ")"}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], " ", "=", " ", \({1.5, \(-0.5\)}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Broyden", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Observe that the subroutine ",
  StyleBox["ImprovedBroyden",
    FontWeight->"Bold"],
  " involves vector functions and is not dependent on the dimension. \nUse \
the subroutine ",
  StyleBox["ImprovedBroyden",
    FontWeight->"Bold"],
  " to solve the nonlinear system in 3D space:  \n\n\t\t",
  Cell[BoxData[
      \(0\  = \ 9\ x\^2 + 36  y\^2 + 4  z\^2 - 36\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - 2\ y\^2 - 20  z\)],
    AspectRatioFixed->False],
  "  \n\t\t",
  Cell[BoxData[
      \(0\  = \ x\^2 - y\^2 + z\^2\)],
    AspectRatioFixed->False],
  "  \n\t\n",
  StyleBox["Hint.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There are four solutions.  Good starting vectors are  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"], "0"],
          FontWeight->"Bold"], 
        "=", \({\(\[PlusMinus]1\), \(\[PlusMinus]1\), 0}\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{\(f\_2\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], "  ",
           
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], 
          RowBox[{\(f\_3\), "[", 
            RowBox[{"{", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], 
            "]"}]}]}]],
    AspectRatioFixed->False],
  " and construct the vector function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  " using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{x_, y_, z_}] = 
        9\ x\^2 + 36  y\^2 + 4  z\^2 - 36;\)\ \ \ \), "\n", 
    \(\(f\_2[{x_, y_, z_}] = x\^2 - 2\ y\^2 - 20  z;\)\ \ \ \), "\n", 
    \(\(f\_3[{x_, y_, z_}] = 
        x\^2 - y\^2 + z\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(F\&\[RightVector][{x_, y_, z_}] = {f\_1[{x, y, z}], f\_2[{x, y, z}], 
          f\_3[{x, y, z}]};\)\ \ \), "\n", 
    \(\(J[{x_, y_, z_}] = 
        Transpose[{\[PartialD]\_x\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_y\ 
              F\&\[RightVector][{x, y, z}], \[PartialD]\_z\ 
              F\&\[RightVector][{x, y, 
                  z}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the vector function\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[{x,y,z}] = \>\"", 
        MatrixForm[
          F\&\[RightVector][{x, y, z}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Jacobian matrix is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<J(x,y,z) = \>", MatrixForm[J[{x, y, z}]]];\)\ \ \)}], "Input",\

  AspectRatioFixed->False],

Cell[TextData[{
  "Second, graph the surfaces  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  ",  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_2\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_3\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}], "=", 
        "0"}]],
    AspectRatioFixed->False],
  "  using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  The points of intersection are the solutions we seek.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ContourPlot3D`\>"];\)\ \ \), "\[IndentingNewLine]", \

    \(\(graph1 = 
        ContourPlot3D[
          9\ x\^2 + 36  y\^2 + 4  z\^2 - 36, {x, \(-1.2\), 
            1.2}, {y, \(-1.2\), 1.2}, {z, \(-1.2\), 1.2}, 
          Lighting \[Rule] False, ContourStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ContourPlot3D[
          x\^2 - 2\ y\^2 - 20  z, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, Lighting \[Rule] False, 
          ContourStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ContourPlot3D[
          x\^2 - y\^2 + z\^2, {x, \(-1.2\), 1.2}, {y, \(-1.2\), 
            1.2}, {z, \(-1.2\), 1.2}, Lighting \[Rule] False, 
          ContourStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, Axes \[Rule] True, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(x,y,z) = \>\"", 
        f\_1[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(x,y,z) = \>\"", 
        f\_2[{x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(x,y,z) = \>\"", 
        f\_3[{x, y, z}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the improved Broyden's method to find a numerical approximation to \
the solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((1.0, 1.0, 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, 1.0, 0.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"ImprovedBroyden", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
          "]"}], ";"}], " "}]}], "Input"],

Cell["Compare with the standard Broyden's method.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, 1.0, 0.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Broyden", "[", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["P",
                    FontWeight->"Bold"], "\[RightVector]"],
                FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), " ", ",", 
            "10"}], "]"}], ";"}], "  "}]}], "Input"],

Cell[TextData[{
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the improved Broyden's method to find a numerical approximation to \
the solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((1.0, \(-1.0\), 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, \(-1.0\), 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"ImprovedBroyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell["Compare with the standard Broyden's method.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({1.0, \(-1.0\), 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell[TextData[{
  StyleBox["(iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the improved Broyden's method to find a numerical approximation to \
the solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], "=", \((\(-1.0\), 1.0, 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), 1.0, 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"ImprovedBroyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell["Compare with the standard Broyden's method.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), 1.0, 0.0}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell[TextData[{
  StyleBox["(iv)",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the improved Broyden's method to find a numerical approximation to \
the solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], 
        "=", \((\(-1.0\), \(-1.0\), 0.0)\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), \(-1.0\), 0.0}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"ImprovedBroyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell["Compare with the standard Broyden's method.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], "=", \({\(-1.0\), \(-1.0\), 0.0}\)}],
         ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Observe that the subroutine ",
  StyleBox["ImprovedBroyden",
    FontWeight->"Bold"],
  " involves vector functions and is not dependent on the dimension. \nUse \
the subroutine ",
  StyleBox["ImprovedBroyden",
    FontWeight->"Bold"],
  " to solve the nonlinear system in 4D space:  \n\n\t\t",
  Cell[BoxData[
      \(0\  = \ w\^2 + x\^2 + 3  y\^2 - z\^3 - 5\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ w + x\^3 - 2\ y\^2 - 10  z\)],
    AspectRatioFixed->False],
  "  \n\t\t",
  Cell[BoxData[
      \(0\  = \ 20 - w + x\^2 + y\^3 + z\^2\)],
    AspectRatioFixed->False],
  "   \n\t\t",
  Cell[BoxData[
      \(0\  = \ w\^3 + x - y\^3 + z - 10\)],
    AspectRatioFixed->False],
  "  \n\t\n",
  StyleBox["Hint.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There is one real solutions.  A good starting vectors is  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"], "0"],
          FontWeight->"Bold"], "=", \({\(-4.0\), 4.0, \(-4.0\), 4.0}\)}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the coordinate functions ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(f\_1\), "[", 
          RowBox[{"{", 
            RowBox[{"w", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(f\_2\), "[", 
          RowBox[{"{", 
            RowBox[{"w", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{\(f\_3\), "[", 
            RowBox[{"{", 
              RowBox[{"w", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], "]"}], "   ",
           
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " "}]], 
          RowBox[{\(f\_4\), "[", 
            RowBox[{"{", 
              RowBox[{"w", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y", ",", "z"}], "}"}], 
            "]"}]}]}]],
    AspectRatioFixed->False],
  " and construct the vector function ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(F\&\[RightVector]\),
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(X\&\[RightVector]\),
            FontWeight->"Bold"], ")"}]}]]],
  " using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and then find the Jacobian matrix",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["J",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y", ",", "z"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f\_1[{w_, x_, y_, z_}] = 
        w\^2 + x\^2 + 3  y\^2 - z\^3 - 5;\)\ \ \ \), "\n", 
    \(\(f\_2[{w_, x_, y_, z_}] = 
        w + x\^3 - 2\ y\^2 - 10  z;\)\ \ \ \), "\n", 
    \(\(f\_3[{w_, x_, y_, z_}] = 
        20 - w + x\^2 + y\^3 + z\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(f\_4[{w_, x_, y_, z_}] = 
        w\^3 + x - y\^3 + z - 10;\)\ \), "\[IndentingNewLine]", 
    \(\(F\&\[RightVector][{w_, x_, y_, z_}] = {f\_1[{w, x, y, z}], 
          f\_2[{w, x, y, z}], f\_3[{w, x, y, z}], 
          f\_4[{w, x, y, z}]};\)\ \ \), "\n", 
    \(\(J[{w_, x_, y_, z_}] = 
        Transpose[{\[PartialD]\_w\ 
              F\&\[RightVector][{w, x, y, z}], \[PartialD]\_x\ 
              F\&\[RightVector][{w, x, y, z}], \[PartialD]\_y\ 
              F\&\[RightVector][{w, x, y, z}], \[PartialD]\_z\ 
              F\&\[RightVector][{w, x, y, 
                  z}]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_1\)(w,x,y,z) = \>\"", 
        f\_1[{w, x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_2\)(w,x,y,z) = \>\"", 
        f\_2[{w, x, y, z}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<0 = \!\(f\_3\)(w,x,y,z) = \>\"", 
        f\_3[{w, x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<0 = \!\(f\_4\)(w,x,y,z) = \>\"", 
        f\_4[{w, x, y, z}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the vector function\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\!\(F\&\[RightVector]\)[{w,x,y,z}] = \>\"", 
        MatrixForm[
          F\&\[RightVector][{w, x, y, z}]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Jacobian matrix is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<J(w,x,y,z) = \>", 
        MatrixForm[J[{w, x, y, z}]]];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use the improved Broyden's method to find a numerical approximation to the \
solution near  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], "0"], 
        "=", \((\(-4.0\), 4.0, \(-4.0\), 4.0)\)}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], 
          "=", \({\(-4.0\), 4.0, \(-4.0\), 4.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"ImprovedBroyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"],

Cell["\<\
These are the same answers we obtained with the Broyden subroutine. \
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], 
          "=", \({\(-4.0\), 4.0, \(-4.0\), 4.0}\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Broyden", "[", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["P",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "0"], ",", \(10\^\(-10\)\), ",", "10"}], 
        "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Broyden's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BroydenMethodBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 652},
WindowMargins->{{-4, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 194, 5, 35, "Text"],
Cell[1973, 60, 1133, 38, 140, "Text"]
}, Closed]],
Cell[3121, 101, 193, 6, 68, "Text"],
Cell[3317, 109, 6399, 201, 242, "Text"],
Cell[9719, 312, 367, 13, 33, "Text"],
Cell[10089, 327, 348, 11, 33, "Text"],
Cell[10440, 340, 175, 3, 33, "Text"],
Cell[10618, 345, 10846, 220, 427, "Input"],
Cell[21467, 567, 1395, 38, 88, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22887, 609, 101, 2, 33, "Text"],
Cell[22991, 613, 2171, 66, 33, "Text"],
Cell[25165, 681, 919, 18, 195, "Input"],
Cell[26087, 701, 1163, 35, 33, "Text"],
Cell[27253, 738, 640, 11, 130, "Input"],
Cell[27896, 751, 851, 27, 33, "Text",
  Evaluatable->False],
Cell[28750, 780, 746, 22, 53, "Input"],
Cell[29499, 804, 135, 3, 33, "Text"],
Cell[29637, 809, 75, 0, 33, "Text"],
Cell[29715, 811, 171, 7, 33, "Text",
  Evaluatable->False],
Cell[29889, 820, 739, 15, 135, "Input"],
Cell[30631, 837, 272, 9, 33, "Text"],
Cell[30906, 848, 66, 1, 30, "Input"],
Cell[30975, 851, 50, 1, 30, "Input"],
Cell[31028, 854, 764, 15, 135, "Input"],
Cell[31795, 871, 817, 25, 33, "Text"],
Cell[32615, 898, 763, 22, 53, "Input"],
Cell[33381, 922, 75, 0, 33, "Text"],
Cell[33459, 924, 171, 7, 33, "Text",
  Evaluatable->False],
Cell[33633, 933, 769, 15, 135, "Input"]
}, Closed]],
Cell[34417, 951, 1162, 38, 163, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[35604, 993, 101, 2, 33, "Text"],
Cell[35708, 997, 3626, 106, 52, "Text"],
Cell[39337, 1105, 1148, 23, 213, "Input"],
Cell[40488, 1130, 1712, 53, 33, "Text"],
Cell[42203, 1185, 1614, 33, 276, "Input"],
Cell[43820, 1220, 509, 17, 33, "Text",
  Evaluatable->False],
Cell[44332, 1239, 724, 21, 53, "Input"],
Cell[45059, 1262, 515, 17, 33, "Text",
  Evaluatable->False],
Cell[45577, 1281, 731, 21, 53, "Input"],
Cell[46311, 1304, 516, 17, 33, "Text",
  Evaluatable->False],
Cell[46830, 1323, 731, 21, 53, "Input"],
Cell[47564, 1346, 529, 18, 33, "Text",
  Evaluatable->False],
Cell[48096, 1366, 736, 21, 53, "Input"],
Cell[48835, 1389, 334, 12, 71, "Text"],
Cell[49172, 1403, 540, 9, 150, "Input"],
Cell[49715, 1414, 293, 7, 52, "Text"]
}, Closed]],
Cell[50023, 1424, 2225, 58, 176, "Text"],
Cell[52251, 1484, 181, 3, 33, "Text"],
Cell[52435, 1489, 10851, 220, 427, "Input"],
Cell[63289, 1711, 1418, 40, 88, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[64732, 1755, 101, 2, 33, "Text"],
Cell[64836, 1759, 2704, 83, 52, "Text"],
Cell[67543, 1844, 1567, 29, 356, "Input"],
Cell[69113, 1875, 1159, 35, 33, "Text"],
Cell[70275, 1912, 640, 11, 130, "Input"],
Cell[70918, 1925, 860, 28, 33, "Text",
  Evaluatable->False],
Cell[71781, 1955, 1009, 29, 53, "Input"],
Cell[72793, 1986, 105, 2, 33, "Text",
  Evaluatable->False],
Cell[72901, 1990, 1003, 29, 53, "Input"],
Cell[73907, 2021, 302, 8, 33, "Text"],
Cell[74212, 2031, 1365, 34, 55, "Input"],
Cell[75580, 2067, 816, 25, 33, "Text"],
Cell[76399, 2094, 1026, 29, 53, "Input"],
Cell[77428, 2125, 105, 2, 33, "Text",
  Evaluatable->False],
Cell[77536, 2129, 1020, 29, 53, "Input"],
Cell[78559, 2160, 302, 8, 33, "Text"],
Cell[78864, 2170, 1365, 34, 55, "Input"]
}, Closed]],
Cell[80244, 2207, 1168, 38, 163, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[81437, 2249, 101, 2, 33, "Text"],
Cell[81541, 2253, 4161, 123, 52, "Text"],
Cell[85705, 2378, 1846, 36, 354, "Input"],
Cell[87554, 2416, 1712, 53, 33, "Text"],
Cell[89269, 2471, 1614, 33, 276, "Input"],
Cell[90886, 2506, 508, 17, 33, "Text",
  Evaluatable->False],
Cell[91397, 2525, 730, 21, 53, "Input"],
Cell[92130, 2548, 86, 2, 33, "Text"],
Cell[92219, 2552, 724, 21, 53, "Input"],
Cell[92946, 2575, 514, 17, 33, "Text",
  Evaluatable->False],
Cell[93463, 2594, 737, 21, 53, "Input"],
Cell[94203, 2617, 86, 2, 33, "Text"],
Cell[94292, 2621, 731, 21, 53, "Input"],
Cell[95026, 2644, 515, 17, 33, "Text",
  Evaluatable->False],
Cell[95544, 2663, 737, 21, 53, "Input"],
Cell[96284, 2686, 86, 2, 33, "Text"],
Cell[96373, 2690, 731, 21, 53, "Input"],
Cell[97107, 2713, 528, 18, 33, "Text",
  Evaluatable->False],
Cell[97638, 2733, 742, 21, 53, "Input"],
Cell[98383, 2756, 86, 2, 33, "Text"],
Cell[98472, 2760, 736, 21, 53, "Input"],
Cell[99211, 2783, 334, 12, 71, "Text"],
Cell[99548, 2797, 540, 9, 150, "Input"],
Cell[100091, 2808, 293, 7, 52, "Text"]
}, Closed]],
Cell[100399, 2818, 1306, 36, 188, "Text"],
Cell[101708, 2856, 7778, 232, 204, "Text"],
Cell[109489, 3090, 3615, 114, 204, "Text"],
Cell[113107, 3206, 5908, 184, 237, "Text"],
Cell[119018, 3392, 367, 13, 33, "Text"],
Cell[119388, 3407, 340, 10, 33, "Text"],
Cell[119731, 3419, 176, 3, 33, "Text"],
Cell[119910, 3424, 17086, 348, 714, "Input"],
Cell[136999, 3774, 1400, 38, 88, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[138424, 3816, 101, 2, 33, "Text"],
Cell[138528, 3820, 2171, 66, 33, "Text"],
Cell[140702, 3888, 1016, 19, 235, "Input"],
Cell[141721, 3909, 1159, 35, 33, "Text"],
Cell[142883, 3946, 1301, 31, 144, "Input"],
Cell[144187, 3979, 842, 27, 33, "Text",
  Evaluatable->False],
Cell[145032, 4008, 1782, 49, 118, "Input"],
Cell[146817, 4059, 4658, 126, 143, "Input"],
Cell[151478, 4187, 4598, 102, 477, "Input"],
Cell[156079, 4291, 3988, 108, 122, "Input"],
Cell[160070, 4401, 54, 0, 33, "Text"],
Cell[160127, 4403, 629, 19, 53, "Input"],
Cell[160759, 4424, 105, 2, 33, "Text",
  Evaluatable->False],
Cell[160867, 4428, 746, 22, 53, "Input"],
Cell[161616, 4452, 802, 25, 33, "Text"],
Cell[162421, 4479, 710, 21, 53, "Input"],
Cell[163134, 4502, 105, 2, 33, "Text",
  Evaluatable->False],
Cell[163242, 4506, 763, 22, 53, "Input"]
}, Closed]],
Cell[164020, 4531, 1196, 40, 163, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[165241, 4575, 101, 2, 33, "Text"],
Cell[165345, 4579, 3627, 106, 52, "Text"],
Cell[168975, 4687, 1453, 29, 275, "Input"],
Cell[170431, 4718, 1712, 53, 33, "Text"],
Cell[172146, 4773, 1614, 33, 276, "Input"],
Cell[173763, 4808, 500, 17, 33, "Text",
  Evaluatable->False],
Cell[174266, 4827, 1824, 50, 118, "Input"],
Cell[176093, 4879, 4658, 126, 143, "Input"],
Cell[180754, 5007, 4598, 102, 477, "Input"],
Cell[185355, 5111, 3988, 108, 122, "Input"],
Cell[189346, 5221, 54, 0, 33, "Text"],
Cell[189403, 5223, 633, 19, 53, "Input"],
Cell[190039, 5244, 70, 0, 33, "Text"],
Cell[190112, 5246, 724, 21, 53, "Input"],
Cell[190839, 5269, 510, 17, 33, "Text",
  Evaluatable->False],
Cell[191352, 5288, 678, 20, 53, "Input"],
Cell[192033, 5310, 70, 0, 33, "Text"],
Cell[192106, 5312, 683, 20, 53, "Input"],
Cell[192792, 5334, 516, 17, 33, "Text",
  Evaluatable->False],
Cell[193311, 5353, 678, 20, 53, "Input"],
Cell[193992, 5375, 70, 0, 33, "Text"],
Cell[194065, 5377, 683, 20, 53, "Input"],
Cell[194751, 5399, 529, 18, 33, "Text",
  Evaluatable->False],
Cell[195283, 5419, 683, 20, 53, "Input"],
Cell[195969, 5441, 70, 0, 33, "Text"],
Cell[196042, 5443, 688, 20, 53, "Input"]
}, Closed]],
Cell[196745, 5466, 1298, 43, 182, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[198068, 5513, 101, 2, 33, "Text"],
Cell[198172, 5517, 5910, 165, 52, "Text"],
Cell[204085, 5684, 1855, 36, 315, "Input"],
Cell[205943, 5722, 445, 15, 33, "Text",
  Evaluatable->False],
Cell[206391, 5739, 1850, 51, 118, "Input"],
Cell[208244, 5792, 4658, 126, 143, "Input"],
Cell[212905, 5920, 4598, 102, 477, "Input"],
Cell[217506, 6024, 3988, 108, 122, "Input"],
Cell[221497, 6134, 54, 0, 33, "Text"],
Cell[221554, 6136, 697, 21, 53, "Input"],
Cell[222254, 6159, 180, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[222459, 6168, 101, 2, 33, "Text"],
Cell[222563, 6172, 638, 12, 130, "Input"],
Cell[223204, 6186, 57, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[223286, 6190, 94, 2, 33, "Text"],
Cell[223383, 6194, 621, 13, 130, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[224043, 6212, 923, 25, 106, "Text"],
Cell[224969, 6239, 4679, 136, 115, "Text"],
Cell[229651, 6377, 3735, 117, 166, "Text"],
Cell[233389, 6496, 7224, 218, 307, "Text"],
Cell[240616, 6716, 367, 13, 33, "Text"],
Cell[240986, 6731, 185, 3, 33, "Text"],
Cell[241174, 6736, 18386, 371, 737, "Input"],
Cell[259563, 7109, 1411, 39, 88, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[260999, 7152, 101, 2, 33, "Text"],
Cell[261103, 7156, 2125, 64, 33, "Text"],
Cell[263231, 7222, 1016, 19, 235, "Input"],
Cell[264250, 7243, 1159, 35, 33, "Text"],
Cell[265412, 7280, 1301, 31, 144, "Input"],
Cell[266716, 7313, 619, 20, 33, "Text",
  Evaluatable->False],
Cell[267338, 7335, 637, 19, 53, "Input"],
Cell[267978, 7356, 549, 17, 33, "Text",
  Evaluatable->False],
Cell[268530, 7375, 741, 22, 53, "Input"],
Cell[269274, 7399, 575, 18, 33, "Text"],
Cell[269852, 7419, 718, 21, 53, "Input"],
Cell[270573, 7442, 552, 17, 33, "Text",
  Evaluatable->False],
Cell[271128, 7461, 758, 22, 53, "Input"]
}, Closed]],
Cell[271901, 7486, 1212, 40, 163, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[273138, 7530, 101, 2, 33, "Text"],
Cell[273242, 7534, 3623, 106, 52, "Text"],
Cell[276868, 7642, 1453, 29, 275, "Input"],
Cell[278324, 7673, 1712, 53, 33, "Text"],
Cell[280039, 7728, 1614, 33, 276, "Input"],
Cell[281656, 7763, 513, 17, 33, "Text",
  Evaluatable->False],
Cell[282172, 7782, 719, 21, 53, "Input"],
Cell[282894, 7805, 59, 0, 33, "Text"],
Cell[282956, 7807, 719, 21, 53, "Input"],
Cell[283678, 7830, 519, 17, 33, "Text",
  Evaluatable->False],
Cell[284200, 7849, 686, 20, 53, "Input"],
Cell[284889, 7871, 59, 0, 33, "Text"],
Cell[284951, 7873, 678, 20, 53, "Input"],
Cell[285632, 7895, 520, 17, 33, "Text",
  Evaluatable->False],
Cell[286155, 7914, 686, 20, 53, "Input"],
Cell[286844, 7936, 59, 0, 33, "Text"],
Cell[286906, 7938, 678, 20, 53, "Input"],
Cell[287587, 7960, 533, 18, 33, "Text",
  Evaluatable->False],
Cell[288123, 7980, 691, 20, 53, "Input"],
Cell[288817, 8002, 59, 0, 33, "Text"],
Cell[288879, 8004, 683, 20, 53, "Input"]
}, Closed]],
Cell[289577, 8027, 1315, 43, 182, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[290917, 8074, 102, 2, 33, "Text"],
Cell[291022, 8078, 5898, 165, 52, "Text"],
Cell[296923, 8245, 1855, 36, 315, "Input"],
Cell[298781, 8283, 410, 13, 33, "Text"],
Cell[299194, 8298, 705, 21, 53, "Input"],
Cell[299902, 8321, 92, 2, 33, "Text"],
Cell[299997, 8325, 697, 21, 53, "Input"]
}, Closed]],
Cell[300709, 8349, 158, 3, 32, "Text"],
Cell[300870, 8354, 306, 8, 33, "Text"],
Cell[301179, 8364, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

