(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     75815,       2364]*)
(*NotebookOutlinePosition[     76794,       2394]*)
(*  CellTagsIndexPosition[     76750,       2390]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Gauss-Jordan Elimination",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tIn this module we develop a algorithm for solving a general linear \
system of equations ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], "=", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  " consisting of n equations and n unknowns where it is assumed that the \
system has a unique solution.  The method is attributed ",
  StyleBox[ButtonBox["Johann Carl Friedrich Gauss",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Gauss.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  " (1777-1855) and ",
  StyleBox[ButtonBox["Wilhelm Jordan",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  " (1842 to 1899).  The following theorem states the sufficient conditions \
for the existence and uniqueness of solutions of a linear system ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], "=", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ".  \n\n",
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Unique Solutions",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LinearSystemofEquations.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[") ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Assume that ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  " is an ",
  Cell[BoxData[
      \(n\[Times]n\)]],
  " matrix.  The following statements are equivalent.\n\n",
  StyleBox["     (i)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Given any ",
  Cell[BoxData[
      \(n\[Times]1\)]],
  " matrix ",
  Cell[BoxData[
      StyleBox["B",
        FontWeight->"Bold"]]],
  ", the linear system ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], "=", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  " has a unique solution.\n     \n",
  StyleBox["    (ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The matrix ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  " is nonsingular (i.e., ",
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["A",
          FontWeight->"Bold"], \(-1\)]]],
  " exists).\n    \n",
  StyleBox["   (iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The system of equations ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], "=", 
        StyleBox["0",
          FontWeight->"Bold"]}]]],
  " has the unique solution ",
  Cell[BoxData[
      RowBox[{
        StyleBox["X",
          FontWeight->"Bold"], "=", 
        StyleBox["0",
          FontWeight->"Bold"]}]]],
  ".  \n   \n",
  StyleBox["   (iv)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The determinant of ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  " is nonzero, i.e. ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"det", 
          RowBox[{"(", 
            StyleBox["A",
              FontWeight->"Bold"], ")"}]}], "\[NotEqual]", "0"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIt is convenient to store all the coefficients of the linear system ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], "=", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  " in one array of dimension ",
  Cell[BoxData[
      \(n\[Times]n + 1\)]],
  ".  The coefficients of ",
  Cell[BoxData[
      StyleBox["B",
        FontWeight->"Bold"]]],
  " are stored in column ",
  Cell[BoxData[
      \(n + 1\)]],
  " of the array (i.e. ",
  Cell[BoxData[
      \(a\_\(i, n + 1\) = b\_i\)]],
  ").  Row ",
  Cell[BoxData[
      \(k\)]],
  " contains all the coefficients necessary to represent the ",
  Cell[BoxData[
      \(i\^th\)]],
  " equation in the linear system. The augmented matrix is denoted ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], "=", 
        RowBox[{"[", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold"], "|", 
            StyleBox["B",
              FontWeight->"Bold"]}], "]"}]}]]],
  " and the linear system is represented as follows:\n\n\t\t ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], "="}]]],
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(a\_\(1, 1\)\), \(a\_\(1, 2\)\), \(a\_\(1, 3\)\), 
              "...", \(a\_\(1, n\)\), \(b\_1\)},
            {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\), \(a\_\(2, 3\)\), 
              "...", \(a\_\(2, n\)\), \(b\_2\)},
            {\(a\_\(3, 1\)\), \(a\_\(3, 2\)\), \(a\_\(3, 3\)\), 
              "...", \(a\_\(3, n\)\), \(b\_3\)},
            {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
              "\[VerticalEllipsis]", " ", "\[VerticalEllipsis]", 
              "\[VerticalEllipsis]"},
            {\(a\_\(n, 1\)\), \(a\_\(n, 2\)\), \(a\_\(n, 3\)\), 
              "...", \(a\_\(n, n\)\), \(b\_n\)}
            }], ")"}]]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThe system ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], "=", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ", with augmented matrix ",
  Cell[BoxData[
      StyleBox["M",
        FontWeight->"Bold"]]],
  ", can be solved by performing row operations on ",
  Cell[BoxData[
      StyleBox["M",
        FontWeight->"Bold"]]],
  ".  The variables  are placeholders for the coefficients and cam be omitted \
until the end of the computation."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/GaussianJordanProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/GaussianJordanProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Elementary Row Operations",
    ButtonData:>{
      URL[ 
      "http://mathworld.wolfram.com/ElementaryRowandColumnOperations.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The following operations applied to the augmented matrix ",
  Cell[BoxData[
      StyleBox["M",
        FontWeight->"Bold"]]],
  " yield an equivalent linear system. \n\n",
  StyleBox["     (i)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  StyleBox["Interchanges:",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tThe order of two rows can be interchanged.  \n     \n",
  StyleBox["    (ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  StyleBox["Scaling:",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   \tMultiplying a row by a nonzero constant.\n    \n",
  StyleBox["   (iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  StyleBox["Replacement:",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tRow r can be replaced by the sum of that tow and a nonzero multiple of \
any other row;\n                           \tthat is:  ",
  Cell[BoxData[
      \(row\_r = row\_r - c\ row\_p\)]],
  ".  \t\n\n\tIt is common practice to implement (iii) by replacing a row \
with the difference of that row and a multiple of another row.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/GaussianJordanProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/GaussianJordanProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Pivot Element",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Pivoting.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The number ",
  Cell[BoxData[
      \(a\_\(p, p\)\)]],
  " in the coefficient matrix ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  " that is used to eliminate ",
  Cell[BoxData[
      \(a\_\(i, p\)\)]],
  " where ",
  Cell[BoxData[
      \(i = p + 1, p + 2,  ... , n\)]],
  ", is called the ",
  Cell[BoxData[
      \(p\^th\)]],
  " pivot element, and the ",
  Cell[BoxData[
      \(p\^th\)]],
  " row is called the pivot row.      "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Gaussian Elimination with Back Substitution",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GaussianElimination.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Assume that ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  " is an ",
  Cell[BoxData[
      \(n\[Times]n\)]],
  " nonsingular matrix. There exists a unique system ",
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], "=", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  " that is equivalent to the given system ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], "=", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ", where ",
  Cell[BoxData[
      StyleBox["U",
        FontWeight->"Bold"]]],
  " is an upper-triangular matrix with ",
  Cell[BoxData[
      \(u\_\(i, i\) \[NotEqual] 0\)]],
  " for ",
  Cell[BoxData[
      \(i = 1, 2,  ... , n\)]],
  ".  After  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["U",
          FontWeight->"Bold"], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  " are constructed, back substitution can be used to solve ",
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], "=", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  " for ",
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/GaussianJordanProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/GaussianJordanProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm I. (Limited Gauss-Jordan Elimination).",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Construct the solution to the linear system  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  "  by using Gauss-Jordan elimination ",
  StyleBox["under the assumption",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " that row interchanges are not needed.  The following subroutine uses row \
operations to eliminate  ",
  Cell[BoxData[
      \(x\_p\)]],
  "  in column  p  for  ",
  Cell[BoxData[
      \(p = 1, 2,  ... , n\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/GaussianJordanProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/GaussianJordanProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Limited Gauss-Jordan Elimination",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    \(\(\(GaussJordan[A0_, 
        n_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[\ {A = A0, i, 
          p}, \ \[IndentingNewLine]Print[\ 
          MatrixForm[A]\ ]; \ \[IndentingNewLine]For[\ p = 1, \ 
          p \[LessEqual] 
            n, \ \(p++\), \ \
\[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\
\)\  = \ A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\)\/A\_\(\
\(\[LeftDoubleBracket]\)\(p, p\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]For[\ i = 1, \ 
            i \[LessEqual] 
              n, \ \(i++\), \ \[IndentingNewLine]\(If[\ 
                i \[NotEqual] 
                  p, \ \[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                  A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)\  - \ \(A\_\(\(\[LeftDoubleBracket]\)\(i, p\)\(\[RightDoubleBracket]\)\)\) 
                      A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\
\[RightDoubleBracket]\)\)\ \ ];\)\ ]; \ \[IndentingNewLine]Print[
            MatrixForm[A]];\ \ ];\ \ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Use the Gauss-Jordan elimination method to solve the linear system  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", "2", "3"},
                {\(-3\), "1", "5"},
                {"2", "4", \(-1\)}
                }], ")"}], 
          InterpretationBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)},
                  {\(x\_3\)}
                  }], "\[NoBreak]", ")"}],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3]}]]}], " ", "=", " ", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3"},
                {\(-2\)},
                {\(-1\)}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Use the menu \"Input\" then submenu \"Create Table/Matrix/Palette\" to \
enter matrices ",
  StyleBox["A",
    FontWeight->"Bold"],
  " and ",
  StyleBox["M",
    FontWeight->"Bold"],
  " and vector ",
  StyleBox["B",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", " ", "=", " ", 
          RowBox[{"(", GridBox[{
                {"1", "2", "3"},
                {\(-3\), "1", "5"},
                {"2", "4", \(-1\)}
                }], ")"}]}], ";"}], " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"B", " ", "=", " ", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"3"},
                  {\(-2\)},
                  {\(-1\)}
                  }], "\[NoBreak]", ")"}],
            (MatrixForm[ #]&)]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(vars = {\*"\"\<\!\(x\_1\)\>\"", \*"\"\<\
\!\(x\_2\)\>\"", \*"\"\<\!\(x\_3\)\>\""};\), "\[IndentingNewLine]", \(Print["\
\<Solve the system\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  "First form the augmented matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"[", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold"], ",", 
            StyleBox["B",
              FontWeight->"Bold"]}], "]"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"M", "=", 
          RowBox[{"(", GridBox[{
                {"1", "2", "3", "3"},
                {\(-3\), "1", "5", \(-2\)},
                {"2", "4", \(-1\), \(-1\)}
                }], ")"}]}], ";"}], " "}]], "Input"],

Cell["Then perform Gauss-Jordan elimination.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(GaussJordan[M, 3]\)\(\ \ \)\)\)], "Input"],

Cell["Verify the solution.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"X", "=", 
          RowBox[{"(", GridBox[{
                {"2"},
                {\(-1\)},
                {"1"}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\), "\[IndentingNewLine]", \(Print["\<X = \>", 
        MatrixForm[vars], "\< = \>", MatrixForm[X]];\), "\[IndentingNewLine]",
   
    RowBox[{\(Print["\<Does A X = B ?\>"];\), " "}], "\n", 
    RowBox[{\(Print[MatrixForm[A], MatrixForm[X], "\< = \>", 
          MatrixForm[B], \ "\< ?\>"\ ];\), " "}], "\n", 
    RowBox[{\(Print[MatrixForm[A . X], "\< = \>", MatrixForm[B]\ ];\), 
      " "}], "\n", 
    RowBox[{\(Print[A . X\  \[Equal] \ B\ ];\), " "}]}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can compare our answer with the answer obtained by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  StyleBox["RowReduce",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  procedure.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<M = \>", MatrixForm[M]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[RowReduce[M]]];\)\)}], "Input"],

Cell[TextData[{
  "This agrees with our answer that was obtained with our subroutine ",
  StyleBox["GaussJordan[M,3]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Interchange rows 2 and 3 and try to use the Gauss-Jordan subroutine to \
solve ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "4", \(-1\)},
                  {\(-3\), "1", "5"}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]], 
          InterpretationBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)},
                  {\(x\_3\)}
                  }], "\[NoBreak]", ")"}],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3]}]]}], " ", "=", " ", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3"},
                {\(-1\)},
                {\(-2\)}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]]],
  ".  \nUse lists in the subscript to select rows 2 and 3 and perform the row \
interchange."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(A\_\(\(\[LeftDoubleBracket]\)\({2, 3}\)\(\[RightDoubleBracket]\)\) = 
        A\_\(\(\[LeftDoubleBracket]\)\({3, 2}\)\(\[RightDoubleBracket]\)\);\)\
\ \), "\[IndentingNewLine]", 
    \(\(B\_\(\(\[LeftDoubleBracket]\)\({2, 3}\)\(\[RightDoubleBracket]\)\) = 
        B\_\(\(\[LeftDoubleBracket]\)\({3, 2}\)\(\[RightDoubleBracket]\)\);\)\
\ \), "\[IndentingNewLine]", 
    \(\(M\_\(\(\[LeftDoubleBracket]\)\({2, 3}\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\({3, 2}\)\(\[RightDoubleBracket]\)\);\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<B = \>", MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<M = \>", MatrixForm[M]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Then try to perform Gauss-Jordan elimination ",
  StyleBox["without",
    FontColor->RGBColor[1, 0, 1]],
  " row interchanges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"M", "=", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "3"},
                  {"2", "4", \(-1\), \(-1\)},
                  {\(-3\), "1", "5", \(-2\)}
                  }], "\[NoBreak]", ")"}],
            (MatrixForm[ #]&)]}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(GaussJordan[M, 3]\), "  "}]}], "Input"],

Cell[TextData[{
  "Gauss-Jordan elimination does ",
  StyleBox["not ",
    FontColor->RGBColor[1, 0, 1]],
  "work without row interchanges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox["Provide for row interchanges in the Gauss-Jordan \
subroutine.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell["\<\
Add the following loop that will interchange rows and perform \
partial pivoting.\
\>", "Text"],

Cell[BoxData[
    \(\(\(For[\ k = p + 1, \ 
        k \[LessEqual] 
          n, \ \(k++\), \ \[IndentingNewLine]\(If[\ 
            Abs[A\_\(\(\[LeftDoubleBracket]\)\(k, \
p\)\(\[RightDoubleBracket]\)\)] > 
              Abs[A\_\(\(\[LeftDoubleBracket]\)\(p, \
p\)\(\[RightDoubleBracket]\)\)], \ \[IndentingNewLine]\(A\_\(\(\
\[LeftDoubleBracket]\)\({p, k}\)\(\[RightDoubleBracket]\)\)\  = \ 
                A\_\(\(\[LeftDoubleBracket]\)\({k, \
p}\)\(\[RightDoubleBracket]\)\);\)\ \ \ ];\)\ ];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "To make these changes, copy your subroutine GaussJordan and place a copy \
below. Then you can copy the above lines by selecting them and then use the \
\"Edit\" and \"Copy\" menus. The improved Gauss-Jordan subroutine should look \
like this (blue is for placement information only).  Or just use the active \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code given below."
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm II. (Complete Gauss-Jordan Elimination).",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Construct the solution to the linear system  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  "  by using Gauss-Jordan elimination.  Provision is made for row \
interchanges if they are needed.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/GaussianJordanProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/GaussianJordanProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Complete Gauss-Jordan Elimination",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    StyleBox[\(\(GaussJordan[A0_, 
          n_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[\ {A = A0, i, k, 
            p}, \ \[IndentingNewLine]Print[\ 
            MatrixForm[A]\ ]; \ \[IndentingNewLine]For[\ p = 1, \ 
            p \[LessEqual] n, \ \(p++\), \ \[IndentingNewLine]For[\ 
              k = p + 1, \ 
              k \[LessEqual] 
                n, \ \(k++\), \ \[IndentingNewLine]\(If[\ 
                  Abs[A\_\(\(\[LeftDoubleBracket]\)\(k, p\)\(\
\[RightDoubleBracket]\)\)] > 
                    Abs[A\_\(\(\[LeftDoubleBracket]\)\(p, p\)\(\
\[RightDoubleBracket]\)\)], \ \
\[IndentingNewLine]\(A\_\(\(\[LeftDoubleBracket]\)\({p, k}\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                      A\_\(\(\[LeftDoubleBracket]\)\({k, p}\)\(\
\[RightDoubleBracket]\)\);\)\ \ \ ];\)\ ]; \ \[IndentingNewLine]A\_\(\(\
\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\)\  = \ 
              A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\)\/\
A\_\(\(\[LeftDoubleBracket]\)\(p, p\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]For[\ i = 1, \ 
              i \[LessEqual] 
                n, \ \(i++\), \ \[IndentingNewLine]\(If[\ 
                  i \[NotEqual] 
                    p, \ \[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(i\)\
\(\[RightDoubleBracket]\)\)\  = \ 
                    A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\  - \ \(A\_\(\(\[LeftDoubleBracket]\)\(i, 
                            p\)\(\[RightDoubleBracket]\)\)\) 
                        A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\
\[RightDoubleBracket]\)\)\ \ ];\)\ ]; \ \[IndentingNewLine]Print[
              MatrixForm[A]];\ \ ]; \[IndentingNewLine]Return[
            A];\ \ ]\)\(\ \)\),
      Background->None]], "Input"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Use the improved Gauss-Jordan elimination subroutine with row \
interchanges to solve",
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "4", \(-1\)},
                  {\(-3\), "1", "5"}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]], 
          InterpretationBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)},
                  {\(x\_3\)}
                  }], "\[NoBreak]", ")"}],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3]}]]}], " ", "=", " ", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"3"},
                {\(-1\)},
                {\(-2\)}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]]],
  ".  ",
  "\nUse the matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " and vector ",
  StyleBox["B",
    FontWeight->"Bold"],
  " in Example 2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(vars = {\*"\"\<\!\(x\_1\)\>\"", \*"\"\<\!\(x\_2\)\>\"", \
\*"\"\<\!\(x\_3\)\>\""};\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<B = \>", MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use the augmented matrix\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<M = \>", MatrixForm[M]\ ];\)\ \)}], "Input"],

Cell["Perform Gauss-Jordan elimination with row interchanges.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(GaussJordan[M, 3];\)\(\ \ \)\)\)], "Input"],

Cell["Verify the solution.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"X", "=", 
          RowBox[{"(", GridBox[{
                {"2"},
                {\(-1\)},
                {"1"}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print["\<X = \>", 
        MatrixForm[vars], "\< = \>", MatrixForm[X]];\), "\[IndentingNewLine]",
   
    RowBox[{\(Print["\<Does A X = B ?\>"];\), " "}], "\n", 
    RowBox[{\(Print[MatrixForm[A], MatrixForm[X], "\< = \>", 
          MatrixForm[B], "\< ?\>"\ ];\), " "}], "\n", 
    RowBox[{\(Print[MatrixForm[A . X], "\< = \>", MatrixForm[B]\ ];\), 
      " "}], "\n", 
    RowBox[{\(Print[A . X\  \[Equal] \ B\ ];\), " "}]}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can compare our answer with the answer obtained by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  StyleBox["RowReduce",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  procedure.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<M = \>", MatrixForm[M]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[RowReduce[M]]];\)\)}], "Input"],

Cell[TextData[{
  "This agrees with our answer that was obtained with our subroutine ",
  StyleBox["GaussJordan[M,3]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can compute the solution X with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"",
  StyleBox["LinearSolve",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "\" procedure."
}], "Text"],

Cell[BoxData[{
    \(\(X = LinearSolve[A, B];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Use the Gauss-Jordan elimination method to solve the linear system  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"4", "8", "4", "0"},
                  {"1", "4", "7", "2"},
                  {"1", "5", "4", \(-3\)},
                  {"1", "3", "0", \(-2\)}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]], 
          InterpretationBox[
            InterpretationBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(x\_1\)},
                    {\(x\_2\)},
                    {\(x\_3\)},
                    {\(x\_4\)}
                    }], "\[NoBreak]", ")"}],
              MatrixForm[ {
                Subscript[ x, 1], 
                Subscript[ x, 2], 
                Subscript[ x, 3], 
                Subscript[ x, 4]}]],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3]}]]}], " ", "=", " ", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"8"},
                {"10"},
                {\(-4\)},
                {\(-4\)}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", " ", "=", " ", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"4", "8", "4", "0"},
                  {"1", "4", "7", "2"},
                  {"1", "5", "4", \(-3\)},
                  {"1", "3", "0", \(-2\)}
                  }], "\[NoBreak]", ")"}],
            (MatrixForm[ #]&)]}], ";"}], " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"B", " ", "=", " ", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"8"},
                  {"10"},
                  {\(-4\)},
                  {\(-4\)}
                  }], "\[NoBreak]", ")"}],
            (MatrixForm[ #]&)]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(vars = {\*"\"\<\!\(x\_1\)\>\"", \*"\"\<\
\!\(x\_2\)\>\"", \*"\"\<\!\(x\_3\)\>\"", \*"\"\<\!\(x\_4\)\>\""};\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print["\<A = \>", MatrixForm[A]\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<B = \>", MatrixForm[B]\ ];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Solve the system\>"];\), "\
\[IndentingNewLine]", \(Print[MatrixForm[A], MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  "Form the augmented matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], " ", "=", 
        RowBox[{"[", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold"], ",", 
            StyleBox["B",
              FontWeight->"Bold"]}], "]"}]}]]],
  "  using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s procedure AppendRows, which adds more elements to each of the rows, \
hence is a command to \"append\" column(s).  First, load the \
\"MatrixManipulation\" procedure into memory.  Be sure to execute the \
following command before any reference to \"AppendRows\" is made, otherwise a \
\"multiple contexts\" error will be committed. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(M = AppendRows[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<B = \>", MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use the augmented matrix\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<M = \>", MatrixForm[M]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Then perform Gauss-Jordan elimination. Note that we are storing the \
solution returned in the variable  ",
  StyleBox["G",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(G = GaussJordan[M, 4];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "This time use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to get the solution vector  ",
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  "  out of this augmented matrix !"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(X = TakeColumns[G, \(-1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]];\)\)}], "Input"],

Cell["Verify the solution.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[MatrixForm[A], MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does A X = B ?\>"];\)\ \), "\n", 
    \(\(Print[MatrixForm[A], MatrixForm[X], "\< = \>", 
        MatrixForm[B], "\< ?\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A . X], "\< = \>", 
        MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[A . X\  \[Equal] \ B\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can compare our answer with the answer obtained by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  StyleBox["RowReduce",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  procedure.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<M = \>", MatrixForm[M]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[RowReduce[M]]];\)\)}], "Input"],

Cell[TextData[{
  "This agrees with our answer that was obtained with our subroutine ",
  StyleBox["GaussJordan[M,4]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can compute the solution X with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"",
  StyleBox["LinearSolve",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "\" procedure."
}], "Text"],

Cell[BoxData[{
    \(\(X = LinearSolve[A, B];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Use the subroutine \"GaussJordan\" to find the \
inverse of a matrix.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Inverse Matrix",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Gauss-JordanElimination.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[") ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Assume that ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  " is an ",
  Cell[BoxData[
      \(n\[Times]n\)]],
  " nonsingular matrix. Form the augmented matrix ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], "=", 
        RowBox[{"[", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold"], "|", 
            StyleBox[
              SubscriptBox["I", 
                StyleBox[\(n, n\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}], "]"}]}]]],
  " of dimension  ",
  Cell[BoxData[
      \(n\[Times]2  n\)]],
  ".  Use Gauss-Jordan elimination to reduce the matrix ",
  Cell[BoxData[
      StyleBox["M",
        FontWeight->"Bold"]]],
  " so that the identity ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox["I", 
          StyleBox[\(n, n\),
            FontWeight->"Plain"]],
        FontWeight->"Bold"]]],
  " is in the first ",
  Cell[BoxData[
      \(n\)]],
  " columns.  Then the inverse ",
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["A",
          FontWeight->"Bold"], \(-1\)]]],
  " is located in columns ",
  Cell[BoxData[
      \(n, n + 1,  ... , 2  n\)]],
  ".       "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["The Inverse Matrix",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/InverseMatrixProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Inverse Matrix",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/InverseMatrixProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Use Gauss-Jordan elimination to find the inverse of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"4", "8", "4", "0"},
                {"1", "4", "7", "2"},
                {"1", "5", "4", \(-3\)},
                {"1", "3", "0", \(-2\)}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the matrix  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  and create a 4 by 4 identity matrix and store it in the variable ",
  StyleBox[" Iden",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", " ", "=", " ", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"4", "8", "4", "0"},
                  {"1", "4", "7", "2"},
                  {"1", "5", "4", \(-3\)},
                  {"1", "3", "0", \(-2\)}
                  }], "\[NoBreak]", ")"}],
            (MatrixForm[ #]&)]}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Iden = IdentityMatrix[4];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(I\_\(4\[Times]4\)\) = \>\"", 
          MatrixForm[Iden]\ ];\), " "}]}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the letter  ",
  Cell[BoxData[
      StyleBox["I",
        FontWeight->"Bold"]]],
  "  is a reserved word which is used for the complex unit, i.e.  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["I",
          FontWeight->"Bold"], "=", \(\@\(-1\)\)}]]],
  ".  For this reason, we used the word  ",
  Cell[BoxData[
      StyleBox["Iden",
        FontWeight->"Bold"]]],
  "  for our \"identity matrix\"  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["I",
          FontWeight->"Bold"], \(4\[Times]4\)]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Form the augmented matrix",
  "  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"[", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold"], ",", 
            StyleBox[\(I\_\(4\[Times]4\)\),
              FontWeight->"Bold"]}], "]"}]}]]],
  ".  ",
  "using the following steps."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(M = AppendRows[A, Iden];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<M = \>", MatrixForm[M]\ ];\)\ \)}], "Input"],

Cell["Then perform Gauss-Jordan elimination.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(G = GaussJordan[M, 4];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to get the inverse of  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  out of  this augmented matrix, and store it in the matrix  ",
  StyleBox["B",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(B = TakeColumns[G, \(-4\)];\)\ \), "\[IndentingNewLine]", 
    \(MatrixForm[B]\ \)}], "Input"],

Cell["Verify the solution.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<Does A B = \!\(I\_\(4\[Times]4\)\) ?\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[B], "\< = \>", 
        MatrixForm[Iden], "\< ?\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A . B], "\< = \>", 
        MatrixForm[Iden]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[A . B\  \[Equal] \ Iden\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<Does B A = \!\(I\_\(4\[Times]4\)\) ?\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[B], MatrixForm[A], "\< = \>", 
        MatrixForm[Iden], "\< ?\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[B . A], "\< = \>", 
        MatrixForm[Iden]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[B . A\  \[Equal] \ Iden\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Notice.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  \nSince integers were entered as the matrix and vector elements, precise \
arithmetic with fractions was performed for all of the computations.  If you \
prefer the numerical approximations, then enter decimal entries or make the \
final answer numerical with the command:"
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<B = \>", MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<B = \>", MatrixForm[N[B]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  \nCompare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s \"Inverse\" procedure for finding the inverse of a matrix."
}], "Text"],

Cell[BoxData[{
    \(\(A1 = Inverse[A];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\^\(-1\)\) = \>\"" 
          MatrixForm[A1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<B = \>", MatrixForm[B]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Algorithm III. (Concise Gauss-Jordan Elimination).",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Construct the solution to the linear system  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  "  by using Gauss-Jordan elimination.  The print statements are for \
pedagogical purposes and are not needed.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/GaussianJordanProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/GaussianJordanProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Concise Gauss-Jordan Elimination",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    \(\(\(GaussJordan[A0_, 
        n_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[\ {A = A0, i, k, 
          p}, \ \[IndentingNewLine]For[\ p = 1, \ 
          p \[LessEqual] n, \ \(p++\), \ \[IndentingNewLine]For[\ 
            k = p + 1, \ 
            k \[LessEqual] 
              n, \ \(k++\), \ \[IndentingNewLine]\(If[\ 
                Abs[A\_\(\(\[LeftDoubleBracket]\)\(k, p\)\(\
\[RightDoubleBracket]\)\)] > 
                  Abs[A\_\(\(\[LeftDoubleBracket]\)\(p, p\)\(\
\[RightDoubleBracket]\)\)], \ \
\[IndentingNewLine]\(A\_\(\(\[LeftDoubleBracket]\)\({p, k}\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                    A\_\(\(\[LeftDoubleBracket]\)\({k, p}\)\(\
\[RightDoubleBracket]\)\);\)\ \ \ ];\)\ ]; \ \[IndentingNewLine]A\_\(\(\
\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\)\  = \ 
            A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\)\/A\_\
\(\(\[LeftDoubleBracket]\)\(p, p\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]For[\ i = 1, \ 
            i \[LessEqual] 
              n, \ \(i++\), \ \[IndentingNewLine]\(If[\ 
                i \[NotEqual] 
                  p, \ \[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                  A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)\  - \ \(A\_\(\(\[LeftDoubleBracket]\)\(i, p\)\(\[RightDoubleBracket]\)\)\) 
                      A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\
\[RightDoubleBracket]\)\)\ \ ];\)\ ];\ ]; \ \[IndentingNewLine]Return[\ 
          A\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The Gauss-Jordan elimination method is the \"heuristic\" scheme found in \
most linear algebra textbooks.  The line of code \n\t\t",
  Cell[BoxData[
      \(\(\(A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\)\  = \
\ A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\)\/A\_\(\(\
\[LeftDoubleBracket]\)\(p, p\)\(\[RightDoubleBracket]\)\);\)\(\ \)\)\)]],
  "\ndivides each entry in the pivot row by its leading coefficient ",
  Cell[BoxData[
      \(A\_\(\(\[LeftDoubleBracket]\)\(p, p\)\(\[RightDoubleBracket]\)\)\)]],
  ".  Is this step necessary?  A more computationally efficient algorithm \
will be studied which uses upper-triangularization followed by back \
substitution.  The partial pivoting strategy will also be employed, which \
reduces propagated error and instability."
}], "Text"],

Cell[TextData[{
  StyleBox["Application to Polynomial Interpolation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tConsider a polynomial of degree ",
  StyleBox["n=5",
    FontFamily->"Courier New"],
  " that passes through the six points ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox[\(x\_i\),
                  FontWeight->"Plain"], 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[\(y\_i\),
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], "   ", 
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["   ",
              FontWeight->"Bold"], "i"}], "=", "1"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "4", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "5", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "6"}]]],
  ";  \n\n\t\t",
  Cell[BoxData[
      \(p[x] = 
        c\_1\  + \ c\_2\ x\  + \ c\_3\ x\^2 + \ c\_4\ x\^3 + \ c\_5\ x\^4 + \ 
          c\_6\ x\^5\)]],
  ".\n\nFor each point  ",
  Cell[BoxData[
      \(\((x\_i, y\_i)\)\)]],
  "  is used to an equation  ",
  Cell[BoxData[
      \(p[x\_i] = y\_i\)]],
  ",  which in turn are used to write a system of six equations in six \
unknowns  ",
  Cell[BoxData[
      \({c\_i}\_\(i = 1\)\%6\)]],
  "  \n\n\t\t",
  Cell[BoxData[GridBox[{
          {\(c\_1\), \(\(+\ c\_2\) x\_1\), \(\(+\ c\_3\) 
              x\_1\%2\), \(\(+\ c\_4\) x\_1\%3\), \(\(+\ c\_5\) 
              x\_1\%4\), \(\(+\ c\_6\) x\_1\%5\), "=", \(y\_1\)},
          {\(c\_1\), \(\(+\ c\_2\) x\_2\), \(\(+\ c\_3\) 
              x\_2\%2\), \(\(+\ c\_4\) x\_2\%3\), \(\(+\ c\_5\) 
              x\_2\%4\), \(\(+\ c\_6\) x\_2\%5\), "=", \(y\_2\)},
          {\(c\_1\), \(\(+\ c\_2\) x\_3\), \(\(+\ c\_3\) 
              x\_3\%2\), \(\(+\ c\_4\) x\_3\%3\), \(\(+\ c\_5\) 
              x\_3\%4\), \(\(+\ c\_6\) x\_3\%5\), "=", \(y\_3\)},
          {\(c\_1\), \(\(+\ c\_2\) x\_4\), \(\(+\ c\_3\) 
              x\_4\%2\), \(\(+\ c\_4\) x\_4\%3\), \(\(+\ c\_5\) 
              x\_4\%4\), \(\(+\ c\_6\) x\_4\%5\), "=", \(y\_4\)},
          {\(c\_1\), \(\(+\ c\_2\) x\_5\), \(\(+\ c\_3\) 
              x\_5\%2\), \(\(+\ c\_4\) x\_5\%3\), \(\(+\ c\_5\) 
              x\_5\%4\), \(\(+\ c\_6\) x\_5\%5\), "=", \(y\_5\)},
          {\(c\_1\), \(\(+\ c\_2\) x\_6\), \(\(+\ c\_3\) 
              x\_6\%2\), \(\(+\ c\_4\) x\_6\%3\), \(\(+\ c\_5\) 
              x\_6\%4\), \(\(+\ c\_6\) x\_6\%5\), "=", \(y\_6\)}
          }]]]
}], "Text"],

Cell[TextData[{
  "The above system can be written in matrix form  ",
  StyleBox["MC",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B  \n\n\t\t",
    FontWeight->"Bold"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {
                  "1", \(x\_1\), \(x\_1\%2\), \(x\_1\%3\), \(x\_1\%4\), \
\(x\_1\%5\)},
                {
                  "1", \(x\_2\), \(x\_2\%2\), \(x\_2\%3\), \(x\_2\%4\), \
\(x\_2\%5\)},
                {
                  "1", \(x\_3\), \(x\_3\%2\), \(x\_3\%3\), \(x\_3\%4\), \
\(x\_3\%5\)},
                {
                  "1", \(x\_4\), \(x\_4\%2\), \(x\_4\%3\), \(x\_4\%4\), \
\(x\_4\%5\)},
                {
                  "1", \(x\_5\), \(x\_5\%2\), \(x\_5\%3\), \(x\_5\%4\), \
\(x\_5\%5\)},
                {
                  "1", \(x\_6\), \(x\_6\%2\), \(x\_6\%3\), \(x\_6\%4\), \
\(x\_6\%5\)}
                }], ")"}], 
          RowBox[{"(", GridBox[{
                {\(c\_1\)},
                {\(c\_2\)},
                {\(c\_3\)},
                {\(c\_4\)},
                {\(c\_5\)},
                {\(c\_6\)}
                }], ")"}]}], "=", 
        RowBox[{"(", GridBox[{
              {\(y\_1\)},
              {\(y\_2\)},
              {\(y\_3\)},
              {\(y\_4\)},
              {\(y\_5\)},
              {\(y\_6\)}
              }], ")"}], "   "}]]],
  "\n\nSolve this linear system for the coefficients  ",
  Cell[BoxData[
      \({c\_i}\_\(i = 1\)\%6\)]],
  "   and then construct the interpolating polynomial \n\n\t\t",
  Cell[BoxData[
      \(p[x] = 
        c\_1\  + \ c\_2\ x\  + \ c\_3\ x\^2 + \ c\_4\ x\^3 + \ c\_5\ x\^4 + \ 
          c\_6\ x\^5\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the polynomial  ",
  StyleBox["p[x]",
    FontFamily->"Courier New"],
  "  that passes through the six points  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{"2", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "3"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{"3", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "0"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{"4", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{"5", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "4"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{"(", 
          RowBox[{"6", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2"}], ")"}]}]]],
  "  using the following steps. \n",
  StyleBox["(a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Write down the linear system ",
  StyleBox["MC",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " to be solved. \n",
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system for the coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  " using our Gauss-Jordan subroutine. \n",
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Construct the polynomial  ",
  StyleBox["p[x]",
    FontFamily->"Courier New"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Write down the linear system ",
  StyleBox["MC",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " to be solved."
}], "Text"],

Cell[BoxData[{\(XY = {{1, 1}, {2, 3}, {3, 0}, {4, 1}, {5, 4}, \ {6, 
            2}};\), "\[IndentingNewLine]", 
    RowBox[{\(X = \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Y = \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\);\), 
      " "}], "\[IndentingNewLine]", \(Clear[
        c];\), "\[IndentingNewLine]", \(vars = 
        Table["\<c\>"\_i, {i, 1, 6}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {
                "1", \(X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\), \(X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\^2\), \(X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\^3\), \(X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\^4\), \(X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\^5\)},
              {
                "1", \(X\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\), \(X\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\^2\), \(X\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\^3\), \(X\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\^4\), \(X\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\^5\)},
              {
                "1", \(X\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)\), \(X\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)\^2\), \(X\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)\^3\), \(X\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)\^4\), \(X\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)\^5\)},
              {
                "1", \(X\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)\), \(X\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)\^2\), \(X\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)\^3\), \(X\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)\^4\), \(X\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)\^5\)},
              {
                "1", \(X\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)\), \(X\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)\^2\), \(X\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)\^3\), \(X\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)\^4\), \(X\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)\^5\)},
              {
                "1", \(X\_\(\(\[LeftDoubleBracket]\)\(6\)\(\
\[RightDoubleBracket]\)\)\), \(X\_\(\(\[LeftDoubleBracket]\)\(6\)\(\
\[RightDoubleBracket]\)\)\^2\), \(X\_\(\(\[LeftDoubleBracket]\)\(6\)\(\
\[RightDoubleBracket]\)\)\^3\), \(X\_\(\(\[LeftDoubleBracket]\)\(6\)\(\
\[RightDoubleBracket]\)\)\^4\), \(X\_\(\(\[LeftDoubleBracket]\)\(6\)\(\
\[RightDoubleBracket]\)\)\^5\)}
              }], ")"}]}], ";", " ", 
      RowBox[{"B", " ", "=", 
        RowBox[{"(", GridBox[{
              {\(Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
\)},
              {\(Y\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\
\)},
              {\(Y\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)\
\)},
              {\(Y\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)\
\)},
              {\(Y\_\(\(\[LeftDoubleBracket]\)\(5\)\(\[RightDoubleBracket]\)\)\
\)},
              {\(Y\_\(\(\[LeftDoubleBracket]\)\(6\)\(\[RightDoubleBracket]\)\)\
\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<A = \>", MatrixForm[A], "\<,  B = \>", 
          MatrixForm[B]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve the system\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]\ ];\)}], "Input"],

Cell[TextData[{
  "Form the augmented matrix  ",
  StyleBox["M = [A,B]",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(M = AppendRows[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<B = \>", MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Use the augmented matrix\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<M = \>", MatrixForm[M]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system for the coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  " using our Gauss-Jordan subroutine."
}], "Text"],

Cell[BoxData[
    \(\(G = GaussJordan[M, 6];\)\)], "Input"],

Cell[TextData[{
  "This time use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to get the solution vector  ",
  Cell[BoxData[
      StyleBox["c",
        FontWeight->"Bold"]]],
  "  out of this augmented matrix !"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(c = TakeColumns[G, \(-1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(c = Flatten[c];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<C = \>", MatrixForm[c]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Or, we could use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  StyleBox["LinearSolve[M,B]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  procedure."
}], "Text"],

Cell[BoxData[{
    \(\(c = LinearSolve[M, B];\)\ \), "\[IndentingNewLine]", 
    \(\(c = Flatten[c];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<C = \>", MatrixForm[c]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Construct the polynomial  ",
  StyleBox["p[x]",
    FontFamily->"Courier New"],
  ".  The coefficients are stored in the array  ",
  StyleBox["c",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and the elements are ",
  Cell[BoxData[
      \(c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(p[
          x_] = \ \[Sum]\+\(i = 1\)\%6\( 
                c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
\) x\^\(i - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\)}], "Input"],

Cell[TextData[{
  "Of course we could do all this work in two lines by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  StyleBox["InterpolatingPolynomial[XY,x]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  procedure."
}], "Text"],

Cell[BoxData[{
    \(\(XY = {{1, 1}, {2, 3}, {3, 0}, {4, 1}, {5, 4}, \ {6, 
            2}};\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Expand[InterpolatingPolynomial[XY, x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nWe can graph the polynomial, this is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[p[t], {t, 0, 6.5}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, dots, PlotRange \[Rule] {{0, 6.5}, {\(-2\), 4.5}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The interpolation polynomial\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<p[t] = \>", p[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Points = \>", XY];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Gauss-Jordan Elimination",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/gj.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Gauss-Jordan Elimination",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/gj.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/GaussianJordanBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Gauss-Jordan Elimination and Pivoting",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/GaussianJordanBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
SpellingDictionaries->{"CorrectWords"->{
  "Mathews", "Bartlett", "Sudbury", "Tele.", "mkt", "jbpub", "com", "mathews",
     "edu", "westmont", "Raphson", "solset", "Steffensen's", "Steffensen", 
    "Aitken's", "Aitken", "eqn"}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 177, 4, 35, "Text"],
Cell[1956, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3435, 111, 3380, 120, 258, "Text"],
Cell[6818, 233, 1904, 58, 169, "Text"],
Cell[8725, 293, 527, 18, 52, "Text"],
Cell[9255, 313, 673, 22, 33, "Text"],
Cell[9931, 337, 1602, 49, 204, "Text"],
Cell[11536, 388, 673, 22, 33, "Text"],
Cell[12212, 412, 865, 33, 52, "Text"],
Cell[13080, 447, 1947, 71, 52, "Text"],
Cell[15030, 520, 673, 22, 33, "Text"],
Cell[15706, 544, 722, 22, 52, "Text"],
Cell[16431, 568, 652, 20, 33, "Text"],
Cell[17086, 590, 348, 10, 33, "Text"],
Cell[17437, 602, 1106, 20, 214, "Input"],
Cell[18546, 624, 1022, 33, 57, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19593, 661, 101, 2, 33, "Text"],
Cell[19697, 665, 327, 14, 33, "Text",
  Evaluatable->False],
Cell[20027, 681, 862, 22, 173, "Input"],
Cell[20892, 705, 404, 15, 33, "Text",
  Evaluatable->False],
Cell[21299, 722, 279, 8, 57, "Input"],
Cell[21581, 732, 102, 2, 33, "Text",
  Evaluatable->False],
Cell[21686, 736, 66, 1, 30, "Input"],
Cell[21755, 739, 84, 2, 33, "Text",
  Evaluatable->False],
Cell[21842, 743, 799, 19, 180, "Input"],
Cell[22644, 764, 489, 18, 72, "Text",
  Evaluatable->False],
Cell[23136, 784, 227, 4, 70, "Input"],
Cell[23366, 790, 243, 8, 34, "Text",
  Evaluatable->False]
}, Closed]],
Cell[23624, 801, 1293, 39, 73, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[24942, 844, 101, 2, 33, "Text"],
Cell[25046, 848, 787, 12, 130, "Input"],
Cell[25836, 862, 206, 7, 33, "Text",
  Evaluatable->False],
Cell[26045, 871, 436, 11, 80, "Input"],
Cell[26484, 884, 200, 7, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[26699, 894, 184, 4, 30, "Text"],
Cell[26886, 900, 105, 3, 33, "Text"],
Cell[26994, 905, 518, 10, 70, "Input"],
Cell[27515, 917, 419, 9, 52, "Text"],
Cell[27937, 928, 481, 13, 52, "Text"],
Cell[28421, 943, 652, 20, 33, "Text"],
Cell[29076, 965, 349, 10, 33, "Text"],
Cell[29428, 977, 1773, 33, 295, "Input"],
Cell[31204, 1012, 1363, 46, 76, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32592, 1062, 101, 2, 33, "Text"],
Cell[32696, 1066, 602, 9, 150, "Input"],
Cell[33301, 1077, 119, 2, 33, "Text",
  Evaluatable->False],
Cell[33423, 1081, 67, 1, 30, "Input"],
Cell[33493, 1084, 84, 2, 33, "Text",
  Evaluatable->False],
Cell[33580, 1088, 685, 17, 160, "Input"],
Cell[34268, 1107, 489, 18, 72, "Text",
  Evaluatable->False],
Cell[34760, 1127, 227, 4, 70, "Input"],
Cell[34990, 1133, 243, 8, 34, "Text",
  Evaluatable->False],
Cell[35236, 1143, 313, 12, 34, "Text"],
Cell[35552, 1157, 350, 6, 90, "Input"]
}, Closed]],
Cell[35917, 1166, 1518, 46, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[37460, 1216, 101, 2, 33, "Text"],
Cell[37564, 1220, 1239, 31, 251, "Input"],
Cell[38806, 1253, 791, 22, 52, "Text",
  Evaluatable->False],
Cell[39600, 1277, 452, 7, 130, "Input"],
Cell[40055, 1286, 233, 8, 33, "Text",
  Evaluatable->False],
Cell[40291, 1296, 69, 1, 30, "Input"],
Cell[40363, 1299, 286, 11, 33, "Text",
  Evaluatable->False],
Cell[40652, 1312, 177, 3, 50, "Input"],
Cell[40832, 1317, 84, 2, 33, "Text",
  Evaluatable->False],
Cell[40919, 1321, 568, 10, 130, "Input"],
Cell[41490, 1333, 489, 18, 72, "Text",
  Evaluatable->False],
Cell[41982, 1353, 227, 4, 70, "Input"],
Cell[42212, 1359, 243, 8, 34, "Text",
  Evaluatable->False],
Cell[42458, 1369, 313, 12, 34, "Text"],
Cell[42774, 1383, 350, 6, 90, "Input"]
}, Closed]],
Cell[43139, 1392, 207, 5, 30, "Text",
  Evaluatable->False],
Cell[43349, 1399, 1644, 61, 52, "Text"],
Cell[44996, 1462, 626, 21, 33, "Text"],
Cell[45625, 1485, 631, 20, 73, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[46281, 1509, 101, 2, 33, "Text"],
Cell[46385, 1513, 264, 10, 33, "Text",
  Evaluatable->False],
Cell[46652, 1525, 613, 14, 118, "Input"],
Cell[47268, 1541, 700, 26, 33, "Text"],
Cell[47971, 1569, 454, 17, 33, "Text",
  Evaluatable->False],
Cell[48428, 1588, 140, 2, 50, "Input"],
Cell[48571, 1592, 102, 2, 33, "Text",
  Evaluatable->False],
Cell[48676, 1596, 69, 1, 30, "Input"],
Cell[48748, 1599, 322, 13, 33, "Text",
  Evaluatable->False],
Cell[49073, 1614, 117, 2, 50, "Input"],
Cell[49193, 1618, 84, 2, 33, "Text",
  Evaluatable->False],
Cell[49280, 1622, 403, 7, 90, "Input"],
Cell[49686, 1631, 403, 7, 90, "Input"],
Cell[50092, 1640, 387, 8, 71, "Text"],
Cell[50482, 1650, 154, 2, 50, "Input"],
Cell[50639, 1654, 248, 8, 52, "Text"],
Cell[50890, 1664, 238, 4, 71, "Input"]
}, Closed]],
Cell[51143, 1671, 492, 13, 49, "Text"],
Cell[51638, 1686, 652, 20, 33, "Text"],
Cell[52293, 1708, 348, 10, 33, "Text"],
Cell[52644, 1720, 1564, 29, 255, "Input"],
Cell[54211, 1751, 919, 17, 99, "Text"],
Cell[55133, 1770, 4390, 116, 281, "Text"],
Cell[59526, 1888, 1701, 55, 243, "Text"],
Cell[61230, 1945, 4493, 138, 90, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[65748, 2087, 101, 2, 33, "Text"],
Cell[65852, 2091, 252, 11, 33, "Text"],
Cell[66107, 2104, 3913, 74, 323, "Input"],
Cell[70023, 2180, 124, 5, 33, "Text"],
Cell[70150, 2187, 452, 7, 130, "Input"],
Cell[70605, 2196, 271, 9, 33, "Text"],
Cell[70879, 2207, 59, 1, 30, "Input"],
Cell[70941, 2210, 286, 11, 33, "Text",
  Evaluatable->False],
Cell[71230, 2223, 196, 3, 70, "Input"],
Cell[71429, 2228, 225, 9, 34, "Text"],
Cell[71657, 2239, 191, 3, 70, "Input"],
Cell[71851, 2244, 439, 15, 34, "Text"],
Cell[72293, 2261, 246, 5, 73, "Input"],
Cell[72542, 2268, 279, 9, 34, "Text"],
Cell[72824, 2279, 267, 5, 70, "Input"],
Cell[73094, 2286, 173, 5, 71, "Text"],
Cell[73270, 2293, 746, 14, 150, "Input"]
}, Closed]],
Cell[74031, 2310, 711, 20, 30, "Text"],
Cell[74745, 2332, 158, 3, 35, "Text"],
Cell[74906, 2337, 609, 17, 33, "Text"],
Cell[75518, 2356, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

