(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    116306,       3566]*)
(*NotebookOutlinePosition[    117377,       3601]*)
(*  CellTagsIndexPosition[    117333,       3597]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for PA = LU Factorization with Pivoting",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["LU-Factorization",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LUDecomposition.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The nonsingular matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " has an LU-factorization if it can be expressed as the product of a \
lower-triangular matrix ",
  StyleBox["L",
    FontWeight->"Bold"],
  " and an upper triangular matrix ",
  StyleBox["U",
    FontWeight->"Bold"],
  ":  \n\n\t\t  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        StyleBox["LU",
          FontWeight->"Bold"]}]]],
  ".  \n\nWhen this is possible we say that ",
  StyleBox["A",
    FontWeight->"Bold"],
  " has an ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "-decomposition.  It turns out that this factorization (when it exists) is \
not unique.  If ",
  StyleBox["L",
    FontWeight->"Bold"],
  " has 1's on it's diagonal, then it is called a Doolittle factorization.  \
If ",
  StyleBox["U",
    FontWeight->"Bold"],
  " has 1's on its diagonal, then it is called a Crout factorization.  When  \
",
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], "=", 
        SuperscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "T"]}]]],
  ", it is called a ",
  ButtonBox["Cholesky decomposition",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CholeskyDecomposition.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  In this module we will develop an algorithm that produces a Doolittle \
factorization. "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["LU Factorization with ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["NO",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" pivoting",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If row interchanges are ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 0]],
  " needed to solve the linear system ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ", then ",
  StyleBox["A",
    FontWeight->"Bold"],
  " has the ",
  StyleBox["LU",
    FontWeight->"Bold"],
  " factorization (illustrated with 4\[Times]4 matrices).  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {\(a\_\(1, 1\)\), \(a\_\(1, 2\)\), \(a\_\(1, 3\)\), \(a\_\(1, 
                      4\)\)},
                {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\), \(a\_\(2, 3\)\), \(a\_\(2, 
                      4\)\)},
                {\(a\_\(3, 1\)\), \(a\_\(3, 2\)\), \(a\_\(3, 3\)\), \(a\_\(3, 
                      4\)\)},
                {\(a\_\(4, 1\)\), \(a\_\(4, 2\)\), \(a\_\(4, 3\)\), \(a\_\(4, 
                      4\)\)}
                }], ")"}],
          (MatrixForm[ #]&)], " "}]]],
  "= ",
  Cell[BoxData[
      TagBox[
        RowBox[{"(", GridBox[{
              {"1", "0", "0", "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(2, 1\)], "1", "0", "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(3, 1\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(3, 2\)], "1", "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(4, 1\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(4, 2\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(4, 3\)], "1"}
              }], ")"}],
        (MatrixForm[ #]&)]]],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", GridBox[{
              {\(u\_\(1, 1\)\), \(u\_\(1, 2\)\), \(u\_\(1, 3\)\), \(u\_\(1, 
                    4\)\)},
              {"0", \(u\_\(2, 2\)\), \(u\_\(2, 3\)\), \(u\_\(2, 4\)\)},
              {"0", "0", \(u\_\(3, 3\)\), \(u\_\(3, 4\)\)},
              {"0", "0", "0", \(u\_\(4, 4\)\)}
              }], ")"}],
        (MatrixForm[ #]&)]]],
  ".\n\t\t\n",
  StyleBox["Remark 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  This is not a linear system. \n",
  StyleBox["Remark 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The easy solution uses row vectors and is a modification of limited \
Gauss Jordan elimination. \n",
  StyleBox["Remark 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  A sufficient condition for the factorization to exist is that all \
principal minors of ",
  StyleBox["A",
    FontWeight->"Bold"],
  " are nonsingular. "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/LUFactorProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LUFactorProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Limited Gauss-Jordan Elimination",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    \(\(\(GaussJordan[A0_, 
        n_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[\ {A = A0, i, 
          p}, \ \[IndentingNewLine]Print[\ 
          MatrixForm[A]\ ]; \ \[IndentingNewLine]For[\ p = 1, \ 
          p \[LessEqual] 
            n, \ \(p++\), \ \
\[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\
\)\  = \ A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\)\/A\_\(\
\(\[LeftDoubleBracket]\)\(p, p\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]For[\ \ i = 1, \ 
            i \[LessEqual] 
              n, \ \(i++\), \ \[IndentingNewLine]\(If[\ \ i \[NotEqual] 
                  p, \ \[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                  A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\)\  - \ \(A\_\(\(\[LeftDoubleBracket]\)\(i, p\)\(\[RightDoubleBracket]\)\)\) 
                      A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\
\[RightDoubleBracket]\)\)\ \ ];\)\ ]; \ \[IndentingNewLine]Print[\ 
            MatrixForm[A]\ ];\ \ ];\ \ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/LUFactorProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LUFactorProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (LandU).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(LandU[A0_, 
        n_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[\ {A = A0, i, 
          p}, \ \[IndentingNewLine]U = A0; \ \[IndentingNewLine]L = 
          IdentityMatrix[n]; \ \[IndentingNewLine]Print[MatrixForm[L], 
          MatrixForm[U], "\< = \>", 
          MatrixForm[A0]]; \ \[IndentingNewLine]For[\ p = 1, \ 
          p \[LessEqual] 
            n - 1, \ \(p++\), \ \[IndentingNewLine]\(For[\ i = p + 1, \ 
              i \[LessEqual] n, \ \(i++\), \ \[IndentingNewLine]m = 
                A\_\(\(\[LeftDoubleBracket]\)\(i, \
p\)\(\[RightDoubleBracket]\)\)\/A\_\(\(\[LeftDoubleBracket]\)\(p, p\)\(\
\[RightDoubleBracket]\)\); \
\[IndentingNewLine]L\_\(\(\[LeftDoubleBracket]\)\(i, p\)\(\
\[RightDoubleBracket]\)\) = 
                m; \ \[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                A\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
\  - \ m\ A\_\(\(\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\); \
\[IndentingNewLine]U\  = \ A; \ \[IndentingNewLine]Print[MatrixForm[L], 
                MatrixForm[U], "\< = \>", 
                MatrixForm[A0]];\ \ ];\)\ \ ];\ \ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Given  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"4", "2", "3"},
              {\(-3\), "1", "4"},
              {"2", "4", "5"}
              }], ")"}]}]]],
  ".  Find matrices ",
  StyleBox["L",
    FontWeight->"Bold"],
  " and ",
  StyleBox["U",
    FontWeight->"Bold"],
  " so that ",
  StyleBox["LU",
    FontWeight->"Bold"],
  " = ",
  StyleBox["A",
    FontWeight->"Bold"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"A", " ", "=", " ", 
          RowBox[{"(", GridBox[{
                {"4", "2", "3"},
                {\(-3\), "1", "4"},
                {"2", "4", "5"}
                }], ")"}]}], ";"}], " "}]], "Input"],

Cell[TextData[{
  "Use the ",
  StyleBox["LandU",
    FontWeight->"Bold"],
  " subroutine and construct matrices ",
  StyleBox["L",
    FontWeight->"Bold"],
  " and ",
  StyleBox["U",
    FontWeight->"Bold"],
  " so that ",
  StyleBox["LU",
    FontWeight->"Bold"],
  " = ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(LandU[A, 3];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Does  ",
  StyleBox["L.U",
    FontWeight->"Bold"],
  " = ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ?  "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<L = \>", MatrixForm[L]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<U = \>", MatrixForm[U]];\)\), "\[IndentingNewLine]", 
    \(Print["\<Does LU = A ?\>"]\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[L], MatrixForm[U], "\< = \>", 
        MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print[L . U \[Equal] A];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Given  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"4", "2", \(-1\), "3"},
              {"3", \(-4\), "2", "5"},
              {\(-2\), "6", \(-5\), \(-2\)},
              {"5", "1", "6", \(-3\)}
              }], ")"}]}]]],
  ".  Find matrices ",
  StyleBox["L",
    FontWeight->"Bold"],
  " and ",
  StyleBox["U",
    FontWeight->"Bold"],
  " so that ",
  StyleBox["LU",
    FontWeight->"Bold"],
  " = ",
  StyleBox["A",
    FontWeight->"Bold"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"A", " ", "=", " ", 
          RowBox[{"(", GridBox[{
                {"4", "2", \(-1\), "3"},
                {"3", \(-4\), "2", "5"},
                {\(-2\), "6", \(-5\), \(-2\)},
                {"5", "1", "6", \(-3\)}
                }], ")"}]}], ";"}], " "}]], "Input"],

Cell[TextData[{
  "Use the ",
  StyleBox["LandU",
    FontWeight->"Bold"],
  " subroutine and construct matrices ",
  StyleBox["L",
    FontWeight->"Bold"],
  " and ",
  StyleBox["U",
    FontWeight->"Bold"],
  " so that ",
  StyleBox["LU",
    FontWeight->"Bold"],
  " = ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(LandU[A, 4];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Does  ",
  StyleBox["L.U",
    FontWeight->"Bold"],
  " = ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ?  "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<L = \>", MatrixForm[L]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<U = \>", MatrixForm[U]];\)\), "\[IndentingNewLine]", 
    \(Print["\<Does LU = A ?\>"]\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[L], MatrixForm[U], "\< = \>", 
        MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print[L . U \[Equal] A];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Given  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "6"},
              {"4", "8", \(-1\)},
              {\(-2\), "3", "5"}
              }], ")"}]}]]],
  ".  Can ",
  StyleBox["A",
    FontWeight->"Bold"],
  " be factored  ",
  StyleBox["A",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "?    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"A", " ", "=", " ", 
          RowBox[{"(", GridBox[{
                {"1", "2", "6"},
                {"4", "8", \(-1\)},
                {\(-2\), "3", "5"}
                }], ")"}]}], ";"}], " "}]], "Input"],

Cell[TextData[{
  "Use the ",
  StyleBox["LandU",
    FontWeight->"Bold"],
  " subroutine and see what happens."
}], "Text"],

Cell[BoxData[
    \(\(\(LandU[A, 3];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We get a division by zero error, hence there is ",
  StyleBox["no",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "-decomposition of ",
  StyleBox["A",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is nonsingular.  "
}], "Text"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  This shows that nonsingular is ",
  StyleBox["not",
    FontColor->RGBColor[1, 0, 0]],
  " sufficient to guarantee an  ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "-decomposition. \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can interchange rows and the new matrix ",
  StyleBox["B",
    FontWeight->"Bold"],
  " will have an   ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "-decomposition. "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", " ", "=", " ", 
          RowBox[{"(", GridBox[{
                {"1", "2", "6"},
                {"4", "8", \(-1\)},
                {\(-2\), "3", "5"}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(B = 
        A\_\(\(\[LeftDoubleBracket]\)\({1, 3, \
2}\)\(\[RightDoubleBracket]\)\);\), "\[IndentingNewLine]", \(A = 
        B;\), "\[IndentingNewLine]", \(Print["\<                  B = \>", 
        MatrixForm[B]];\), "\[IndentingNewLine]", 
    RowBox[{\(LandU[A, 3];\), 
      " "}], "\[IndentingNewLine]", \(Print[MatrixForm[L], 
        MatrixForm[U], "\< = \>", MatrixForm[B]];\), "\[IndentingNewLine]", 
    RowBox[{\(Print[L . U \[Equal] B];\), " "}]}], "Input"],

Cell[BoxData[{
    \(\(Print["\<B = \>", MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<L = \>", MatrixForm[L]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<U = \>", MatrixForm[U]];\)\), "\[IndentingNewLine]", 
    \(Print["\<Does LU = B ?\>"]\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[L], MatrixForm[U], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[L . U \[Equal] B];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem (A = LU;  Factorization with ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["NO",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" Pivoting).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" has a ",
    FontFamily->"Times New Roman"],
  "Doolittle, Crout or Cholesky factorization",
  StyleBox[".  The solution ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" to the linear system",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ", ",
  StyleBox[" is found in three steps:  \n\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["1.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Construct the matrices  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], "  ", 
        StyleBox["U",
          FontWeight->"Bold"]}]]],
  ", if possible.  ",
  StyleBox["\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["2.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["LY",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox["  for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["Y",
        FontWeight->"Bold"]]],
  StyleBox["  using forward substitution.\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["3.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  StyleBox["  using back substitution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/LUFactorProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LUFactorProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThe above theorem assumes that there are no row interchanges.  We have \
seen in Example 3 an example of a nonsingular matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " could not be directly factored as ",
  StyleBox["A",
    FontWeight->"Bold"],
  " =",
  StyleBox[" LU",
    FontWeight->"Bold"],
  ".  If row interchanges are permitted then a factorization of a \"permuted \
matrix\" will be obtained.  A permutation of the first ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " positive integers  ",
  Cell[BoxData[
      RowBox[{"1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ".  is an arrangement  ",
  Cell[BoxData[
      RowBox[{\(k\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(k\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(k\_n\)}]]],
  "  of these integers in a definite order.  For example,  ",
  Cell[BoxData[
      RowBox[{"1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "4", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "5"}]]],
  "  is a permutation of the five integers  ",
  Cell[BoxData[
      RowBox[{"1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "4", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "5"}]]],
  ".  The standard base vectors  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["E",
            FontWeight->"Bold"], "i"], " ", "=", " ", 
        RowBox[{"[", 
          RowBox[{"0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            SubscriptBox[
              StyleBox["1",
                FontFamily->"Times New Roman"], "i"], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "0"}], "]"}]}]]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(i = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  "  are used in the next definition.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Permutation Matrix",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/PermutationMatrix.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  An n\[Times]n permutation matrix ",
    FontFamily->"Times New Roman"],
  StyleBox["P",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" is a matrix with precisely one entry whose value is \"1\" in \
each column and row, and all of whose other entries are \"0.\"  The rows of  \
",
    FontFamily->"Times New Roman"],
  StyleBox["P",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  are a permutation of the rows of the identity matrix and  ",
    FontFamily->"Times New Roman"],
  StyleBox["P",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  can be written as  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["P",
          FontWeight->"Bold"], " ", "=", 
        SuperscriptBox[
          RowBox[{"[", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["E",
                  FontWeight->"Bold"], \(k\_1\), "T"], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              SubsuperscriptBox[
                StyleBox["E",
                  FontWeight->"Bold"], \(k\_2\), "T"], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "...", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              SubsuperscriptBox[
                StyleBox["E",
                  FontWeight->"Bold"], \(k\_n\), "T"]}], "]"}], "T"]}]]],
  ".\n\nThe elements of  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["P",
          FontWeight->"Bold"], " ", "=", \([p\_\(i, j\)]\)}]]],
  "  have the form  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\(p\_\(i, j\)\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {"1", 
                RowBox[{"  ", 
                  RowBox[{
                    RowBox[{
                      StyleBox["for",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "  ", "j"}], " ", 
                    "=", \(k\_i\), " "}]}]},
              {"0", 
                StyleBox["otherwise",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}
              }], 
          StyleBox["}",
            FontColor->GrayLevel[1]]}]}]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Suppose that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["P",
          FontWeight->"Bold"], " ", "=", 
        SuperscriptBox[
          RowBox[{"[", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["E",
                  FontWeight->"Bold"], \(k\_1\), "T"], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              SubsuperscriptBox[
                StyleBox["E",
                  FontWeight->"Bold"], \(k\_2\), "T"], 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "...", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              SubsuperscriptBox[
                StyleBox["E",
                  FontWeight->"Bold"], \(k\_n\), "T"]}], "]"}], "T"]}]]],
  StyleBox["  is a permutation matrix.  The product  ",
    FontFamily->"Times New Roman"],
  StyleBox["PA",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  is a new matrix whose rows consists of the rows of  ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  rearranged in the new order  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(row\_\(k\_1\)\), 
          StyleBox["A",
            FontWeight->"Bold"]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(row\_\(k\_2\)\), 
          StyleBox["A",
            FontWeight->"Bold"]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(row\_\(k\_n\)\), 
          StyleBox["A",
            FontWeight->"Bold"]}]}]]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  "For example, the permutation matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["P",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0", "1", "0", "0"},
              {"1", "0", "0", "0"},
              {"0", "0", "0", "1"},
              {"0", "0", "1", "0"}
              }], ")"}]}]]],
  "  will interchange rows 1 and 2 and also interchange rows 3 and 4.  "
}], "Text"],

Cell[BoxData[{\(Clear[a];\), "\[IndentingNewLine]", 
    RowBox[{"MatrixForm", "[", 
      RowBox[{
        RowBox[{"(", GridBox[{
              {"0", "1", "0", "0"},
              {"1", "0", "0", "0"},
              {"0", "0", "0", "1"},
              {"0", "0", "1", "0"}
              }], ")"}], ".", 
        TagBox[
          RowBox[{"(", GridBox[{
                {\(a\_\(1, 1\)\), \(a\_\(1, 2\)\), \(a\_\(1, 3\)\), \(a\_\(1, 
                      4\)\)},
                {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\), \(a\_\(2, 3\)\), \(a\_\(2, 
                      4\)\)},
                {\(a\_\(3, 1\)\), \(a\_\(3, 2\)\), \(a\_\(3, 3\)\), \(a\_\(3, 
                      4\)\)},
                {\(a\_\(4, 1\)\), \(a\_\(4, 2\)\), \(a\_\(4, 3\)\), \(a\_\(4, 
                      4\)\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], " ", "]"}]}], "Input"],

Cell[TextData[{
  StyleBox["Theorem.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  If  ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  is a nonsingular matrix, then there exists a permutation matrix \
 ",
    FontFamily->"Times New Roman"],
  StyleBox["P",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  so that  ",
    FontFamily->"Times New Roman"],
  StyleBox["PA",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  has an LU-factorization \n\n\t\t",
    FontFamily->"Times New Roman"],
  StyleBox["PA",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"Times New Roman"],
  StyleBox["LU",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (PA = LU;  Factorization with Pivoting).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Given that ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" is nonsingular.  The solution ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" to the linear system",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ", ",
  StyleBox["is found in four steps:  \n\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["1.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Construct the matrices  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], ",", 
        RowBox[{
          StyleBox["U",
            FontWeight->"Bold"], "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", 
          StyleBox["P",
            FontWeight->"Bold"]}]}]]],
  StyleBox[".  \n\t",
    FontFamily->"Times New Roman"],
  StyleBox["2.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Compute the column vector   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["PB",
        FontWeight->"Bold"]]],
  StyleBox[".\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["3.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["LY",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["PB",
          FontWeight->"Bold"]}]]],
  StyleBox["  for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["Y",
        FontWeight->"Bold"]]],
  StyleBox["  using forward substitution.\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["4.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  StyleBox["  using back substitution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/LUFactorProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LUFactorProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/LUFactorProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LUFactorProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (LUfactor).\n",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The matrix  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  is a global variable and elements are changed when ",
  StyleBox["the  ",
    FontFamily->"Times New Roman"],
  StyleBox["LUfactor",
    FontWeight->"Bold"],
  StyleBox["  subroutine ",
    FontFamily->"Times New Roman"],
  "is executed.  Hence, it is important to save a copy of  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  in the variable  ",
  StyleBox["A0",
    FontWeight->"Bold"],
  ".\n",
  StyleBox["Use one of the following two versions of the  ",
    FontFamily->"Times New Roman"],
  StyleBox["LUfactor",
    FontWeight->"Bold"],
  StyleBox["  subroutine and the  ",
    FontFamily->"Times New Roman"],
  StyleBox["SolveLU",
    FontWeight->"Bold"],
  StyleBox["  subroutine.  The first version of  ",
    FontFamily->"Times New Roman"],
  StyleBox["LUfactor",
    FontWeight->"Bold"],
  StyleBox["  uses ",
    FontFamily->"Times New Roman"],
  "parallel programming and \"row operations\" instead of loops."
}], "Text"],

Cell[BoxData[
    \(\(\(LUfactor[
        n_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[\ {i, j, k, p, 
          Z}, \[IndentingNewLine]r\  = \ 
          Table[j, {j, n}]; \[IndentingNewLine]For[\ p = 1, \ 
          p \[LessEqual] n - 1, \ \(p++\), \[IndentingNewLine]For[\ 
            j = p + 1, \ 
            j \[LessEqual] 
              n, \ \(j++\), \[IndentingNewLine]\(If[\ 
                Abs[A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\
\)\(j\)\(\[RightDoubleBracket]\)\), p\)\(\[RightDoubleBracket]\)\)] > 
                  Abs[A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\
\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\), p\)\(\
\[RightDoubleBracket]\)\)], \
\[IndentingNewLine]r\_\(\(\[LeftDoubleBracket]\)\({j, p}\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                  r\_\(\(\[LeftDoubleBracket]\)\({p, j}\)\(\
\[RightDoubleBracket]\)\)\ \ ];\)\ ]; \[IndentingNewLine]For[\ k = p + 1, \ 
            k \[LessEqual] 
              n, \ \(k++\), \
\[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\
\)\(k\)\(\[RightDoubleBracket]\)\), p\)\(\[RightDoubleBracket]\)\)\  = \ 
              A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(k\
\)\(\[RightDoubleBracket]\)\), p\)\(\[RightDoubleBracket]\)\)\/A\_\(\(\
\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(p\)\(\
\[RightDoubleBracket]\)\), p\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(\ \)\(r\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\), Range[p + 1, n]\)\(\ \
\)\(\[RightDoubleBracket]\)\)\  = \ 
              A\_\(\(\[LeftDoubleBracket]\)\(\ \
\)\(r\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\), Range[p + \
1, n]\)\(\ \)\(\[RightDoubleBracket]\)\)\  - \ 
                A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(\
k\)\(\[RightDoubleBracket]\)\), p\)\(\[RightDoubleBracket]\)\)\ A\_\(\(\
\[LeftDoubleBracket]\)\(\ \)\(r\_\(\(\[LeftDoubleBracket]\)\(p\)\(\
\[RightDoubleBracket]\)\), Range[p + 1, n]\)\(\ \
\)\(\[RightDoubleBracket]\)\);\ \ ];\ ]; \ \[IndentingNewLine]L\  = \ \(P\  = \
\ IdentityMatrix[n]\); \[IndentingNewLine]Z\  = \ 
          Table[0, {j, n}]; \[IndentingNewLine]P\  = \ 
          P\_\(\(\[LeftDoubleBracket]\)\(r\)\(\[RightDoubleBracket]\)\); \
\[IndentingNewLine]U\  = \ 
          A\_\(\(\[LeftDoubleBracket]\)\(r\)\(\[RightDoubleBracket]\)\); \
\[IndentingNewLine]For[\ i = 1, \ 
          i \[LessEqual] 
            n, \ \(i++\), \[IndentingNewLine]L\_\(\(\[LeftDoubleBracket]\)\(\ \
\)\(i, Range[1, i - 1]\)\(\ \)\(\[RightDoubleBracket]\)\)\  = \ 
            A\_\(\(\[LeftDoubleBracket]\)\(\ \
\)\(r\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), Range[1, i \
- 1]\)\(\ \)\(\[RightDoubleBracket]\)\); \ \[IndentingNewLine]U\_\(\(\
\[LeftDoubleBracket]\)\(\ \)\(i, Range[1, i - 1]\)\(\ \)\(\
\[RightDoubleBracket]\)\)\  = \ 
            Z\_\(\(\[LeftDoubleBracket]\)\(\ \)\(Range[1, i - 1]\)\(\ \)\(\
\[RightDoubleBracket]\)\);\ \ ];\ ]\)\(\ \ \)\)\)], "Input",
  PageWidth->Infinity],

Cell[TextData[{
  StyleBox["This is the second version of  ",
    FontFamily->"Times New Roman"],
  StyleBox["LUfactor",
    FontWeight->"Bold"],
  StyleBox["  and it uses ",
    FontFamily->"Times New Roman"],
  "more loops and traditional programming. "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (LUfactor).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(LUfactor[
          n_] := \[IndentingNewLine]Module[\ {i, j, k, 
            p}, \[IndentingNewLine]r\  = \ 
            Table[j, {j, n}]; \[IndentingNewLine]For[\ p = 1, \ 
            p \[LessEqual] n - 1, \ \(p++\), \[IndentingNewLine]For[\ 
              j = p + 1, \ 
              j \[LessEqual] 
                n, \ \(j++\), \[IndentingNewLine]\(If[\ 
                  Abs[A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\
\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\), p\)\(\
\[RightDoubleBracket]\)\)] > 
                    Abs[A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\
\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\), p\)\(\
\[RightDoubleBracket]\)\)], \
\[IndentingNewLine]r\_\(\(\[LeftDoubleBracket]\)\({j, p}\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                    r\_\(\(\[LeftDoubleBracket]\)\({p, j}\)\(\
\[RightDoubleBracket]\)\)\ \ ];\)\ ]; \[IndentingNewLine]For[\ k = p + 1, \ 
              k \[LessEqual] 
                n, \ \(k++\), \
\[IndentingNewLine]A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\
\)\(k\)\(\[RightDoubleBracket]\)\), p\)\(\[RightDoubleBracket]\)\)\  = \ 
                A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(\
k\)\(\[RightDoubleBracket]\)\), p\)\(\[RightDoubleBracket]\)\)\/A\_\(\(\
\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(p\)\(\
\[RightDoubleBracket]\)\), p\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]For[\ c = p + 1, \ 
                c \[LessEqual] 
                  n, \ \(c++\), \[IndentingNewLine]\(A\_\(\(\
\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\), c\)\(\[RightDoubleBracket]\)\)\  = \ 
                    A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\
\)\(k\)\(\[RightDoubleBracket]\)\), c\)\(\[RightDoubleBracket]\)\)\  - \ 
                      A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\), p\)\(\
\[RightDoubleBracket]\)\)\ A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\
\[LeftDoubleBracket]\)\(p\)\(\[RightDoubleBracket]\)\), c\)\(\
\[RightDoubleBracket]\)\);\)\ ];\ ];\ ]; \ \[IndentingNewLine]L\  = \ \(P\  = \
\ IdentityMatrix[n]\); \[IndentingNewLine]P\  = \ 
            
            P\_\(\(\[LeftDoubleBracket]\)\(r\)\(\[RightDoubleBracket]\)\); \
\[IndentingNewLine]U\  = \ 
            A\_\(\(\[LeftDoubleBracket]\)\(r\)\(\[RightDoubleBracket]\)\); \
\[IndentingNewLine]For[\ i = 1, \ 
            i \[LessEqual] 
              n, \ \(i++\), \[IndentingNewLine]\(For[\ j = 1, \ 
                j \[LessEqual] 
                  i - 1, \ \(j++\), \[IndentingNewLine]L\_\(\(\
\[LeftDoubleBracket]\)\(i, j\)\(\[RightDoubleBracket]\)\)\  = \ 
                  A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\
\(i\)\(\[RightDoubleBracket]\)\), j\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]U\_\(\(\[LeftDoubleBracket]\)\(i, j\)\(\
\[RightDoubleBracket]\)\)\  = \ 0;\ ];\)\ ];\ ];\)\)], "Input",
  PageWidth->Infinity],

Cell[TextData[{
  StyleBox["Use the subroutine",
    FontFamily->"Times New Roman"],
  StyleBox[" SolveLU",
    FontWeight->"Bold"],
  StyleBox[" which is similar to the forward substitution and back \
substitution subroutines.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (SolveLU).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(SolveLU[
          n_] := \[IndentingNewLine]Module[{k}, \[IndentingNewLine]X = \(Y = 
              Table[0, {n}]\); \[IndentingNewLine]For[\ k = 1, \ 
            k \[LessEqual] 
              n, \ \(k++\), \
\[IndentingNewLine]\(Y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\
\)\)\  = \ \((B\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(k\
\)\(\[RightDoubleBracket]\)\)\)\(\[RightDoubleBracket]\)\) - \[Sum]\+\(j = \ \
1\)\%\(k - \
1\)\(A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\), j\)\(\[RightDoubleBracket]\)\)\) 
                        Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\))\);\)\ ]; \[IndentingNewLine]For[\ k = n, \ 
            1 \[LessEqual] 
              k, \ \(k--\), \
\[IndentingNewLine]X\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\
\)\  = \ \((Y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\) - \
\[Sum]\+\(j = \ k + 1\)\%n\( 
                            A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\), 
                            j\)\(\[RightDoubleBracket]\)\)\) 
                        X\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\))\)/
                A\_\(\(\[LeftDoubleBracket]\)\(r\_\(\(\[LeftDoubleBracket]\)\(\
k\)\(\[RightDoubleBracket]\)\), k\)\(\[RightDoubleBracket]\)\)\ ];\ ];\)\)], \
"Input",
  PageWidth->Infinity],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Everything has been carefully set up so that  ",
  StyleBox["L",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["U",
    FontWeight->"Bold"],
  ", and  ",
  StyleBox["P",
    FontWeight->"Bold"],
  "  can all be studied."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use  ",
  StyleBox["PA",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "  factorization with pivoting to solve the linear system  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {"2.0", "4.0", "1.0"},
                {"4.0", \(-10\), "2.0"},
                {"1.0", "2.0", "4.0"}
                }], ")"}], 
          InterpretationBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)},
                  {\(x\_3\)}
                  }], "\[NoBreak]", ")"}],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3]}]]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"5.0"},
              {\(-8.0\)},
              {"13.0"}
              }], ")"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Remark.  The  ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "  factorization part does not depend on  ",
  StyleBox["B",
    FontWeight->"Bold"],
  ".  To emphasize this, we only enter the matrix  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  at this time."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", 
        RowBox[{"(", GridBox[{
              {"2.0", "4.0", "1.0"},
              {"4.0", \(-10.0\), "2.0"},
              {"1.0", "2.0", "4.0"}
              }], ")"}]}], ";"}], "\n", \(A0\  = \ A;\)}], "Input"],

Cell[TextData[{
  "Execute the  ",
  StyleBox["LUfactor",
    FontWeight->"Bold"],
  "  subroutine.  Note that the dimension of the system must be used, in this \
case n = 3."
}], "Text"],

Cell[BoxData[
    \(\(LUfactor[3];\)\)], "Input"],

Cell[TextData[{
  "Now print out the matrices  ",
  StyleBox["L",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["U",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["L.U",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["L.U",
    FontWeight->"Bold"],
  " and  ",
  StyleBox["P.A",
    FontWeight->"Bold"],
  ".  (Remember we stored a copy of  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  in ",
  StyleBox["A0",
    FontWeight->"Bold"],
  ")."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\< L = \>", MatrixForm[L]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< U = \>", MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< P = \>", MatrixForm[P]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< A = \>", MatrixForm[A0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<LU = \>", MatrixForm[L . U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<PA = \>", MatrixForm[P . A0]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Now enter the matrix  ",
  StyleBox["B",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"B", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"5.0"},
              {\(-8.0\)},
              {"13.0"}
              }], ")"}]}], ";"}]], "Input"],

Cell[TextData[{
  "Solve the system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(SolveLU[3];\)\), "\[IndentingNewLine]", 
    \(\(vars = {\*"\"\<\!\(x\_1\)\>\"", \*"\"\<\!\(x\_2\)\>\"", \
\*"\"\<\!\(x\_3\)\>\""};\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve AX = B\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A0]\ , MatrixForm[vars], "\< = \>", 
        MatrixForm[A0 . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<AX = \>", MatrixForm[A0]\ , MatrixForm[X], "\< = \>", 
        MatrixForm[A0 . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[B]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  For curiosity, we can check to see the \"in between\" steps that were \
made in the solution.  First, we solved",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["LY",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["PB",
          FontWeight->"Bold"]}]]],
  StyleBox["  for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["Y",
        FontWeight->"Bold"]]],
  StyleBox["  using forward substitution.  This is just for fun ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<L = \>", MatrixForm[L]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y = \>", MatrixForm[Y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P = \>", MatrixForm[P]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<LY = \>", MatrixForm[L], MatrixForm[Y], "\< = \>", 
        MatrixForm[L . Y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<PB = \>", MatrixForm[P], MatrixForm[B], "\< = \>", 
        MatrixForm[P . B]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Second, we solved",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  StyleBox["  using back substitution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(Print["\< U = \>", MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< X = \>", MatrixForm[X]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<UX = \>", MatrixForm[U]\ , MatrixForm[X], "\< = \>", 
        MatrixForm[U . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< Y = \>", MatrixForm[Y]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Finally, we can verify that the residual is  zero, i. e. use matrix \
multiplication to see if    ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " - ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  =  ",
  StyleBox["0",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<AX - B\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", MatrixForm[A0]\ , MatrixForm[X], "\< - \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", MatrixForm[A0 . X], "\< - \>", 
        MatrixForm[B], "\< = \>", MatrixForm[A0 . X - B]];\)\)}], "Input",
  PageWidth->Infinity],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Suppose a new linear system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  is to be solved, where  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  is the same we used above, but  ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  is a new vector.\nThen we enter  ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  and only invoke the  ",
  StyleBox["SolveLU",
    FontWeight->"Bold"],
  "  subroutine.\n"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"B", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"1.0"},
              {"5.0"},
              {"4.0"}
              }], ")"}]}], ";"}]], "Input"],

Cell[TextData[{
  "Solve the new system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(SolveLU[3];\)\), "\[IndentingNewLine]", 
    \(\(vars = {\*"\"\<\!\(x\_1\)\>\"", \*"\"\<\!\(x\_2\)\>\"", \
\*"\"\<\!\(x\_3\)\>\""};\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve AX = B\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A0]\ , MatrixForm[vars], "\< = \>", 
        MatrixForm[A0 . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<AX = \>", MatrixForm[A0]\ , MatrixForm[X], "\< = \>", 
        MatrixForm[A0 . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[B]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use  ",
  StyleBox["PA",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "  factorization with pivoting to solve the linear system  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {"4.0", "2.0", \(-1.0\), "3.0"},
                {"3.0", \(-4.0\), "2.0", "5.0"},
                {\(-2.0\), "6.0", \(-5.0\), \(-2.0\)},
                {"5.0", "1.0", "6.0", \(-3.0\)}
                }], ")"}], 
          InterpretationBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)},
                  {\(x\_3\)},
                  {\(x\_4\)}
                  }], "\[NoBreak]", ")"}],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3], 
              Subscript[ x, 4]}]]}], " ", "=", " ", 
        RowBox[{"(", 
          TagBox[GridBox[{
                {"16.9"},
                {\(-14.0\)},
                {"25.0"},
                {"9.4"}
                }],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]], ")"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The  ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "  factorization part does not depend on  ",
  StyleBox["B",
    FontWeight->"Bold"],
  ".  To emphasize this, we only enter the matrix  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  at this time."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", " ", "=", " ", 
          RowBox[{"(", GridBox[{
                {"4.0", "2.0", \(-1.0\), "3.0"},
                {"3.0", \(-4.0\), "2.0", "5.0"},
                {\(-2.0\), "6.0", \(-5.0\), \(-2.0\)},
                {"5.0", "1.0", "6.0", \(-3.0\)}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(A0\  = \ A;\)}], "Input"],

Cell[TextData[{
  "Execute the  ",
  StyleBox["LUfactor",
    FontWeight->"Bold"],
  "  subroutine.  Note that the dimension of the system must be used, in this \
case n = 3."
}], "Text"],

Cell[BoxData[
    \(\(LUfactor[4];\)\)], "Input"],

Cell[TextData[{
  "Now print out the matrices  ",
  StyleBox["L",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["U",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["L.U",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["L.U",
    FontWeight->"Bold"],
  " and  ",
  StyleBox["P.A",
    FontWeight->"Bold"],
  ".  (Remember we stored a copy of  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  in ",
  StyleBox["A0",
    FontWeight->"Bold"],
  ")."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\< L = \>", MatrixForm[L]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< U = \>", MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< P = \>", MatrixForm[P]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< A = \>", MatrixForm[A0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<LU = \>", MatrixForm[L . U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<PA = \>", MatrixForm[P . A0]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Now enter the matrix  ",
  StyleBox["B",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"B", " ", "=", " ", 
        RowBox[{"(", 
          TagBox[GridBox[{
                {"16.9"},
                {\(-14.0\)},
                {"25.0"},
                {"9.4"}
                }],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]], ")"}]}], ";"}]], "Input"],

Cell[TextData[{
  "Solve the system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(SolveLU[4];\)\), "\[IndentingNewLine]", 
    \(\(vars = {\*"\"\<\!\(x\_1\)\>\"", \*"\"\<\!\(x\_2\)\>\"", \
\*"\"\<\!\(x\_3\)\>\"", \*"\"\<\!\(x\_4\)\>\""};\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve AX = B\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A0]\ , MatrixForm[vars], "\< = \>", 
        MatrixForm[A0 . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<AX = \>", MatrixForm[A0]\ , MatrixForm[X], "\< = \>", 
        MatrixForm[A0 . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[B]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  For curiosity, we can check to see the \"in between\" steps that were \
made in the solution.  First, we solved",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["LY",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["PB",
          FontWeight->"Bold"]}]]],
  StyleBox["  for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["Y",
        FontWeight->"Bold"]]],
  StyleBox["  using forward substitution.  This is just for fun ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<L = \>", MatrixForm[L]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y = \>", MatrixForm[Y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P = \>", MatrixForm[P]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<LY = \>", MatrixForm[L], MatrixForm[Y], "\< = \>", 
        MatrixForm[L . Y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<PB = \>", MatrixForm[P], MatrixForm[B], "\< = \>", 
        MatrixForm[P . B]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Second, we solved",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  StyleBox["  using back substitution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(Print["\< U = \>", MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< X = \>", MatrixForm[X]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<UX = \>", MatrixForm[U]\ , MatrixForm[X], "\< = \>", 
        MatrixForm[U . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< Y = \>", MatrixForm[Y]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Finally, we can verify that the residual is  zero, i. e. use matrix \
multiplication to see if    ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " - ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  =  ",
  StyleBox["0",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<AX - B\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", MatrixForm[A0]\ , MatrixForm[X], "\< - \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<= \>", MatrixForm[A0 . X], "\< - \>", 
        MatrixForm[B], "\< = \>", MatrixForm[A0 . X - B]];\)\)}], "Input",
  PageWidth->Infinity],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Suppose a new linear system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  is to be solved, where  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  is the same we used above, but  ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  is a new vector.\nThen we enter  ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  and only invoke the  ",
  StyleBox["SolveLU",
    FontWeight->"Bold"],
  "  subroutine.\n"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"B", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(-12.0\)},
              {"34.0"},
              {"27.0"},
              {\(-19.0\)}
              }], ")"}]}], ";"}]], "Input"],

Cell[TextData[{
  "Solve the new system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(SolveLU[4];\)\), "\[IndentingNewLine]", 
    \(\(vars = {\*"\"\<\!\(x\_1\)\>\"", \*"\"\<\!\(x\_2\)\>\"", \
\*"\"\<\!\(x\_3\)\>\"", \*"\"\<\!\(x\_4\)\>\""};\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve AX = B\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A0]\ , MatrixForm[vars], "\< = \>", 
        MatrixForm[A0 . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<AX = \>", MatrixForm[A0]\ , MatrixForm[X], "\< = \>", 
        MatrixForm[A0 . X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[B]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Application to Polynomial Curve Fitting\n\nTheorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Least-Squares Polynomial Curve Fitting",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LeastSquaresFittingPolynomial.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " Given the  ",
  Cell[BoxData[
      \(n\)]],
  "  data points  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(x\_1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(y\_1\)}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{\(x\_2\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(y\_2\)}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{\(x\_n\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(y\_n\)}], ")"}]}]]],
  ",  the ",
  StyleBox["least squares polynomial of degree  m  of the form  ",
    FontFamily->"Times New Roman"],
  "\n\n\t",
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(P\_m\) \((x)\)\  = \ \(c\_1\  + \ 
              c\_2\ x + \ \(c\_3\) x\^2\  + \  ... \) + \(c\_m\) 
            x\^\(m - 1\)\  + \ \(c\_\(m + 1\)\) x\^m\)]],
  " \n\n",
  StyleBox["that fits the n data points ",
    FontFamily->"Times New Roman"],
  "is obtained by solving the following linear system\n \n\n\t\t",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {
              "n", \(\[Sum]\+\(i = 1\)\%n x\_i\), \(\[Sum]\+\(i = 1\)\%n x\_i\
\^2\), "\[CenterEllipsis]", \(\[Sum]\+\(i = 1\)\%n x\_i\^m\)},
            {\(\[Sum]\+\(i = 1\)\%n x\_i\), \(\[Sum]\+\(i = 1\)\%n x\_i\^2\), \
\(\[Sum]\+\(i = 1\)\%n x\_i\^3\), 
              "\[CenterEllipsis]", \(\[Sum]\+\(i = 1\)\%n x\_i\^\(m + 1\)\)},
            {\(\[Sum]\+\(i = 1\)\%n x\_i\^2\), \(\[Sum]\+\(i = 1\)\%n x\_i\^3\
\), \(\[Sum]\+\(i = 1\)\%n x\_i\^4\), 
              "\[CenterEllipsis]", \(\[Sum]\+\(i = 1\)\%n x\_i\^\(m + 2\)\)},
            {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
              "\[VerticalEllipsis]", "\[DescendingEllipsis]", 
              "\[VerticalEllipsis]"},
            {\(\[Sum]\+\(i = 1\)\%n x\_i\^m\), \(\[Sum]\+\(i = 1\)\%n \
x\_i\^\(m + 1\)\), \(\[Sum]\+\(i = 1\)\%n x\_i\^\(m + 2\)\), 
              "\[CenterEllipsis]", \(\[Sum]\+\(i = 1\)\%n x\_i\^\(2  m\)\)}
            }], ")"}]]],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(\ \)\(c\_1\)\)},
              {\(\(\ \)\(c\_2\)\)},
              {\(\(\ \)\(c\_3\)\)},
              {"\[VerticalEllipsis]"},
              {\(\(\ \)\(c\_\(m + 1\)\)\)}
              }], ")"}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(\ \)\(\[Sum]\+\(i = 1\)\%n y\_i\)\)},
              {\(\(\ \)\(\[Sum]\+\(i = 1\)\%n\( x\_i\) y\_i\)\)},
              {\(\(\ \)\(\[Sum]\+\(i = 1\)\%n\( x\_i\^2\) y\_i\)\)},
              {"\[VerticalEllipsis]"},
              {\(\[Sum]\+\(i = 1\)\%n\( x\_i\^m\) y\_i\)}
              }], ")"}]}]]],
  "  \n\nfor the m+1 coefficients ",
  Cell[BoxData[
      \({c\_1, c\_2,  ... , c\_m, c\_\(m + 1\)}\)]],
  ".  These equations are referred to as the \"normal equations\"."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Least Squares Polynomials",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LeastSqPolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Least Squares Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LeastSqPolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the \"least squares parabola\" that for the four data points  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"2", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "8"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{"3", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "27"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{"4", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "64"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{"(", 
            RowBox[{"5", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "125"}], ")"}]}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Write down the linear system ",
  StyleBox["AC",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " to be solved."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(XY\  = \ {{2, 8}, {3, 27}, {4, 64}, {5, 125}};\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(n = 4;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(x = \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(y = \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\);\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {
                "n", \(\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\), \
\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\^2\)},
              {\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^2\), \(\[Sum]\+\(k = \
1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^3\)},
              {\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\^2\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^3\), \(\[Sum]\+\(k = \
1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^4\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"B", "=", 
          RowBox[{"(", GridBox[{
                {\(\[Sum]\+\(k = 1\)\%n y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)},
                {\(\[Sum]\+\(k = 1\)\%n\( 
                          x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\) 
                      y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)},
                {\(\[Sum]\+\(k = \
1\)\%n\(\((x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\))\)\^\
2\) y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\)}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(vars = {\*"\"\<\!\(c\_1\)\>\"", \*"\"\<\
\!\(c\_2\)\>\"", \*"\"\<\!\(c\_3\)\>\""};\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve AC = B\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system for the coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  " using our  ",
  StyleBox["LUfactor[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["SolveLU[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  subroutines."
}], "Text"],

Cell[BoxData[{
    \(\(LUfactor[3];\)\), "\[IndentingNewLine]", 
    \(\(SolveLU[3];\)\), "\[IndentingNewLine]", 
    \(\(c = Flatten[X];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[c]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Construct the polynomial  ",
  StyleBox["p[x]",
    FontFamily->"Courier New"],
  ".  The coefficients are stored in the array  ",
  StyleBox["c",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and the elements are ",
  Cell[BoxData[
      \(c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x];\)\), "\[IndentingNewLine]", 
    \(\(p[
          x_] = \ \[Sum]\+\(i = 1\)\%3\( 
                c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
\) x\^\(i - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\)}], "Input"],

Cell[TextData[{
  "Of course we could do all this work in two lines by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  Cell[BoxData[
      StyleBox[\(Fit[XY, {1, x, x\^2}, x]\),
        FontWeight->"Bold"]]],
  "  procedure."
}], "Text"],

Cell[BoxData[{
    \(\(q[x_] = Fit[XY, {1, x, x\^2}, x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nWe can graph the polynomial, this is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[p[x], {x, 0, 6}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, dots, PlotRange \[Rule] All, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The `least-squares` polynomial\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Points = \>", XY];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the \"least squares cubic\" that for the four data points",
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"2", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "8"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{"3", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "27"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{"4", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "64"}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{"(", 
            RowBox[{"5", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "125"}], ")"}]}]}]]],
  ".  ",
  " "
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Write down the linear system ",
  StyleBox["AC",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " to be solved."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(XY\  = \ {{2, 8}, {3, 27}, {4, 64}, {5, 125}};\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(n = 4;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(x = \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(y = \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\);\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {
                "n", \(\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\), \
\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\^2\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^3\)},
              {\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^2\), \(\[Sum]\+\(k = \
1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^3\), \(\
\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^4\)},
              {\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\^2\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^3\), \(\[Sum]\+\(k = \
1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^4\), \(\
\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^5\)},
              {\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\^3\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^4\), \(\[Sum]\+\(k = \
1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^5\), \(\
\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^6\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"B", "=", 
          RowBox[{"(", GridBox[{
                {\(\[Sum]\+\(k = 1\)\%n y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)},
                {\(\[Sum]\+\(k = 1\)\%n\( 
                          x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\) 
                      y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)},
                {\(\[Sum]\+\(k = \
1\)\%n\(\((x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\))\)\^\
2\) y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\)},
                {\(\[Sum]\+\(k = \
1\)\%n\(\((x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\))\)\^\
3\) y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\)}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(A1 = 
        A;\), "\[IndentingNewLine]", \(vars = {\*"\"\<\!\(c\_1\)\>\"", \
\*"\"\<\!\(c\_2\)\>\"", \*"\"\<\!\(c\_3\)\>\"", \*"\"\<\!\(c\_4\)\>\""};\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve AC = B\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system for the coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  " using our  ",
  StyleBox["LUfactor[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["SolveLU[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  subroutines."
}], "Text"],

Cell[BoxData[{
    \(\(LUfactor[4];\)\), "\[IndentingNewLine]", 
    \(\(SolveLU[4];\)\), "\[IndentingNewLine]", 
    \(\(c = Flatten[X];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[c]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Construct the polynomial  ",
  StyleBox["p[x]",
    FontFamily->"Courier New"],
  ".  The coefficients are stored in the array  ",
  StyleBox["c",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and the elements are ",
  Cell[BoxData[
      \(c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x];\)\), "\[IndentingNewLine]", 
    \(\(p[
          x_] = \ \[Sum]\+\(i = 1\)\%4\( 
                c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
\) x\^\(i - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\)}], "Input"],

Cell[TextData[{
  "Of course we could do all this work in two lines by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  Cell[BoxData[
      StyleBox[\(Fit[XY, {1, x, x\^2, x\^3}, x]\),
        FontWeight->"Bold"]]],
  "  procedure."
}], "Text"],

Cell[BoxData[{
    \(\(q[x_] = Fit[XY, {1, x, x\^2, x\^3}, x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\)}], "Input"],

Cell["\<\
Notice that there appears to be a little \"round-off\" error \
creeping into the computation.  Lets \"chop\" it off.\
\>", "Text"],

Cell[BoxData[{
    \(\(q[x_] = Chop[q[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nWe can graph the polynomial, this is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[p[x], {x, 0, 6}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, dots, PlotRange \[Rule] All, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The `least-squares` polynomial\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Points = \>", XY];\)\)}], "Input"],

Cell[TextData[{
  "Why is the \"least-squares\" polynomial a \"perfect\" power   ",
  Cell[BoxData[
      \(p[x]\  = \ x\^3\)]],
  "?  Because the four data points are \"perfect powers.\"\nOf course we \
could do all this work in two lines by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  StyleBox["InterpolatingPolynomial[XY,x]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  procedure."
}], "Text"],

Cell[BoxData[{
    \(\(q[x_] = 
        Expand[InterpolatingPolynomial[XY, x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\)}], "Input"],

Cell[TextData[{
  "The  ",
  StyleBox["InterpolatingPolynomial[XY,x]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  procedure produces more accurate results if the answer should be an \
interpolating polynomial instead of a \"least-squares\" fit polynomial. "
}], "Text"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  \n\n\tIn numerical analysis we are concerned with round off error.  In \
the next example we will explore the \"what if\" scenario.  What will happen \
if the element  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["A",
            FontWeight->"Bold"], \(\(\[LeftDoubleBracket]\)\(4, 
          4\)\(\[RightDoubleBracket]\)\)], " ", "=", " ", "20514"}]]],
  "  is replaced with ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["A",
            FontWeight->"Bold"], \(\(\[LeftDoubleBracket]\)\(4, 
          4\)\(\[RightDoubleBracket]\)\)], " ", "=", " ", "20515"}]]],
  " in the matrix ?  This change is merely ",
  Cell[BoxData[
      \(1\/20514 = \ \(0.0000487\  = \ 0.00487\ %\)\)]],
  ".  We will see that this will result is tremendous changes in the \
coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  ".  The numerical algorithms are correct, it is a problem with the matrix, \
it has a large ",
  ButtonBox["condition number",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ConditionNumber.html"], None},
    ButtonStyle->"Hyperlink"],
  " and is ",
  ButtonBox["ill conditioned",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Ill-ConditionedMatrix.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  We need to be aware of these pitfalls. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(C1 = MatrixConditionNumber[N[A1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Condition number for A is \>", C1];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the linear system ",
  StyleBox["AC",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["=",
    FontFamily->"Courier New"],
  StyleBox["B",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " in Example 7, i.e.  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"4", "14", "54", "224"},
                  {"14", "54", "224", "978"},
                  {"54", "224", "978", "4424"},
                  {"224", "978", "4424", "20514"}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]], 
          InterpretationBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(c\_1\)},
                  {\(c\_2\)},
                  {\(c\_3\)},
                  {\(c\_4\)}
                  }], "\[NoBreak]", ")"}],
            MatrixForm[ {
              Subscript[ c, 1], 
              Subscript[ c, 2], 
              Subscript[ c, 3], 
              Subscript[ c, 4]}]]}], " ", "=", " ", 
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"224"},
              {"978"},
              {"4424"},
              {"20514"}
              }], "\[NoBreak]", ")"}]}]]],
  ".\n\nReplace the element  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["A",
            FontWeight->"Bold"], \(\(\[LeftDoubleBracket]\)\(4, 
          4\)\(\[RightDoubleBracket]\)\)], " ", "=", " ", "20514"}]]],
  "  with ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["A",
            FontWeight->"Bold"], \(\(\[LeftDoubleBracket]\)\(4, 
          4\)\(\[RightDoubleBracket]\)\)], " ", "=", " ", "20515"}]]],
  " in matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " and solve the new system ",
  StyleBox["AC",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["=",
    FontFamily->"Courier New"],
  StyleBox["B",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Enter the new matrix ",
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " and vector ",
  StyleBox["B",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(XY\  = \ {{2, 8}, {3, 27}, {4, 64}, {5, 125}};\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"A", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"4", "14", "54", "224"},
                {"14", "54", "224", "978"},
                {"54", "224", "978", "4424"},
                {"224", "978", "4424", "20515"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"B", "=", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"224"},
                  {"978"},
                  {"4424"},
                  {"20514"}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(A2 = 
        A;\), "\[IndentingNewLine]", \(vars = {\*"\"\<\!\(c\_1\)\>\"", \
\*"\"\<\!\(c\_2\)\>\"", \*"\"\<\!\(c\_3\)\>\"", \*"\"\<\!\(c\_4\)\>\""};\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve AC = B\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system for the coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  " using our  ",
  StyleBox["LUfactor[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["SolveLU[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  subroutines."
}], "Text"],

Cell[BoxData[{
    \(\(LUfactor[4];\)\), "\[IndentingNewLine]", 
    \(\(SolveLU[4];\)\), "\[IndentingNewLine]", 
    \(\(c = Flatten[X];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[c], "\< = \>", 
        MatrixForm[N[c]]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solution is quite different from that of Example 7.  This is not a \
problem in our subroutines, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will also get this answer."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"4", "14", "54", "224"},
                {"14", "54", "224", "978"},
                {"54", "224", "978", "4424"},
                {"224", "978", "4424", "20515"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"B", "=", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"224"},
                  {"978"},
                  {"4424"},
                  {"20514"}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(c1 = 
        LinearSolve[A, B];\), "\[IndentingNewLine]", 
    RowBox[{\(Print[MatrixForm[vars], "\< = \>", MatrixForm[c1], "\< = \>", 
          MatrixForm[N[c1]]];\), " "}]}], "Input"],

Cell[TextData[{
  "\tThese solution values are so far from the previous ones in Example 7 \
that they appear to be a worthless answer, and this type of ill-conditioning \
is not easy to detect.  One would normally expect that a small change in a \
coefficient in the matrix would result in a small change in the computed \
solution.  We changed the element  ",
  Cell[BoxData[
      \(A\_\(\(\[LeftDoubleBracket]\)\(4, 4\)\(\[RightDoubleBracket]\)\)\)]],
  " a small fraction,  ",
  Cell[BoxData[
      \(1\/20514 = \ 0.0000487\)]],
  ",  and the changes in the coefficients went \n\nfrom   ",
  Cell[BoxData[
      RowBox[{
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\<\"\\!\\(c\\_1\\)\"\>"},
                {"\<\"\\!\\(c\\_2\\)\"\>"},
                {"\<\"\\!\\(c\\_3\\)\"\>"},
                {"\<\"\\!\\(c\\_4\\)\"\>"}
                }], "\[NoBreak]", ")"}],
          
          MatrixForm[ {"\!\(c\_1\)", "\!\(c\_2\)", "\!\(c\_3\)", 
            "\!\(c\_4\)"}]], "=", 
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\<\"0\"\>"},
                {"\<\"0\"\>"},
                {"\<\"0\"\>"},
                {"\<\"1\"\>"}
                }], "\[NoBreak]", ")"}],
          
          MatrixForm[ {"\!\(c\_1\)", "\!\(c\_2\)", "\!\(c\_3\)", 
            "\!\(c\_4\)"}]]}]]],
  "    to    ",
  Cell[BoxData[
      RowBox[{
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\<\"\\!\\(c\\_1\\)\"\>"},
                {"\<\"\\!\\(c\\_2\\)\"\>"},
                {"\<\"\\!\\(c\\_3\\)\"\>"},
                {"\<\"\\!\\(c\\_4\\)\"\>"}
                }], "\[NoBreak]", ")"}],
          
          MatrixForm[ {"\!\(c\_1\)", "\!\(c\_2\)", "\!\(c\_3\)", 
            "\!\(c\_4\)"}]], "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"12.75`"},
                {\(-12.392857142857142`\)},
                {"3.75`"},
                {"0.6428571428571429`"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]]],
  ".   "
}], "Text"],

Cell[TextData[{
  "\tThe element  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["A",
            FontWeight->"Bold"], \(\(\[LeftDoubleBracket]\)\(4, 
          4\)\(\[RightDoubleBracket]\)\)], " ", "=", " ", "20514"}]]],
  "  was replaced with ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["A",
            FontWeight->"Bold"], \(\(\[LeftDoubleBracket]\)\(4, 
          4\)\(\[RightDoubleBracket]\)\)], " ", "=", " ", "20515"}]]],
  " in the matrix ?  This change is merely ",
  Cell[BoxData[
      \(1\/20514 = \ \(0.0000487\  = \ 0.00487\ %\)\)]],
  ".  The percentage change in the solution ",
  Cell[BoxData[
      \(c\_4\)]],
  " is ",
  StyleBox["36%",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(C2 = MatrixConditionNumber[N[A2]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A2]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Condition number for A is \>", C2];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For the `original matrix`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Condition number for A is \>", C1];\)\)}], "Input"],

Cell["Continue with the explorations.", "Text"],

Cell[TextData[{
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Construct the polynomial  ",
  StyleBox["p[x]",
    FontFamily->"Courier New"],
  ".  The coefficients are stored in the array  ",
  StyleBox["c",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and the elements are ",
  Cell[BoxData[
      \(c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x];\)\), "\[IndentingNewLine]", 
    \(\(q[
          x_] = \ \[Sum]\+\(i = 1\)\%4\( 
                c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
\) x\^\(i - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nWe can graph the polynomial, this is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[q[x], {x, 0, 6}, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr2, dots, PlotRange \[Rule] All, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The `least-squares` polynomial\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Points = \>", XY];\)\)}], "Input"],

Cell["\<\
Behold, do our eyes see anything significantly different from the \
previous graph in Example 7 ?\
\>", "Text"],

Cell[BoxData[{
    \(\(Show[gr1, gr2, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[gr1, gr2, dots, PlotRange \[Rule] {{2, 5}, {8, 125}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\ \)}], "Input"],

Cell[TextData[{
  "If you were looking for the polynomial  ",
  Cell[BoxData[
      \(p[x] = x\^3\)]],
  " and found the polynomial  ",
  Cell[BoxData[
      \(q[x] = 
        51\/4 - \(347\ x\)\/28 + \(15\ x\^2\)\/4 + \(9\ x\^3\)\/14\)]],
  "  would you be happy ?"
}], "Text"],

Cell[TextData[{
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Remember to check the condition number of your matrix, beware if it is \
large and seek alternate ways to find compute a solution.  In ",
  ButtonBox["approximation theory",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/topics/ApproximationTheory.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " there are other methods and algorithms which can be used. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/lu.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/lu.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/LUFactorBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LUFactorBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  ",
  "Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 188, 4, 35, "Text"],
Cell[1967, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3446, 111, 1917, 64, 182, "Text"],
Cell[5366, 177, 5000, 141, 193, "Text"],
Cell[10369, 320, 605, 20, 33, "Text"],
Cell[10977, 342, 348, 10, 33, "Text"],
Cell[11328, 354, 1097, 19, 214, "Input"],
Cell[12428, 375, 591, 19, 33, "Text"],
Cell[13022, 396, 135, 2, 33, "Text"],
Cell[13160, 400, 1210, 21, 275, "Input"],
Cell[14373, 423, 649, 29, 57, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[15047, 456, 101, 2, 33, "Text"],
Cell[15151, 460, 265, 8, 57, "Input"],
Cell[15419, 470, 333, 17, 33, "Text"],
Cell[15755, 489, 59, 1, 30, "Input"],
Cell[15817, 492, 141, 8, 33, "Text"],
Cell[15961, 502, 447, 7, 130, "Input"]
}, Closed]],
Cell[16423, 512, 715, 30, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[17163, 546, 101, 2, 33, "Text"],
Cell[17267, 550, 333, 9, 73, "Input"],
Cell[17603, 561, 333, 17, 33, "Text"],
Cell[17939, 580, 59, 1, 30, "Input"],
Cell[18001, 583, 141, 8, 33, "Text"],
Cell[18145, 593, 447, 7, 130, "Input"]
}, Closed]],
Cell[18607, 603, 597, 26, 54, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19229, 633, 101, 2, 33, "Text"],
Cell[19333, 637, 268, 8, 57, "Input"],
Cell[19604, 647, 124, 5, 33, "Text"],
Cell[19731, 654, 59, 1, 30, "Input"],
Cell[19793, 657, 423, 18, 71, "Text"],
Cell[20219, 677, 565, 21, 71, "Text"],
Cell[20787, 700, 765, 17, 180, "Input"],
Cell[21555, 719, 447, 7, 130, "Input"]
}, Closed]],
Cell[22017, 729, 2683, 94, 125, "Text"],
Cell[24703, 825, 605, 20, 33, "Text"],
Cell[25311, 847, 7437, 218, 90, "Text"],
Cell[32751, 1067, 3949, 109, 177, "Text"],
Cell[36703, 1178, 3317, 96, 53, "Text"],
Cell[40023, 1276, 446, 13, 73, "Text"],
Cell[40472, 1291, 870, 20, 107, "Input"],
Cell[41345, 1313, 958, 33, 71, "Text"],
Cell[42306, 1348, 2758, 96, 128, "Text"],
Cell[45067, 1446, 605, 20, 33, "Text"],
Cell[45675, 1468, 591, 19, 33, "Text"],
Cell[46269, 1489, 1224, 39, 90, "Text"],
Cell[47496, 1530, 3059, 53, 395, "Input"],
Cell[50558, 1585, 267, 8, 33, "Text"],
Cell[50828, 1595, 138, 2, 33, "Text"],
Cell[50969, 1599, 3003, 54, 416, "Input"],
Cell[53975, 1655, 276, 8, 33, "Text"],
Cell[54254, 1665, 137, 2, 33, "Text"],
Cell[54394, 1669, 1467, 27, 208, "Input"],
Cell[55864, 1698, 333, 14, 33, "Text"],
Cell[56200, 1714, 1085, 38, 57, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[57310, 1756, 101, 2, 33, "Text"],
Cell[57414, 1760, 292, 11, 33, "Text"],
Cell[57709, 1773, 270, 7, 80, "Input"],
Cell[57982, 1782, 187, 6, 33, "Text"],
Cell[58172, 1790, 49, 1, 30, "Input"],
Cell[58224, 1793, 452, 23, 33, "Text"],
Cell[58679, 1818, 559, 8, 170, "Input"],
Cell[59241, 1828, 104, 5, 33, "Text"],
Cell[59348, 1835, 208, 7, 57, "Input"],
Cell[59559, 1844, 202, 11, 33, "Text"],
Cell[59764, 1857, 724, 12, 170, "Input"],
Cell[60491, 1871, 761, 25, 71, "Text"],
Cell[61255, 1898, 476, 7, 110, "Input"],
Cell[61734, 1907, 543, 21, 33, "Text"],
Cell[62280, 1930, 351, 5, 90, "Input"],
Cell[62634, 1937, 363, 15, 33, "Text",
  Evaluatable->False],
Cell[63000, 1954, 350, 6, 70, "Input"],
Cell[63353, 1962, 568, 23, 71, "Text"],
Cell[63924, 1987, 204, 7, 57, "Input"],
Cell[64131, 1996, 206, 11, 33, "Text"],
Cell[64340, 2009, 724, 12, 170, "Input"]
}, Closed]],
Cell[65079, 2024, 1360, 45, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[66464, 2073, 101, 2, 33, "Text"],
Cell[66568, 2077, 366, 14, 33, "Text"],
Cell[66937, 2093, 414, 10, 98, "Input"],
Cell[67354, 2105, 187, 6, 33, "Text"],
Cell[67544, 2113, 49, 1, 30, "Input"],
Cell[67596, 2116, 452, 23, 33, "Text"],
Cell[68051, 2141, 559, 8, 170, "Input"],
Cell[68613, 2151, 104, 5, 33, "Text"],
Cell[68720, 2158, 337, 11, 73, "Input"],
Cell[69060, 2171, 202, 11, 33, "Text"],
Cell[69265, 2184, 748, 12, 170, "Input"],
Cell[70016, 2198, 761, 25, 71, "Text"],
Cell[70780, 2225, 476, 7, 110, "Input"],
Cell[71259, 2234, 543, 21, 33, "Text"],
Cell[71805, 2257, 351, 5, 90, "Input"],
Cell[72159, 2264, 363, 15, 33, "Text",
  Evaluatable->False],
Cell[72525, 2281, 350, 6, 70, "Input"],
Cell[72878, 2289, 568, 23, 71, "Text"],
Cell[73449, 2314, 237, 8, 73, "Input"],
Cell[73689, 2324, 206, 11, 33, "Text"],
Cell[73898, 2337, 748, 12, 170, "Input"]
}, Closed]],
Cell[74661, 2352, 4878, 128, 331, "Text"],
Cell[79542, 2482, 636, 21, 33, "Text"],
Cell[80181, 2505, 3425, 100, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[83631, 2609, 101, 2, 33, "Text"],
Cell[83735, 2613, 252, 11, 33, "Text"],
Cell[83990, 2626, 2335, 44, 309, "Input"],
Cell[86328, 2672, 444, 17, 34, "Text"],
Cell[86775, 2691, 245, 4, 90, "Input"],
Cell[87023, 2697, 439, 15, 34, "Text"],
Cell[87465, 2714, 293, 6, 95, "Input"],
Cell[87761, 2722, 271, 9, 33, "Text"],
Cell[88035, 2733, 137, 2, 51, "Input"],
Cell[88175, 2737, 173, 5, 71, "Text"],
Cell[88351, 2744, 724, 14, 150, "Input"]
}, Closed]],
Cell[89090, 2761, 3435, 102, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[92550, 2867, 101, 2, 33, "Text"],
Cell[92654, 2871, 252, 11, 33, "Text"],
Cell[92909, 2884, 3263, 60, 392, "Input"],
Cell[96175, 2946, 444, 17, 34, "Text"],
Cell[96622, 2965, 245, 4, 90, "Input"],
Cell[96870, 2971, 439, 15, 34, "Text"],
Cell[97312, 2988, 293, 6, 95, "Input"],
Cell[97608, 2996, 277, 9, 33, "Text"],
Cell[97888, 3007, 143, 2, 51, "Input"],
Cell[98034, 3011, 140, 3, 33, "Text"],
Cell[98177, 3016, 127, 2, 50, "Input"],
Cell[98307, 3020, 173, 5, 71, "Text"],
Cell[98483, 3027, 724, 14, 150, "Input"],
Cell[99210, 3043, 451, 13, 53, "Text"],
Cell[99664, 3058, 160, 3, 50, "Input"],
Cell[99827, 3063, 287, 7, 34, "Text"],
Cell[100117, 3072, 1484, 40, 112, "Text"],
Cell[101604, 3114, 314, 5, 90, "Input"]
}, Closed]],
Cell[101933, 3122, 2232, 74, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[104190, 3200, 101, 2, 33, "Text"],
Cell[104294, 3204, 301, 13, 34, "Text"],
Cell[104598, 3219, 1295, 32, 256, "Input"],
Cell[105896, 3253, 444, 17, 34, "Text"],
Cell[106343, 3272, 283, 5, 90, "Input"],
Cell[106629, 3279, 301, 9, 33, "Text"],
Cell[106933, 3290, 1028, 27, 191, "Input"],
Cell[107964, 3319, 2163, 57, 133, "Text"],
Cell[110130, 3378, 768, 25, 36, "Text"],
Cell[110901, 3405, 314, 5, 90, "Input"],
Cell[111218, 3412, 232, 3, 70, "Input"],
Cell[111453, 3417, 47, 0, 33, "Text"],
Cell[111503, 3419, 439, 15, 34, "Text"],
Cell[111945, 3436, 293, 6, 95, "Input"],
Cell[112241, 3444, 173, 5, 71, "Text"],
Cell[112417, 3451, 722, 14, 150, "Input"],
Cell[113142, 3467, 121, 3, 33, "Text"],
Cell[113266, 3472, 249, 5, 70, "Input"],
Cell[113518, 3479, 287, 5, 70, "Input"],
Cell[113808, 3486, 278, 9, 37, "Text"],
Cell[114089, 3497, 491, 12, 33, "Text"]
}, Closed]],
Cell[114595, 3512, 695, 20, 30, "Text"],
Cell[115293, 3534, 158, 3, 35, "Text"],
Cell[115454, 3539, 552, 17, 33, "Text"],
Cell[116009, 3558, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

