(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    120965,       3699]*)
(*NotebookOutlinePosition[    121693,       3724]*)
(*  CellTagsIndexPosition[    121649,       3720]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Module for ",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Cholesky, Doolittle and Crout Factorization",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["LU-Factorization",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LUDecomposition.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The nonsingular matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " has an LU-factorization if it can be expressed as the product of a \
lower-triangular matrix ",
  StyleBox["L",
    FontWeight->"Bold"],
  " and an upper triangular matrix ",
  StyleBox["U",
    FontWeight->"Bold"],
  ":  \n\n\t\t  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        StyleBox["LU",
          FontWeight->"Bold"]}]]],
  ".  \n\nWhen this is possible we say that ",
  StyleBox["A",
    FontWeight->"Bold"],
  " has an ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "-decomposition.  It turns out that this factorization (when it exists) is \
not unique.  If ",
  StyleBox["L",
    FontWeight->"Bold"],
  " has 1's on it's diagonal, then it is called a Doolittle factorization.  \
If ",
  StyleBox["U",
    FontWeight->"Bold"],
  " has 1's on its diagonal, then it is called a Crout factorization.  When  \
",
  Cell[BoxData[
      RowBox[{
        StyleBox["U",
          FontWeight->"Bold"], "=", 
        SuperscriptBox[
          StyleBox["L",
            FontWeight->"Bold"], "T"]}]]],
  "  (or ",
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], "=", 
        SuperscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "T"]}]]],
  "),  it is called a ",
  ButtonBox["Cholesky decomposition",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CholeskyDecomposition.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (A = LU;  Factorization with ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["NO",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" Pivoting).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" has a ",
    FontFamily->"Times New Roman"],
  "Doolittle, Crout or Cholesky factorization",
  StyleBox[".  The solution ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" to the linear system",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ", ",
  StyleBox[" is found in three steps:  \n\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["1.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Construct the matrices  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], "  ", 
        StyleBox["U",
          FontWeight->"Bold"]}]]],
  ", if possible.  ",
  StyleBox["\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["2.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["LY",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox["  for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["Y",
        FontWeight->"Bold"]]],
  StyleBox["  using forward substitution.\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["3.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  StyleBox["  using back substitution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/LUFactorProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["LU Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LUFactorProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (A = LU;  Doolittle Factorization).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" has a ",
    FontFamily->"Times New Roman"],
  "Doolittle factorization ",
  StyleBox["A",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  ".  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(a\_\(1, 1\)\), \(a\_\(1, 2\)\), \(a\_\(1, 3\)\), \(a\_\(1, 
                    4\)\), "...", \(a\_\(1, n\)\)},
              {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\), \(a\_\(2, 3\)\), \(a\_\(2, 
                    4\)\), "...", \(a\_\(2, n\)\)},
              {\(a\_\(3, 1\)\), \(a\_\(3, 2\)\), \(a\_\(3, 3\)\), \(a\_\(3, 
                    4\)\), "...", \(a\_\(3, n\)\)},
              {\(a\_\(4, 1\)\), \(a\_\(4, 2\)\), \(a\_\(4, 3\)\), \(a\_\(4, 
                    4\)\), "...", \(a\_\(4, n\)\)},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {\(a\_\(n, 1\)\), \(a\_\(n, 2\)\), \(a\_\(n, 3\)\), \(a\_\(n, 
                    4\)\), "...", \(a\_\(n, n\)\)}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  StyleBox[" = ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"1", "0", "0", "0", "...", "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(2, 1\)\)], "1", "0", 
                "0", "...", "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 2\)\)], "1", "0", "...",
                 "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 3\)\)], "1", "...",
                 "0"},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 3\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 4\)\)], "...", 
                "1"}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(u\_\(1, 1\)\), \(u\_\(1, 2\)\), \(u\_\(1, 3\)\), \(u\_\(1, 
                    4\)\), "...", \(u\_\(1, n\)\)},
              {"0", \(u\_\(2, 2\)\), \(u\_\(2, 3\)\), \(u\_\(2, 4\)\), 
                "...", \(u\_\(2, n\)\)},
              {"0", "0", \(u\_\(3, 3\)\), \(u\_\(3, 4\)\), 
                "...", \(u\_\(3, n\)\)},
              {"0", "0", "0", \(u\_\(4, 4\)\), "...", \(u\_\(4, n\)\)},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {"0", "0", "0", "0", "...", \(u\_\(n, n\)\)}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  "  \n",
  StyleBox["\nThe solution ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" to the linear system",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ", ",
  StyleBox[" is found in three steps:  \n\t",
    FontFamily->"Times New Roman"],
  StyleBox["1.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Construct the matrices  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], "  ", 
        StyleBox["U",
          FontWeight->"Bold"]}]]],
  ", if possible.  ",
  StyleBox["\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["2.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["LY",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox["  for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["Y",
        FontWeight->"Bold"]]],
  StyleBox["  using forward substitution.\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["3.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  StyleBox["  using back substitution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CholeskyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CholeskyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  "For curiosity, the reader might be interested in other methods of \
computing  ",
  StyleBox["L",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["U",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (A = LU;  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Crout",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CroutsMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" Factorization).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" has a Crout",
    FontFamily->"Times New Roman"],
  " ",
  "factorization ",
  StyleBox["A",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  ".  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(a\_\(1, 1\)\), \(a\_\(1, 2\)\), \(a\_\(1, 3\)\), \(a\_\(1, 
                    4\)\), "...", \(a\_\(1, n\)\)},
              {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\), \(a\_\(2, 3\)\), \(a\_\(2, 
                    4\)\), "...", \(a\_\(2, n\)\)},
              {\(a\_\(3, 1\)\), \(a\_\(3, 2\)\), \(a\_\(3, 3\)\), \(a\_\(3, 
                    4\)\), "...", \(a\_\(3, n\)\)},
              {\(a\_\(4, 1\)\), \(a\_\(4, 2\)\), \(a\_\(4, 3\)\), \(a\_\(4, 
                    4\)\), "...", \(a\_\(4, n\)\)},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {\(a\_\(n, 1\)\), \(a\_\(n, 2\)\), \(a\_\(n, 3\)\), \(a\_\(n, 
                    4\)\), "...", \(a\_\(n, n\)\)}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  StyleBox[" = ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(1, 1\)\)], "0", "0", 
                "0", "...", "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(2, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(2, 2\)\)], "0", "0", "...",
                 "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 3\)\)], "0", "...",
                 "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 3\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 4\)\)], "...", 
                "0"},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 3\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 4\)\)], "...", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  RowBox[{
                    StyleBox[" ",
                      FontFamily->"Script",
                      FontSize->14], \(n, n\)}]]}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"1", \(u\_\(1, 2\)\), \(u\_\(1, 3\)\), \(u\_\(1, 4\)\), 
                "...", \(u\_\(1, n\)\)},
              {"0", "1", \(u\_\(2, 3\)\), \(u\_\(2, 4\)\), 
                "...", \(u\_\(2, n\)\)},
              {"0", "0", "1", \(u\_\(3, 4\)\), "...", \(u\_\(3, n\)\)},
              {"0", "0", "0", "1", "...", \(u\_\(4, n\)\)},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {"0", "0", "0", "0", "...", "1"}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  "  \n",
  StyleBox["\nThe solution ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" to the linear system",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ", ",
  StyleBox[" is found in three steps:  \n\t",
    FontFamily->"Times New Roman"],
  StyleBox["1.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Construct the matrices  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], "  ", 
        StyleBox["U",
          FontWeight->"Bold"]}]]],
  ", if possible.  ",
  StyleBox["\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["2.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["LY",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox["  for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["Y",
        FontWeight->"Bold"]]],
  StyleBox["  using forward substitution.\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["3.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  StyleBox["  using back substitution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CholeskyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CholeskyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Doolittle).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(Doolittle[
        n_] := \[IndentingNewLine]Module[{i, j, k, 
          m}, \[IndentingNewLine]L\  = \ 
          Table[0, {n}, {n}]; \[IndentingNewLine]U\  = \ 
          L; \[IndentingNewLine]For[k = 1, 
          k \[LessEqual] 
            n, \(k++\), \[IndentingNewLine]L\_\(\(\[LeftDoubleBracket]\)\(k, \
k\)\(\[RightDoubleBracket]\)\) = \ 1; \[IndentingNewLine]For[j = k, 
            j \[LessEqual] 
              n, \(j++\), \
\[IndentingNewLine]U\_\(\(\[LeftDoubleBracket]\)\(k, j\)\(\
\[RightDoubleBracket]\)\) = 
              A\_\(\(\[LeftDoubleBracket]\)\(k, \
j\)\(\[RightDoubleBracket]\)\) - \[Sum]\+\(m = 1\)\%\(k - 1\)\(L\_\(\(\
\[LeftDoubleBracket]\)\(k, m\)\(\[RightDoubleBracket]\)\)\) 
                    U\_\(\(\[LeftDoubleBracket]\)\(m, j\)\(\
\[RightDoubleBracket]\)\)\ ]; \[IndentingNewLine]For[i = k + 1, 
            i \[LessEqual] 
              n, \(i++\), \
\[IndentingNewLine]L\_\(\(\[LeftDoubleBracket]\)\(i, k\)\(\
\[RightDoubleBracket]\)\) = \((A\_\(\(\[LeftDoubleBracket]\)\(i, k\)\(\
\[RightDoubleBracket]\)\) - \[Sum]\+\(m = 1\)\%\(k - 1\)\(L\_\(\(\
\[LeftDoubleBracket]\)\(i, m\)\(\[RightDoubleBracket]\)\)\) 
                        U\_\(\(\[LeftDoubleBracket]\)\(m, k\)\(\
\[RightDoubleBracket]\)\))\)/
                U\_\(\(\[LeftDoubleBracket]\)\(k, \
k\)\(\[RightDoubleBracket]\)\)]]]\)], "Input"],

Cell[TextData[StyleBox["Mathematica Subroutine (Crout).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(Crout[
        n_] := \[IndentingNewLine]Module[{i, j, k, 
          m}, \[IndentingNewLine]L\  = \ 
          Table[0, {n}, {n}]; \[IndentingNewLine]U\  = \ 
          L; \[IndentingNewLine]For[k = 1, 
          k \[LessEqual] 
            n, \(k++\), \[IndentingNewLine]L\_\(\(\[LeftDoubleBracket]\)\(k, \
k\)\(\[RightDoubleBracket]\)\) = \ 
            A\_\(\(\[LeftDoubleBracket]\)\(k, k\)\(\[RightDoubleBracket]\)\) \
- \[Sum]\+\(m = 1\)\%\(k - 1\)\(L\_\(\(\[LeftDoubleBracket]\)\(k, 
                      m\)\(\[RightDoubleBracket]\)\)\) 
                  U\_\(\(\[LeftDoubleBracket]\)\(m, \
k\)\(\[RightDoubleBracket]\)\); \[IndentingNewLine]For[j = k, 
            j \[LessEqual] 
              n, \(j++\), \
\[IndentingNewLine]U\_\(\(\[LeftDoubleBracket]\)\(k, j\)\(\
\[RightDoubleBracket]\)\) = \((A\_\(\(\[LeftDoubleBracket]\)\(k, j\)\(\
\[RightDoubleBracket]\)\) - \[Sum]\+\(m = 1\)\%\(k - 1\)\(L\_\(\(\
\[LeftDoubleBracket]\)\(k, m\)\(\[RightDoubleBracket]\)\)\) 
                        U\_\(\(\[LeftDoubleBracket]\)\(m, j\)\(\
\[RightDoubleBracket]\)\)\ )\)/
                L\_\(\(\[LeftDoubleBracket]\)\(k, \
k\)\(\[RightDoubleBracket]\)\)]; \[IndentingNewLine]For[i = k + 1, 
            i \[LessEqual] 
              n, \(i++\), \
\[IndentingNewLine]L\_\(\(\[LeftDoubleBracket]\)\(i, k\)\(\
\[RightDoubleBracket]\)\) = \((A\_\(\(\[LeftDoubleBracket]\)\(i, k\)\(\
\[RightDoubleBracket]\)\) - \[Sum]\+\(m = 1\)\%\(k - 1\)\(L\_\(\(\
\[LeftDoubleBracket]\)\(i, m\)\(\[RightDoubleBracket]\)\)\) 
                        U\_\(\(\[LeftDoubleBracket]\)\(m, k\)\(\
\[RightDoubleBracket]\)\))\)/
                U\_\(\(\[LeftDoubleBracket]\)\(k, \
k\)\(\[RightDoubleBracket]\)\)]]]\)], "Input"],

Cell[TextData[StyleBox["Mathematica Subroutine (Forward Elimination).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(ForeSub[
        n_] := \[IndentingNewLine]Module[{i, j}, \[IndentingNewLine]Y = 
          Table[0, {n}]; \
\[IndentingNewLine]Y\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\
\) = B\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\/L\_\(\(\
\[LeftDoubleBracket]\)\(n, n\)\(\[RightDoubleBracket]\)\); \
\[IndentingNewLine]For[i = 1, \ 
          i \[LessEqual] 
            n, \ \(i++\), \[IndentingNewLine]Y\_\(\(\[LeftDoubleBracket]\)\(i\
\)\(\[RightDoubleBracket]\)\) = \((B\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\) - \[Sum]\+\(j = \ 1\)\%\(i - 1\)\(L\_\(\(\
\[LeftDoubleBracket]\)\(i, j\)\(\[RightDoubleBracket]\)\)\) 
                      Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\))\)/
              L\_\(\(\[LeftDoubleBracket]\)\(i, \
i\)\(\[RightDoubleBracket]\)\)]]\)], "Input"],

Cell[TextData[StyleBox["Mathematica Subroutine (Back Substitution).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(BackSub[
        n_] := \[IndentingNewLine]Module[{i, j}, \[IndentingNewLine]X = 
          Table[0, {n}]; \
\[IndentingNewLine]X\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\
\) = Y\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\/U\_\(\(\
\[LeftDoubleBracket]\)\(n, n\)\(\[RightDoubleBracket]\)\); \
\[IndentingNewLine]For[i = n - 1, \ 
          1 \[LessEqual] 
            i, \ \(i--\), \[IndentingNewLine]X\_\(\(\[LeftDoubleBracket]\)\(i\
\)\(\[RightDoubleBracket]\)\) = \((Y\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\) - \[Sum]\+\(j = \ i + 1\)\%n\( 
                          U\_\(\(\[LeftDoubleBracket]\)\(i, 
                          j\)\(\[RightDoubleBracket]\)\)\) 
                      X\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\))\)/
              U\_\(\(\[LeftDoubleBracket]\)\(i, \
i\)\(\[RightDoubleBracket]\)\)]]\)], "Input"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Cholesky Factorization",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CholeskyDecomposition.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is real, symmetric and positive definite matrix, then it has a Cholesky \
factorization  \n\n\t\t  ",
  Cell[BoxData[
      StyleBox[\(A\  = \ U\^T\ U\),
        FontWeight->"Bold"]]],
  "\t\t\n\nwhere ",
  StyleBox["U",
    FontWeight->"Bold"],
  " an upper triangular matrix.  \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Observe that ",
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], "=", 
        SuperscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "T"]}]]],
  " is a lower triangular matrix, so that  ",
  StyleBox["A",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  ".  Hence we could also write Cholesky factorization  \n\n\t\t  ",
  Cell[BoxData[
      StyleBox[\(A\  = \ L\ L\^T\),
        FontWeight->"Bold"]]],
  "\t\n\nwhere ",
  StyleBox["L",
    FontWeight->"Bold"],
  " a lower triangular matrix.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (A = LU;  Cholesky Factorization).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that ",
    FontFamily->"Times New Roman"],
  StyleBox["A",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" has a Cholesky",
    FontFamily->"Times New Roman"],
  " factorization  ",
  Cell[BoxData[
      StyleBox[\(A\  = \ U\^T\ U\),
        FontWeight->"Bold"]]],
  ",  where  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["L",
          FontWeight->"Bold"], "=", 
        SuperscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "T"]}]]],
  ".",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(a\_\(1, 1\)\), \(a\_\(1, 2\)\), \(a\_\(1, 3\)\), \(a\_\(1, 
                    4\)\), "...", \(a\_\(1, n\)\)},
              {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\), \(a\_\(2, 3\)\), \(a\_\(2, 
                    4\)\), "...", \(a\_\(2, n\)\)},
              {\(a\_\(3, 1\)\), \(a\_\(3, 2\)\), \(a\_\(3, 3\)\), \(a\_\(3, 
                    4\)\), "...", \(a\_\(3, n\)\)},
              {\(a\_\(4, 1\)\), \(a\_\(4, 2\)\), \(a\_\(4, 3\)\), \(a\_\(4, 
                    4\)\), "...", \(a\_\(4, n\)\)},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {\(a\_\(n, 1\)\), \(a\_\(n, 2\)\), \(a\_\(n, 3\)\), \(a\_\(n, 
                    4\)\), "...", \(a\_\(n, n\)\)}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  StyleBox[" = ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(u\_\(1, 1\)\), "0", "0", "0", "...", "0"},
              {\(u\_\(1, 2\)\), \(u\_\(2, 2\)\), "0", "0", "...", "0"},
              {\(u\_\(1, 3\)\), \(u\_\(2, 3\)\), \(u\_\(3, 3\)\), "0", "...", 
                "0"},
              {\(u\_\(1, 4\)\), \(u\_\(2, 4\)\), \(u\_\(3, 4\)\), \(u\_\(4, 
                    4\)\), "...", "0"},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {\(u\_\(1, n\)\), \(u\_\(2, n\)\), \(u\_\(3, n\)\), \(u\_\(4, 
                    n\)\), "...", \(u\_\(n, n\)\)}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(u\_\(1, 1\)\), \(u\_\(1, 2\)\), \(u\_\(1, 3\)\), \(u\_\(1, 
                    4\)\), "...", \(u\_\(1, n\)\)},
              {"0", \(u\_\(2, 2\)\), \(u\_\(2, 3\)\), \(u\_\(2, 4\)\), 
                "...", \(u\_\(2, n\)\)},
              {"0", "0", \(u\_\(3, 3\)\), \(u\_\(3, 4\)\), 
                "...", \(u\_\(3, n\)\)},
              {"0", "0", "0", \(u\_\(4, 4\)\), "...", \(u\_\(4, n\)\)},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {"0", "0", "0", "0", "...", \(u\_\(n, n\)\)}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  "  \n\nOr if you prefer to write the ",
  StyleBox[" Cholesky",
    FontFamily->"Times New Roman"],
  " factorization as  ",
  Cell[BoxData[
      StyleBox[\(A\  = \ L\ L\^T\),
        FontWeight->"Bold"]]],
  ",  where ",
  Cell[BoxData[
      RowBox[{
        StyleBox["U",
          FontWeight->"Bold"], "=", 
        SuperscriptBox[
          StyleBox["L",
            FontWeight->"Bold"], "T"]}]]],
  ".\n",
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(a\_\(1, 1\)\), \(a\_\(1, 2\)\), \(a\_\(1, 3\)\), \(a\_\(1, 
                    4\)\), "...", \(a\_\(1, n\)\)},
              {\(a\_\(2, 1\)\), \(a\_\(2, 2\)\), \(a\_\(2, 3\)\), \(a\_\(2, 
                    4\)\), "...", \(a\_\(2, n\)\)},
              {\(a\_\(3, 1\)\), \(a\_\(3, 2\)\), \(a\_\(3, 3\)\), \(a\_\(3, 
                    4\)\), "...", \(a\_\(3, n\)\)},
              {\(a\_\(4, 1\)\), \(a\_\(4, 2\)\), \(a\_\(4, 3\)\), \(a\_\(4, 
                    4\)\), "...", \(a\_\(4, n\)\)},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {\(a\_\(n, 1\)\), \(a\_\(n, 2\)\), \(a\_\(n, 3\)\), \(a\_\(n, 
                    4\)\), "...", \(a\_\(n, n\)\)}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  StyleBox[" = ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(1, 1\)\)], "0", "0", 
                "0", "...", "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(2, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(2, 2\)\)], "0", "0", "...",
                 "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 3\)\)], "0", "...",
                 "0"},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 3\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 4\)\)], "...", 
                "0"},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 3\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 4\)\)], "...", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  RowBox[{
                    StyleBox[" ",
                      FontFamily->"Script",
                      FontSize->14], \(n, n\)}]]}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  Cell[BoxData[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(1, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(2, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 1\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 1\)\)], "...", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 1\)\)]},
              {"0", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(2, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 2\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 2\)\)], "...", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 2\)\)]},
              {"0", "0", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(3, 3\)\)], 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 3\)\)], "...", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 3\)\)]},
              {"0", "0", "0", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(4, 4\)\)], "...", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(\(\ \)\(n, 4\)\)]},
              {"   ", "   ", "  ", "  ", "  ", "  "},
              {"0", "0", "0", "0", "...", 
                SubscriptBox[
                  StyleBox["l",
                    FontFamily->"Math5",
                    FontSize->14,
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  RowBox[{
                    StyleBox[" ",
                      FontFamily->"Script",
                      FontSize->14], \(n, n\)}]]}
              }], "\[NoBreak]", ")"}],
        (MatrixForm[ #]&)]]],
  "  \n",
  StyleBox["\nThe solution ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" to the linear system",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  ", ",
  StyleBox[" is found in three steps:  \n\t",
    FontFamily->"Times New Roman"],
  StyleBox["1.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Construct the matrices  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["L",
            FontWeight->"Bold"], " ", 
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", 
          StyleBox["U",
            FontWeight->"Bold"]}], 
        StyleBox["=",
          FontWeight->"Bold"], 
        StyleBox[
          SuperscriptBox[
            StyleBox["L",
              FontWeight->"Bold"], "T"],
          FontWeight->"Bold"]}]]],
  ", if possible.  ",
  StyleBox["\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["2.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["LY",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox["  for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["Y",
        FontWeight->"Bold"]]],
  StyleBox["  using forward substitution.\n\t",
    FontFamily->"Times New Roman"],
  StyleBox["3.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Solve  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["UX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox["Y",
          FontWeight->"Bold"]}]]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["X",
        FontWeight->"Bold"]]],
  StyleBox["  using back substitution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CholeskyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CholeskyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThe following Cholesky subroutine can be used when the matrix  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  is real, symmetric and positive definite.\nObserve that the loop \
starting with  ",
  StyleBox["For[j=k,j\[LessEqual]n,j++,",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  is not necessary and that  ",
  StyleBox["U",
    FontWeight->"Bold"],
  "  is computed by forming the transpose of  ",
  StyleBox["L",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorization",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CholeskyProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorization",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CholeskyProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Cholesky factorization).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(Cholesky[
        n_] := \[IndentingNewLine]Module[{i, k, 
          m}, \[IndentingNewLine]L\  = \ 
          Table[0, {n}, {n}]; \[IndentingNewLine]For[k = 1, 
          k \[LessEqual] 
            n, \(k++\), \[IndentingNewLine]L\_\(\(\[LeftDoubleBracket]\)\(k, \
k\)\(\[RightDoubleBracket]\)\) = \@\(A\_\(\(\[LeftDoubleBracket]\)\(k, k\)\(\
\[RightDoubleBracket]\)\) - \[Sum]\+\(m = 1\)\%\(k - 1\)\((L\_\(\(\
\[LeftDoubleBracket]\)\(k, m\)\(\[RightDoubleBracket]\)\))\)\^2\); \
\[IndentingNewLine]For[i = k + 1, 
            i \[LessEqual] 
              n, \(i++\), \
\[IndentingNewLine]L\_\(\(\[LeftDoubleBracket]\)\(i, k\)\(\
\[RightDoubleBracket]\)\) = \((A\_\(\(\[LeftDoubleBracket]\)\(i, k\)\(\
\[RightDoubleBracket]\)\) - \[Sum]\+\(m = 1\)\%\(k - 1\)\(L\_\(\(\
\[LeftDoubleBracket]\)\(i, m\)\(\[RightDoubleBracket]\)\)\) 
                        L\_\(\(\[LeftDoubleBracket]\)\(k, m\)\(\
\[RightDoubleBracket]\)\))\)/
                L\_\(\(\[LeftDoubleBracket]\)\(k, \
k\)\(\[RightDoubleBracket]\)\)]]; \[IndentingNewLine]U = 
          Transpose[L]]\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the  ",
  StyleBox["A",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  " factorization for the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}]]],
  ".  Use the Doolittle method.  \n\n",
  StyleBox["Example 1 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the ",
  StyleBox["A",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "  factorization for the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}]]],
  ".  Use the Crout method.  \n\n",
  StyleBox["Example 1 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the ",
  StyleBox["A",
    FontWeight->"Bold"],
  " = ",
  StyleBox["LU",
    FontWeight->"Bold"],
  "  factorization for the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}]]],
  ".  Use the Cholesky method.  "
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the matrix.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}], " ", ";"}]], "Input"],

Cell["Invoke the subroutine Doolittle.  ", "Text"],

Cell[BoxData[{
    \(\(Doolittle[5];\)\), "\n", 
    \(\(L1 = L;\)\), "\[IndentingNewLine]", 
    \(\(U1 = U;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<L = \>", MatrixForm[\ L]\ ];\)\), "\n", 
    \(\(Print["\<U = \>", MatrixForm[\ U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Doolittle factorization\>"];\)\), "\[IndentingNewLine]", \

    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Verify the factorization.", "Text"],

Cell[BoxData[{
    \(\(Print["\<The Doolittle factorization\>"];\)\), "\[IndentingNewLine]", \

    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", 
        MatrixForm[L . U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does A = L U ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[A \[Equal] L . U];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the matrix.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}], " ", ";"}]], "Input"],

Cell["Invoke the subroutine Crout.  ", "Text"],

Cell[BoxData[{
    \(\(Crout[5];\)\), "\n", 
    \(\(Print["\<L = \>", MatrixForm[\ L]\ ];\)\), "\n", 
    \(\(Print["\<U = \>", MatrixForm[\ U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Crout factorization\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Verify the factorization.", "Text"],

Cell[BoxData[{
    \(\(Print["\<The Crout factorization\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", 
        MatrixForm[L . U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does A = L U ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[A \[Equal] L . U];\)\)}], "Input"],

Cell[TextData[{
  "The matrix has been factored it is similar to the Doolittle factorization. \
But this time the elements on the diagonal of  ",
  StyleBox["U",
    FontWeight->"Bold"],
  "  are ",
  Cell[BoxData[
      \(u\_\(k, k\) = 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  This is different from the Doolittle factorization that we found in part \
(a)."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<The Doolittle factorization\>"];\)\), "\[IndentingNewLine]", \

    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L1]\ , 
        MatrixForm[U1]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  If the LU factorization is used to solve a linear system then a wee bit \
more computing effort required for the Crout factorization than the Doolittle \
factorization.  For this reason we prefer the Doolittle method. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the matrix.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}], " ", ";"}]], "Input"],

Cell["Invoke the subroutine Cholesky.  ", "Text"],

Cell[BoxData[{
    \(\(Cholesky[5];\)\), "\n", 
    \(\(Print["\<L = \>", MatrixForm[\ L]\ ];\)\), "\n", 
    \(\(Print["\<U = \>", MatrixForm[\ U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Cholesky factorization\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Verify the factorization.", "Text"],

Cell[BoxData[{
    \(\(Print["\<The Cholesk factorization\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", 
        MatrixForm[L . U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does A = L U ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[A \[Equal] L . U];\)\)}], "Input"],

Cell[TextData[{
  "This time the elements on the diagonals of  ",
  StyleBox["L",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["U",
    FontWeight->"Bold"],
  "  are the same.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The Cholesky method is used only when ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is a ",
  "real, symmetric and positive definite matrix",
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the linear system  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}], 
          InterpretationBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)},
                  {\(x\_3\)},
                  {\(x\_4\)},
                  {\(x\_5\)}
                  }], "\[NoBreak]", ")"}],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3], 
              Subscript[ x, 4], 
              Subscript[ x, 5]}]]}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(-2\)},
              {"4"},
              {"3"},
              {\(-5\)},
              {"1"}
              }], ")"}]}]]],
  ".  \n\n",
  StyleBox["2 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the linear system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  by using the Doolittle method.  \n",
  StyleBox["2 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the linear system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  by using the Crout method.  \n",
  StyleBox["2 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the linear system  ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  by using the Cholesky method.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(i).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Enter the matrix and vector.  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}], " ", ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(-2\)},
              {"4"},
              {"3"},
              {\(-5\)},
              {"1"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars\  = \ {\*"\"\<\!\(x\_1\)\>\"", \*"\
\"\<\!\(x\_2\)\>\"", \*"\"\<\!\(x\_3\)\>\"", \*"\"\<\!\(x\_4\)\>\"", \
\*"\"\<\!\(x\_5\)\>\""};\), "\[IndentingNewLine]", \(Print["\<Solve the \
linear system\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  StyleBox["(ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the Doolittle factorization of matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Doolittle[5];\)\ \), "\n", 
    \(\(Print["\<The Doolittle factorization\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system using our  ",
  StyleBox["ForeSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["[BackSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  subroutines."
}], "Text"],

Cell[TextData[{
  "First, s",
  "olve the lower-triangular system    ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ForeSub[5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y = \>", MatrixForm[Y]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[MatrixForm[L], MatrixForm[Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[L . Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[L . Y \[Equal] B];\)\)}], "Input"],

Cell[TextData[{
  "Second, s",
  "olve the upper-triangular system    ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(BackSub[5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X]\ , "\< = \>", N[MatrixForm[X]]];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Y = N[Y];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U], MatrixForm[X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U . X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[N[U . X]], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[U . X \[Equal] Y];\)\)}], "Input"],

Cell[TextData[{
  "Therefore ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is the solution to  ",
  StyleBox["LUX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". and hence ",
  StyleBox["A",
    FontWeight->"Bold"],
  StyleBox["X",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "\nAnd we can verify that it is the solution."
}], "Text"],

Cell[BoxData[{
    \(\(X1 = X;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X1]\ , "\< = \>", N[MatrixForm[X1]]];\)\)}], "Input"],

Cell[BoxData[
    \(L . U . X \[Equal] B\)], "Input"],

Cell[BoxData[
    \(A . X \[Equal] B\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(i).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Enter the matrix and vector.  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}], " ", ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(-2\)},
              {"4"},
              {"3"},
              {\(-5\)},
              {"1"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars\  = \ {\*"\"\<\!\(x\_1\)\>\"", \*"\
\"\<\!\(x\_2\)\>\"", \*"\"\<\!\(x\_3\)\>\"", \*"\"\<\!\(x\_4\)\>\"", \
\*"\"\<\!\(x\_5\)\>\""};\), "\[IndentingNewLine]", \(Print["\<Solve the \
linear system\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  StyleBox["(ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the Crout factorization of matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Crout[5];\)\ \), "\n", 
    \(\(Print["\<The Crout factorization\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system using our  ",
  StyleBox["ForeSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["[BackSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  subroutines."
}], "Text"],

Cell[TextData[{
  "First, s",
  "olve the lower-triangular system    ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ForeSub[5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y = \>", MatrixForm[Y]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[MatrixForm[L], MatrixForm[Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[L . Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[L . Y \[Equal] B];\)\)}], "Input"],

Cell[TextData[{
  "Second, s",
  "olve the upper-triangular system    ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(BackSub[5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X]\ , "\< = \>", N[MatrixForm[X]]];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Y = N[Y];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U], MatrixForm[X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U . X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[N[U . X]], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[U . X \[Equal] Y];\)\)}], "Input"],

Cell[TextData[{
  "Therefore ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is the solution to  ",
  StyleBox["LUX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". and hence ",
  StyleBox["A",
    FontWeight->"Bold"],
  StyleBox["X",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "\nAnd we can verify that it is the solution."
}], "Text"],

Cell[BoxData[{
    \(\(X2 = X;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X2]\ , "\< = \>", N[MatrixForm[X2]]];\)\)}], "Input"],

Cell[BoxData[
    \(L . U . X \[Equal] B\)], "Input"],

Cell[BoxData[
    \(A . X \[Equal] B\)], "Input"],

Cell["\<\
We can compare this solution with the solution obtained in part \
(a).\
\>", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(X\_2\) = \>\"", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X2]\ , "\< = \>", 
        N[MatrixForm[X2]]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(X\_1\) = \>\"", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X1]\ , "\< = \>", N[MatrixForm[X1]]];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(i).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Enter the matrix and vector.  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2", "1", "1", "3", "2"},
                {"1", "2", "2", "1", "1"},
                {"1", "2", "9", "1", "5"},
                {"3", "1", "1", "7", "1"},
                {"2", "1", "5", "1", "8"}
                }], ")"}],
          (MatrixForm[ #]&)]}], " ", ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(-2\)},
              {"4"},
              {"3"},
              {\(-5\)},
              {"1"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars\  = \ {\*"\"\<\!\(x\_1\)\>\"", \*"\
\"\<\!\(x\_2\)\>\"", \*"\"\<\!\(x\_3\)\>\"", \*"\"\<\!\(x\_4\)\>\"", \
\*"\"\<\!\(x\_5\)\>\""};\), "\[IndentingNewLine]", \(Print["\<Solve the \
linear system\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  StyleBox["(ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the Cholesky factorization of matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Cholesky[5];\)\ \), "\n", 
    \(\(Print["\<The Cholesky factorization\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system using our  ",
  StyleBox["ForeSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["[BackSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  subroutines."
}], "Text"],

Cell[TextData[{
  "First, s",
  "olve the lower-triangular system    ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ForeSub[5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y = \>", MatrixForm[Y]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[MatrixForm[L], MatrixForm[Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[L . Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[L . Y \[Equal] B];\)\)}], "Input"],

Cell[TextData[{
  "Second, s",
  "olve the upper-triangular system    ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(BackSub[5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X]];\)\), "\[IndentingNewLine]", 
    \(\(X = MapAll[Simplify, X];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X]\ , "\< = \>", N[MatrixForm[X]]];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Y = N[Y];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U], MatrixForm[X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U . X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[N[MatrixForm[U . X]], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[U . X \[Equal] Y];\)\)}], "Input"],

Cell[TextData[{
  "Therefore ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is the solution to  ",
  StyleBox["LUX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". and hence ",
  StyleBox["A",
    FontWeight->"Bold"],
  StyleBox["X",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "\nAnd we can verify that it is the solution."
}], "Text"],

Cell[BoxData[{
    \(\(X3 = X;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[MapAll[Simplify, X3]]\ , "\< = \>", 
        N[MatrixForm[X3]]];\)\)}], "Input"],

Cell[BoxData[
    \(L . U . X \[Equal] B\)], "Input"],

Cell[BoxData[
    \(A . X \[Equal] B\)], "Input"],

Cell["\<\
We can compare this solution with the solution obtained in parts \
(a) and (b).\
\>", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(X\_3\) = \>\"", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X3]\ , "\< = \>", 
        N[MatrixForm[X3]]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(X\_2\) = \>\"", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X2]\ , "\< = \>", 
        N[MatrixForm[X2]]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(X\_1\) = \>\"", MatrixForm[vars]\ , "\< = \>", 
        MatrixForm[X1]\ , "\< = \>", N[MatrixForm[X1]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Application to Polynomial Curve Fitting\n\nTheorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Least-Squares Polynomial Curve Fitting",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LeastSquaresFittingPolynomial.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " Given the  ",
  Cell[BoxData[
      \(n\)]],
  "  data points  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(x\_1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(y\_1\)}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{\(x\_2\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(y\_2\)}], ")"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"(", 
          RowBox[{\(x\_n\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(y\_n\)}], ")"}]}]]],
  ",  the ",
  StyleBox["least squares polynomial of degree  m  of the form  ",
    FontFamily->"Times New Roman"],
  "\n\n\t",
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(P\_m\) \((x)\)\  = \ \(c\_1\  + \ 
              c\_2\ x + \ \(c\_3\) x\^2\  + \  ... \) + \(c\_m\) 
            x\^\(m - 1\)\  + \ \(c\_\(m + 1\)\) x\^m\)]],
  " \n\n",
  StyleBox["that fits the n data points ",
    FontFamily->"Times New Roman"],
  "is obtained by solving the following linear system\n \n\n\t\t",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {
              "n", \(\[Sum]\+\(i = 1\)\%n x\_i\), \(\[Sum]\+\(i = 1\)\%n x\_i\
\^2\), "\[CenterEllipsis]", \(\[Sum]\+\(i = 1\)\%n x\_i\^m\)},
            {\(\[Sum]\+\(i = 1\)\%n x\_i\), \(\[Sum]\+\(i = 1\)\%n x\_i\^2\), \
\(\[Sum]\+\(i = 1\)\%n x\_i\^3\), 
              "\[CenterEllipsis]", \(\[Sum]\+\(i = 1\)\%n x\_i\^\(m + 1\)\)},
            {\(\[Sum]\+\(i = 1\)\%n x\_i\^2\), \(\[Sum]\+\(i = 1\)\%n x\_i\^3\
\), \(\[Sum]\+\(i = 1\)\%n x\_i\^4\), 
              "\[CenterEllipsis]", \(\[Sum]\+\(i = 1\)\%n x\_i\^\(m + 2\)\)},
            {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
              "\[VerticalEllipsis]", "\[DescendingEllipsis]", 
              "\[VerticalEllipsis]"},
            {\(\[Sum]\+\(i = 1\)\%n x\_i\^m\), \(\[Sum]\+\(i = 1\)\%n \
x\_i\^\(m + 1\)\), \(\[Sum]\+\(i = 1\)\%n x\_i\^\(m + 2\)\), 
              "\[CenterEllipsis]", \(\[Sum]\+\(i = 1\)\%n x\_i\^\(2  m\)\)}
            }], ")"}]]],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\(\ \)\(c\_1\)\)},
              {\(\(\ \)\(c\_2\)\)},
              {\(\(\ \)\(c\_3\)\)},
              {"\[VerticalEllipsis]"},
              {\(\(\ \)\(c\_\(m + 1\)\)\)}
              }], ")"}], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(\ \)\(\[Sum]\+\(i = 1\)\%n y\_i\)\)},
              {\(\(\ \)\(\[Sum]\+\(i = 1\)\%n\( x\_i\) y\_i\)\)},
              {\(\(\ \)\(\[Sum]\+\(i = 1\)\%n\( x\_i\^2\) y\_i\)\)},
              {"\[VerticalEllipsis]"},
              {\(\[Sum]\+\(i = 1\)\%n\( x\_i\^m\) y\_i\)}
              }], ")"}]}]]],
  "  \n\nfor the m+1 coefficients ",
  Cell[BoxData[
      \({c\_1, c\_2,  ... , c\_m, c\_\(m + 1\)}\)]],
  ".  These equations are referred to as the \"normal equations\"."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Least Squares Polynomials",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LeastSqPolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Least Squares Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LeastSqPolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the \"least squares cubic\" that for the four data points",
  Cell[BoxData[
      RowBox[{"  ", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "12"}], ")"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{"(", 
            RowBox[{"1", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "3"}], ")"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{"(", 
            RowBox[{"2", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "3"}], ")"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{"(", 
            RowBox[{"3", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "7"}], ")"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{"(", 
            RowBox[{"4", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "9"}], ")"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            RowBox[{"(", 
              RowBox[{"5", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "2"}], ")"}]}]}]}]]],
  ".   "
}], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["(a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Write down the linear system ",
  StyleBox["AC",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " to be solved."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(XY\  = \ {{0, 12}, {1, 3}, {2, 3}, {3, 7}, {4, 9}, {5, 2}};\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(n = 6;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(x = \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(y = \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\);\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {
                "n", \(\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\), \
\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\^2\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^3\)},
              {\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^2\), \(\[Sum]\+\(k = \
1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^3\), \(\
\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^4\)},
              {\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\^2\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^3\), \(\[Sum]\+\(k = \
1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^4\), \(\
\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^5\)},
              {\(\[Sum]\+\(k = 1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\^3\), \(\[Sum]\+\(k = 1\)\%n x\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^4\), \(\[Sum]\+\(k = \
1\)\%n x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^5\), \(\
\[Sum]\+\(k = 1\)\%n \
x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\^6\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"B", "=", 
          RowBox[{"(", GridBox[{
                {\(\[Sum]\+\(k = 1\)\%n y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)},
                {\(\[Sum]\+\(k = 1\)\%n\( 
                          x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\) 
                      y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)},
                {\(\[Sum]\+\(k = \
1\)\%n\(\((x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\))\)\^\
2\) y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\)},
                {\(\[Sum]\+\(k = \
1\)\%n\(\((x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\))\)\^\
3\) y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\)}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(A1 = 
        A;\), "\[IndentingNewLine]", \(vars = {\*"\"\<\!\(c\_1\)\>\"", \
\*"\"\<\!\(c\_2\)\>\"", \*"\"\<\!\(c\_3\)\>\"", \*"\"\<\!\(c\_4\)\>\""};\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve AC = B\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell[TextData[{
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the Cholesky factorization of matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell["Invoke the subroutine Cholesky.  ", "Text"],

Cell[BoxData[{
    \(\(Cholesky[4];\)\), "\n", 
    \(\(Print["\<L = \>", MatrixForm[\ L]\ ];\)\), "\n", 
    \(\(Print["\<U = \>", MatrixForm[\ U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Cholesky factorization\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Verify the factorization.", "Text"],

Cell[BoxData[{
    \(\(Print["\<The Cholesk factorization\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", 
        MatrixForm[L . U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does A = L U ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[A \[Equal] L . U];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system for the coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  " using our  ",
  StyleBox["ForeSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["[BackSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  subroutines."
}], "Text"],

Cell[TextData[{
  "First, s",
  "olve the lower-triangular system    ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ForeSub[4];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y = \>", MatrixForm[Y]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[MatrixForm[L], MatrixForm[Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[L . Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[L . Y \[Equal] B];\)\)}], "Input"],

Cell[TextData[{
  "Second, s",
  "olve the upper-triangular system    ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(BackSub[4];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[X]\ ];\)\), "\[IndentingNewLine]", 
    \(\(X = Simplify[X];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[X], "\< = \>", \ 
        MatrixForm[N[X]]];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Y = N[Y];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U], MatrixForm[X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U . X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[N[U . X]], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[U . X \[Equal] Y];\)\)}], "Input"],

Cell[TextData[{
  "Therefore ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is the solution to  ",
  StyleBox["LUX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". and hence ",
  StyleBox["A",
    FontWeight->"Bold"],
  StyleBox["X",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "\nAnd we can verify that it is the solution."
}], "Text"],

Cell[BoxData[
    \(L . U . X \[Equal] B\)], "Input"],

Cell[BoxData[
    \(A . X \[Equal] B\)], "Input"],

Cell[TextData[{
  "Now use the solution to ",
  StyleBox["X",
    FontWeight->"Bold"],
  " make the coefficients  ",
  Cell[BoxData[
      \({c\_i}\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(c = Flatten[N[X]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[c]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Construct the polynomial  ",
  StyleBox["p[x]",
    FontFamily->"Courier New"],
  ".  The coefficients are stored in the array  ",
  StyleBox["c",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and the elements are ",
  Cell[BoxData[
      \(c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x];\)\), "\[IndentingNewLine]", 
    \(\(p[
          x_] = \ \[Sum]\+\(i = 1\)\%4\( 
                c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
\) x\^\(i - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\)}], "Input"],

Cell[TextData[{
  "Of course we could do all this work in two lines by using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in  ",
  Cell[BoxData[
      StyleBox[\(Fit[XY, {1, x, x\^2, x\^3}, x]\),
        FontWeight->"Bold"]]],
  "  procedure."
}], "Text"],

Cell[BoxData[{
    \(\(q[x_] = Fit[XY, {1, x, x\^2, x\^3}, x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nWe can graph the polynomial, this is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[p[x], {x, 0, 5}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, dots, PlotRange \[Rule] {{0, 5}, {0, 12}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The `least-squares` polynomial\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Points = \>", XY];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Application to Continuous Least Squares Approximation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe continuous least squares approximation to a function  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " on the interval ",
  StyleBox["[0,1]",
    FontFamily->"Courier New"],
  " for the set of functions  ",
  Cell[BoxData[
      \({\(u\_i\) \((x)\)}\_\(i = 1\)\%n\)]],
  "  can solved by using the normal equations\n\n(1)\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(j = 1\)\%n\( c\_i\) \[LeftAngleBracket]u\_i, 
              u\_j\[RightAngleBracket]\  = \ \[LeftAngleBracket]f, 
          u\_i\[RightAngleBracket]\)]],
  "   for   ",
  Cell[BoxData[
      \(1 \[LessEqual] i \[LessEqual] n\)]],
  ". \n\nWhere the inner product is ",
  Cell[BoxData[
      \(\[LeftAngleBracket]f, g\[RightAngleBracket]\  = \ \[Integral]\_0\%1\ 
          f \((x)\) g \((x)\) \[DifferentialD]x\)]],
  ".  Solve the linear system (1) for the coefficients ",
  Cell[BoxData[
      \({c\_i}\_\(i = 1\)\%n\)]],
  " and construct the approximation function \n\t\t\n\t\t",
  Cell[BoxData[
      \(F[x] = \ \[Sum]\+\(i = 1\)\%n\( c\_i\) \(u\_i\) \((x)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Gram Matrix",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GramMatrix.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The Gram matrix ",
  StyleBox["G",
    FontWeight->"Bold"],
  " is a matrix of inner products where the elements are  ",
  Cell[BoxData[
      \(G\_\(i, j\) = \[LeftAngleBracket]u\_i, u\_j\[RightAngleBracket]\)]],
  ".  \n\n\tThe case when the set of functions is  ",
  Cell[BoxData[
      RowBox[{\({\(u\_i\) \((x)\)}\_\(i = 1\)\%n\), " ", "=", 
        RowBox[{"{", 
          RowBox[{"1", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\^2\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\^\(n - 2\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\^\(n - 1\)\)}], "}"}]}]]],
  "  will produce the Hilbert matrix.  Since we require the computation to be \
as exact as possible and an exact formula is known for the inverse of the \
Hilbert matrix, this is an example where an inverse matrix comes in handy. "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the continuous least squares polynomial of degree ",
  StyleBox["n=4",
    FontFamily->"Courier New"],
  " that approximates the function  ",
  Cell[BoxData[
      \(f[x] = Cos[x]\)]],
  "  over the interval  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The set of functions is ",
  Cell[BoxData[
      \({\(u\_i\) \((x)\)}\_\(i = 1\)\%5\  = {1, x, x\^2, x\^3, x\^4}\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(u[i_, x_] = x\^\(i - 1\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_i\)(x) = \>\"", u[i, x]];\)\)}], "Input"],

Cell[TextData[{
  "The inner product ",
  Cell[BoxData[
      \(\[LeftAngleBracket]u\_i, 
          u\_j\[RightAngleBracket]\  = \ \[Integral]\_0\%1\ \ \(u\_i\) \
\((x)\) \(u\_j\) \((x)\) \[DifferentialD]x\)]]
}], "Text"],

Cell[BoxData[{
    \(\(val = \[Integral]\_0\%1\( 
                x\^\(i - 1\)\) \(x\^\(j - 
                  1\)\) \[DifferentialD]x;\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(u\_i\),\!\(u\_j\)\
\[RightAngleBracket] = \!\(\[Integral]\_0\%1\)  \!\(u\_i\)(x)\!\(u\_j\)(x)\
\[DifferentialD]x = \>\"", val];\)\)}], "Input"],

Cell[TextData[{
  "Since  ",
  StyleBox["i",
    FontFamily->"Courier New"],
  "  and  ",
  StyleBox["j",
    FontFamily->"Courier New"],
  "  are positive integers, this can be simplified with the command"
}], "Text"],

Cell[BoxData[{
    \(\(val = 
        Simplify[val, 
          And[{i, j} \[Element] Integers, 
            i + j > 1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(u\_i\),\!\(u\_j\)\
\[RightAngleBracket] = \!\(\[Integral]\_0\%1\)  \!\(u\_i\)(x)\!\(u\_j\)(x)\
\[DifferentialD]x = \>\"", val];\)\)}], "Input"],

Cell[TextData[{
  "Therefore, the Gram matrix ",
  StyleBox["G",
    FontWeight->"Bold"],
  " is the 5\[Times]5 Hilbert matrix, which is a ",
  "real, symmetric and positive definite matrix.  "
}], "Text"],

Cell[TextData[{
  StyleBox["(a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Form the matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " and vector ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(A = HilbertMatrix[5, 5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = G = \>", MatrixForm[A]];\)\)}], "Input"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[x] = Cos[x]\)]],
  ",  and the set of functions  ",
  Cell[BoxData[
      \({\(u\_i\) \((x)\)}\_\(i = 1\)\%5\  = {1, x, x\^2, x\^3, x\^4}\)]],
  ", and compute ",
  Cell[BoxData[
      \(\[LeftAngleBracket]f, u\_i\[RightAngleBracket]\)]],
  "  for   ",
  Cell[BoxData[
      \(1 \[LessEqual] i \[LessEqual] n\)]],
  ", and write down the linear system ",
  StyleBox["AC",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  " to be solved."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f[x_] = Cos[x];\)\), "\n", 
    \(\(F = {1, x, x\^2, x\^3, x\^4};\)\), "\n", 
    \(\(B = 
        N[\[Integral]\_0\%1\ 
            f[x] F \[DifferentialD]x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<B = Y = \>", MatrixForm[B]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[c];\)\), "\[IndentingNewLine]", 
    \(\(vars = {\*"\"\<\!\(c\_1\)\>\"", \*"\"\<\!\(c\_2\)\>\"", \
\*"\"\<\!\(c\_3\)\>\"", \*"\"\<\!\(c\_4\)\>\"", \*"\"\<\!\(c\_5\)\>\""};\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\), "\[IndentingNewLine]", 
    \(Print[MatrixForm[A], MatrixForm[vars], "\<   \>", 
      MatrixForm[B]]\)}], "Input"]
}, Open  ]],

Cell[TextData[{
  StyleBox["(b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the Cholesky factorization of matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell["Invoke the subroutine Cholesky.  ", "Text"],

Cell[BoxData[{
    \(\(Cholesky[5];\)\), "\n", 
    \(\(Print["\<L = \>", MatrixForm[\ L]\ ];\)\), "\n", 
    \(\(Print["\<U = \>", MatrixForm[\ U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Cholesky factorization\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Verify the factorization.", "Text"],

Cell[BoxData[{
    \(\(Print["\<The Cholesk factorization\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", MatrixForm[L]\ , 
        MatrixForm[U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[\ A], "\< = \>", 
        MatrixForm[L . U]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does A = L U ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[A \[Equal] L . U];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["(c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Solve the linear system for the coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  " using our  ",
  StyleBox["ForeSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and  ",
  StyleBox["[BackSub[n]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  subroutines."
}], "Text"],

Cell[TextData[{
  "First, s",
  "olve the lower-triangular system    ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(ForeSub[5];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Y = \>", MatrixForm[Y]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["LY",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[MatrixForm[L], MatrixForm[Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[L . Y], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[L . Y \[Equal] B];\)\)}], "Input"],

Cell[TextData[{
  "Second, s",
  "olve the upper-triangular system    ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(BackSub[5]\), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[X]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Verify that  ",
  StyleBox["UX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Y",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Y = N[Y];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U], MatrixForm[X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[U . X], "\< = \>", 
        MatrixForm[Y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[U . X \[Equal] Y];\)\)}], "Input"],

Cell[TextData[{
  "Therefore ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is the solution to  ",
  StyleBox["LUX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ". and hence ",
  StyleBox["A",
    FontWeight->"Bold"],
  StyleBox["X",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  "\nAnd we can verify that it is the solution."
}], "Text"],

Cell[BoxData[
    \(L . U . X \[Equal] B\)], "Input"],

Cell[BoxData[
    \(A . X \[Equal] B\)], "Input"],

Cell[TextData[{
  "Now use the solution to ",
  StyleBox["X",
    FontWeight->"Bold"],
  " make the coefficients  ",
  Cell[BoxData[
      \({c\_i}\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(c = Flatten[N[X]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[c]];\)\ \)}], "Input"],

Cell[TextData[{
  "Solve the linear system for the coefficients ",
  Cell[BoxData[
      StyleBox[\({c\_i}\),
        FontWeight->"Bold"]]],
  " using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], "=", 
        SuperscriptBox[
          StyleBox["G",
            FontWeight->"Bold"], \(-1\)]}]]],
  " and the computation  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["C",
          FontWeight->"Bold"], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox["G",
                FontWeight->"Bold"], \(-1\)], 
            StyleBox["Y",
              FontWeight->"Bold"]}], " ", "=", " ", 
          StyleBox["MY",
            FontWeight->"Bold"]}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Construct the polynomial  ",
  StyleBox["p[x]",
    FontFamily->"Courier New"],
  ".  The coefficients are stored in the array  ",
  StyleBox["c",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and the elements are ",
  Cell[BoxData[
      \(c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(p[
          x_] = \ \[Sum]\+\(i = 1\)\%5\( 
                c\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\
\) x\^\(i - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nWe can graph the polynomial, this is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], p[x]}, {x, \(-2.0\), 2.5}, 
        PlotRange \[Rule] {{\(-2.0\), 2.5}, {\(-0.8\), 1.0}}, 
        PlotStyle \[Rule] {Magenta, Blue}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Continuous least squares polynomial\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x], p[x]}, {x, 0, 1}, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        PlotStyle \[Rule] {Magenta, Blue}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Continuous least squares polynomial\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{f[x] - p[x]}, {x, 0, 1}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Red];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The error\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<e[x] = f[x]-p[x] = \>", f[x] - p[x]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Doolittle's Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/numerical/linear/dol/dol.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Doolittle's Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/linear/dol/dol.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorizations",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CholeskyBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cholesky, Doolittle and Crout Factorizations",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CholeskyBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 302, 10, 37, "Text"],
Cell[2081, 65, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3560, 117, 2025, 71, 163, "Text"],
Cell[5588, 190, 2683, 94, 128, "Text"],
Cell[8274, 286, 605, 20, 33, "Text"],
Cell[8882, 308, 8504, 232, 227, "Text"],
Cell[17389, 542, 659, 20, 33, "Text"],
Cell[18051, 564, 213, 9, 33, "Text"],
Cell[18267, 575, 10782, 291, 229, "Text"],
Cell[29052, 868, 659, 20, 33, "Text"],
Cell[29714, 890, 139, 2, 33, "Text"],
Cell[29856, 894, 1364, 27, 262, "Input"],
Cell[31223, 923, 135, 2, 33, "Text"],
Cell[31361, 927, 1725, 33, 288, "Input"],
Cell[33089, 962, 149, 2, 33, "Text"],
Cell[33241, 966, 873, 16, 179, "Input"],
Cell[34117, 984, 147, 2, 33, "Text"],
Cell[34267, 988, 926, 17, 179, "Input"],
Cell[35196, 1007, 1427, 50, 223, "Text"],
Cell[36626, 1059, 19271, 493, 362, "Text"],
Cell[55900, 1554, 659, 20, 33, "Text"],
Cell[56562, 1576, 500, 16, 53, "Text"],
Cell[57065, 1594, 645, 19, 33, "Text"],
Cell[57713, 1615, 152, 2, 33, "Text"],
Cell[57868, 1619, 1094, 21, 225, "Input"],
Cell[58965, 1642, 2196, 76, 277, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[61186, 1722, 105, 2, 33, "Text"],
Cell[61294, 1726, 33, 0, 33, "Text"],
Cell[61330, 1728, 405, 11, 89, "Input"],
Cell[61738, 1741, 50, 0, 33, "Text"],
Cell[61791, 1743, 488, 10, 170, "Input"],
Cell[62282, 1755, 41, 0, 33, "Text"],
Cell[62326, 1757, 427, 8, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[62790, 1770, 105, 2, 30, "Text"],
Cell[62898, 1774, 33, 0, 33, "Text"],
Cell[62934, 1776, 405, 11, 89, "Input"],
Cell[63342, 1789, 46, 0, 33, "Text"],
Cell[63391, 1791, 388, 7, 130, "Input"],
Cell[63782, 1800, 41, 0, 33, "Text"],
Cell[63826, 1802, 421, 7, 110, "Input"],
Cell[64250, 1811, 263, 9, 33, "Text"],
Cell[64516, 1822, 193, 6, 33, "Text"],
Cell[64712, 1830, 199, 4, 50, "Input"],
Cell[64914, 1836, 333, 7, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[65284, 1848, 105, 2, 30, "Text"],
Cell[65392, 1852, 33, 0, 33, "Text"],
Cell[65428, 1854, 405, 11, 89, "Input"],
Cell[65836, 1867, 49, 0, 33, "Text"],
Cell[65888, 1869, 394, 7, 130, "Input"],
Cell[66285, 1878, 41, 0, 33, "Text"],
Cell[66329, 1880, 423, 7, 110, "Input"],
Cell[66755, 1889, 194, 8, 33, "Text"],
Cell[66952, 1899, 265, 10, 33, "Text"]
}, Closed]],
Cell[67232, 1912, 1867, 67, 162, "Text"],

Cell[CellGroupData[{
Cell[69124, 1983, 105, 2, 33, "Text"],
Cell[69232, 1987, 142, 5, 33, "Text"],
Cell[69377, 1994, 987, 25, 249, "Input"],
Cell[70367, 2021, 209, 8, 33, "Text"],
Cell[70579, 2031, 237, 5, 70, "Input"],
Cell[70819, 2038, 344, 13, 34, "Text"],
Cell[71166, 2053, 235, 12, 33, "Text"],
Cell[71404, 2067, 123, 2, 50, "Input"],
Cell[71530, 2071, 145, 8, 33, "Text"],
Cell[71678, 2081, 270, 5, 70, "Input"],
Cell[71951, 2088, 236, 12, 33, "Text"],
Cell[72190, 2102, 192, 3, 50, "Input"],
Cell[72385, 2107, 146, 8, 33, "Text"],
Cell[72534, 2117, 418, 8, 110, "Input"],
Cell[72955, 2127, 403, 19, 52, "Text"],
Cell[73361, 2148, 190, 3, 50, "Input"],
Cell[73554, 2153, 53, 1, 30, "Input"],
Cell[73610, 2156, 49, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[73696, 2162, 105, 2, 30, "Text"],
Cell[73804, 2166, 142, 5, 33, "Text"],
Cell[73949, 2173, 987, 25, 249, "Input"],
Cell[74939, 2200, 205, 8, 33, "Text"],
Cell[75147, 2210, 227, 4, 70, "Input"],
Cell[75377, 2216, 344, 13, 34, "Text"],
Cell[75724, 2231, 235, 12, 33, "Text"],
Cell[75962, 2245, 123, 2, 50, "Input"],
Cell[76088, 2249, 145, 8, 33, "Text"],
Cell[76236, 2259, 270, 5, 70, "Input"],
Cell[76509, 2266, 236, 12, 33, "Text"],
Cell[76748, 2280, 192, 3, 50, "Input"],
Cell[76943, 2285, 146, 8, 33, "Text"],
Cell[77092, 2295, 418, 8, 110, "Input"],
Cell[77513, 2305, 403, 19, 52, "Text"],
Cell[77919, 2326, 190, 3, 50, "Input"],
Cell[78112, 2331, 53, 1, 30, "Input"],
Cell[78168, 2334, 49, 1, 30, "Input"],
Cell[78220, 2337, 94, 3, 33, "Text"],
Cell[78317, 2342, 328, 5, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[78682, 2352, 105, 2, 30, "Text"],
Cell[78790, 2356, 142, 5, 33, "Text"],
Cell[78935, 2363, 987, 25, 249, "Input"],
Cell[79925, 2390, 208, 8, 33, "Text"],
Cell[80136, 2400, 235, 5, 70, "Input"],
Cell[80374, 2407, 344, 13, 34, "Text"],
Cell[80721, 2422, 235, 12, 33, "Text"],
Cell[80959, 2436, 123, 2, 50, "Input"],
Cell[81085, 2440, 145, 8, 33, "Text"],
Cell[81233, 2450, 270, 5, 70, "Input"],
Cell[81506, 2457, 236, 12, 33, "Text"],
Cell[81745, 2471, 365, 6, 90, "Input"],
Cell[82113, 2479, 146, 8, 33, "Text"],
Cell[82262, 2489, 418, 8, 110, "Input"],
Cell[82683, 2499, 403, 19, 52, "Text"],
Cell[83089, 2520, 217, 4, 50, "Input"],
Cell[83309, 2526, 53, 1, 30, "Input"],
Cell[83365, 2529, 49, 1, 30, "Input"],
Cell[83417, 2532, 103, 3, 33, "Text"],
Cell[83523, 2537, 496, 8, 70, "Input"]
}, Closed]],
Cell[84034, 2548, 4878, 128, 331, "Text"],
Cell[88915, 2678, 636, 21, 33, "Text"],
Cell[89554, 2701, 4945, 137, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[94524, 2842, 101, 2, 33, "Text"],
Cell[94628, 2846, 252, 11, 33, "Text"],
Cell[94883, 2859, 3276, 60, 392, "Input"],
Cell[98162, 2921, 207, 8, 33, "Text"],
Cell[98372, 2931, 49, 0, 33, "Text"],
Cell[98424, 2933, 394, 7, 130, "Input"],
Cell[98821, 2942, 41, 0, 33, "Text"],
Cell[98865, 2944, 423, 7, 110, "Input"],
Cell[99291, 2953, 444, 17, 34, "Text"],
Cell[99738, 2972, 235, 12, 33, "Text"],
Cell[99976, 2986, 123, 2, 50, "Input"],
Cell[100102, 2990, 145, 8, 33, "Text"],
Cell[100250, 3000, 270, 5, 70, "Input"],
Cell[100523, 3007, 236, 12, 33, "Text"],
Cell[100762, 3021, 288, 5, 90, "Input"],
Cell[101053, 3028, 146, 8, 33, "Text"],
Cell[101202, 3038, 418, 8, 110, "Input"],
Cell[101623, 3048, 403, 19, 52, "Text"],
Cell[102029, 3069, 53, 1, 30, "Input"],
Cell[102085, 3072, 49, 1, 30, "Input"],
Cell[102137, 3075, 170, 8, 33, "Text"],
Cell[102310, 3085, 149, 2, 50, "Input"],
Cell[102462, 3089, 439, 15, 34, "Text"],
Cell[102904, 3106, 293, 6, 95, "Input"],
Cell[103200, 3114, 277, 9, 33, "Text"],
Cell[103480, 3125, 143, 2, 51, "Input"],
Cell[103626, 3129, 173, 5, 71, "Text"],
Cell[103802, 3136, 738, 14, 150, "Input"]
}, Closed]],
Cell[104555, 3153, 1201, 32, 183, "Text"],
Cell[105759, 3187, 2596, 67, 90, "Text"],
Cell[108358, 3256, 429, 16, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[108812, 3276, 101, 2, 33, "Text"],
Cell[108916, 3280, 156, 5, 33, "Text"],
Cell[109075, 3287, 147, 2, 50, "Input"],
Cell[109225, 3291, 221, 6, 34, "Text"],
Cell[109449, 3299, 352, 6, 76, "Input"],
Cell[109804, 3307, 218, 8, 33, "Text"],
Cell[110025, 3317, 339, 7, 63, "Input"],
Cell[110367, 3326, 205, 6, 33, "Text"],
Cell[110575, 3334, 236, 11, 33, "Text"],
Cell[110814, 3347, 225, 4, 70, "Input"],
Cell[111042, 3353, 545, 20, 33, "Text"],

Cell[CellGroupData[{
Cell[111612, 3377, 273, 6, 105, "Input"],
Cell[111888, 3385, 391, 7, 90, "Input"]
}, Open  ]],
Cell[112294, 3395, 207, 8, 33, "Text"],
Cell[112504, 3405, 49, 0, 33, "Text"],
Cell[112556, 3407, 394, 7, 130, "Input"],
Cell[112953, 3416, 41, 0, 33, "Text"],
Cell[112997, 3418, 423, 7, 110, "Input"],
Cell[113423, 3427, 444, 17, 34, "Text"],
Cell[113870, 3446, 235, 12, 33, "Text"],
Cell[114108, 3460, 123, 2, 50, "Input"],
Cell[114234, 3464, 145, 8, 33, "Text"],
Cell[114382, 3474, 270, 5, 70, "Input"],
Cell[114655, 3481, 236, 12, 33, "Text"],
Cell[114894, 3495, 118, 2, 50, "Input"],
Cell[115015, 3499, 146, 8, 33, "Text"],
Cell[115164, 3509, 317, 6, 90, "Input"],
Cell[115484, 3517, 403, 19, 52, "Text"],
Cell[115890, 3538, 53, 1, 30, "Input"],
Cell[115946, 3541, 49, 1, 30, "Input"],
Cell[115998, 3544, 170, 8, 33, "Text"],
Cell[116171, 3554, 149, 2, 50, "Input"],
Cell[116323, 3558, 756, 28, 33, "Text"],
Cell[117082, 3588, 360, 12, 34, "Text"],
Cell[117445, 3602, 246, 5, 73, "Input"],
Cell[117694, 3609, 173, 5, 71, "Text"],
Cell[117870, 3616, 478, 8, 110, "Input"],
Cell[118351, 3626, 442, 7, 110, "Input"],
Cell[118796, 3635, 342, 5, 90, "Input"]
}, Closed]],
Cell[119153, 3643, 746, 23, 30, "Text"],
Cell[119902, 3668, 158, 3, 35, "Text"],
Cell[120063, 3673, 602, 16, 33, "Text"],
Cell[120668, 3691, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

