(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    161925,       4475]*)
(*NotebookOutlinePosition[    162618,       4499]*)
(*  CellTagsIndexPosition[    162574,       4495]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Kirchoff's Law",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tSolution of linear systems can be applied to resistor network \
circuits.  Kirchoff's voltage law says that the sum of the voltage drops \
around any closed loop in the network must equal zero.  A closed loop has the \
obvious definition: starting at a node, trace a path through the circuit that \
returns you to the original starting node."
}], "Text"],

Cell[TextData[{
  StyleBox["Network #1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tConsider the network consisting of six resistors and two battery, \
shown in the figure below.\n\t\n\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0714286 0.142857 -0.214286 0.142857 [
[ 0 0 0 0 ]
[ 1 .57143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57143 L
0 .57143 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.21429 .5 m
.23077 .5 L
.23626 .47857 L
.24725 .52143 L
.25824 .47857 L
.26923 .52143 L
.28022 .47857 L
.29121 .52143 L
.3022 .47857 L
.31319 .52143 L
.32418 .47857 L
.33516 .52143 L
.34066 .5 L
.35714 .5 L
s
.64286 .5 m
.65934 .5 L
.66484 .47857 L
.67582 .52143 L
.68681 .47857 L
.6978 .52143 L
.70879 .47857 L
.71978 .52143 L
.73077 .47857 L
.74176 .52143 L
.75275 .47857 L
.76374 .52143 L
.76923 .5 L
.78571 .5 L
s
.5 .21429 m
.5 .23077 L
.52143 .23626 L
.47857 .24725 L
.52143 .25824 L
.47857 .26923 L
.52143 .28022 L
.47857 .29121 L
.52143 .3022 L
.47857 .31319 L
.52143 .32418 L
.47857 .33516 L
.5 .34066 L
.5 .35714 L
s
.21429 .07143 m
.23077 .07143 L
.23626 .05 L
.24725 .09286 L
.25824 .05 L
.26923 .09286 L
.28022 .05 L
.29121 .09286 L
.3022 .05 L
.31319 .09286 L
.32418 .05 L
.33516 .09286 L
.34066 .07143 L
.35714 .07143 L
s
.64286 .07143 m
.65934 .07143 L
.66484 .05 L
.67582 .09286 L
.68681 .05 L
.6978 .09286 L
.70879 .05 L
.71978 .09286 L
.73077 .05 L
.74176 .09286 L
.75275 .05 L
.76374 .09286 L
.76923 .07143 L
.78571 .07143 L
s
.92857 .21429 m
.92857 .23077 L
.95 .23626 L
.90714 .24725 L
.95 .25824 L
.90714 .26923 L
.95 .28022 L
.90714 .29121 L
.95 .3022 L
.90714 .31319 L
.95 .32418 L
.90714 .33516 L
.92857 .34066 L
.92857 .35714 L
s
newpath
.28571 .28571 .11429 -45 225 arc
s
newpath
.71429 .28571 .11429 -45 225 arc
s
newpath
1.14286 .28571 .11429 -45 225 arc
s
.36653 .2049 m
.35224 .19062 L
s
% Start of user PostScript
2.06569 2.93431 1.96569 2.83431 MAarrowhead1
% End of user PostScript
.7951 .2049 m
.78081 .19062 L
s
% Start of user PostScript
5.06569 2.93431 4.96569 2.83431 MAarrowhead1
% End of user PostScript
% Start of user PostScript
8.06569 2.93431 7.96569 2.83431 MAarrowhead1
% End of user PostScript
.07143 .27143 m
.07143 .07143 L
s
.92857 .21429 m
.92857 .07143 L
s
.07143 .3 m
.07143 .5 L
.21429 .5 L
s
.92857 .35714 m
.92857 .5 L
.78571 .5 L
s
.35714 .5 m
.64286 .5 L
s
.35714 .07143 m
.64286 .07143 L
s
.07143 .07143 m
.21429 .07143 L
s
.78571 .07143 m
.92857 .07143 L
s
.5 .07143 m
.5 .21429 L
s
.5 .35714 m
.5 .5 L
s
0 .3 m
.14286 .3 L
s
.02 w
.02857 .27143 m
.11429 .27143 L
s
gsave
.28571 .28571 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71429 .28571 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 -0.07143 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28571 .55 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71429 .55 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45 .28571 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.87857 .28571 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28571 .12857 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71429 .12857 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02143 .21429 -68.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.250 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.750 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 164.563},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Y1000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol004Aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo05ioo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo04Ioo`00A7oo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0GWoo00<007ooOol00goo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol0AWoo0013Ool20005Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`1NOol00`00Oomoo`03Ool20005Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`16Ool004=oo`03001oo`0000=oo`03001oo`00
00=oo`03001oo`0000=oo`03001oo`0000Aoo`03001oo`0005moo`8000=oo`03001oo`0000Aoo`03
001oo`0000=oo`03001oo`0000=oo`03001oo`0004Moo`00@goo00<007oo00000goo00<007oo0000
0goo00<007oo00000goo00<007oo000017oo00<007oo0000GWoo00<007oo00000goo00<007oo0000
17oo00<007oo00000goo00<007oo00000goo00<007oo0000Agoo0012Ool01000Oomoo`000goo00<0
07oo00000goo00<007oo00000goo00@007ooOol000=oo`03001oo`0005ioo`03001oo`0000=oo`04
001oogoo0003Ool00`00Ool00003Ool00`00Ool00003Ool00`00Ool00017Ool001Aoobl0009oo`07
001oogooOol007oo00000goo00<007oo00000goo00@007ooOol000=oo`03001oo`00009ooed00003
Ool007oo009oo`04001oogoo0003Ool00`00Ool00003Ool00`00Ool00003Ool00`00Ool00003Ool_
000EOol001Aoo`03001oogoo02moo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000=oo`04
001oogoo0003Ool00`00Ool0000]Ool00`00Oomoo`0^Ool00`00Ool00003Ool01000Oomoo`000goo
00<007oo00000goo00<007oo00000goo00@007ooOol002eoo`03001oogoo01=oo`0057oo00<007oo
Ool0;goo00<007oo00000goo00<007oo00000goo00<007oo00000goo00@007ooOol000=oo`03001o
o`0002eoo`03001oogoo02ioo`03001oo`0000=oo`04001oogoo0003Ool00`00Ool00003Ool00`00
Ool00003Ool00`00Ool0000^Ool00`00Oomoo`0COol001Aoo`03001oogoo02moo`03001oo`0000=o
o`03001oo`0000=oo`03001oo`0000Aoo`03001oo`0000=oo`03001oo`0002eoo`03001oogoo02io
o`03001oo`0000Aoo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0002io
o`03001oogoo01=oo`0057oo00<007ooOol0;goo00<007oo00000goo00<007oo00000goo00<007oo
000017oo00<007oo00000goo0P00;Woo00<007ooOol0;Woo00<007oo000017oo00<007oo00000goo
00<007oo00000goo00<007oo00000goo00<007oo0000;Woo00<007ooOol04goo000DOol00`00Oomo
o`0`Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0/Ool0
0`00Oomoo`0_Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool2000^Ool0
0`00Oomoo`0COol001Aoo`03001oogoo031oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo00=oo`03001oogoo02aoo`03001oogoo02moo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo02eoo`03001oogoo01=oo`0057oo00<0
07ooOol0<7oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol0;7oo00<007ooOol0;goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol0;Goo00<007ooOol04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1h
Ool00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo
00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000DOol00`00Oomoo`0jOol3000kOol0
0`00Oomoo`0kOol2000kOol00`00Oomoo`0COol001Aoo`03001oogoo03eoo`03001oogoo03Qoo`03
001oogoo03Yoo`04001oogoo000jOol00`00Oomoo`0COol001Aoo`03001oogoo03Ioo`<000Aoo`03
001oogoo03Qoo`03001oogoo03Eoo`<0009oo`04001oogoo000jOol00`00Oomoo`0COol001Aoo`03
001oogoo03Moo`03001oogoo00=oo`03001oogoo03Qoo`03001oogoo03Ioo`05001oogooOol00002
Ool00`00Oomoo`0hOol00`00Oomoo`0COol001Aoo`03001oogoo03Moo`04001oogooOol2000kOol0
0`00Oomoo`0fOol01000Oomoogoo0`00>goo00<007ooOol04goo000DOol00`00Oomoo`0gOol01@00
Oomoogoo0000?7oo00<007ooOol0=Woo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol04goo
000DOol00`00Oomoo`0gOol00`00Oomoo`02Ool2000jOol00`00Oomoo`0fOol00`00Oomoo`03Ool2
000jOol00`00Oomoo`0COol001Aoo`03001oogoo03Ioo`<003moo`03001oogoo03Eoo`<0041oo`03
001oogoo01=oo`0057oo00<007ooOol0=goo00@007oo000003eoo`03001oogoo03Ioo`04001oo`00
000nOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`00
57oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000DOol00`00Oomoo`1hOol00`00
Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=o
o`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000DOol00`00Oomoo`1hOol0
0`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qoo`03001oogoo
01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000DOol00`00Oomoo`1h
Ool00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qoo`03001o
ogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000DOol00`00Oomo
o`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qoo`03
001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000DOol00`00
Oomoo`1>Ool00`00Oomoo`0WOol00`00Oomoo`1=Ool00`00Oomoo`0XOol00`00Oomoo`0COol000Mo
o`<000Yoo`03001oogoo04moo`8002Moo`03001oogoo04ioo`8002Qoo`03001oogoo01=oo`0027oo
00<007ooOol02Goo00<007ooOol0Cgoo0`009Woo00<007ooOol0CWoo10009Woo00<007ooOol04goo
0008Ool00`00Oomoo`09Ool00`00Oomoo`1@Ool4000TOol00`00Oomoo`1?Ool4000UOol00`00Oomo
o`0COol0009oo`<000=oo`03001oogoo00Uoo`03001oogoo051oo`D002=oo`03001oogoo04moo`H0
02=oo`03001oogoo01=oo`0000=oo`00Ool00Woo00@007ooOol000]oo`03001oogoo02=oo`8002ao
o`H0025oo`03001oogoo02=oo`03001oogoo02Yoo`H0029oo`03001oogoo01=oo`0000=oo`00Ool0
1Goo00<007ooOol02Goo00<007ooOol08Woo00<007ooOol0;7oo1`0087oo00<007ooOol08Woo00<0
07ooOol0;7oo1`0087oo00<007ooOol04goo00000goo001oo`04Ool2000;Ool00`00Oomoo`0QOol0
0`00Oomoo`0^Ool8000NOol00`00Oomoo`0QOol00`00Oomoo`0]Ool9000NOol00`00Oomoo`0COol0
0003Ool0000000<000ioo`03001oogoo021oo`03001oogoo02moo`T001eoo`03001oogoo021oo`03
001oogoo02moo`T001eoo`03001oogoo01=oo`0000=oo`00Ool00Woo00<007ooOol037oo00<007oo
Ool087oo00<007ooOol0<7oo1`007Woo00<007ooOol087oo00<007ooOol0<7oo1`007Woo00<007oo
Ool04goo0002Ool3000?Ool00`00Oomoo`0OOol00`00Oomoo`0aOol6000OOol00`00Oomoo`0OOol0
0`00Oomoo`0aOol6000OOol00`00Oomoo`0COol001Aoo`03001oogoo01moo`03001oogoo039oo`@0
021oo`03001oogoo01ioo`03001oogoo03=oo`@0021oo`03001oogoo01=oo`0057oo00<007ooOol0
7Woo00<007ooOol0<goo0`0000=oo`00Ool07Woo0P007Woo00<007ooOol0=7oo100087oo0P0057oo
000DOol00`00Oomoo`0NOol00`00Oomoo`0dOol01@00Oomoogoo000087oo0`006goo00<007ooOol0
=Goo00@007ooOol0025oo`<0015oo`0057oo00<007ooOol07Goo00<007ooOol0>Goo00<007ooOol0
87oo0`0067oo00<007ooOol0>Goo00<007ooOol08Goo0`003goo000DOol00`00Oomoo`0MOol00`00
Oomoo`0iOol00`00Oomoo`0LOol4000KOol00`00Oomoo`0iOol00`00Oomoo`0MOol4000BOol001Ao
o`03001oogoo01aoo`03001oogoo03Yoo`03001oogoo01Qoo`@001moo`03001oogoo03Yoo`03001o
ogoo01Qoo`@001Ioo`0057oo00<007ooOol077oo00<007ooOol0>Woo00<007ooOol05Woo0`008Woo
00<007ooOol0>Woo00<007ooOol05Woo0`006Goo000DOol00`00Oomoo`0LOol00`00Oomoo`0kOol0
0`00Oomoo`0HOol4000NOol00`00Oomoo`0kOol00`00Oomoo`0HOol4000EOol001Aoo`03001oogoo
01]oo`03001oogoo03aoo`03001oogoo01aoo`@001Uoo`03001oogoo03aoo`03001oogoo01aoo`@0
015oo`0057oo00<007ooOol06goo00<007ooOol0?Goo00<007ooOol07Woo0`005goo00<007ooOol0
?7oo00<007ooOol07goo0`003goo000DOol00`00Oomoo`0KOol00`00Oomoo`0mOol00`00Oomoo`0J
Ool4000IOol00`00Oomoo`0mOol00`00Oomoo`0KOol4000BOol000Iooah000ioo`03001oogoo01eo
o`<001eoo`03001oogoo00]oo`<000Qoo`@001eoo`03001oogoo01eoo`@001aoo`03001oogoo00io
o`03001oogoo00Ioo`@001Ioo`001Woo7P003Goo00<007ooOol07goo00<007ooOol077oo00<007oo
Ool03Woo00<007ooOol00goo0`0087oo00<007ooOol07Woo00<007oo00007Goo00<007ooOol03Goo
00<007ooOol017oo0`006Goo0006OolN000=Ool00`00Oomoo`0IOol30003Ool00`00Oomoo`0LOol0
0`00Oomoo`07Ool30004Ool00`00Oomoo`06Ool4000LOol00`00Oomoo`0IOol30003Ool00`00Oomo
o`0LOol00`00Oomoo`06Ool30002Ool40008Ool4000EOol000Iooah000eoo`03001oogoo01Yoo`03
001oogoo009oo`03001oogoo01aoo`03001oogoo00Qoo`04001oogooOol2000=Ool4000HOol00`00
Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`0KOol00`00Oomoo`07Ool01`00Oomoogoo001oo`00
00eoo`@0015oo`001Woo7P003Goo00<007ooOol06Woo00<007ooOol00Woo00<007ooOol077oo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol03Woo0`005Woo00<007ooOol06Woo00<007ooOol0
0goo00<007ooOol06goo00<007ooOol01goo00<007ooOol00Woo0P0047oo0`003goo000aOol00`00
Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`08Ool00`00Oomoo`03Ool00`00
Oomoo`09Ool4000IOol00`00Oomoo`0JOol01000Oomoo`000Woo00<007ooOol06goo00<007ooOol0
1goo00<007ooOol00Woo0P0037oo10004Woo000aOol00`00Oomoo`0JOol01000Oomoogoo0P007Woo
00<007ooOol027oo00<007ooOol00`0027oo10007Goo00<007ooOol06Woo00@007ooOomoo`8001io
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`@001Ioo`00<Goo00<007ooOol06Goo
0P008goo00<007ooOol01goo0`002Woo0`0087oo00<007ooOol06Goo0P008goo00<007ooOol01Woo
0`002goo0`006Goo000aOol00`00Oomoo`0JOol00`00Oomoo`0QOol00`00Oomoo`08Ool01000Ool0
00002goo100077oo00<007ooOol06Woo00<007ooOol08Goo00<007ooOol01goo00@007oo000000ao
o`@001Eoo`00<Goo00<007ooOol0?Woo00<007ooOol06goo100067oo00<007ooOol0?Woo00<007oo
Ool06goo10004Goo000Z0007Ool00`00Oomoo`0nOol00`00Oomoo`0OOol2000FOol00`00Oomoo`0n
Ool00`00Oomoo`0OOol2000?Ool001Aoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo025o
o`03001oogoo01aoo`<001Qoo`03001oogoo01Yoo`03001oogoo025oo`03001oogoo01aoo`<0015o
o`0057oo00<007ooOol06Woo00<007ooOol0?Woo00<007ooOol06Goo0`006goo00<007ooOol0?Woo
00<007ooOol06Goo0`0057oo000DOol00`00Oomoo`0KOol00`00Oomoo`0lOol00`00Oomoo`0GOol3
000OOol00`00Oomoo`0lOol00`00Oomoo`0GOol3000GOol001Aoo`03001oogoo01]oo`03001oogoo
03aoo`03001oogoo01Eoo`<0025oo`03001oogoo03aoo`03001oogoo01Eoo`<001Uoo`0057oo00<0
07ooOol077oo00<007ooOol0>goo00<007ooOol067oo10007Goo00<007ooOol0?7oo00<007ooOol0
67oo10005Goo000DOol00`00Oomoo`0LOol00`00Oomoo`0kOol00`00Oomoo`0LOol4000IOol00`00
Oomoo`0kOol00`00Oomoo`0MOol4000AOol001Aoo`03001oogoo01aoo`03001oogoo03]oo`03001o
ogoo01moo`<001Qoo`03001oogoo03Yoo`03001oogoo021oo`<000moo`0057oo00<007ooOol077oo
00<007ooOol0>Woo00<007ooOol077oo10006goo00<007ooOol0>Woo00<007ooOol077oo10004Woo
000DOol00`00Oomoo`0MOol00`00Oomoo`0iOol00`00Oomoo`0HOol4000POol00`00Oomoo`0iOol0
0`00Oomoo`0HOol4000FOol001Aoo`03001oogoo01eoo`03001oogoo03Qoo`03001oogoo01Moo`@0
029oo`03001oogoo03Qoo`03001oogoo01Moo`@001Qoo`0057oo00<007ooOol07Woo00<007ooOol0
=goo00<007ooOol06goo0`007goo00<007ooOol0=goo00<007ooOol077oo0`005Goo000DOol00`00
Oomoo`0NOol00`00Oomoo`0fOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0fOol00`00
Oomoo`0NOol00`00Oomoo`0COol001Aoo`03001oogoo01moo`03001oogoo03Eoo`03001oogoo01io
o`03001oogoo01ioo`03001oogoo03Eoo`03001oogoo01moo`03001oogoo01=oo`0057oo00<007oo
Ool087oo00<007ooOol0<goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0=7oo00<007oo
Ool07goo00<007ooOol04goo000DOol00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0POol0
0`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0POol00`00Oomoo`0COol001Aoo`03001oogoo
025oo`03001oogoo031oo`03001oogoo025oo`03001oogoo025oo`03001oogoo031oo`03001oogoo
025oo`03001oogoo01=oo`0057oo00<007ooOol08Woo00<007ooOol0;Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol0;Woo00<007ooOol08Woo00<007ooOol04goo000DOol00`00Oomoo`0S
Ool00`00Oomoo`0/Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0/Ool00`00Oomoo`0S
Ool00`00Oomoo`0COol001Aoo`03001oogoo02Aoo`03001oogoo02]oo`03001oogoo02=oo`03001o
ogoo02Aoo`03001oogoo02Yoo`03001oogoo02Aoo`03001oogoo01=oo`0057oo00<007ooOol09Goo
00<007ooOol0:Goo00<007ooOol097oo00<007ooOol097oo00<007ooOol0:Goo00<007ooOol09Goo
00<007ooOol04goo000DOol00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0UOol00`00Oomo
o`0UOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomoo`0COol001Aoo`03001oogoo02Moo`03
001oogoo02Aoo`8002Qoo`03001oogoo02Ioo`8002Ioo`03001oogoo02Moo`03001oogoo01=oo`00
57oo00<007ooOol0:7oo0P008Woo0P00:Woo00<007ooOol0:7oo0P008Woo0P00:Woo00<007ooOol0
4goo000DOol00`00Oomoo`0ZOol3000MOol2000/Ool00`00Oomoo`0ZOol2000MOol3000/Ool00`00
Oomoo`0COol001Aoo`03001oogoo02eoo`8001Uoo`8002ioo`03001oogoo02aoo`8001Uoo`8002mo
o`03001oogoo01=oo`0057oo00<007ooOol0;goo0P0057oo0`00<7oo00<007ooOol0;Woo0`0057oo
0P00<Goo00<007ooOol04goo000DOol00`00Oomoo`0aOol2000@Ool2000cOol00`00Oomoo`0aOol2
000@Ool2000cOol00`00Oomoo`0COol001Aoo`03001oogoo03=ooa0003Eoo`03001oogoo03=ooa00
03Eoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000D
Ool00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001o
ogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo
000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03
001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol0
4goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qo
o`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007oo
Ool04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo
07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<0
07ooOol04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001o
ogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo
00<007ooOol04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03
001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0
N7oo00<007ooOol04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Ao
o`03001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007oo
Ool0N7oo00<007ooOol04goo000DOol00`00Oomoo`0]Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0_Ool00`00Oomoo`0/Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool00`00Oomoo`0COol0
01Aoo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo02moo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo031oo`03001oogoo01=oo`0057oo00<007ooOol0;7oo00<0
07oo000017oo0P0017oo0P0017oo0P001Goo0P00<7oo00<007ooOol0;7oo0P0017oo0P001Goo0P00
17oo0P0017oo0P00<Goo00<007ooOol04goo000DOol00`00Oomoo`0/Ool00`00Ool00003Ool00`00
Ool00003Ool00`00Ool00003Ool00`00Ool00004Ool00`00Ool0000`Ool00`00Oomoo`0/Ool20003
Ool00`00Ool00004Ool00`00Ool00003Ool00`00Ool00003Ool00`00Ool0000aOol00`00Oomoo`0C
Ool001Aoo`03001oogoo02aoo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000=oo`03001o
o`0000Aoo`03001oo`00031oo`03001oogoo02]oo`03001oo`0000=oo`03001oo`0000Aoo`03001o
o`0000=oo`03001oo`0000=oo`03001oo`00035oo`03001oogoo01=oo`0057oo00<007ooOol0:goo
00@007ooOol000=oo`03001oo`0000=oo`03001oo`0000=oo`04001oogoo0003Ool00`00Ool0000`
Ool00`00Oomoo`0[Ool00`00Ool00003Ool01000Oomoo`000goo00<007oo00000goo00<007oo0000
0goo00<007oo0000<Goo00<007ooOol04goo000DOol_0003Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007oo0000G0000Woo00@007ooOol0009o
o`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo02l001Eoo`00
AWoo00<007oo00000goo00<007oo00000goo00<007oo00000goo00@007ooOol000=oo`03001oo`00
05ioo`03001oo`0000=oo`04001oogoo0003Ool00`00Ool00003Ool00`00Ool00003Ool01000Oomo
o`00@goo0016Ool00`00Ool00003Ool00`00Ool00003Ool00`00Ool00004Ool00`00Ool00003Ool0
0`00Ool0001NOol00`00Ool00004Ool00`00Ool00003Ool00`00Ool00003Ool00`00Ool00003Ool0
0`00Ool00014Ool004Ioo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000Aoo`03001oo`00
00=oo`03001oo`0005ioo`03001oo`0000Aoo`03001oo`0000=oo`03001oo`0000=oo`03001oo`00
00=oo`03001oo`0004Aoo`00Agoo0P0017oo0P0017oo0P0017oo00<007oo000017oo00<007ooOol0
GWoo0P0017oo00<007oo000017oo0P0017oo0P0017oo0P00A7oo0017Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`1NOol00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`13Ool004Moo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo05ioo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo04=oo`00ogoo8Goo003o
OolQOol0059oo`<007Moo`@0051oo`00Dgoo00<007ooOol0Mgoo00<007oo0000D7oo001=Ool30003
Ool00`00Oomoo`1aOol30004Ool00`00Oomoo`1?Ool004ioo`03001oogoo009oo`03001oogoo079o
o`03001oogoo00Aoo`03001oogoo04ioo`00CWoo00<007ooOol00Woo00<007ooOol0LWoo00<007oo
Ool017oo00<007ooOol0CWoo001>Ool00`00Oomoo`02Ool00`00Oomoo`1bOol01@00Oomoogoo0000
0Woo00<007ooOol0CWoo001>Ool01000Oomoogoo0P00M7oo00<007ooOol00Woo0P00DGoo001=Ool3
001gOol3001FOol004ioo`04001oo`00001fOol01000Ool00000E7oo003oOolQOol00?moob5oo`00
ogoo8Goo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {163.563, 0}} -> {0, 1, 0, 0}}],
  "  "
}], "Text"],

Cell[TextData[{
  "There are two closed loops. When Kirchoff's voltage law is applied, we \
obtain the following linear system of equations.  \n\n\t\t\t",
  Cell[BoxData[GridBox[{
          {\(\((r\_1 + r\_3 + r\_5)\) i\_1\), 
            "-", \(\(r\_3\) 
              i\_2\), \(\(=\)\(\[IndentingNewLine]\)\), \(e\_1\)},
          {\(\(-\ r\_3\) i\_1\), 
            "+", \(\((r\_2 + r\_3 + r\_4 + r\_6)\) i\_2\), "=", "0"}
          }]]]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Kirchoff's Law",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/KirchoffProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Kirchoff's Law",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/KirchoffProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Kirchoff's Law",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/KirchoffProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Kirchoff's Law",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/KirchoffProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the network #1 for the currents  ",
  Cell[BoxData[
      \(i\_1, i\_2\)]],
  "  given the following value for the resistors and battery:  \n\n\t\t",
  Cell[BoxData[{\(r\_1 = 10, r\_2 = 10, r\_3 = 10, r\_4 = 20, r\_5 = 10, 
      r\_6 = 30\), "\[IndentingNewLine]", 
      StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}], "\[IndentingNewLine]", \(e\_1 = 20\)}]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Set up the equations. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {\((r\_1 + r\_3 + r\_5)\), \(-r\_3\)},
              {\(-\ r\_3\), \((r\_2 + r\_3 + r\_4 + r\_6)\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(e\_1\)},
              {"0"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars = {i\_1, 
          i\_2};\), "\[IndentingNewLine]", \(Print["\<Solve the linear system\
\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell["Make the substitutions for the resistors and batteries.  ", "Text"],

Cell[BoxData[{
    \(\(a = 
        ReplaceAll[
          A, {r\_1 \[Rule] 10, r\_2 \[Rule] 10, r\_3 \[Rule] 10, 
            r\_4 \[Rule] 20, r\_5 \[Rule] 10, 
            r\_6 \[Rule] 30}];\)\), "\[IndentingNewLine]", 
    \(\(b = ReplaceAll[B, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(vars = {i\_1, i\_2};\)\), "\[IndentingNewLine]", 
    \(\(x = LinearSolve[a, b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the linear system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[a], MatrixForm[vars], "\< = \>", 
        MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[x], "\< = \>", 
        MatrixForm[N[x]]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solution could be found using Cramer's rule. "
}], "Text"],

Cell[BoxData[{
    \(\(a1 = a;\)\), "\[IndentingNewLine]", 
    \(\(a2 = a;\)\), "\[IndentingNewLine]", 
    \(\(a1\_\(\(\[LeftDoubleBracket]\)\(All, 1\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a2\_\(\(\[LeftDoubleBracket]\)\(All, 2\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a1 = ReplaceAll[a1, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a2 = ReplaceAll[a2, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< A = \>", MatrixForm[a]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_1\) = \>\"", 
        MatrixForm[a1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_2\) = \>\"", MatrixForm[a2]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", "\<Det[\>", 
        MatrixForm[a1], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = (\>\"", Det[a1], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", Det[a1]\/Det[a], "\< = \>", 
        N[Det[a1]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", "\<Det[\>", 
        MatrixForm[a2], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = (\>\"", Det[a2], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", Det[a2]\/Det[a], "\< = \>", 
        N[Det[a2]\/Det[a]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the network #1 for the currents  ",
  Cell[BoxData[
      \(i\_1, i\_2\)]],
  "  given the following value for the resistors and battery:  \n\n\t\t",
  Cell[BoxData[{\(r\_1 = 10, r\_2 = 10, r\_3 = 10, r\_4 = 10, r\_5 = 10, 
      r\_6 = 10\), "\[IndentingNewLine]", 
      StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}], "\[IndentingNewLine]", \(e\_1 = 55\)}]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Set up the equations. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {\((r\_1 + r\_3 + r\_5)\), \(-r\_3\)},
              {\(-\ r\_3\), \((r\_2 + r\_3 + r\_4 + r\_6)\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(e\_1\)},
              {"0"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars = {i\_1, 
          i\_2};\), "\[IndentingNewLine]", \(Print["\<Solve the linear system\
\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell["Make the substitutions for the resistors and batteries.  ", "Text"],

Cell[BoxData[{
    \(\(a = 
        ReplaceAll[
          A, {r\_1 \[Rule] 10, r\_2 \[Rule] 10, r\_3 \[Rule] 10, 
            r\_4 \[Rule] 10, r\_5 \[Rule] 10, 
            r\_6 \[Rule] 10}];\)\), "\[IndentingNewLine]", 
    \(\(b = ReplaceAll[B, {e\_1 \[Rule] 55}];\)\), "\[IndentingNewLine]", 
    \(\(vars = {i\_1, i\_2};\)\), "\[IndentingNewLine]", 
    \(\(x = LinearSolve[a, b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the linear system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[a], MatrixForm[vars], "\< = \>", 
        MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[x], "\< = \>", 
        MatrixForm[N[x]]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solution could be found using Cramer's rule. "
}], "Text"],

Cell[BoxData[{
    \(\(a1 = a;\)\), "\[IndentingNewLine]", 
    \(\(a2 = a;\)\), "\[IndentingNewLine]", 
    \(\(a1\_\(\(\[LeftDoubleBracket]\)\(All, 1\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a2\_\(\(\[LeftDoubleBracket]\)\(All, 2\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a1 = ReplaceAll[a1, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a2 = ReplaceAll[a2, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< A = \>", MatrixForm[a]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_1\) = \>\"", 
        MatrixForm[a1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_2\) = \>\"", MatrixForm[a2]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", "\<Det[\>", 
        MatrixForm[a1], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = (\>\"", Det[a1], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", Det[a1]\/Det[a], "\< = \>", 
        N[Det[a1]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", "\<Det[\>", 
        MatrixForm[a2], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = (\>\"", Det[a2], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", Det[a2]\/Det[a], "\< = \>", 
        N[Det[a2]\/Det[a]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Network #2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tConsider the network consisting of nine resistors and one battery, \
shown in the figure below.\n\t\n\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.05 0.1 -0.15 0.1 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.15 .35 m
.16154 .35 L
.16538 .335 L
.17308 .365 L
.18077 .335 L
.18846 .365 L
.19615 .335 L
.20385 .365 L
.21154 .335 L
.21923 .365 L
.22692 .335 L
.23462 .365 L
.23846 .35 L
.25 .35 L
s
.45 .35 m
.46154 .35 L
.46538 .335 L
.47308 .365 L
.48077 .335 L
.48846 .365 L
.49615 .335 L
.50385 .365 L
.51154 .335 L
.51923 .365 L
.52692 .335 L
.53462 .365 L
.53846 .35 L
.55 .35 L
s
.35 .15 m
.35 .16154 L
.365 .16538 L
.335 .17308 L
.365 .18077 L
.335 .18846 L
.365 .19615 L
.335 .20385 L
.365 .21154 L
.335 .21923 L
.365 .22692 L
.335 .23462 L
.35 .23846 L
.35 .25 L
s
.15 .05 m
.16154 .05 L
.16538 .035 L
.17308 .065 L
.18077 .035 L
.18846 .065 L
.19615 .035 L
.20385 .065 L
.21154 .035 L
.21923 .065 L
.22692 .035 L
.23462 .065 L
.23846 .05 L
.25 .05 L
s
.45 .05 m
.46154 .05 L
.46538 .035 L
.47308 .065 L
.48077 .035 L
.48846 .065 L
.49615 .035 L
.50385 .065 L
.51154 .035 L
.51923 .065 L
.52692 .035 L
.53462 .065 L
.53846 .05 L
.55 .05 L
s
.65 .15 m
.65 .16154 L
.665 .16538 L
.635 .17308 L
.665 .18077 L
.635 .18846 L
.665 .19615 L
.635 .20385 L
.665 .21154 L
.635 .21923 L
.665 .22692 L
.635 .23462 L
.65 .23846 L
.65 .25 L
s
.75 .35 m
.76154 .35 L
.76538 .335 L
.77308 .365 L
.78077 .335 L
.78846 .365 L
.79615 .335 L
.80385 .365 L
.81154 .335 L
.81923 .365 L
.82692 .335 L
.83462 .365 L
.83846 .35 L
.85 .35 L
s
.75 .05 m
.76154 .05 L
.76538 .035 L
.77308 .065 L
.78077 .035 L
.78846 .065 L
.79615 .035 L
.80385 .065 L
.81154 .035 L
.81923 .065 L
.82692 .035 L
.83462 .065 L
.83846 .05 L
.85 .05 L
s
.95 .15 m
.95 .16154 L
.965 .16538 L
.935 .17308 L
.965 .18077 L
.935 .18846 L
.965 .19615 L
.935 .20385 L
.965 .21154 L
.935 .21923 L
.965 .22692 L
.935 .23462 L
.95 .23846 L
.95 .25 L
s
newpath
.2 .2 .08 -45 225 arc
s
newpath
.5 .2 .08 -45 225 arc
s
newpath
.8 .2 .08 -45 225 arc
s
.25657 .14343 m
.24657 .13343 L
s
% Start of user PostScript
2.06569 2.93431 1.96569 2.83431 MAarrowhead1
% End of user PostScript
.55657 .14343 m
.54657 .13343 L
s
% Start of user PostScript
5.06569 2.93431 4.96569 2.83431 MAarrowhead1
% End of user PostScript
.85657 .14343 m
.84657 .13343 L
s
% Start of user PostScript
8.06569 2.93431 7.96569 2.83431 MAarrowhead1
% End of user PostScript
.05 .19 m
.05 .05 L
s
.65 .15 m
.65 .05 L
s
.95 .15 m
.95 .05 L
.85 .05 L
s
.05 .21 m
.05 .35 L
.15 .35 L
s
.65 .25 m
.65 .35 L
.55 .35 L
s
.95 .25 m
.95 .35 L
.85 .35 L
s
.25 .35 m
.45 .35 L
s
.25 .05 m
.45 .05 L
s
.05 .05 m
.15 .05 L
s
.55 .05 m
.65 .05 L
s
.35 .05 m
.35 .15 L
s
.35 .25 m
.35 .35 L
s
.65 .05 m
.75 .05 L
s
.65 .35 m
.75 .35 L
s
0 .21 m
.1 .21 L
s
.02 w
.02 .19 m
.08 .19 L
s
gsave
.2 .2 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .2 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8 .2 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.2 .385 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .385 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.315 .2 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.615 .2 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.2 .09 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .09 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.915 .2 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8 .385 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8 .09 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.015 .15 -68.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.250 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.750 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{461, 184.375},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007=0000^1000`40O003h00OogoocWoo003oOoo>
Ool00?moolioo`00ogoocWoo003oOoo>Ool00?moolioo`00ogoocWoo003oOoo>Ool00?moolioo`00
ogoocWoo003oOoo>Ool00?moolioo`00ogoocWoo003oOoo>Ool00?moolioo`00ogoocWoo001<Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`1[Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`1ZOol0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`1?Ool0
04aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
06]oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
06Yoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
04moo`00Bgoo00<007oo00001Goo0P001Goo0P001Goo0P001Goo0P00Jgoo0P001Goo0P001Goo0P00
1Goo0P001Goo0P00Jgoo00<007oo00001Goo0P001Goo0P001Goo0P001Goo0P00D7oo001;Ool00`00
Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0001[Ool00`00
Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0001ZOol00`00
Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0001@Ool004]o
o`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0006]o
o`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0006Yo
o`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`00051o
o`00Bgoo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo
0000Jgoo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo
0000JWoo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo
0000D7oo001:Ool01@00Oomoogoo00000goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomo
o`000goo00@007ooOol006Uoo`04001oogoo0003Ool01000Oomoo`000goo00@007ooOol000=oo`04
001oogoo0003Ool01000Oomoo`00JGoo00D007ooOomoo`0000=oo`04001oogoo0003Ool01000Oomo
o`000goo00@007ooOol000=oo`04001oogoo001?Ool001Mooc@000=oo`05001oogooOol00002Ool0
1@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05001oogooOol00002Ool01000OomoogooI`00
0goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo00@007ooOol000=oo`03001o
ogoo06L000=oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo00D007ooOomoo`00009oo`05
001oogooOol00002Ool01000Oomoogoo=00067oo000GOol00`00Oomoo`0dOol01000Oomoo`000goo
00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo00D007ooOomoo`00039oo`03001o
ogoo03Aoo`04001oogoo0003Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo0003Ool0
1000Oomoo`00<Woo00<007ooOol0=7oo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`00
0goo00@007ooOol000=oo`05001oogooOol0000bOol00`00Oomoo`0FOol001Moo`03001oogoo03Eo
o`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0003=o
o`03001oogoo03Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Ao
o`03001oo`0003=oo`03001oogoo03Eoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Ao
o`03001oo`0000Aoo`03001oo`0003=oo`03001oogoo01Ioo`005goo00<007ooOol0=Goo00<007oo
000017oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo0000<goo00<007oo
Ool0=7oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo
0000<goo00<007ooOol0=Goo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo
000017oo00<007oo0000<goo00<007ooOol05Woo000GOol00`00Oomoo`0eOol00`00Ool00004Ool0
0`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0000cOol00`00Oomoo`0dOol0
0`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0000cOol0
0`00Oomoo`0eOol00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool0
0`00Ool0000cOol00`00Oomoo`0FOol001Moo`03001oogoo03Eoo`8000Eoo`8000Eoo`8000Eoo`80
00Eoo`03001oo`0003=oo`03001oogoo03Eoo`8000Eoo`8000Eoo`8000Eoo`8000Eoo`8003=oo`03
001oogoo03Eoo`8000Eoo`8000Eoo`8000Eoo`8000Eoo`03001oo`0003=oo`03001oogoo01Ioo`00
5goo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
17oo00<007ooOol0<Woo00<007ooOol0=Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol0=Woo00<007ooOol017oo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol05Woo000GOol00`00
Oomoo`0fOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`0bOol00`00Oomoo`0eOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0bOol00`00Oomoo`0FOol001Moo`03001oogoo08Mo
o`03001oogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007oo
Ool0QWoo00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool0
0`00Oomoo`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo
08Moo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<0
07ooOol05Woo000GOol00`00Oomoo`13Ool00`00Oomoo`11Ool00`00Oomoo`12Ool20012Ool00`00
Oomoo`12Ool20013Ool00`00Oomoo`0FOol001Moo`03001oogoo04=oo`03001oogoo045oo`03001o
ogoo045oo`04001oogoo0011Ool00`00Oomoo`14Ool00`00Oomoo`10Ool00`00Oomoo`0FOol001Mo
o`03001oogoo03eoo`<000Aoo`03001oogoo041oo`03001oogoo03aoo`<0009oo`04001oogoo0011
Ool00`00Oomoo`0mOol30003Ool30011Ool00`00Oomoo`0FOol001Moo`03001oogoo03ioo`03001o
ogoo00=oo`03001oogoo041oo`03001oogoo03eoo`03001oogoo009oo`80049oo`03001oogoo03io
o`05001oogooOol00002Ool00`00Oomoo`0oOol00`00Oomoo`0FOol001Moo`03001oogoo03ioo`03
001oogoo00=oo`03001oogoo041oo`03001oogoo03eoo`05001oogooOol00002Ool00`00Oomoo`0o
Ool00`00Oomoo`0nOol01@00Oomoogoo00000Woo00<007ooOol0?goo00<007ooOol05Woo000GOol0
0`00Oomoo`0nOol01@00Oomoogoo00000Woo00<007ooOol0?goo00<007ooOol0?Goo00D007ooOomo
o`00009oo`03001oogoo03moo`03001oogoo03ioo`05001oogooOol00002Ool00`00Oomoo`0oOol0
0`00Oomoo`0FOol001Moo`03001oogoo03ioo`03001oogoo009oo`<0045oo`03001oogoo03eoo`03
001oogoo009oo`80049oo`03001oogoo03ioo`03001oogoo009oo`80049oo`03001oogoo01Ioo`00
5goo00<007ooOol0?Goo0`00Agoo00<007ooOol0?7oo0`00Agoo00<007ooOol0?Goo0`00Agoo00<0
07ooOol05Woo000GOol00`00Oomoo`0nOol01000Ool00000AGoo00<007ooOol0?Goo00@007oo0000
04Eoo`03001oogoo03ioo`04001oo`000015Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03
001oogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0
QWoo00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00
Oomoo`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Mo
o`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<007oo
Ool05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0FOol0
01Moo`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<0
07ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`27
Ool00`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03001o
ogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo
00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00Oomo
o`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Moo`03
001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<007ooOol0
5Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0FOol001Mo
o`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<007oo
Ool0Egoo00<007ooOol0;Goo00<007ooOol0Egoo00<007ooOol0;7oo00<007ooOol0Egoo00<007oo
Ool0;Goo00<007ooOol05Woo000GOol00`00Oomoo`1HOol2000]Ool00`00Oomoo`1HOol2000/Ool0
0`00Oomoo`1HOol2000]Ool00`00Oomoo`0FOol000Uoo`<000]oo`03001oogoo05Qoo`<002aoo`03
001oogoo05Qoo`<002]oo`03001oogoo05Qoo`@002]oo`03001oogoo01Ioo`002Woo00<007ooOol0
2Woo00<007ooOol0FGoo1000:Woo00<007ooOol0FGoo1000:Goo00<007ooOol0FGoo1000:Woo00<0
07ooOol05Woo0003Ool30004Ool00`00Oomoo`0:Ool00`00Oomoo`1IOol5000YOol00`00Oomoo`1I
Ool5000XOol00`00Oomoo`1IOol6000XOol00`00Oomoo`0FOol0009oo`05001oogooOol00003Ool0
0`00Oomoo`0:Ool00`00Oomoo`0XOol00`00Oomoo`0_Ool6000WOol00`00Oomoo`0XOol00`00Oomo
o`0_Ool6000VOol00`00Oomoo`0XOol00`00Oomoo`0_Ool6000WOol00`00Oomoo`0FOol0009oo`03
001oogoo00Eoo`03001oogoo00Yoo`03001oogoo02Moo`03001oogoo031oo`P002Eoo`03001oogoo
02Moo`03001oogoo031oo`P002Aoo`03001oogoo02Moo`03001oogoo031oo`P002Eoo`03001oogoo
01Ioo`000Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol09Woo00<007ooOol0<Woo2000
97oo00<007ooOol09Woo00<007ooOol0<Woo20008goo00<007ooOol09Woo00<007ooOol0<Woo2@00
8goo00<007ooOol05Woo0002Ool50002Ool2000<Ool00`00Oomoo`0VOol00`00Oomoo`0cOol9000R
Ool00`00Oomoo`0UOol00`00Oomoo`0dOol9000QOol00`00Oomoo`0VOol00`00Oomoo`0cOol9000R
Ool00`00Oomoo`0FOol0009oo`05001oogooOol0000@Ool00`00Oomoo`0UOol00`00Oomoo`0dOol:
000QOol00`00Oomoo`0TOol00`00Oomoo`0eOol:000POol00`00Oomoo`0UOol00`00Oomoo`0dOol;
000POol00`00Oomoo`0FOol000=oo`<0015oo`03001oogoo02Aoo`03001oogoo03Ioo`/001moo`03
001oogoo02Aoo`03001oogoo03Ioo`/001ioo`03001oogoo02Aoo`03001oogoo03Ioo`/001moo`03
001oogoo01Ioo`005goo00<007ooOol08goo00<007ooOol0=goo30007Woo00<007ooOol08goo00<0
07ooOol0=goo30007Goo00<007ooOol08goo00<007ooOol0=goo3@007Goo00<007ooOol05Woo000G
Ool00`00Oomoo`0SOol00`00Oomoo`0hOol=000LOol00`00Oomoo`0ROol00`00Oomoo`0iOol=000K
Ool00`00Oomoo`0SOol00`00Oomoo`0hOol>000KOol00`00Oomoo`0FOol001Moo`03001oogoo029o
o`03001oogoo03Uoo`h001]oo`8002=oo`03001oogoo03Uoo`h001Yoo`8002=oo`03001oogoo03Uo
o`l001Yoo`8001Moo`005goo00<007ooOol08Woo00<007ooOol0>Woo30007Woo10007Woo00<007oo
Ool0>goo30007Goo10007goo00<007ooOol0>Woo3@007Goo10004goo000GOol00`00Oomoo`0QOol0
0`00Oomoo`0lOol:000ROol3000LOol00`00Oomoo`0lOol:000QOol3000MOol00`00Oomoo`0kOol;
000QOol3000AOol001Moo`03001oogoo021oo`03001oogoo03eoo`T001ioo`D001ioo`03001oogoo
03eoo`T001eoo`D001moo`03001oogoo03aoo`X001eoo`D001Aoo`005goo00<007ooOol087oo00<0
07ooOol0?Woo1`006goo10008goo00<007ooOol0?Woo1`006Woo100097oo00<007ooOol0?Goo2000
6Woo10006Goo000GOol00`00Oomoo`0OOol00`00Oomoo`0oOol6000IOol3000VOol00`00Oomoo`0o
Ool6000HOol3000WOol00`00Oomoo`0nOol6000IOol3000MOol001Moo`03001oogoo01moo`03001o
ogoo041oo`@001aoo`@002=oo`03001oogoo041oo`@001]oo`@002Aoo`03001oogoo03moo`@001ao
o`@001Yoo`005goo00<007ooOol07goo00<007ooOol0@7oo100087oo0`007goo00<007ooOol0@Goo
10007goo0`0087oo00<007ooOol0@7oo100087oo0`005goo000GOol00`00Oomoo`0OOol00`00Oomo
o`11Ool00`00Ool0000SOol4000KOol00`00Oomoo`12Ool00`00Ool0000ROol4000LOol00`00Oomo
o`11Ool00`00Ool0000SOol4000COol000EoobD000moo`03001oogoo04=oo`03001oogoo02Eoo`80
01Uoo`03001oogoo04Aoo`03001oogoo02Aoo`8001Yoo`03001oogoo04=oo`03001oogoo02Eoo`80
015oo`001Goo9@003Woo00<007ooOol0AGoo00<007ooOol087oo10006goo00<007ooOol0A7oo00<0
07ooOol087oo10006goo00<007ooOol0AGoo00<007ooOol087oo10004goo0005OolU000>Ool00`00
Oomoo`15Ool00`00Oomoo`0MOol3000OOol00`00Oomoo`14Ool00`00Oomoo`0MOol3000OOol00`00
Oomoo`15Ool00`00Oomoo`0MOol3000GOol000EoobD000ioo`03001oogoo025oo`<0025oo`03001o
ogoo00moo`03001oogoo00Moo`@0029oo`03001oogoo021oo`@0025oo`03001oogoo00eoo`<000Qo
o`@0029oo`03001oogoo021oo`<0029oo`03001oogoo00ioo`8000Uoo`@001Yoo`001Goo9@003Woo
00<007ooOol08Woo00<007ooOol087oo00<007ooOol03goo00<007ooOol01Goo0`0097oo00<007oo
Ool08Woo00<007oo00008Goo00<007ooOol047oo00<007ooOol00goo0`009Goo00<007ooOol08goo
00<007ooOol07goo00<007ooOol03Goo00@007ooOol000Ioo`<001eoo`001Goo9@003Woo00<007oo
Ool077oo0`000goo00<007ooOol087oo00<007ooOol02Goo0`0000=oo`0000000P002Goo1@007goo
00<007ooOol07Goo0`000goo00<007ooOol087oo00<007ooOol027oo0`001Goo00<007ooOol01Woo
1@0087oo00<007ooOol077oo0`0017oo00<007ooOol07goo00<007ooOol02Goo0`0000Eoo`00Oomo
o`0000Uoo`D001Qoo`001Goo9@003Goo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol08Goo
00<007ooOol02Goo00H007ooOol007oo000?Ool4000KOol00`00Oomoo`0NOol00`00Oomoo`03Ool0
0`00Oomoo`0OOol00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool4000KOol00`00Oomo
o`0NOol01000Oomoogoo0P008goo00<007ooOol02Goo00@007ooOol0009oo`03001oogoo00aoo`@0
01Aoo`001Goo9@003Goo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol0
2Goo00@007ooOomoo`8001=oo`<001Qoo`03001oogoo01ioo`03001oogoo00=oo`03001oogoo01mo
o`03001oogoo00Uoo`03001oogoo009oo`80019oo`<001Qoo`03001oogoo01ioo`03001oogoo009o
o`03001oogoo025oo`03001oogoo00Uoo`03001oogoo00<001=oo`<0015oo`001Goo9@003Goo00<0
07ooOol07Woo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol02Goo00@007ooOomoo`80011o
o`@001Yoo`03001oogoo01ioo`04001oogoo0002Ool00`00Oomoo`0OOol00`00Oomoo`09Ool00`00
Oomoo`02Ool00`00Oomoo`0>Ool4000JOol00`00Oomoo`0NOol00`00Oomoo`03Ool00`00Oomoo`0P
Ool00`00Oomoo`09Ool01@00Oomoogoo00004Goo10004goo000gOol00`00Oomoo`0NOol01000Oomo
ogoo0P008goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol02goo0`007Woo00<007ooOol0
7Woo00@007ooOomoo`80029oo`03001oogoo00Uoo`03001oogoo00=oo`8000]oo`<001ioo`03001o
ogoo01ioo`03001oogoo00<002=oo`03001oogoo00Uoo`03001oogoo009oo`8000aoo`<001Moo`00
=goo00<007ooOol07Goo0P00:7oo00<007ooOol027oo0`003Goo10008Goo00<007ooOol07Goo0P00
9goo00<007ooOol027oo0`003Goo10008Goo00<007ooOol07Goo0P00:7oo00<007ooOol027oo0`00
3Goo10006Woo000gOol00`00Oomoo`0NOol00`00Oomoo`0VOol00`00Oomoo`09Ool01000Ool00000
2Goo0`0097oo00<007ooOol07Woo00<007ooOol09Goo00<007ooOol02Goo00@007oo000000Uoo`<0
02Eoo`03001oogoo01eoo`03001oogoo02Ioo`03001oogoo00Uoo`04001oo`000009Ool3000MOol0
03Moo`03001oogoo04Ioo`03001oogoo01Yoo`D001moo`03001oogoo04Ioo`03001oogoo01Uoo`D0
021oo`03001oogoo04Ioo`03001oogoo01Uoo`D001Qoo`00;`0027oo00<007ooOol0AWoo00<007oo
Ool07goo10006goo00<007ooOol0AWoo00<007ooOol07Woo100077oo00<007ooOol0AWoo00<007oo
Ool07Woo100057oo000GOol00`00Oomoo`0NOol00`00Oomoo`0MOol00`00Oomoo`0UOol00`00Oomo
o`0SOol3000HOol00`00Oomoo`0NOol00`00Oomoo`0UOol00`00Oomoo`0ROol3000IOol00`00Oomo
o`0MOol00`00Oomoo`0UOol00`00Oomoo`0SOol3000AOol001Moo`03001oogoo01ioo`03001oogoo
04Eoo`03001oogoo021oo`@001Yoo`03001oogoo04Ioo`03001oogoo01moo`@001]oo`03001oogoo
04Eoo`03001oogoo021oo`@001=oo`005goo00<007ooOol07Woo00<007ooOol0AGoo00<007ooOol0
7Goo0`007Woo00<007ooOol0AWoo00<007ooOol077oo0`007goo00<007ooOol0AGoo00<007ooOol0
7Goo0`005goo000GOol00`00Oomoo`0NOol00`00Oomoo`15Ool00`00Oomoo`0IOol4000ROol00`00
Oomoo`14Ool00`00Oomoo`0IOol4000ROol00`00Oomoo`15Ool00`00Oomoo`0IOol4000JOol001Mo
o`03001oogoo01ioo`03001oogoo04Eoo`03001oogoo01Moo`<002Eoo`03001oogoo04Aoo`03001o
ogoo01Moo`<002Eoo`03001oogoo04Eoo`03001oogoo01Moo`<001eoo`005goo00<007ooOol07goo
00<007ooOol0A7oo00<007ooOol06Woo1@008Goo00<007ooOol0@goo00<007ooOol06Woo1@008Goo
00<007ooOol0A7oo00<007ooOol06Woo1@0067oo000GOol00`00Oomoo`0OOol00`00Oomoo`13Ool0
0`00Oomoo`0POol4000MOol00`00Oomoo`12Ool00`00Oomoo`0POol4000MOol00`00Oomoo`13Ool0
0`00Oomoo`0POol4000DOol001Moo`03001oogoo01moo`03001oogoo04=oo`03001oogoo02Aoo`<0
01Yoo`03001oogoo049oo`03001oogoo02Aoo`<001Yoo`03001oogoo04=oo`03001oogoo02Aoo`<0
015oo`005goo00<007ooOol087oo00<007ooOol0@Goo00<007ooOol08Woo10007Goo00<007ooOol0
@7oo00<007ooOol08Woo10007Goo00<007ooOol0@Goo00<007ooOol08Woo10004goo000GOol00`00
Oomoo`0POol00`00Oomoo`11Ool00`00Oomoo`0OOol3000QOol00`00Oomoo`10Ool00`00Oomoo`0O
Ool3000QOol00`00Oomoo`11Ool00`00Oomoo`0OOol3000GOol001Moo`03001oogoo025oo`03001o
ogoo041oo`03001oogoo01]oo`@002Eoo`03001oogoo03moo`03001oogoo01]oo`@002Eoo`03001o
ogoo041oo`03001oogoo01]oo`@001Yoo`005goo00<007ooOol08Goo00<007ooOol0?goo00<007oo
Ool06Woo10009goo00<007ooOol0?Woo00<007ooOol06Woo10009goo00<007ooOol0?goo00<007oo
Ool06Woo100077oo000GOol00`00Oomoo`0ROol00`00Oomoo`0mOol00`00Oomoo`0OOol4000SOol0
0`00Oomoo`0nOol00`00Oomoo`0NOol4000TOol00`00Oomoo`0mOol00`00Oomoo`0OOol4000HOol0
01Moo`03001oogoo029oo`03001oogoo03eoo`03001oogoo029oo`03001oogoo029oo`03001oogoo
03aoo`03001oogoo029oo`03001oogoo029oo`03001oogoo03eoo`03001oogoo029oo`03001oogoo
01Ioo`005goo00<007ooOol08goo00<007ooOol0>goo00<007ooOol08goo00<007ooOol08Woo00<0
07ooOol0?7oo00<007ooOol08Woo00<007ooOol08goo00<007ooOol0>goo00<007ooOol08goo00<0
07ooOol05Woo000GOol00`00Oomoo`0TOol00`00Oomoo`0jOol00`00Oomoo`0SOol00`00Oomoo`0S
Ool00`00Oomoo`0jOol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`0jOol00`00Oomoo`0S
Ool00`00Oomoo`0FOol001Moo`03001oogoo02Aoo`03001oogoo03Uoo`03001oogoo02Aoo`03001o
ogoo02Aoo`03001oogoo03Qoo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo03Uoo`03001o
ogoo02Aoo`03001oogoo01Ioo`005goo00<007ooOol09Goo00<007ooOol0=goo00<007ooOol09Goo
00<007ooOol09Goo00<007ooOol0=goo00<007ooOol097oo00<007ooOol09Goo00<007ooOol0=goo
00<007ooOol09Goo00<007ooOol05Woo000GOol00`00Oomoo`0VOol00`00Oomoo`0eOol00`00Oomo
o`0VOol00`00Oomoo`0UOol00`00Oomoo`0fOol00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomo
o`0eOol00`00Oomoo`0VOol00`00Oomoo`0FOol001Moo`03001oogoo02Moo`03001oogoo03Aoo`03
001oogoo02Ioo`03001oogoo02Ioo`03001oogoo03Aoo`03001oogoo02Ioo`03001oogoo02Moo`03
001oogoo03Aoo`03001oogoo02Ioo`03001oogoo01Ioo`005goo00<007ooOol09goo00<007ooOol0
<goo00<007ooOol09goo00<007ooOol09goo00<007ooOol0<Woo00<007ooOol09goo00<007ooOol0
9goo00<007ooOol0<goo00<007ooOol09goo00<007ooOol05Woo000GOol00`00Oomoo`0XOol00`00
Oomoo`0aOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0`Ool00`00Oomoo`0XOol00`00
Oomoo`0XOol00`00Oomoo`0aOol00`00Oomoo`0XOol00`00Oomoo`0FOol001Moo`03001oogoo02Uo
o`03001oogoo02moo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo02ioo`03001oogoo02Uo
o`03001oogoo02Uoo`03001oogoo02moo`03001oogoo02Uoo`03001oogoo01Ioo`005goo00<007oo
Ool0:Woo00<007ooOol0;Goo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0;7oo00<007oo
Ool0:Woo00<007ooOol0:Woo00<007ooOol0;Goo00<007ooOol0:Woo00<007ooOol05Woo000GOol0
0`00Oomoo`0[Ool2000[Ool2000]Ool00`00Oomoo`0[Ool2000ZOol2000]Ool00`00Oomoo`0[Ool2
000[Ool2000]Ool00`00Oomoo`0FOol001Moo`03001oogoo02eoo`8002Moo`8002moo`03001oogoo
02eoo`03001oogoo02Ioo`03001oogoo02eoo`03001oogoo02eoo`8002Moo`8002moo`03001oogoo
01Ioo`005goo00<007ooOol0;goo00<007ooOol08goo00<007ooOol0;goo00<007ooOol0;Woo00<0
07ooOol097oo00<007ooOol0;Woo00<007ooOol0;goo00<007ooOol08goo00<007ooOol0;goo00<0
07ooOol05Woo000GOol00`00Oomoo`0`Ool2000QOol2000bOol00`00Oomoo`0_Ool2000ROol2000a
Ool00`00Oomoo`0`Ool2000QOol2000bOol00`00Oomoo`0FOol001Moo`03001oogoo039oo`8001eo
o`8003Aoo`03001oogoo035oo`<001aoo`<003=oo`03001oogoo039oo`8001eoo`8003Aoo`03001o
ogoo01Ioo`005goo00<007ooOol0=7oo0`005goo0`00=Woo00<007ooOol0=7oo0P0067oo0P00=Woo
00<007ooOol0=7oo0`005goo0`00=Woo00<007ooOol05Woo000GOol00`00Oomoo`0gOol2000COol2
000iOol00`00Oomoo`0fOol3000BOol3000hOol00`00Oomoo`0gOol2000COol2000iOol00`00Oomo
o`0FOol001Moo`03001oogoo03Uooa<003]oo`03001oogoo03Uooa8003]oo`03001oogoo03Uooa<0
03]oo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<0
07ooOol05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0F
Ool001Moo`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo
00<007ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomo
o`27Ool00`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03
001oogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0
QWoo00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00
Oomoo`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Mo
o`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<007oo
Ool05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0FOol0
01Moo`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<0
07ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`27
Ool00`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03001o
ogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo
00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00Oomo
o`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Moo`03
001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<007ooOol0
5Woo000GOol00`00Oomoo`27Ool00`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0FOol001Mo
o`03001oogoo08Moo`03001oogoo08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<007oo
Ool0Qgoo00<007ooOol0QWoo00<007ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`27Ool0
0`00Oomoo`26Ool00`00Oomoo`27Ool00`00Oomoo`0FOol001Moo`03001oogoo08Moo`03001oogoo
08Ioo`03001oogoo08Moo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol0QWoo00<0
07ooOol0Qgoo00<007ooOol05Woo000GOol00`00Oomoo`0bOol00`00Oomoo`04Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0eOol00`00Oomoo`0b
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0f
Ool00`00Oomoo`0FOol001Moo`03001oogoo039oo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo03Ioo`03001oogoo039oo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo03Eoo`03001oogoo039oo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo03Ioo`03001o
ogoo01Ioo`005goo00<007ooOol0<Goo00<007oo00001Goo0P001Goo0P001Goo0P001Goo0P00=goo
00<007ooOol0<Goo0P001Goo0P001Goo0P001Goo0P001Goo0P00=goo00<007ooOol0<Goo00<007oo
00001Goo0P001Goo0P001Goo0P001Goo0P00=goo00<007ooOol05Woo000GOol00`00Oomoo`0aOol0
0`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0000gOol0
0`00Oomoo`0aOol00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool0
0`00Ool0000fOol00`00Oomoo`0aOol00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool0
0`00Ool00004Ool00`00Ool0000gOol00`00Oomoo`0FOol001Moo`03001oogoo035oo`03001oo`00
00Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0003Moo`03001oogoo
035oo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`00
03Ioo`03001oogoo035oo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oo`00
00Aoo`03001oo`0003Moo`03001oogoo01Ioo`005goo00<007ooOol0<Goo00@007ooOol000=oo`04
001oogoo0003Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo000fOol00`00Oomoo`0a
Ool00`00Ool00003Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomo
o`00=Woo00<007ooOol0<Goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo00@0
07ooOol000=oo`04001oogoo000fOol00`00Oomoo`0FOol001Moo`03001oogoo031oo`05001oogoo
Ool00003Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`00=Woo
00<007ooOol0<7oo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo00@007ooOol0
00=oo`04001oogoo000fOol00`00Oomoo`0`Ool01@00Oomoogoo00000goo00@007ooOol000=oo`04
001oogoo0003Ool01000Oomoo`000goo00@007ooOol003Ioo`03001oogoo01Ioo`005goo=0000goo
00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo
OomW0003Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo
00<007ooOol0I`000goo00@007ooOol000=oo`04001oogoo0003Ool01000Oomoo`000goo00@007oo
Ool000=oo`04001oogooOold000HOol004ioo`04001oogoo0003Ool01000Oomoo`000goo00@007oo
Ool000=oo`04001oogoo0003Ool01@00Oomoogoo0000JGoo00@007ooOol000=oo`04001oogoo0003
Ool01000Oomoo`000goo00@007ooOol000=oo`04001oogoo001YOol01000Oomoo`000goo00@007oo
Ool000=oo`04001oogoo0003Ool01000Oomoo`000goo00D007ooOomoo`0004]oo`00Cgoo00<007oo
000017oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo0000JWoo00<007oo
000017oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo0000Jgoo00<007oo
000017oo00<007oo000017oo00<007oo000017oo00<007oo000017oo00<007oo0000C7oo001?Ool0
0`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0001ZOol0
0`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0001[Ool0
0`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool00004Ool00`00Ool0001<Ool0
04moo`8000Eoo`8000Eoo`8000Eoo`8000Eoo`03001oo`0006]oo`8000Eoo`8000Eoo`8000Eoo`80
00Eoo`8006]oo`8000Eoo`8000Eoo`8000Eoo`8000Eoo`03001oo`0004aoo`00D7oo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol0JWoo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol0Jgoo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol0Bgoo001@Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`1ZOol00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`1[Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`1;Ool00?mo
olioo`00ogoocWoo003oOoo>Ool005eoo`<008Eoo`@008Ioo`<005]oo`00GWoo00<007ooOol0QGoo
00<007oo0000RGoo00<007ooOol0F7oo001GOol30004Ool00`00Oomoo`1oOol30004Ool00`00Oomo
o`20Ool30005Ool00`00Oomoo`1HOol005Qoo`03001oogoo00=oo`03001oogoo081oo`03001oogoo
00Aoo`03001oogoo081oo`03001oogoo009oo`8005]oo`00F7oo00<007ooOol00goo00<007ooOol0
P7oo00<007ooOol017oo00<007ooOol0P7oo00<007ooOol00goo00<007ooOol0FGoo001HOol00`00
Oomoo`03Ool00`00Oomoo`20Ool01@00Oomoogoo00000Woo00<007ooOol0P7oo00<007ooOol017oo
00<007ooOol0F7oo001HOol00`00Oomoo`02Ool20022Ool00`00Oomoo`02Ool20023Ool01000Oomo
ogoo0`00Fgoo001GOol30026Ool30027Ool3001POol005Qoo`04001oo`000025Ool01000Ool00000
QWoo00@007oo000005ioo`00ogoocWoo003oOoo>Ool00?moolioo`00ogoocWoo0000\
\>"],
    ImageRangeCache->{{{0, 460}, {183.375, 0}} -> {0, 1, 0, 0}}],
  "  "
}], "Text"],

Cell[TextData[{
  "There are three loops.  When Kirchoff's voltage law is applied, we obtain \
the following linear system of equations.  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {\(\((r\_1 + r\_4 + r\_7)\) i\_1\), "-", \(\(r\_4\) i\_2\), " ", 
              " ", \(\(=\)\(\[IndentingNewLine]\)\), \(e\_1\)},
            {\(\(-\ r\_4\) i\_1\), 
              "+", \(\((r\_2 + r\_4 + r\_5 + r\_8)\) i\_2\), 
              "-", \(\(r\_5\) i\_3\), \(\(=\)\(\[IndentingNewLine]\)\), "0"},
            {" ", " ", \(\(-\ r\_5\) i\_2\), 
              "+", \(\((r\_3 + r\_5 + r\_6 + r\_9)\) i\_3\), "=", "0"}
            }], "  "}]]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the network #2 for the currents  ",
  Cell[BoxData[
      \(i\_1, i\_2, i\_3\)]],
  "  given the following value for the resistors and battery:  \n\n\t\t",
  Cell[BoxData[{\(r\_1 = 10, r\_2 = 10, r\_3 = 10, r\_4 = 10, r\_5 = 20, 
      r\_6 = 20, r\_7 = 10, r\_8 = 10, r\_9 = 10\), "\[IndentingNewLine]", 
      StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}], "\[IndentingNewLine]", \(e\_1 = 36\)}]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Set up the equations. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {\((r\_1 + r\_4 + r\_7)\), \(-r\_4\), "0"},
              {\(-r\_4\), \(r\_2 + r\_4 + r\_5 + r\_8\), \(-r\_5\)},
              {"0", \(-r\_5\), \(r\_3 + r\_5 + r\_6 + r\_9\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(e\_1\)},
              {"0"},
              {"0"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars = {i\_1, i\_2, 
          i\_3};\), "\[IndentingNewLine]", \(Print["\<Solve the linear system\
\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell["Make the substitutions for the resistors and batteries.  ", "Text"],

Cell[BoxData[{
    \(\(a = 
        ReplaceAll[
          A, {r\_1 \[Rule] 10, r\_2 \[Rule] 10, r\_3 \[Rule] 10, 
            r\_4 \[Rule] 10, r\_5 \[Rule] 20, r\_6 \[Rule] 20, 
            r\_7 \[Rule] 10, r\_8 \[Rule] 10, 
            r\_9 \[Rule] 10}];\)\), "\[IndentingNewLine]", 
    \(\(b = ReplaceAll[B, {e\_1 \[Rule] 36}];\)\), "\[IndentingNewLine]", 
    \(\(vars = {i\_1, i\_2, i\_3};\)\), "\[IndentingNewLine]", 
    \(\(x = LinearSolve[a, b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the linear system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[a], MatrixForm[vars], "\< = \>", 
        MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[x], "\< = \>", 
        MatrixForm[N[x]]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solution could be found using Cramer's rule. "
}], "Text"],

Cell[BoxData[{
    \(\(a1 = a;\)\), "\[IndentingNewLine]", 
    \(\(a2 = a;\)\), "\[IndentingNewLine]", 
    \(\(a3 = a;\)\), "\[IndentingNewLine]", 
    \(\(a1\_\(\(\[LeftDoubleBracket]\)\(All, 1\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a2\_\(\(\[LeftDoubleBracket]\)\(All, 2\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a3\_\(\(\[LeftDoubleBracket]\)\(All, 3\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a1 = ReplaceAll[a1, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a2 = ReplaceAll[a2, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a3 = ReplaceAll[a3, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< A = \>", MatrixForm[a]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_1\) = \>\"", 
        MatrixForm[a1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_2\) = \>\"", 
        MatrixForm[a2]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_3\) = \>\"", MatrixForm[a3]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", "\<Det[\>", 
        MatrixForm[a1], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = (\>\"", Det[a1], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", Det[a1]\/Det[a], "\< = \>", 
        N[Det[a1]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", "\<Det[\>", 
        MatrixForm[a2], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = (\>\"", Det[a2], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", Det[a2]\/Det[a], "\< = \>", 
        N[Det[a2]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_3\) = \>\"", "\<Det[\>", 
        MatrixForm[a3], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_3\) = (\>\"", Det[a3], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_3\) = \>\"", Det[a3]\/Det[a], "\< = \>", 
        N[Det[a3]\/Det[a]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the network #2 for the currents  ",
  Cell[BoxData[
      \(i\_1, i\_2, i\_3\)]],
  "  given the following value for the resistors and battery:  \n\n\t\t",
  Cell[BoxData[{\(r\_1 = 10, r\_2 = 10, r\_3 = 10, r\_4 = 20, r\_5 = 10, 
      r\_6 = 10, r\_7 = 5, r\_8 = 10, r\_9 = 20\), "\[IndentingNewLine]", 
      StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}], "\[IndentingNewLine]", \(e\_1 = 16\)}]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Set up the equations. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {\((r\_1 + r\_4 + r\_7)\), \(-r\_4\), "0"},
              {\(-r\_4\), \(r\_2 + r\_4 + r\_5 + r\_8\), \(-r\_5\)},
              {"0", \(-r\_5\), \(r\_3 + r\_5 + r\_6 + r\_9\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(e\_1\)},
              {"0"},
              {"0"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars = {i\_1, i\_2, 
          i\_3};\), "\[IndentingNewLine]", \(Print["\<Solve the linear system\
\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell["Make the substitutions for the resistors and batteries.  ", "Text"],

Cell[BoxData[{
    \(\(a = 
        ReplaceAll[
          A, {r\_1 \[Rule] 10, r\_2 \[Rule] 10, r\_3 \[Rule] 10, 
            r\_4 \[Rule] 20, r\_5 \[Rule] 10, r\_6 \[Rule] 10, 
            r\_7 \[Rule] 5, r\_8 \[Rule] 10, 
            r\_9 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(b = ReplaceAll[B, {e\_1 \[Rule] 16}];\)\), "\[IndentingNewLine]", 
    \(\(vars = {i\_1, i\_2, i\_3};\)\), "\[IndentingNewLine]", 
    \(\(x = LinearSolve[a, b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the linear system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[a], MatrixForm[vars], "\< = \>", 
        MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[x], "\< = \>", 
        MatrixForm[N[x]]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solution could be found using Cramer's rule. "
}], "Text"],

Cell[BoxData[{
    \(\(a1 = a;\)\), "\[IndentingNewLine]", 
    \(\(a2 = a;\)\), "\[IndentingNewLine]", 
    \(\(a3 = a;\)\), "\[IndentingNewLine]", 
    \(\(a1\_\(\(\[LeftDoubleBracket]\)\(All, 1\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a2\_\(\(\[LeftDoubleBracket]\)\(All, 2\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a3\_\(\(\[LeftDoubleBracket]\)\(All, 3\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a1 = ReplaceAll[a1, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a2 = ReplaceAll[a2, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a3 = ReplaceAll[a3, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< A = \>", MatrixForm[a]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_1\) = \>\"", 
        MatrixForm[a1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_2\) = \>\"", 
        MatrixForm[a2]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_3\) = \>\"", MatrixForm[a3]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", "\<Det[\>", 
        MatrixForm[a1], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = (\>\"", Det[a1], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", Det[a1]\/Det[a], "\< = \>", 
        N[Det[a1]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", "\<Det[\>", 
        MatrixForm[a2], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = (\>\"", Det[a2], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", Det[a2]\/Det[a], "\< = \>", 
        N[Det[a2]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_3\) = \>\"", "\<Det[\>", 
        MatrixForm[a3], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_3\) = (\>\"", Det[a3], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_3\) = \>\"", Det[a3]\/Det[a], "\< = \>", 
        N[Det[a3]\/Det[a]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Network #3",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tConsider the network consisting of six resistors and two batteries, \
shown in the figure below.\n\t\n\t\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85714 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0714286 0.142857 0.0714286 0.142857 [
[ 0 0 0 0 ]
[ 1 .85714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .85714 L
0 .85714 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.21429 .78571 m
.23077 .78571 L
.23626 .76429 L
.24725 .80714 L
.25824 .76429 L
.26923 .80714 L
.28022 .76429 L
.29121 .80714 L
.3022 .76429 L
.31319 .80714 L
.32418 .76429 L
.33516 .80714 L
.34066 .78571 L
.35714 .78571 L
s
.64286 .78571 m
.65934 .78571 L
.66484 .76429 L
.67582 .80714 L
.68681 .76429 L
.6978 .80714 L
.70879 .76429 L
.71978 .80714 L
.73077 .76429 L
.74176 .80714 L
.75275 .76429 L
.76374 .80714 L
.76923 .78571 L
.78571 .78571 L
s
.5 .5 m
.5 .51648 L
.52143 .52198 L
.47857 .53297 L
.52143 .54396 L
.47857 .55495 L
.52143 .56593 L
.47857 .57692 L
.52143 .58791 L
.47857 .5989 L
.52143 .60989 L
.47857 .62088 L
.5 .62637 L
.5 .64286 L
s
.21429 .35714 m
.23077 .35714 L
.23626 .33571 L
.24725 .37857 L
.25824 .33571 L
.26923 .37857 L
.28022 .33571 L
.29121 .37857 L
.3022 .33571 L
.31319 .37857 L
.32418 .33571 L
.33516 .37857 L
.34066 .35714 L
.35714 .35714 L
s
.64286 .35714 m
.65934 .35714 L
.66484 .33571 L
.67582 .37857 L
.68681 .33571 L
.6978 .37857 L
.70879 .33571 L
.71978 .37857 L
.73077 .33571 L
.74176 .37857 L
.75275 .33571 L
.76374 .37857 L
.76923 .35714 L
.78571 .35714 L
s
.42857 .07143 m
.44505 .07143 L
.45055 .05 L
.46154 .09286 L
.47253 .05 L
.48352 .09286 L
.49451 .05 L
.50549 .09286 L
.51648 .05 L
.52747 .09286 L
.53846 .05 L
.54945 .09286 L
.55495 .07143 L
.57143 .07143 L
s
newpath
.28571 .57143 .11429 -45 225 arc
s
newpath
.71429 .57143 .11429 -45 225 arc
s
newpath
.5 .21429 .11429 -45 225 arc
s
.41919 .13347 m
.43347 .11919 L
s
% Start of user PostScript
2.43431 0.434315 2.53431 0.334315 MAarrowhead1
% End of user PostScript
.36653 .49062 m
.35224 .47633 L
s
% Start of user PostScript
2.06569 2.93431 1.96569 2.83431 MAarrowhead1
% End of user PostScript
.63347 .49062 m
.64776 .47633 L
s
% Start of user PostScript
3.93431 2.93431 4.03431 2.83431 MAarrowhead1
% End of user PostScript
.07143 .55714 m
.07143 .07143 L
.42857 .07143 L
s
.92857 .55714 m
.92857 .07143 L
.57143 .07143 L
s
.07143 .58571 m
.07143 .78571 L
.21429 .78571 L
s
.92857 .58571 m
.92857 .78571 L
.78571 .78571 L
s
.35714 .78571 m
.64286 .78571 L
s
.35714 .35714 m
.64286 .35714 L
s
.07143 .35714 m
.21429 .35714 L
s
.78571 .35714 m
.92857 .35714 L
s
.5 .35714 m
.5 .5 L
s
.5 .64286 m
.5 .78571 L
s
0 .58571 m
.14286 .58571 L
s
.85714 .58571 m
1 .58571 L
s
.02 w
.02857 .55714 m
.11429 .55714 L
s
.88571 .55714 m
.97143 .55714 L
s
gsave
.28571 .57143 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71429 .57143 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .21429 -67.7188 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
66.938 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
72.438 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28571 .83571 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71429 .83571 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45 .57143 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28571 .41429 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71429 .41429 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .02143 -68.0938 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.688 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
73.188 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02143 .5 -68.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.250 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.750 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97857 .5 -68.875 -12.9063 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.500 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.250 19.750 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
74.750 17.500 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 246.813},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000mQ000`40O003h00OT7oo0P00SWoo002?
Ool01000Oomoo`00SGoo002:Ool30002Ool01000Oomoo`00SGoo002;Ool01@00Oomoogoo00000Woo
00<007ooOol0Rgoo002;Ool01000Oomoogoo0`00SWoo002;Ool00`00Oomoo`02Ool00`00Oomoo`2=
Ool008]oo`03001oogoo00=oo`8008eoo`00RWoo0`00Tgoo002;Ool01000Ool00000TGoo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00PGoo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0Pgoo0021Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`23Ool0081oo`03001oo`0000Ao
o`8000Aoo`8000Eoo`8000Aoo`8008Aoo`00P7oo00<007oo00000goo00<007oo00000goo00<007oo
000017oo00<007oo00000goo00<007oo0000Q7oo0020Ool00`00Ool00003Ool00`00Ool00003Ool0
0`00Ool00004Ool00`00Ool00003Ool00`00Ool00024Ool007moo`04001oogoo0003Ool00`00Ool0
0003Ool01000Oomoo`000goo00<007oo00000goo00<007oo0000Q7oo000DOom/0003Ool01000Oomo
o`000Woo00@007ooOol0009oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0K000
5Goo000DOol00`00Oomoo`1/Ool00`00Ool00003Ool00`00Ool00003Ool01000Oomoo`000goo00<0
07oo00000goo00@007ooOol006Yoo`03001oogoo01=oo`0057oo00<007ooOol0K7oo00<007oo0000
0goo00<007oo000017oo00<007oo00000goo00<007oo00000goo00<007oo0000Jgoo00<007ooOol0
4goo000DOol00`00Oomoo`1/Ool00`00Ool00003Ool00`00Ool00004Ool00`00Ool00003Ool00`00
Ool00003Ool00`00Ool0001[Ool00`00Oomoo`0COol001Aoo`03001oogoo06eoo`8000Aoo`8000Ao
o`03001oo`0000Aoo`8000Aoo`8006]oo`03001oogoo01=oo`0057oo00<007ooOol0KGoo00<007oo
Ool00goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol0JWoo00<007oo
Ool04goo000DOol00`00Oomoo`1]Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`1ZOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo
01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo000DOol00`00Oomoo`3cOol00`00Oomoo`0C
Ool001Aoo`03001oogoo0?=oo`03001oogoo01=oo`0057oo00<007ooOol0lgoo00<007ooOol04goo
000DOol00`00Oomoo`3cOol00`00Oomoo`0COol001Aoo`03001oogoo0?=oo`03001oogoo01=oo`00
57oo00<007ooOol0IGoo00<007ooOol0Rgoo00<007ooOol04goo000DOol00`00Oomoo`1SOol2002>
Ool00`00Oomoo`0COol001Aoo`03001oogoo065oo`@008ioo`03001oogoo01=oo`0057oo00<007oo
Ool0H7oo1000Sgoo00<007ooOol04goo000DOol00`00Oomoo`1NOol6000[Ool00`00Oomoo`1QOol0
0`00Oomoo`0COol001Aoo`03001oogoo05eoo`H002eoo`03001oogoo061oo`03001oogoo01=oo`00
57oo00<007ooOol0Fgoo1`00;goo00<007ooOol0Ggoo00<007ooOol04goo000DOol00`00Oomoo`1I
Ool9000`Ool00`00Oomoo`1NOol00`00Oomoo`0COol001Aoo`03001oogoo05Qoo`T0035oo`03001o
ogoo05ioo`03001oogoo01=oo`0057oo00<007ooOol0FGoo1`00<goo00<007ooOol0GGoo00<007oo
Ool04goo000DOol00`00Oomoo`1JOol6000dOol00`00Oomoo`1LOol00`00Oomoo`0COol001Aoo`03
001oogoo05]oo`@003Ioo`03001oogoo05]oo`03001oogoo01=oo`0057oo00<007ooOol0Fgoo1000
=Woo00<007ooOol0Fgoo00<007ooOol04goo000DOol00`00Oomoo`1KOol00`00Ool0000hOol00`00
Oomoo`1JOol00`00Oomoo`0COol001Aoo`03001oogoo05Yoo`03001oogoo03Uoo`03001oogoo05Yo
o`03001oogoo01=oo`0057oo00<007ooOol0FWoo00<007ooOol0>Woo00<007ooOol0FGoo00<007oo
Ool04goo000DOol00`00Oomoo`1IOol00`00Oomoo`0kOol00`00Oomoo`1IOol00`00Oomoo`0COol0
01Aoo`03001oogoo05Uoo`03001oogoo03aoo`03001oogoo05Qoo`03001oogoo01=oo`0057oo00<0
07ooOol0F7oo00<007ooOol0?Goo00<007ooOol0F7oo00<007ooOol04goo000DOol00`00Oomoo`1H
Ool00`00Oomoo`0mOol00`00Oomoo`1HOol00`00Oomoo`0COol001Aoo`03001oogoo05Qoo`03001o
ogoo03eoo`03001oogoo05Qoo`03001oogoo01=oo`0057oo00<007ooOol0F7oo00<007ooOol077oo
0`007Woo00<007ooOol0F7oo00<007ooOol04goo000DOol00`00Oomoo`1HOol00`00Oomoo`0OOol0
0`00Oomoo`0LOol00`00Oomoo`1GOol00`00Oomoo`0COol001Aoo`03001oogoo05Moo`03001oogoo
021oo`03001oogoo01aoo`03001oogoo05Moo`03001oogoo01=oo`0057oo00<007ooOol0Egoo00<0
07ooOol06Goo0`000Woo0P007goo00<007ooOol0Egoo00<007ooOol04goo000DOol00`00Oomoo`1G
Ool00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`0MOol00`00Oomoo`1GOol00`00Oomoo`0C
Ool001Aoo`03001oogoo05Moo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo01aoo`03001o
ogoo05Moo`03001oogoo01=oo`0057oo00<007ooOol0Egoo00<007ooOol06Woo00<007ooOol00`00
7goo00<007ooOol0Egoo00<007ooOol04goo000DOol00`00Oomoo`1GOol00`00Oomoo`0JOol00`00
Oomoo`0ROol00`00Oomoo`1GOol00`00Oomoo`0COol001Aoo`03001oogoo05Moo`03001oogoo01Uo
o`8002Aoo`03001oogoo05Moo`03001oogoo01=oo`0057oo00<007ooOol0Egoo00<007ooOol06Woo
00<007ooOol08Woo00<007ooOol0Egoo00<007ooOol04goo000DOol00`00Oomoo`1GOol00`00Oomo
o`0oOol00`00Oomoo`1GOol00`00Oomoo`0COol001Aoo`03001oogoo05Qoo`03001oogoo03eoo`03
001oogoo05Qoo`03001oogoo01=oo`0057oo00<007ooOol0F7oo00<007ooOol06Goo00<007ooOol0
8Goo00<007ooOol0F7oo00<007ooOol04goo000DOol00`00Oomoo`1HOol00`00Oomoo`0mOol00`00
Oomoo`1HOol00`00Oomoo`0COol001Aoo`03001oogoo05Qoo`03001oogoo03eoo`03001oogoo05Qo
o`03001oogoo01=oo`0057oo00<007ooOol0FGoo00<007ooOol0?7oo00<007ooOol0F7oo00<007oo
Ool04goo000DOol00`00Oomoo`1IOol00`00Oomoo`0kOol00`00Oomoo`1IOol00`00Oomoo`0COol0
01Aoo`03001oogoo05Uoo`03001oogoo03]oo`03001oogoo05Uoo`03001oogoo01=oo`0057oo00<0
07ooOol0FWoo00<007ooOol0>Goo00<007ooOol0FWoo00<007ooOol04goo000DOol00`00Oomoo`1J
Ool00`00Oomoo`0iOol00`00Oomoo`1JOol00`00Oomoo`0COol001Aoo`03001oogoo05]oo`03001o
ogoo03Qoo`03001oogoo05Yoo`03001oogoo01=oo`0057oo00<007ooOol0Fgoo00<007ooOol0=goo
00<007ooOol0Fgoo00<007ooOol04goo000DOol00`00Oomoo`1LOol00`00Oomoo`0fOol00`00Oomo
o`1KOol00`00Oomoo`0COol001Aoo`03001oogoo05aoo`03001oogoo03Eoo`03001oogoo05aoo`03
001oogoo01=oo`0057oo00<007ooOol0GGoo00<007ooOol0=7oo00<007ooOol0G7oo00<007ooOol0
4goo000DOol00`00Oomoo`1MOol00`00Oomoo`0cOol00`00Oomoo`1MOol00`00Oomoo`0COol001Ao
o`03001oogoo05ioo`03001oogoo035oo`03001oogoo05ioo`03001oogoo01=oo`0057oo00<007oo
Ool0Ggoo00<007ooOol0;goo00<007ooOol0Ggoo00<007ooOol04goo000DOol00`00Oomoo`1POol0
0`00Oomoo`0^Ool00`00Oomoo`1OOol00`00Oomoo`0COol001Aoo`03001oogoo061oo`8002eoo`80
069oo`03001oogoo01=oo`0057oo00<007ooOol0HWoo00<007ooOol0:Goo00<007ooOol0HWoo00<0
07ooOol04goo000DOol00`00Oomoo`1SOol00`00Oomoo`0WOol00`00Oomoo`1SOol00`00Oomoo`0C
Ool001Aoo`03001oogoo06Aoo`8002Eoo`8006Ioo`03001oogoo01=oo`0057oo00<007ooOol0IWoo
00<007ooOol08Goo00<007ooOol0IWoo00<007ooOol04goo000DOol00`00Oomoo`1WOol00`00Oomo
o`0OOol00`00Oomoo`1WOol00`00Oomoo`0COol001Aoo`03001oogoo06Qoo`8001eoo`8006Yoo`03
001oogoo01=oo`0057oo00<007ooOol0JWoo0P006Goo0P00K7oo00<007ooOol04goo000DOol00`00
Oomoo`1/Ool2000EOol2001^Ool00`00Oomoo`0COol001Aoo`03001oogoo06ioo`D000]oo`D0071o
o`03001oogoo01=oo`0057oo00<007ooOol0Lgoo2`00MGoo00<007ooOol04goo000DOol00`00Oomo
o`3cOol00`00Oomoo`0COol001Aoo`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo05ioo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo031oo`03001oogoo01=oo`0057oo00<007ooOol0
;7oo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
GWoo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
<7oo00<007ooOol04goo000DOol00`00Oomoo`0/Ool20005Ool20004Ool20004Ool20004Ool00`00
Ool0001OOol20004Ool00`00Ool00004Ool20004Ool20004Ool2000aOol00`00Oomoo`0COol001Ao
o`03001oogoo02aoo`8000Aoo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000Aoo`03001o
o`0005moo`8000Aoo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000=oo`03001oo`00035o
o`03001oogoo01=oo`0057oo00<007ooOol0:goo00<007oo000017oo00<007oo00000goo00<007oo
00000goo00<007oo000017oo00<007oo0000GWoo00<007oo000017oo00<007oo00000goo00<007oo
00000goo00<007oo00000goo00<007oo0000<Goo00<007ooOol04goo000DOol00`00Oomoo`0[Ool0
1000Oomoo`000goo00<007oo00000goo00<007oo00000goo00<007oo00000goo00@007ooOol005io
o`03001oo`0000=oo`04001oogoo0003Ool00`00Ool00003Ool00`00Ool00003Ool01000Oomoo`00
<7oo00<007ooOol04goo000DOol_0002Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007oo0000G0000Woo00@007ooOol000=oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo02l001Eoo`0057oo00<007ooOol0;Woo
00@007ooOol000=oo`03001oo`0000=oo`03001oo`0000=oo`04001oogoo0003Ool00`00Ool0000]
Ool00`00Oomoo`0^Ool01000Oomoo`000goo00<007oo00000goo00<007oo00000goo00<007oo0000
0goo00@007ooOol002eoo`03001oogoo01=oo`0057oo00<007ooOol0;goo00<007oo00000goo00<0
07oo00000goo00<007oo00000goo00<007oo000017oo00<007oo0000;Goo00<007ooOol0;Woo00<0
07oo000017oo00<007oo00000goo00<007oo00000goo00<007oo000017oo00<007oo0000;Goo00<0
07ooOol04goo000DOol00`00Oomoo`0_Ool00`00Ool00003Ool00`00Ool00003Ool00`00Ool00003
Ool00`00Ool00004Ool00`00Ool0000]Ool00`00Oomoo`0^Ool00`00Ool00004Ool00`00Ool00003
Ool00`00Ool00003Ool00`00Ool00004Ool00`00Ool0000]Ool00`00Oomoo`0COol001Aoo`03001o
ogoo02moo`03001oo`0000Aoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo02aoo`03001oogoo02mo
o`8000Eoo`8000Aoo`8000Aoo`8000Aoo`8002ioo`03001oogoo01=oo`0057oo00<007ooOol0<7oo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0;7oo
00<007ooOol0;goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo
00<007ooOol0;7oo00<007ooOol04goo000DOol00`00Oomoo`0`Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0/Ool00`00Oomoo`0_Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0/Ool00`00Oomo
o`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0
N7oo00<007ooOol0N7oo00<007ooOol04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00
Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007oo
Ool0?7oo00<007ooOol0>Goo00<007ooOol0>Woo0`00>goo00<007ooOol04goo000DOol00`00Oomo
o`0lOol00`00Oomoo`0iOol00`00Oomoo`0mOol00`00Oomoo`0hOol00`00Oomoo`0COol001Aoo`03
001oogoo03Eoo`<0009oo`@003Yoo`03001oogoo03Eoo`<000Eoo`03001oogoo03Qoo`03001oogoo
01=oo`0057oo00<007ooOol0=Woo00L007ooOomoo`00Ool0000kOol00`00Oomoo`0fOol00`00Oomo
o`04Ool00`00Oomoo`0hOol00`00Oomoo`0COol001Aoo`03001oogoo03Ioo`03001oogoo009oo`80
03]oo`03001oogoo03Ioo`03001oogoo009oo`8003]oo`03001oogoo01=oo`0057oo00<007ooOol0
=Woo00<007ooOol00Woo0P00>goo00<007ooOol0=Woo00<007ooOol00Woo00<007ooOol0>Woo00<0
07ooOol04goo000DOol00`00Oomoo`0fOol00`00Oomoo`03Ool00`00Oomoo`0iOol00`00Oomoo`0f
Ool00`00Oomoo`03Ool2000jOol00`00Oomoo`0COol001Aoo`03001oogoo03Eoo`<0041oo`03001o
ogoo03Eoo`<0041oo`03001oogoo01=oo`0057oo00<007ooOol0=Woo00@007oo000003ioo`03001o
ogoo03Ioo`04001oo`00000nOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo07Qo
o`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000DOol0
0`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001oogoo
07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000D
Ool00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001o
ogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo
000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03
001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol0
4goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qo
o`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007oo
Ool04goo000DOol00`00Oomoo`1>Ool00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`1>Ool0
0`00Oomoo`0COol000Moo`<000Yoo`03001oogoo04moo`8002Moo`03001oogoo02Eoo`80055oo`03
001oogoo00aoo`@000=oo`0027oo00<007ooOol02Goo00<007ooOol0Cgoo0`009Woo00<007ooOol0
97oo0`00DGoo00<007ooOol03Goo00<007oo00000goo0002Ool30003Ool00`00Oomoo`09Ool00`00
Oomoo`1@Ool4000TOol00`00Oomoo`0ROol4001BOol00`00Oomoo`07Ool30004Ool00`00Oomoo`02
Ool00003Ool007oo009oo`04001oogoo000;Ool00`00Oomoo`0SOol00`00Oomoo`0ZOol5000SOol0
0`00Oomoo`0QOol5000/Ool00`00Oomoo`0SOol00`00Oomoo`06Ool01@00Oomoogoo000017oo00<0
07ooOol00Goo00000goo001oo`05Ool00`00Oomoo`09Ool00`00Oomoo`0SOol00`00Oomoo`0[Ool6
000QOol00`00Oomoo`0OOol6000^Ool00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`01Ool00003Ool007oo00Eoo`03001oogoo00Uoo`03001oogoo029oo`03001oogoo02ao
o`L0021oo`03001oogoo01ioo`L002ioo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo00=o
o`04001oogoo0003Ool00003Ool0000000<00003Ool0000000]oo`03001oogoo025oo`03001oogoo
02ioo`P001ioo`03001oogoo01aoo`P0031oo`03001oogoo025oo`03001oogoo00Ioo`D0009oo`80
00Aoo`0000=oo`00Ool00Woo00<007ooOol037oo00<007ooOol087oo00<007ooOol0;goo2@007Goo
00<007ooOol06goo2@00<Goo00<007ooOol087oo00<007ooOol01Woo00D007ooOomoo`0000Qoo`00
0Woo0`003goo00<007ooOol087oo00<007ooOol0<7oo1`007Woo00<007ooOol077oo1`00<goo00<0
07ooOol07goo00<007ooOol01goo0`002Goo000DOol00`00Oomoo`0OOol00`00Oomoo`0aOol6000O
Ool00`00Oomoo`0MOol6000cOol00`00Oomoo`0OOol00`00Oomoo`0COol001Aoo`03001oogoo01mo
o`03001oogoo039oo`@0021oo`03001oogoo01ioo`@003Eoo`03001oogoo01ioo`03001oogoo01=o
o`0057oo00<007ooOol07Woo00<007ooOol0<goo100087oo10007Goo1000=Goo00<007ooOol07Woo
00<007ooOol04goo000DOol00`00Oomoo`0NOol00`00Oomoo`0dOol01000Oomoo`008goo0`006Goo
00@007ooOol003Moo`03001oogoo01eoo`03001oogoo01=oo`0057oo00<007ooOol07Goo00<007oo
Ool0>Goo00<007ooOol07Woo0`006Woo00<007ooOol0>Goo00<007ooOol07Goo00<007ooOol04goo
000DOol00`00Oomoo`0MOol00`00Oomoo`0iOol00`00Oomoo`0KOol3000MOol00`00Oomoo`0iOol0
0`00Oomoo`0MOol00`00Oomoo`0COol001Aoo`03001oogoo01aoo`03001oogoo03Yoo`03001oogoo
01Qoo`<0021oo`03001oogoo03Yoo`03001oogoo01aoo`03001oogoo01=oo`0057oo00<007ooOol0
77oo00<007ooOol0>Woo00<007ooOol05Woo0`008Woo00<007ooOol0>Woo00<007ooOol077oo00<0
07ooOol04goo000DOol00`00Oomoo`0LOol00`00Oomoo`0kOol00`00Oomoo`0HOol4000NOol00`00
Oomoo`0kOol00`00Oomoo`0KOol00`00Oomoo`0COol001Aoo`03001oogoo01]oo`03001oogoo03ao
o`03001oogoo01aoo`@001Uoo`03001oogoo03aoo`03001oogoo01]oo`03001oogoo01=oo`0057oo
00<007ooOol06goo00<007ooOol0?Goo00<007ooOol07Woo0`005goo00<007ooOol0?Goo00<007oo
Ool06Woo00<007ooOol04goo0006OolM000>Ool00`00Oomoo`0nOol00`00Oomoo`0JOol4000IOol0
0`00Oomoo`0nOol00`00Oomoo`0<OolM0007Ool000Iooad000ioo`03001oogoo01ioo`<001eoo`03
001oogoo00]oo`<000Qoo`@001eoo`03001oogoo01eoo`@001eoo`03001oogoo00aooad000Moo`00
1Woo7@003Woo00<007ooOol07goo00<007ooOol077oo00<007ooOol03Woo00<007ooOol00goo0`00
87oo00<007ooOol07Woo00<007oo00007Goo00<007ooOol037oo7@001goo0006OolM000>Ool00`00
Oomoo`0IOol30003Ool00`00Oomoo`0LOol00`00Oomoo`07Ool30004Ool00`00Oomoo`06Ool4000L
Ool00`00Oomoo`0IOol30003Ool00`00Oomoo`0LOol00`00Oomoo`0<OolM0007Ool000Iooad000io
o`03001oogoo01Yoo`03001oogoo009oo`03001oogoo01aoo`03001oogoo00Qoo`04001oogooOol2
000=Ool4000HOol00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`0KOol00`00Oomoo`0<OolM
0007Ool0035oo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo01aoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo00ioo`<001Ioo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo
01]oo`03001oogoo031oo`00<Goo00<007ooOol06Woo00<007ooOol00Woo00<007ooOol077oo00<0
07ooOol027oo00<007ooOol00goo00<007ooOol02Goo10006Goo00<007ooOol06Woo00@007ooOol0
009oo`03001oogoo01]oo`03001oogoo031oo`00<Goo00<007ooOol06Woo00@007ooOomoo`8001io
o`03001oogoo00Qoo`03001oogoo00<000Qoo`@001eoo`03001oogoo01Yoo`04001oogooOol2000N
Ool00`00Oomoo`0`Ool0035oo`03001oogoo01Uoo`8002=oo`03001oogoo00Moo`<000Yoo`<0021o
o`03001oogoo01Uoo`8002=oo`03001oogoo031oo`00<Goo00<007ooOol06Woo00<007ooOol08Goo
00<007ooOol027oo00@007oo000000]oo`@001aoo`03001oogoo01Yoo`03001oogoo025oo`03001o
ogoo031oo`00<Goo00<007ooOol0?Woo00<007ooOol06goo100067oo00<007ooOol0?Woo00<007oo
Ool0<7oo000Z0007Ool00`00Oomoo`0nOol00`00Oomoo`0NOol3000FOol00`00Oomoo`0nOol00`00
Oomoo`05OolZ0001Ool001Aoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo025oo`03001o
ogoo01Yoo`@001Uoo`03001oogoo01Yoo`03001oogoo025oo`03001oogoo01Yoo`03001oogoo01=o
o`0057oo00<007ooOol06Woo00<007ooOol0?Woo00<007ooOol05Woo10007Goo00<007ooOol0?Woo
00<007ooOol06Woo00<007ooOol04goo000DOol00`00Oomoo`0KOol00`00Oomoo`0lOol00`00Oomo
o`0EOol2000ROol00`00Oomoo`0lOol00`00Oomoo`0KOol00`00Oomoo`0COol001Aoo`03001oogoo
01]oo`03001oogoo03aoo`03001oogoo01Moo`<001moo`03001oogoo03aoo`03001oogoo01]oo`03
001oogoo01=oo`0057oo00<007ooOol06goo00<007ooOol0?7oo00<007ooOol06Woo0`0077oo00<0
07ooOol0?7oo00<007ooOol06goo00<007ooOol04goo000DOol00`00Oomoo`0KOol00`00Oomoo`0l
Ool00`00Oomoo`0MOol3000IOol00`00Oomoo`0lOol00`00Oomoo`0KOol00`00Oomoo`0COol001Ao
o`03001oogoo01aoo`03001oogoo03]oo`03001oogoo01moo`<001Qoo`03001oogoo03]oo`03001o
ogoo01]oo`03001oogoo01=oo`0057oo00<007ooOol077oo00<007ooOol0>Woo00<007ooOol077oo
10006goo00<007ooOol0>Woo00<007ooOol077oo00<007ooOol04goo000DOol00`00Oomoo`0MOol0
0`00Oomoo`0iOol00`00Oomoo`0HOol4000POol00`00Oomoo`0iOol00`00Oomoo`0LOol00`00Oomo
o`0COol001Aoo`03001oogoo01eoo`03001oogoo03Qoo`03001oogoo01Moo`@0029oo`03001oogoo
03Qoo`03001oogoo01eoo`03001oogoo01=oo`0057oo00<007ooOol07Woo00<007ooOol0=goo00<0
07ooOol06goo0`0087oo00<007ooOol0=goo00<007ooOol07Goo00<007ooOol04goo000DOol00`00
Oomoo`0NOol00`00Oomoo`0fOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`0fOol00`00
Oomoo`0NOol00`00Oomoo`0COol001Aoo`03001oogoo01moo`03001oogoo03Aoo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo03Aoo`03001oogoo01moo`03001oogoo01=oo`0057oo00<007oo
Ool087oo00<007ooOol0<Woo00<007ooOol087oo00<007ooOol087oo00<007ooOol0<Woo00<007oo
Ool087oo00<007ooOol04goo000DOol00`00Oomoo`0QOol00`00Oomoo`0aOol00`00Oomoo`0POol0
0`00Oomoo`0QOol00`00Oomoo`0aOol00`00Oomoo`0POol00`00Oomoo`0COol001Aoo`03001oogoo
025oo`03001oogoo031oo`03001oogoo025oo`03001oogoo025oo`03001oogoo031oo`03001oogoo
025oo`03001oogoo01=oo`0057oo00<007ooOol08Woo00<007ooOol0;Woo00<007ooOol08Woo00<0
07ooOol08Woo00<007ooOol0;Woo00<007ooOol08Woo00<007ooOol04goo000DOol00`00Oomoo`0S
Ool00`00Oomoo`0/Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0/Ool00`00Oomoo`0S
Ool00`00Oomoo`0COol001Aoo`03001oogoo02Aoo`03001oogoo02]oo`03001oogoo02=oo`03001o
ogoo02Aoo`03001oogoo02Yoo`03001oogoo02Aoo`03001oogoo01=oo`0057oo00<007ooOol09Goo
00<007ooOol0:7oo0P009Woo00<007ooOol097oo0P00:Woo00<007ooOol09Goo00<007ooOol04goo
000DOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomo
o`0VOol00`00Oomoo`0VOol00`00Oomoo`0COol001Aoo`03001oogoo02Moo`03001oogoo02Aoo`03
001oogoo02Moo`03001oogoo02Moo`03001oogoo02Aoo`03001oogoo02Moo`03001oogoo01=oo`00
57oo00<007ooOol0:7oo0P008Woo0P00:Woo00<007ooOol0:7oo0P008Woo0P00:Woo00<007ooOol0
4goo000DOol00`00Oomoo`0ZOol2000NOol2000/Ool00`00Oomoo`0ZOol2000NOol2000/Ool00`00
Oomoo`0COol001Aoo`03001oogoo02aoo`<001Uoo`8002ioo`03001oogoo02aoo`8001Uoo`<002io
o`03001oogoo01=oo`0057oo00<007ooOol0;goo0P0057oo0`00<7oo00<007ooOol0;Woo0`0057oo
0P00<Goo00<007ooOol04goo000DOol00`00Oomoo`0aOol2000@Ool2000cOol00`00Oomoo`0aOol2
000@Ool2000cOol00`00Oomoo`0COol001Aoo`03001oogoo03=ooa0003Eoo`03001oogoo03=ooa00
03Eoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo000D
Ool00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03001o
ogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol04goo
000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qoo`03
001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007ooOol0
4goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo07Qo
o`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<007oo
Ool04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001oogoo
07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo00<0
07ooOol04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03001o
ogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0N7oo
00<007ooOol04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Aoo`03
001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007ooOol0
N7oo00<007ooOol04goo000DOol00`00Oomoo`1hOol00`00Oomoo`1hOol00`00Oomoo`0COol001Ao
o`03001oogoo07Qoo`03001oogoo07Qoo`03001oogoo01=oo`0057oo00<007ooOol0N7oo00<007oo
Ool0N7oo00<007ooOol04goo000DOol00`00Oomoo`0/Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0_Ool00`00Oomoo`0/Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0`Ool00`00Oomoo`0COol0
01Aoo`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo02moo`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo031oo`03001oogoo01=oo`0057oo00<007ooOol0;7oo0P00
1Goo0P0017oo0P0017oo0P0017oo00<007oo0000<7oo00<007ooOol0;7oo0P0017oo00<007oo0000
17oo0P0017oo0P0017oo0P00<Goo00<007ooOol04goo000DOol00`00Oomoo`0/Ool20004Ool00`00
Ool00003Ool00`00Ool00003Ool00`00Ool00004Ool00`00Ool0000`Ool00`00Oomoo`0/Ool20004
Ool00`00Ool00003Ool00`00Ool00003Ool00`00Ool00003Ool00`00Ool0000aOol00`00Oomoo`0C
Ool001Aoo`03001oogoo02]oo`03001oo`0000Aoo`03001oo`0000=oo`03001oo`0000=oo`03001o
o`0000Aoo`03001oo`00031oo`03001oogoo02]oo`03001oo`0000Aoo`03001oo`0000=oo`03001o
o`0000=oo`03001oo`0000=oo`03001oo`00035oo`03001oogoo01=oo`0057oo00<007ooOol0:goo
00@007ooOol000=oo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000=oo`04001oogoo000`
Ool00`00Oomoo`0[Ool00`00Ool00003Ool01000Oomoo`000goo00<007oo00000goo00<007oo0000
0goo00@007ooOol0031oo`03001oogoo01=oo`0057oo;`000Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0005`0009oo`04001oogoo0003
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0_000EOol004Eo
o`04001oogoo0003Ool00`00Ool00003Ool00`00Ool00003Ool01000Oomoo`000goo00<007oo0000
GWoo00@007ooOol000=oo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000=oo`04001oogoo
0013Ool004Ioo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000Aoo`03
001oo`0005ioo`03001oo`0000Aoo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000Aoo`03
001oo`0004=oo`00AWoo00<007oo00000goo00<007oo00000goo00<007oo00000goo00<007oo0000
17oo00<007oo0000GWoo00<007oo000017oo00<007oo00000goo00<007oo00000goo00<007oo0000
17oo00<007oo0000@goo0016Ool00`00Ool00004Ool20004Ool20004Ool20005Ool00`00Oomoo`1N
Ool20005Ool20004Ool20004Ool20004Ool20014Ool004Moo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo05ioo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo049oo`00Agoo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0GWoo00<007ooOol017oo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0@Woo003oOolQOol00?moob5oo`00
DWoo0`00Mgoo1000D7oo001COol00`00Oomoo`1gOol00`00Ool0001@Ool004aoo`<000Aoo`03001o
ogoo075oo`<000Aoo`03001oogoo04moo`00CGoo00<007ooOol00goo00<007ooOol0LWoo00<007oo
Ool017oo00<007ooOol0CWoo001=Ool00`00Oomoo`03Ool00`00Oomoo`1bOol00`00Oomoo`04Ool0
0`00Oomoo`1>Ool004eoo`03001oogoo00=oo`03001oogoo079oo`05001oogooOol00002Ool00`00
Oomoo`1>Ool004eoo`03001oogoo009oo`8007Aoo`03001oogoo009oo`80055oo`00C7oo0`00N7oo
0`00EWoo001=Ool01000Ool00000Mgoo00@007oo000005Aoo`00ogoo8Goo003oOolQOol00?moob5o
o`00\
\>"],
    ImageRangeCache->{{{0, 287}, {245.813, 0}} -> {0, 0, 0, 0}}],
  "  "
}], "Text"],

Cell[TextData[{
  "There are three loops.  When Kirchoff's voltage law is applied, we obtain \
the following linear system of equations.  \n\n\t\t\t",
  Cell[BoxData[GridBox[{
          {\(\((r\_1 + r\_3 + r\_4)\) i\_1\), "+", \(\(r\_3\) i\_2\), 
            "+", \(\(r\_4\) 
              i\_3\), \(\(=\)\(\[IndentingNewLine]\)\), \(e\_1\)},
          {\(\(r\_3\) i\_1\), "+", \(\((r\_2 + r\_3 + r\_5)\) i\_2\), 
            "-", \(\(r\_5\) 
              i\_3\), \(\(=\)\(\[IndentingNewLine]\)\), \(e\_2\)},
          {\(\(r\_4\) i\_1\), "-", \(\(r\_5\) i\_2\), 
            "+", \(\((r\_4 + r\_5 + r\_6)\) i\_3\), "=", "0"}
          }]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the network #3 for the currents  ",
  Cell[BoxData[
      \(i\_1, i\_2, i\_3\)]],
  "  given the following value for the resistors and batteries:  \n\n\t\t",
  Cell[BoxData[{\(r\_1 = 1, r\_2 = 1, r\_3 = 2, r\_4 = 1, r\_5 = 2, 
      r\_6 = 4\), "\[IndentingNewLine]", 
      StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}], 
    "\[IndentingNewLine]", \(e\_1 = 23, e\_2 = 29\)}]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Set up the equations. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {\((r\_1 + r\_3 + r\_4)\), \(r\_3\), \(r\_4\)},
              {\(r\_3\), \(r\_2 + r\_3 + r\_5\), \(-r\_5\)},
              {\(r\_4\), \(-r\_5\), \(r\_4 + r\_5 + r\_6\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(e\_1\)},
              {\(e\_2\)},
              {"0"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars = {i\_1, i\_2, 
          i\_3};\), "\[IndentingNewLine]", \(Print["\<Solve the linear system\
\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell["Make the substitutions for the resistors and batteries.  ", "Text"],

Cell[BoxData[{
    \(\(a = 
        ReplaceAll[
          A, {r\_1 \[Rule] 1, r\_2 \[Rule] 1, r\_3 \[Rule] 2, r\_4 \[Rule] 1, 
            r\_5 \[Rule] 2, r\_6 \[Rule] 4}];\)\), "\[IndentingNewLine]", 
    \(\(b = 
        ReplaceAll[
          B, {e\_1 \[Rule] 23, 
            e\_2 \[Rule] 29}];\)\), "\[IndentingNewLine]", 
    \(\(vars = {i\_1, i\_2, i\_3};\)\), "\[IndentingNewLine]", 
    \(\(x = LinearSolve[a, b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the linear system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[a], MatrixForm[vars], "\< = \>", 
        MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[x], "\< = \>", 
        MatrixForm[N[x]]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solution could be found using Cramer's rule. "
}], "Text"],

Cell[BoxData[{
    \(\(a1 = a;\)\), "\[IndentingNewLine]", 
    \(\(a2 = a;\)\), "\[IndentingNewLine]", 
    \(\(a3 = a;\)\), "\[IndentingNewLine]", 
    \(\(a1\_\(\(\[LeftDoubleBracket]\)\(All, 1\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a2\_\(\(\[LeftDoubleBracket]\)\(All, 2\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a3\_\(\(\[LeftDoubleBracket]\)\(All, 3\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a1 = ReplaceAll[a1, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a2 = ReplaceAll[a2, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a3 = ReplaceAll[a3, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< A = \>", MatrixForm[a]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_1\) = \>\"", 
        MatrixForm[a1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_2\) = \>\"", 
        MatrixForm[a2]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_3\) = \>\"", MatrixForm[a3]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", "\<Det[\>", 
        MatrixForm[a1], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = (\>\"", Det[a1], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", Det[a1]\/Det[a], "\< = \>", 
        N[Det[a1]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", "\<Det[\>", 
        MatrixForm[a2], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = (\>\"", Det[a2], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", Det[a2]\/Det[a], "\< = \>", 
        N[Det[a2]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_3\) = \>\"", "\<Det[\>", 
        MatrixForm[a3], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_3\) = (\>\"", Det[a3], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_3\) = \>\"", Det[a3]\/Det[a], "\< = \>", 
        N[Det[a3]\/Det[a]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the network #3 for the currents  ",
  Cell[BoxData[
      \(i\_1, i\_2, i\_3\)]],
  "  given the following value for the resistors and batteries:  \n\n\t\t",
  Cell[BoxData[{\(r\_1 = 1, r\_2 = 2, r\_3 = 4, r\_4 = 3, r\_5 = 1, 
      r\_6 = 5\), "\[IndentingNewLine]", 
      StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}], 
    "\[IndentingNewLine]", \(e\_1 = 41, e\_2 = 38\)}]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Set up the equations. ", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {\((r\_1 + r\_3 + r\_4)\), \(r\_3\), \(r\_4\)},
              {\(r\_3\), \(r\_2 + r\_3 + r\_5\), \(-r\_5\)},
              {\(r\_4\), \(-r\_5\), \(r\_4 + r\_5 + r\_6\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {\(e\_1\)},
              {\(e\_2\)},
              {"0"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(vars = {i\_1, i\_2, 
          i\_3};\), "\[IndentingNewLine]", \(Print["\<Solve the linear system\
\>"];\), "\[IndentingNewLine]", \(Print[MatrixForm[A], 
        MatrixForm[vars], "\< = \>", MatrixForm[B]];\)}], "Input"],

Cell["Make the substitutions for the resistors and batteries.  ", "Text"],

Cell[BoxData[{
    \(\(a = 
        ReplaceAll[
          A, {r\_1 \[Rule] 1, r\_2 \[Rule] 2, r\_3 \[Rule] 4, r\_4 \[Rule] 3, 
            r\_5 \[Rule] 1, r\_6 \[Rule] 5}];\)\), "\[IndentingNewLine]", 
    \(\(b = 
        ReplaceAll[
          B, {e\_1 \[Rule] 41, 
            e\_2 \[Rule] 38}];\)\), "\[IndentingNewLine]", 
    \(\(vars = {i\_1, i\_2, i\_3};\)\), "\[IndentingNewLine]", 
    \(\(x = LinearSolve[a, b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the linear system\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[a], MatrixForm[vars], "\< = \>", 
        MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[vars], "\< = \>", MatrixForm[x], "\< = \>", 
        MatrixForm[N[x]]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solution could be found using Cramer's rule. "
}], "Text"],

Cell[BoxData[{
    \(\(a1 = a;\)\), "\[IndentingNewLine]", 
    \(\(a2 = a;\)\), "\[IndentingNewLine]", 
    \(\(a3 = a;\)\), "\[IndentingNewLine]", 
    \(\(a1\_\(\(\[LeftDoubleBracket]\)\(All, 1\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a2\_\(\(\[LeftDoubleBracket]\)\(All, 2\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a3\_\(\(\[LeftDoubleBracket]\)\(All, 3\)\(\[RightDoubleBracket]\)\) = 
        Flatten[b];\)\), "\[IndentingNewLine]", 
    \(\(a1 = ReplaceAll[a1, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a2 = ReplaceAll[a2, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(a3 = ReplaceAll[a3, {e\_1 \[Rule] 20}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< A = \>", MatrixForm[a]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< B = \>", MatrixForm[b]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_1\) = \>\"", 
        MatrixForm[a1]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_2\) = \>\"", 
        MatrixForm[a2]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(A\_3\) = \>\"", MatrixForm[a3]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", "\<Det[\>", 
        MatrixForm[a1], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = (\>\"", Det[a1], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_1\) = \>\"", Det[a1]\/Det[a], "\< = \>", 
        N[Det[a1]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", "\<Det[\>", 
        MatrixForm[a2], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = (\>\"", Det[a2], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_2\) = \>\"", Det[a2]\/Det[a], "\< = \>", 
        N[Det[a2]\/Det[a]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(i\_3\) = \>\"", "\<Det[\>", 
        MatrixForm[a3], "\<] / Det[\>", 
        MatrixForm[a], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_3\) = (\>\"", Det[a3], "\<)/(\>", 
        Det[a], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(i\_3\) = \>\"", Det[a3]\/Det[a], "\< = \>", 
        N[Det[a3]\/Det[a]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Kirchoff's Law",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/KirchoffBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Kirchoff's Law",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/KirchoffBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 167, 4, 35, "Text"],
Cell[1946, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3425, 111, 463, 9, 87, "Text"],
Cell[3891, 122, 34527, 1006, 260, "Text"],
Cell[38421, 1130, 452, 10, 103, "Text"],
Cell[38876, 1142, 598, 20, 33, "Text"],
Cell[39477, 1164, 584, 19, 33, "Text"],
Cell[40064, 1185, 691, 19, 107, "Text"],

Cell[CellGroupData[{
Cell[40780, 1208, 101, 2, 33, "Text"],
Cell[40884, 1212, 38, 0, 33, "Text"],
Cell[40925, 1214, 653, 16, 135, "Input"],
Cell[41581, 1232, 73, 0, 33, "Text"],
Cell[41657, 1234, 780, 14, 170, "Input"],
Cell[42440, 1250, 259, 9, 71, "Text"],
Cell[42702, 1261, 828, 13, 210, "Input"],
Cell[43533, 1276, 404, 7, 85, "Input"],
Cell[43940, 1285, 404, 7, 85, "Input"]
}, Closed]],
Cell[44359, 1295, 691, 19, 104, "Text"],

Cell[CellGroupData[{
Cell[45075, 1318, 101, 2, 33, "Text"],
Cell[45179, 1322, 38, 0, 33, "Text"],
Cell[45220, 1324, 653, 16, 135, "Input"],
Cell[45876, 1342, 73, 0, 33, "Text"],
Cell[45952, 1344, 780, 14, 170, "Input"],
Cell[46735, 1360, 259, 9, 71, "Text"],
Cell[46997, 1371, 828, 13, 210, "Input"],
Cell[47828, 1386, 404, 7, 85, "Input"],
Cell[48235, 1395, 404, 7, 85, "Input"]
}, Closed]],
Cell[48654, 1405, 47633, 1338, 277, "Text"],
Cell[96290, 2745, 669, 14, 143, "Text"],
Cell[96962, 2761, 730, 19, 107, "Text"],

Cell[CellGroupData[{
Cell[97717, 2784, 101, 2, 33, "Text"],
Cell[97821, 2788, 38, 0, 33, "Text"],
Cell[97862, 2790, 755, 18, 173, "Input"],
Cell[98620, 2810, 73, 0, 33, "Text"],
Cell[98696, 2812, 850, 15, 170, "Input"],
Cell[99549, 2829, 259, 9, 71, "Text"],
Cell[99811, 2840, 1174, 19, 290, "Input"],
Cell[100988, 2861, 404, 7, 85, "Input"],
Cell[101395, 2870, 404, 7, 85, "Input"],
Cell[101802, 2879, 404, 7, 85, "Input"]
}, Closed]],
Cell[102221, 2889, 729, 19, 104, "Text"],

Cell[CellGroupData[{
Cell[102975, 2912, 101, 2, 33, "Text"],
Cell[103079, 2916, 38, 0, 33, "Text"],
Cell[103120, 2918, 755, 18, 173, "Input"],
Cell[103878, 2938, 73, 0, 33, "Text"],
Cell[103954, 2940, 849, 15, 170, "Input"],
Cell[104806, 2957, 259, 9, 71, "Text"],
Cell[105068, 2968, 1174, 19, 290, "Input"],
Cell[106245, 2989, 404, 7, 85, "Input"],
Cell[106652, 2998, 404, 7, 85, "Input"],
Cell[107059, 3007, 404, 7, 85, "Input"]
}, Closed]],
Cell[107478, 3017, 42375, 1149, 339, "Text"],
Cell[149856, 4168, 661, 14, 143, "Text"],
Cell[150520, 4184, 709, 20, 107, "Text"],

Cell[CellGroupData[{
Cell[151254, 4208, 101, 2, 33, "Text"],
Cell[151358, 4212, 38, 0, 33, "Text"],
Cell[151399, 4214, 754, 18, 173, "Input"],
Cell[152156, 4234, 73, 0, 33, "Text"],
Cell[152232, 4236, 817, 16, 170, "Input"],
Cell[153052, 4254, 259, 9, 71, "Text"],
Cell[153314, 4265, 1174, 19, 290, "Input"],
Cell[154491, 4286, 404, 7, 85, "Input"],
Cell[154898, 4295, 404, 7, 85, "Input"],
Cell[155305, 4304, 404, 7, 85, "Input"]
}, Closed]],
Cell[155724, 4314, 709, 20, 104, "Text"],

Cell[CellGroupData[{
Cell[156458, 4338, 101, 2, 33, "Text"],
Cell[156562, 4342, 38, 0, 33, "Text"],
Cell[156603, 4344, 754, 18, 173, "Input"],
Cell[157360, 4364, 73, 0, 33, "Text"],
Cell[157436, 4366, 817, 16, 170, "Input"],
Cell[158256, 4384, 259, 9, 71, "Text"],
Cell[158518, 4395, 1174, 19, 290, "Input"],
Cell[159695, 4416, 404, 7, 85, "Input"],
Cell[160102, 4425, 404, 7, 85, "Input"],
Cell[160509, 4434, 404, 7, 85, "Input"]
}, Closed]],
Cell[160928, 4444, 158, 3, 32, "Text"],
Cell[161089, 4449, 536, 16, 33, "Text"],
Cell[161628, 4467, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

