(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     69028,       2099]*)
(*NotebookOutlinePosition[     69694,       2122]*)
(*  CellTagsIndexPosition[     69650,       2118]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Leontief Economic Model",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Introduction",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe mathematics model for the economy of a country or a region is \
based on the various sectors of this economy.  The Leontief model is \
addresses this problem.  Assume that each industry in the economy has two \
types of demands: an external demand (from outside the system) and an \
internal demand (demand placed on one industry by another in the same \
system), the Leontief model is a system of linear equations. The Leontief \
model was invented in the 30\[CloseCurlyQuote]s by Wassily Leontief who \
developed an economic model of the United States economy by dividing it into \
500 economic sectors.  Wassily Leontief received the economics ",
  ButtonBox["Nobel Prize",
    ButtonData:>{
      URL[ "http://www.nobel.se/economics/laureates/1973/"], None},
    ButtonStyle->"Hyperlink"],
  " on October 18, 1973.  "
}], "Text"],

Cell[TextData[{
  StyleBox["The Closed Leontief Model",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tAssume that an economy consists of  ",
  StyleBox["n",
    FontFamily->"Courier New"],
  "  interdependent industries (or sectors)  ",
  Cell[BoxData[
      RowBox[{\(S\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_n\)}]]],
  ".  Each industry will consume some of the goods produced by the other \
industries, including itself (for example, a power-generating plant uses some \
of its own power for production).  An economy is called ",
  StyleBox["closed",
    FontColor->RGBColor[0, 0, 1]],
  " if it satisfies its own needs; that is, no goods leave or enter the \
system.  We make the following conventions: \n\n",
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t ",
  Cell[BoxData[
      \(p\_i\)]],
  "     is  the production level of industry  ",
  Cell[BoxData[
      \(S\_i\)]],
  ",  \n\t\n",
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(a\_\(i, j\)\)]],
  "     is the number of units produced by industry ",
  Cell[BoxData[
      \(S\_i\)]],
  " that is necessary to produce one unit by industry ",
  Cell[BoxData[
      \(S\_j\)]],
  ",  \n\n",
  StyleBox["(iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(a\_\(i, j\)\) p\_j\)]],
  "     is the number of units produced by industry  ",
  Cell[BoxData[
      \(S\_i\)]],
  "  and consumed by industry  ",
  Cell[BoxData[
      \(S\_j\)]],
  ",  \n\n",
  StyleBox["(iv)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(a\_\(i, 1\)\) p\_1 + \(a\_\(i, 2\)\) p\_2 + \(a\_\(i, 3\)\) 
              p\_3 +  ... \) + \(a\_\(i, n\)\) p\_n\)]],
  "  is the total number of units produced by industry  ",
  Cell[BoxData[
      \(S\_i\)]],
  ".  \n\nSince the economy is closed, the total production for industry ",
  Cell[BoxData[
      \(S\_i\)]],
  " equals it total consumption and we have the equations \n\n\t\t",
  Cell[BoxData[
      \(\(\(a\_\(i, 1\)\) p\_1 + \(a\_\(i, 2\)\) p\_2 + \(a\_\(i, 3\)\) 
                p\_3 +  ... \) + \(a\_\(i, n\)\) p\_n\  = \ p\_i\)]],
  "   \n\nfor  ",
  Cell[BoxData[
      RowBox[{\(i = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  "."
}], "Text"],

Cell[TextData[{
  "If the economy is balanced, the total production of each industry must be \
equal to its total consumption. This results in the linear system:",
  StyleBox["\n\n",
    FontFamily->"Times New Roman"],
  "\t\t",
  Cell[BoxData[{
      \(\(a\_\(1, 1\)\) p\_1 + \(a\_\(1, 2\)\) p\_2 + \(a\_\(1, 3\)\) 
            p\_3 + \[CenterEllipsis] + \(a\_\(1, n - 1\)\) 
            p\_\(n - 1\) + \(a\_\(1, n\)\) p\_n\  = \ p\_1\), 
    "\[IndentingNewLine]", 
      \(\(a\_\(2, 1\)\) p\_1 + \(a\_\(2, 2\)\) p\_2 + \(a\_\(2, 3\)\) 
            p\_3 + \[CenterEllipsis] + \(a\_\(2, n - 1\)\) 
            p\_\(n - 1\) + \(a\_\(2, n\)\) p\_n\  = \ p\_2\), "\n", 
      \(\(\(\(a\_\(3, 1\)\) p\_1 + \(a\_\(3, 2\)\) p\_2 + \(a\_\(3, 3\)\) 
            p\_3 + \[CenterEllipsis] + \(a\_\(3, n - 1\)\) 
            p\_\(n - 1\) + \(a\_\(3, n\)\) p\_n\  = \ 
        p\_3\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(\[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\(a\_\(n, 1\)\) p\_1 + \(a\_\(n, 2\)\) p\_2 + \(a\_\(n, 3\)\) 
            p\_3 + \[CenterEllipsis] + \(a\_\(n, n - 1\)\) 
            p\_\(n - 1\) + \(a\_\(n, n\)\) p\_n\  = \ p\_n\)}]],
  "     ",
  StyleBox["   \n\nwhich can be written in matrix form",
    FontFamily->"Times New Roman"],
  "  \n\t\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\ P\),
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", " ", 
        StyleBox["P",
          FontWeight->"Bold"]}]]],
  StyleBox[". \n\nThe matrix",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "is called the input-output matrix, and  ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  "  is the production vector.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " ",
  StyleBox[ButtonBox["Leontief Model",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LeontiefModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Leontief Model",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LeontiefModelProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the closed three sector economy  ",
  Cell[BoxData[
      RowBox[{\(S\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_3\)}]]],
  " consisting of say:  Energy, Manufacturing, and Services where the \
input-output matrix is given by \n\n",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0.2", "0.3", "0.2"},
              {"0.5", "0.2", "0.3"},
              {"0.3", "0.5", "0.5"}
              }], ")"}]}]]],
  ".   Find the production vector  ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  ".   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the matrix  ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          RowBox[{"(", GridBox[{
                {"0.2", "0.3", "0.2"},
                {"0.5", "0.2", "0.3"},
                {"0.3", "0.5", "0.5"}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(vars = {x\_1\ , x\_2\ , 
          x\_3};\), "\[IndentingNewLine]", \(Print["\<Solve the equation A X \
= X\>"];\), "\n", \(Print[MatrixForm[A] MatrixForm[vars], "\< = \>", 
        MatrixForm[vars]];\)}], "Input"],

Cell[TextData[{
  "If  ",
  Cell[BoxData[
      \(\[Lambda]\_1 = 1\)]],
  " is an eigenvalue of  ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Lambda]\_1\), ",", 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "1"]}]]],
  StyleBox["  an eigen-pair, ",
    FontFamily->"Times New Roman"],
  "then the solution to  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\ X\),
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", " ", 
        StyleBox["X",
          FontWeight->"Bold"]}]]],
  StyleBox[" will be a multiple of the eigenvector  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SubscriptBox[
        StyleBox["V",
          FontWeight->"Bold"], "1"]]],
  StyleBox[". \nLet us verify that ",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      \(\[Lambda]\_1 = 1\)]],
  " ",
  StyleBox["is an eigenvalue of",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvalues are\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(\[Lambda]\_i\)} = \>\"", 
        Chop[Eigenvalues[A]]];\)\ \)}], "Input"],

Cell[TextData[{
  "The eigen-pair ",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Lambda]\_1\), ",", 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "1"]}]]],
  StyleBox["  is easily computed using ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["'s subroutines  ",
    FontFamily->"Times New Roman"],
  StyleBox["Eigenvalues",
    FontFamily->"Courier New"],
  " ",
  StyleBox[" and  ",
    FontFamily->"Times New Roman"],
  StyleBox["Eigenvectors",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(\[Lambda]\_1\  = \ \
\(Eigenvalues[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ \(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1 = Partition[V\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \[Lambda]\_1, \*"\"\<,   \
\!\(V\_1\) = \>\"", MatrixForm[V\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<We can verify that  A \!\(V\_1\) = \
\!\(V\_1\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[V\_1], "\< = \>", 
        MatrixForm[V\_1]];\)\)}], "Input"],

Cell[TextData[{
  "Since",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["X",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", 
        RowBox[{"c", " ", 
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "1"]}]}]]],
  "  is a solution for any constant  ",
  StyleBox["c",
    FontFamily->"Courier New"],
  StyleBox[", we are permitted to choose any multiple of  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SubscriptBox[
        StyleBox["V",
          FontWeight->"Bold"], "1"]]],
  StyleBox[" we desire for the solution.  For illustration:",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(c = 64.6684;\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda]\_1\  = \ \
\(Eigenvalues[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        c\ \(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1 = Partition[V\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \[Lambda]\_1, \*"\"\<,   \
\!\(V\_1\) = \>\"", c, 
        MatrixForm[\(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)], "\< = \>", 
        MatrixForm[V\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<We can verify that  A \!\(V\_1\) = \
\!\(V\_1\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[V\_1], "\< = \>", 
        MatrixForm[V\_1]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  ",
  "Any value of  ",
  StyleBox["c",
    FontFamily->"Courier New"],
  StyleBox["  is permitted, it is your choice.  ",
    FontFamily->"Times New Roman"],
  "When ",
  Cell[BoxData[
      \(c = 80\)]],
  " we get "
}], "Text"],

Cell[BoxData[{
    \(\(c = 80;\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda]\_1\  = \ \
\(Eigenvalues[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ 
        c\ \(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1 = Partition[V\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \[Lambda]\_1, \*"\"\<,   \
\!\(V\_1\) = \>\"", c, 
        MatrixForm[\(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)], "\< = \>", 
        MatrixForm[V\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<We can verify that  A \!\(V\_1\) = \
\!\(V\_1\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[V\_1], "\< = \>", 
        MatrixForm[V\_1]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\nHow did we get that \"nice\" vector ?\nBy using exact arithmetic and \
the following calculations."
}], "Text"],

Cell[TextData[{
  "Form the homogeneous system ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], 
              StyleBox["-",
                FontWeight->"Plain"], 
              StyleBox["I",
                FontWeight->"Bold"]}], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["P",
            FontWeight->"Bold"]}], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", " ", 
        StyleBox["0",
          FontWeight->"Bold"]}]]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  "  \nand the augmented matrix   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], " ", "=", 
        RowBox[{"[", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["A",
                  FontWeight->"Bold"], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox["I",
                  FontWeight->"Bold"]}], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox[")",
                FontWeight->"Plain"]}], ",", " ", 
            StyleBox["0",
              FontWeight->"Bold"]}], "]"}]}]]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "and find its reduced row echelon form."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"2", "3", "2"},
                  {"5", "2", "3"},
                  {"3", "5", "5"}
                  }], ")"}], "/", "10"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(a = 
        A - IdentityMatrix[3];\), "\n", \(B = {0, 0, 0};\), "\n", \(b = 
        Partition[B, 
          1];\), "\n", \(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\), "\
\n", 
    RowBox[{\(M = AppendRows[a, b];\), 
      " "}], "\n", \(Print["\< A  = \>", 
        MatrixForm[A]];\), "\[IndentingNewLine]", \(Print["\<A-I = \>", 
        MatrixForm[a]];\), "\n", \(Print["\< b  = \>", 
        MatrixForm[
          b]];\), "\n", \(Print["\<The augmented matrix M = [A-I,b] \
is\>"];\), "\n", \(Print["\<M = \>", MatrixForm[M]];\), "\[IndentingNewLine]",
   
    RowBox[{\(Print["\<The row reduced echelon form is\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<    \>", 
        MatrixForm[RowReduce[M]]];\)}], "Input"],

Cell["\<\
The step used in finding the row reduced echelon form are familiar row \
operations.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print[MatrixForm[M]];\)\), "\[IndentingNewLine]", 
    \(\(M\_\(\(\[LeftDoubleBracket]\)\({1, 2}\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\({2, 1}\)\(\[RightDoubleBracket]\)\);\)\
\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) = 
        2  M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\),\
 "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) + \
\(4\/5\) M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\) - \
\(3\/10\) 
            M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\)\
, "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) = \
\(-\(50\/49\)\) 
          M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\) - \
\(49\/50\) 
            M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\)\
, "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) + \
\(8\/5\) M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[TextData[{
  "The equations for this augmented matrix are  \n\n\t",
  Cell[BoxData[{
      \(x\_1\ \ \  - \ \ \ \ \ \ 25\/49\ x\_3\  = \ 0\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ x\_2\ \  - \ 34\/49\ x\_3\  = \ 0\)}]],
  "  \n\nThere is one free variables which we choose to be  ",
  Cell[BoxData[
      \(x\_3 = 49  t\)]],
  ".   It is used in computing  ",
  Cell[BoxData[
      \(x\_1\)]],
  "  and   ",
  Cell[BoxData[
      \(x\_2\)]],
  ".  \nUse ",
  Cell[BoxData[
      \(x\_3 = 49  t\)]],
  " and solve the previous equations for  ",
  Cell[BoxData[
      \(x\_1\)]],
  "  and   ",
  Cell[BoxData[
      \(x\_2\)]],
  " \n\n\t",
  Cell[BoxData[{
      \(x\_1\ \  - \ 25\/49\ 49  t\  = \ 0\), "\[IndentingNewLine]", 
      \(x\_2\ \  - \ 34\/49\ 49  t\  = \ 0\)}]],
  "  \n\nGet\t\n\t",
  Cell[BoxData[{
      \(x\_1\  = \ 25\ t\), "\[IndentingNewLine]", 
      \(x\_2\  = \ 34\ t\), "\[IndentingNewLine]", 
      \(x\_3\  = \ 49  t\)}]],
  " \n\nThe solution vector  ",
  Cell[BoxData[
      InterpretationBox[
        RowBox[{
          StyleBox["X",
            FontWeight->"Bold"], " ", "=", " ", 
          InterpretationBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)},
                  {\(x\_3\)}
                  }], "\[NoBreak]", ")"}],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3], 
              Subscript[ x, 4], 
              Subscript[ x, 5]}]]}],
        MatrixForm[ {
          Subscript[ x, 1], 
          Subscript[ x, 2], 
          Subscript[ x, 3]}]]]],
  "  is"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"X", "=", 
        TagBox[
          RowBox[{"(", GridBox[{
                {\(25\ t\)},
                {\(34\ t\)},
                {\(49\ t\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n\n",
    FontWeight->"Bold"],
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can verify that this is the solution by direct multiplication ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ",
  StyleBox["X",
    FontWeight->"Bold"],
  ".  This is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(\[Lambda]\_1\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ X;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \[Lambda]\_1, \*"\"\<,   \
\!\(V\_1\) = \>\"", MatrixForm[V\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<We can verify that  A \!\(V\_1\) = \
\!\(V\_1\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[V\_1], "\< = \>", 
        MatrixForm[V\_1]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are really done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n\n",
    FontWeight->"Bold"],
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Iteration can be used to solve for the solution of the closed Leontief \
model.  If the sum of the production levels is known and a starting vector is \
given  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["P",
          FontWeight->"Bold"], "0"]]],
  " then the simple iteration  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["P",
            FontWeight->"Bold"], "i"], " ", "=", " ", 
        RowBox[{
          StyleBox["A",
            FontWeight->"Bold"], " ", 
          SubscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], \(i - 1\)]}]}]]],
  "  will converge to  ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  ".  Because the largest eigenvalue is  ",
  Cell[BoxData[
      \(\[Lambda]\_1\  = \ 1\)]],
  ",  this is a simplified version of the \"power method\" for  finding the \
dominant eigen-pair.  For the example above  ",
  Cell[BoxData[
      \(p\_1 + p\_2 + p\_3 = \(25 + 34 + 49 = 108\)\)]],
  " and the following iteration will converge."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          RowBox[{"(", GridBox[{
                {"0.2", "0.3", "0.2"},
                {"0.5", "0.2", "0.3"},
                {"0.3", "0.5", "0.5"}
                }], ")"}]}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(P\_0\), "=", 
        RowBox[{"(", GridBox[{
              {"36"},
              {"36"},
              {"36"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>", \*"\"\<\!\(P\_0\) = \>\"", MatrixForm[P\_0]];\), 
      " "}], "\[IndentingNewLine]", \(For[i = 1, 
      i \[LessEqual] 8, \(i++\), \[IndentingNewLine]P\_i = 
        A . P\_\(i - 1\); \[IndentingNewLine]Print["\<\>", "\<P\>"\_i, "\< = \
\>", MatrixForm[A], MatrixForm[P\_\(i - 1\)], "\< = \>", 
        MatrixForm[P\_i]];\ ]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the closed five sector economy  ",
  Cell[BoxData[
      RowBox[{\(S\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_4\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_5\)}]]],
  " consisting of say: Agriculture, Construction, Energy, Manufacturing, and \
Services where the input-output matrix is given by \n\n",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0.1", "0.2", "0.2", "0.2", "0.1"},
              {"0.2", "0.2", "0.2", "0.2", "0.2"},
              {"0.2", "0.2", "0.1", "0.1", "0.1"},
              {"0.2", "0.2", "0.3", "0.2", "0.2"},
              {"0.3", "0.2", "0.2", "0.3", "0.4"}
              }], ")"}]}]]],
  " .   Find the production vector  ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  ".   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the matrix  ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          RowBox[{"(", GridBox[{
                {"0.1", "0.2", "0.2", "0.2", "0.1"},
                {"0.2", "0.2", "0.2", "0.2", "0.2"},
                {"0.2", "0.2", "0.1", "0.1", "0.1"},
                {"0.2", "0.2", "0.3", "0.2", "0.2"},
                {"0.3", "0.2", "0.2", "0.3", "0.4"}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(vars = {x\_1\ , x\_2\ , x\_3, x\_4\ , 
          x\_5};\), "\[IndentingNewLine]", \(Print["\<Solve the equation A X \
= X\>"];\), "\n", \(Print[MatrixForm[A] MatrixForm[vars], "\< = \>", 
        MatrixForm[vars]];\)}], "Input"],

Cell[TextData[{
  "If  ",
  Cell[BoxData[
      \(\[Lambda]\_1 = 1\)]],
  " is an eigenvalue of  ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Lambda]\_1\), ",", 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "1"]}]]],
  StyleBox["  an eigen-pair, ",
    FontFamily->"Times New Roman"],
  "then the solution to  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\ X\),
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", " ", 
        StyleBox["X",
          FontWeight->"Bold"]}]]],
  StyleBox[" will be a multiple of the eigenvector  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SubscriptBox[
        StyleBox["V",
          FontWeight->"Bold"], "1"]]],
  StyleBox[". \nLet us verify that ",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      \(\[Lambda]\_1 = 1\)]],
  " ",
  StyleBox["is an eigenvalue of",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvalues are\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(\[Lambda]\_i\)} = \>\"", 
        Chop[Eigenvalues[A]]];\)\ \)}], "Input"],

Cell[TextData[{
  "The eigen-pair ",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Lambda]\_1\), ",", 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "1"]}]]],
  StyleBox["  is easily computed using ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["'s subroutines  ",
    FontFamily->"Times New Roman"],
  StyleBox["Eigenvalues",
    FontFamily->"Courier New"],
  " ",
  StyleBox[" and  ",
    FontFamily->"Times New Roman"],
  StyleBox["Eigenvectors",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(\[Lambda]\_1\  = \ \
\(Eigenvalues[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ \(-\ \
\(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1 = Partition[V\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \[Lambda]\_1, \*"\"\<,   \
\!\(V\_1\) = \>\"", MatrixForm[V\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<We can verify that  A \!\(V\_1\) = \
\!\(V\_1\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[V\_1], "\< = \>", 
        MatrixForm[V\_1]];\)\)}], "Input"],

Cell[TextData[{
  "Since",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["X",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", 
        RowBox[{"c", " ", 
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "1"]}]}]]],
  "  is a solution for any constant  ",
  StyleBox["c",
    FontFamily->"Courier New"],
  StyleBox[", we are permitted to choose any multiple of  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SubscriptBox[
        StyleBox["V",
          FontWeight->"Bold"], "1"]]],
  StyleBox[" we desire for the solution.  For illustration:",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(c = 2296.13;\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda]\_1\  = \ \ \
\(Eigenvalues[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1\  = \(-\ 
            c\)\ \(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1 = Partition[V\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \[Lambda]\_1, \*"\"\<,   \
\!\(V\_1\) = \>\"", c, 
        MatrixForm[\(-\(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\)], "\< = \>", 
        MatrixForm[V\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<We can verify that  A \!\(V\_1\) = \
\!\(V\_1\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[V\_1], "\< = \>", 
        MatrixForm[V\_1]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  ",
  "Any value of  ",
  StyleBox["c",
    FontFamily->"Courier New"],
  StyleBox["  is permitted, it is your choice.  ",
    FontFamily->"Times New Roman"],
  "When ",
  Cell[BoxData[
      \(c = 80\)]],
  " we get "
}], "Text"],

Cell[BoxData[{
    \(\(c = 1000;\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda]\_1\  = \ \
\(Eigenvalues[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ \(-\ 
            c\)\ \(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1 = Partition[V\_1, 1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \[Lambda]\_1, \*"\"\<,   \
\!\(V\_1\) = \>\"", c, 
        MatrixForm[\(-\ \
\(Eigenvectors[A]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)\)], "\< = \>", MatrixForm[V\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<We can verify that  A \!\(V\_1\) = \
\!\(V\_1\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[V\_1], "\< = \>", 
        MatrixForm[V\_1]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\nHow did we get that \"nice\" vector ?\nBy using exact arithmetic and \
the following calculations."
}], "Text"],

Cell[TextData[{
  "Form the homogeneous system ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], 
              StyleBox["-",
                FontWeight->"Plain"], 
              StyleBox["I",
                FontWeight->"Bold"]}], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["P",
            FontWeight->"Bold"]}], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", " ", 
        StyleBox["0",
          FontWeight->"Bold"]}]]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  "  \nand the augmented matrix   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontWeight->"Bold"], " ", "=", 
        RowBox[{"[", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["A",
                  FontWeight->"Bold"], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox["I",
                  FontWeight->"Bold"]}], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox[")",
                FontWeight->"Plain"]}], ",", " ", 
            StyleBox["0",
              FontWeight->"Bold"]}], "]"}]}]]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "and find its reduced row echelon form."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", "2", "2", "2", "1"},
                {"2", "2", "2", "2", "2"},
                {"2", "2", "1", "1", "1"},
                {"2", "2", "3", "2", "2"},
                {"3", "2", "2", "3", "4"}
                }], ")"}], "/", "10"}]}], 
      ";"}], "\[IndentingNewLine]", \(a = 
        A - IdentityMatrix[5];\), "\n", \(B = {0, 0, 0, 0, 0};\), "\n", \(b = 
        Partition[B, 
          1];\), "\n", \(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\), "\
\n", 
    RowBox[{\(M = AppendRows[a, b];\), 
      " "}], "\n", \(Print["\< A  = \>", 
        MatrixForm[A]];\), "\[IndentingNewLine]", \(Print["\<A-I = \>", 
        MatrixForm[a]];\), "\n", \(Print["\< b  = \>", 
        MatrixForm[
          b]];\), "\n", \(Print["\<The augmented matrix M = [A-I,b] \
is\>"];\), "\n", \(Print["\<M = \>", MatrixForm[M]];\), "\[IndentingNewLine]",
   
    RowBox[{\(Print["\<The row reduced echelon form is\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<    \>", 
        MatrixForm[RowReduce[M]]];\)}], "Input"],

Cell[TextData[{
  "The equations for this augmented matrix are  \n\n\t",
  Cell[BoxData[{
      \(x\_1\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - \ 383\/732\ x\_5\  = \ 
        0\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ x\_2\ \ \ \ \ \ \ \ \ \ \ \ \  - \ 989\/1464\ x\_5\  = \ 
        0\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ x\_\(\(3\)\(\ \ \ \ \ \ \)\)\ \ \  - \ 
          335\/732\ x\_5\  = \ 0\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ x\_4\ \  - \ 44\/61\ x\_5\  = \ 
        0\)}]],
  "  \n\nThere is one free variables which we choose to be  ",
  Cell[BoxData[
      \(x\_5 = 1464  t\)]],
  ".   It is used in computing  ",
  Cell[BoxData[
      \(x\_1, x\_2, x\_3, x\_4\)]],
  ".  \nUse ",
  Cell[BoxData[
      \(x\_5 = 1464  t\)]],
  " and solve the previous equations for  ",
  Cell[BoxData[
      \(x\_1, x\_2, x\_3, x\_4\)]],
  "  \n\n\t",
  Cell[BoxData[{
      \(x\_1\ \ \  - \ 383\/732\ 1464  t\  = \ 0\), "\[IndentingNewLine]", 
      \(x\_2\ \ \  - \ 989\/1464\ 1464  t\  = \ 0\), "\[IndentingNewLine]", 
      \(x\_\(\(3\)\(\ \ \ \)\) - \ 335\/732\ 1464  t\  = \ 0\), 
    "\[IndentingNewLine]", 
      \(x\_4\ \  - \ 44\/61\ 1464  t\  = \ 0\)}]],
  "  \n\nGet\t\n\n\t",
  Cell[BoxData[{
      \(x\_1\  = \ 766\ t\), "\[IndentingNewLine]", 
      \(x\_2\  = \ 989\ t\), "\[IndentingNewLine]", 
      \(x\_\(\(3\)\(\ \ \)\) = \ 670\ t\), "\[IndentingNewLine]", 
      \(x\_4\  = \ 1056\ t\), "\[IndentingNewLine]", 
      \(x\_5\  = \ 1464  t\)}]],
  " \n\nThe solution vector  ",
  Cell[BoxData[
      InterpretationBox[
        RowBox[{
          StyleBox["X",
            FontWeight->"Bold"], " ", "=", " ", 
          InterpretationBox[
            RowBox[{"(", GridBox[{
                  {\(x\_1\)},
                  {\(x\_2\)},
                  {\(x\_3\)},
                  {\(x\_4\)},
                  {\(x\_5\)}
                  }], ")"}],
            MatrixForm[ {
              Subscript[ x, 1], 
              Subscript[ x, 2], 
              Subscript[ x, 3], 
              Subscript[ x, 4], 
              Subscript[ x, 5]}]]}],
        MatrixForm[ {
          Subscript[ x, 1], 
          Subscript[ x, 2], 
          Subscript[ x, 3]}]]]],
  "  is"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"X", "=", 
        TagBox[
          RowBox[{"(", GridBox[{
                {\(766\ t\)},
                {\(989\ t\)},
                {\(670\ t\)},
                {\(1056\ t\)},
                {\(1464  t\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n\n",
    FontWeight->"Bold"],
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can verify that this is the solution by direct multiplication ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ",
  StyleBox["X",
    FontWeight->"Bold"],
  ".  This is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(\[Lambda]\_1\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_1\  = \ X;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \[Lambda]\_1, \*"\"\<,   \
\!\(V\_1\) = \>\"", MatrixForm[V\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<We can verify that  A \!\(V\_1\) = \
\!\(V\_1\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[V\_1], "\< = \>", 
        MatrixForm[V\_1]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We are really done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n\n",
    FontWeight->"Bold"],
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Iteration can be used to solve for the solution of the closed Leontief \
model.  If the sum of the production levels is known and a starting vector is \
given  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["P",
          FontWeight->"Bold"], "0"]]],
  " then the simple iteration  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["P",
            FontWeight->"Bold"], "i"], " ", "=", " ", 
        RowBox[{
          StyleBox["A",
            FontWeight->"Bold"], " ", 
          SubscriptBox[
            StyleBox["P",
              FontWeight->"Bold"], \(i - 1\)]}]}]]],
  "  will converge to  ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  ".  Because the largest eigenvalue is  ",
  Cell[BoxData[
      \(\[Lambda]\_1\  = \ 1\)]],
  ",  this is a simplified version of the \"power method\" for  finding the \
dominant eigen-pair.  For the example above  ",
  Cell[BoxData[
      \(p\_1 + p\_2 + p\_3 + p\_4 + \(p\_5\) 766 + 989 + 670 + 1056 + 1464 = 
        4945\)]],
  " and the following iteration will converge."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          RowBox[{"(", GridBox[{
                {"0.1", "0.2", "0.2", "0.2", "0.1"},
                {"0.2", "0.2", "0.2", "0.2", "0.2"},
                {"0.2", "0.2", "0.1", "0.1", "0.1"},
                {"0.2", "0.2", "0.3", "0.2", "0.2"},
                {"0.3", "0.2", "0.2", "0.3", "0.4"}
                }], ")"}]}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(P\_0\), "=", 
        RowBox[{"(", GridBox[{
              {"989"},
              {"989"},
              {"989"},
              {"989"},
              {"989"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>", \*"\"\<\!\(P\_0\) = \>\"", MatrixForm[P\_0]];\), 
      " "}], "\[IndentingNewLine]", \(For[i = 1, 
      i \[LessEqual] 8, \(i++\), \[IndentingNewLine]P\_i = 
        A . P\_\(i - 1\); \[IndentingNewLine]Print["\<\>", "\<P\>"\_i, "\< = \
\>", MatrixForm[A], MatrixForm[P\_\(i - 1\)], "\< = \>", 
        MatrixForm[P\_i]];\ ]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Open Leontief Model",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe closed Leontief model describes the case when no goods leave or \
enter the economy.  But often times, an economy has to satisfy an outside \
demand.  In this case, let  ",
  Cell[BoxData[
      \(b\_i\)]],
  "  be the demand from the ",
  Cell[BoxData[
      \(i\^th\)]],
  " outside industry.  Let  ",
  Cell[BoxData[
      \(p\_i\)]],
  "  and  ",
  Cell[BoxData[
      \(a\_\(i, j\)\)]],
  "  be as in the closed model, then  \n\n\t\t",
  Cell[BoxData[
      \(p\_i\  = \ \(\(a\_\(i, 1\)\) p\_1 + \(a\_\(i, 2\)\) 
                p\_2 + \(a\_\(i, 3\)\) p\_3 +  ... \) + \(a\_\(i, n\)\) 
            p\_n + b\_i\)]],
  "  \n\nfor  ",
  Cell[BoxData[
      RowBox[{\(i = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ". "
}], "Text"],

Cell[TextData[{
  "This results in the linear system:",
  StyleBox["\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[{
      \(p\_1\  = \ \(a\_\(1, 1\)\) p\_1 + \(a\_\(1, 2\)\) 
            p\_2 + \(a\_\(1, 3\)\) 
            p\_3 + \[CenterEllipsis] + \(a\_\(1, n - 1\)\) 
            p\_\(n - 1\) + \(a\_\(1, n\)\) p\_n\  + \ b\_1\), "\n", 
      \(p\_2\  = \ \(a\_\(2, 1\)\) p\_1 + \(a\_\(2, 2\)\) 
            p\_2 + \(a\_\(2, 3\)\) 
            p\_3 + \[CenterEllipsis] + \(a\_\(2, n - 1\)\) 
            p\_\(n - 1\) + \(a\_\(2, n\)\) p\_n\  + \ b\_2\), "\n", 
      \(\(\(p\_3\  = \ \(a\_\(3, 1\)\) p\_1 + \(a\_\(3, 2\)\) 
            p\_2 + \(a\_\(3, 3\)\) 
            p\_3 + \[CenterEllipsis] + \(a\_\(3, n - 1\)\) 
            p\_\(n - 1\) + \(a\_\(3, n\)\) p\_n\  + \ 
          b\_3\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis\
]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(p\_n\  = \ \(a\_\(n, 1\)\) p\_1 + \(a\_\(n, 2\)\) 
            p\_2 + \(a\_\(n, 3\)\) 
            p\_3 + \[CenterEllipsis] + \(a\_\(n, n - 1\)\) 
            p\_\(n - 1\) + \(a\_\(n, n\)\) p\_n\  + \ b\_n\)}]],
  StyleBox["\n\nwhich can be written in matrix form",
    FontFamily->"Times New Roman"],
  "  \n\t\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox["P",
          FontWeight->"Bold"], "=", 
        RowBox[{
          StyleBox[\(A\ P\),
            FontWeight->"Bold"], " ", "+", " ", 
          StyleBox["B",
            FontWeight->"Bold"]}]}]]],
  StyleBox[", \n\nwhere ",
    FontFamily->"Times New Roman"],
  " ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  StyleBox["  and ",
    FontFamily->"Times New Roman"],
  " ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox["  are the same as in the closed model and ",
    FontFamily->"Times New Roman"],
  " ",
  Cell[BoxData[
      StyleBox["B",
        FontWeight->"Bold"]]],
  "  ",
  StyleBox["is the demand vector. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  "One way to solve this linear system is\n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["P",
            FontWeight->"Bold"], "-", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold"], " ", 
            StyleBox["P",
              FontWeight->"Bold"]}]}], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"], "  "}]]],
  "\n\t\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["P",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{
              StyleBox["I",
                FontWeight->"Bold"], "-", 
              StyleBox["A",
                FontWeight->"Bold"]}], ")"}]}], " ", "=", " ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  "  \n\t\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox["P",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox["I",
                  FontWeight->"Bold"], "-", 
                StyleBox["A",
                  FontWeight->"Bold"]}], ")"}], \(-1\)], 
          StyleBox["B",
            FontWeight->"Bold"]}]}]]],
  ".\n",
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  "\nOf course, the matrix  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{
          StyleBox["I",
            FontWeight->"Bold"], "-", 
          StyleBox["A",
            FontWeight->"Bold"]}], ")"}]]],
  "  must be invertible, which might not be always the case.  If, in \
addition, ",
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox["I",
              FontWeight->"Bold"], "-", 
            StyleBox["A",
              FontWeight->"Bold"]}], ")"}], \(-1\)]]],
  " has nonnegative entries, then the components of the vector",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  " ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "are nonnegative and therefore they are acceptable as solutions for this \
model.  We say in this case that the matrix",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  " ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "is productive."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " ",
  StyleBox[ButtonBox["Leontief Model",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LeontiefModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Leontief Model",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LeontiefModelProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the open three sector economy  ",
  Cell[BoxData[
      RowBox[{\(S\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_3\)}]]],
  " consisting of say:  Energy, Manufacturing, and Services where the \
input-output matrix is \n\n",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0.1", "0.2", "0.1"},
              {"0.4", "0.2", "0.2"},
              {"0.2", "0.3", "0.5"}
              }], ")"}]}]]],
  "  and the demand vector is  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["B",
          FontWeight->"Bold"], "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"92"},
                {"69"},
                {"115"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]]],
  ".  Find the production vector  ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  ".   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0.1", "0.2", "0.1"},
              {"0.4", "0.2", "0.2"},
              {"0.2", "0.3", "0.5"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {"92"},
              {"69"},
              {"115"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(X\  = \ 
        LinearSolve[IdentityMatrix[3] - A, 
          B];\), "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[A]];\), "\[IndentingNewLine]", \(Print["\<B = \>", 
        MatrixForm[B]];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<X  =  A X + B\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Get\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<X = \>", 
        MatrixForm[X]];\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done!",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can verify the solution by direct substitution."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<Does  X = A X + B ?\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[X], "\< = \>", MatrixForm[A], \ 
        MatrixForm[X], "\< + \>", \ 
        MatrixForm[B]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[X], "\< = \>", MatrixForm[A . \ X], "\< + \>", \ 
        MatrixForm[B]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[X], "\< = \>", 
        MatrixForm[A . \ X\  + \ B]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ X\  \[Equal] \ A . \ X\  + \ B\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["We are really done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n\n",
    FontWeight->"Bold"],
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Iteration can be used to solve for the solution of the closed Leontief \
model.  If the sum of the production levels is known and a starting vector is \
given  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["P",
          FontWeight->"Bold"], "0"]]],
  " then the simple iteration  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["P",
            FontWeight->"Bold"], "i"], " ", "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold"], " ", 
            SubscriptBox[
              StyleBox["P",
                FontWeight->"Bold"], \(i - 1\)]}], " ", "+", " ", 
          StyleBox["B",
            FontWeight->"Bold"]}]}]]],
  "  will converge to  ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  ".  This is reminiscent of Jacobi iteration and Gauss-Seidel iteration for \
solving a linear system.  For the example above  ",
  Cell[BoxData[
      \(p\_1 + p\_2 + p\_3 = \(235 + 335 + 525 = 1095\)\)]],
  " and the following iteration will converge (slowly)."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0.1", "0.2", "0.1"},
              {"0.4", "0.2", "0.2"},
              {"0.2", "0.3", "0.5"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {"92"},
              {"69"},
              {"115"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(P\_0\), "=", 
        RowBox[{"(", GridBox[{
              {"365"},
              {"365"},
              {"365"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>", \*"\"\<\!\(P\_0\) = \>\"", MatrixForm[P\_0]];\), 
      " "}], "\[IndentingNewLine]", \(For[i = 1, 
      i \[LessEqual] 22, \(i++\), \[IndentingNewLine]P\_i = 
        A . P\_\(i - 1\) + 
          B; \[IndentingNewLine]Print["\<\>", "\<P\>"\_i, "\< = \>", 
        MatrixForm[A], 
        PaddedForm[MatrixForm[P\_\(i - 1\)], {4, 1}], "\< + \>", 
        MatrixForm[B], "\< = \>", 
        PaddedForm[MatrixForm[P\_i], {4, 1}]];\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Any demand vector can be used, it is your choice.  For example:"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0.1", "0.2", "0.1"},
              {"0.4", "0.2", "0.2"},
              {"0.2", "0.3", "0.5"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
              {"80"},
              {"60"},
              {"100"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(X\  = \ 
        LinearSolve[IdentityMatrix[3] - A, 
          B];\), "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[A]];\), "\[IndentingNewLine]", \(Print["\<B = \>", 
        MatrixForm[B]];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<X  =  A X + B\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Get\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<X = \>", 
        MatrixForm[X]];\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the open five sector economy  ",
  Cell[BoxData[
      RowBox[{\(S\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_4\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(S\_5\)}]]],
  " consisting of say: Agriculture, Construction, Energy, Manufacturing, and \
Services where the input-output matrix is given by \n\n",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", "  ", 
        RowBox[{"(", GridBox[{
              {"0.1", "0.1", "0.2", "0.1", "0.1"},
              {"0.2", "0.2", "0.2", "0.2", "0.1"},
              {"0.1", "0.2", "0.1", "0.2", "0.1"},
              {"0.3", "0.1", "0.2", "0.2", "0.3"},
              {"0.2", "0.2", "0.2", "0.1", "0.3"}
              }], ")"}]}]]],
  "  and the demand vector is  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["B",
          FontWeight->"Bold"], "=", 
        TagBox[
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"21898"},
                  {"27270"},
                  {"25362"},
                  {"32732"},
                  {"29996"}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]]],
  ".  Find the production vector  ",
  Cell[BoxData[
      StyleBox["P",
        FontWeight->"Bold"]]],
  ".   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0.1", "0.1", "0.2", "0.1", "0.1"},
              {"0.2", "0.2", "0.2", "0.2", "0.1"},
              {"0.1", "0.2", "0.1", "0.2", "0.1"},
              {"0.3", "0.1", "0.2", "0.2", "0.3"},
              {"0.2", "0.2", "0.2", "0.1", "0.3"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"21898"},
                {"27270"},
                {"25362"},
                {"32732"},
                {"29996"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], 
      ";"}], "\[IndentingNewLine]", \(X\  = \ 
        LinearSolve[IdentityMatrix[5] - A, 
          B];\), "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[A]];\), "\[IndentingNewLine]", \(Print["\<B = \>", 
        MatrixForm[B]];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<X  =  A X + B\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Get\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<X = \>", 
        MatrixForm[X]];\)}], "Input"],

Cell[TextData[{
  StyleBox["We are done!",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can verify the solution by direct substitution."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<Does  X = A X + B ?\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[X], "\< = \>", MatrixForm[A], \ 
        MatrixForm[X], "\< + \>", \ 
        MatrixForm[B]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[X], "\< = \>", MatrixForm[A . \ X], "\< + \>", \ 
        MatrixForm[B]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[X], "\< = \>", 
        MatrixForm[A . \ X\  + \ B]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ X\  \[Equal] \ A . \ X\  + \ B\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Any demand vector can be used, it is your choice.  For example:"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0.1", "0.1", "0.2", "0.1", "0.1"},
              {"0.2", "0.2", "0.2", "0.2", "0.1"},
              {"0.1", "0.2", "0.1", "0.2", "0.1"},
              {"0.3", "0.1", "0.2", "0.2", "0.3"},
              {"0.2", "0.2", "0.2", "0.1", "0.3"}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"B", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"20000"},
                {"20000"},
                {"25000"},
                {"35000"},
                {"30000"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], 
      ";"}], "\[IndentingNewLine]", \(X\  = \ 
        LinearSolve[IdentityMatrix[5] - A, 
          B];\), "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[A]];\), "\[IndentingNewLine]", \(Print["\<B = \>", 
        MatrixForm[B]];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Solve\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<X  =  A X + B\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Get\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<X = \>", 
        MatrixForm[X]];\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Leontief Model",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LeontiefModelBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Leontief Model",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LeontiefModelBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1003, 603},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 180, 4, 35, "Text"],
Cell[1959, 59, 1464, 49, 96, "Text"]
}, Closed]],
Cell[3438, 111, 948, 18, 125, "Text"],
Cell[4389, 131, 3933, 122, 375, "Text"],
Cell[8325, 255, 2177, 54, 297, "Text"],
Cell[10505, 311, 730, 25, 33, "Text"],
Cell[11238, 338, 1254, 39, 95, "Text"],

Cell[CellGroupData[{
Cell[12517, 381, 101, 2, 33, "Text"],
Cell[12621, 385, 178, 8, 33, "Text"],
Cell[12802, 395, 508, 12, 120, "Input"],
Cell[13313, 409, 1207, 46, 52, "Text"],
Cell[14523, 457, 257, 4, 70, "Input"],
Cell[14783, 463, 665, 24, 33, "Text"],
Cell[15451, 489, 810, 14, 172, "Input"],
Cell[16264, 505, 738, 25, 33, "Text"],
Cell[17005, 532, 999, 19, 193, "Input"],
Cell[18007, 553, 330, 14, 33, "Text"],
Cell[18340, 569, 994, 19, 193, "Input"],
Cell[19337, 590, 220, 6, 90, "Text"],
Cell[19560, 598, 1466, 49, 52, "Text"],
Cell[21029, 649, 1056, 25, 300, "Input"],
Cell[22088, 676, 108, 3, 33, "Text"],
Cell[22199, 681, 304, 5, 70, "Input"],
Cell[22506, 688, 238, 4, 50, "Input"],
Cell[22747, 694, 574, 10, 97, "Input"],
Cell[23324, 706, 255, 5, 63, "Input"],
Cell[23582, 713, 325, 6, 63, "Input"],
Cell[23910, 721, 310, 5, 63, "Input"],
Cell[24223, 728, 1665, 56, 375, "Text"],
Cell[25891, 786, 262, 9, 57, "Input"],
Cell[26156, 797, 429, 16, 71, "Text"],
Cell[26588, 815, 585, 10, 150, "Input"],
Cell[27176, 827, 1292, 40, 109, "Text"],
Cell[28471, 869, 851, 21, 193, "Input"]
}, Closed]],
Cell[29337, 893, 1978, 57, 143, "Text"],

Cell[CellGroupData[{
Cell[31340, 954, 101, 2, 33, "Text"],
Cell[31444, 958, 178, 8, 33, "Text"],
Cell[31625, 968, 670, 14, 156, "Input"],
Cell[32298, 984, 1207, 46, 52, "Text"],
Cell[33508, 1032, 257, 4, 70, "Input"],
Cell[33768, 1038, 665, 24, 33, "Text"],
Cell[34436, 1064, 819, 15, 172, "Input"],
Cell[35258, 1081, 738, 25, 33, "Text"],
Cell[35999, 1108, 1015, 19, 193, "Input"],
Cell[37017, 1129, 330, 14, 33, "Text"],
Cell[37350, 1145, 1007, 19, 193, "Input"],
Cell[38360, 1166, 220, 6, 90, "Text"],
Cell[38583, 1174, 1466, 49, 52, "Text"],
Cell[40052, 1225, 1142, 26, 336, "Input"],
Cell[41197, 1253, 2253, 62, 560, "Text"],
Cell[43453, 1317, 327, 11, 89, "Input"],
Cell[43783, 1330, 429, 16, 71, "Text"],
Cell[44215, 1348, 585, 10, 150, "Input"],
Cell[44803, 1360, 1331, 41, 109, "Text"],
Cell[46137, 1403, 1048, 25, 269, "Input"]
}, Closed]],
Cell[47200, 1431, 1644, 51, 163, "Text"],
Cell[48847, 1484, 2346, 63, 297, "Text"],
Cell[51196, 1549, 2400, 84, 204, "Text"],
Cell[53599, 1635, 730, 25, 33, "Text"],
Cell[54332, 1662, 1618, 52, 95, "Text"],

Cell[CellGroupData[{
Cell[55975, 1718, 101, 2, 33, "Text"],
Cell[56079, 1722, 1022, 26, 253, "Input"],
Cell[57104, 1750, 260, 9, 71, "Text"],
Cell[57367, 1761, 546, 9, 110, "Input"],
Cell[57916, 1772, 1320, 40, 109, "Text"],
Cell[59239, 1814, 1179, 32, 266, "Input"],
Cell[60421, 1848, 177, 5, 33, "Text"],
Cell[60601, 1855, 1022, 26, 253, "Input"]
}, Closed]],
Cell[61638, 1884, 2521, 75, 143, "Text"],

Cell[CellGroupData[{
Cell[64184, 1963, 101, 2, 33, "Text"],
Cell[64288, 1967, 1354, 33, 329, "Input"],
Cell[65645, 2002, 260, 9, 71, "Text"],
Cell[65908, 2013, 546, 9, 110, "Input"],
Cell[66457, 2024, 177, 5, 33, "Text"],
Cell[66637, 2031, 1354, 33, 329, "Input"]
}, Closed]],
Cell[68006, 2067, 158, 3, 32, "Text"],
Cell[68167, 2072, 561, 17, 33, "Text"],
Cell[68731, 2091, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

