(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    167437,       4844]*)
(*NotebookOutlinePosition[    168121,       4868]*)
(*  CellTagsIndexPosition[    168077,       4864]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Lagrange Polynomials",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox["Background.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tWe have seen how to expand a function  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " in a Maclaurin polynomial about ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  " involving the powers ",
  Cell[BoxData[
      \(x\^k\)]],
  " and a Taylor polynomial about ",
  Cell[BoxData[
      \(x\_0 \[NotEqual] 0\)]],
  " involving the powers ",
  Cell[BoxData[
      \(\((x - x\_0)\)\^k\)]],
  ".  The Lagrange polynomial of degree ",
  Cell[BoxData[
      \(n\)]],
  " passes through the ",
  Cell[BoxData[
      \(n + 1\)]],
  " points  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_k\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(y\_k\)}], ")"}]]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[\(\(...\)\(.\)\),
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  "  and were investigated by the mathematician ",
  StyleBox[ButtonBox["Joseph-Louis Lagrange",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Lagrange.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  " (1736-1813).   "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem ( ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://mathworld.wolfram.com/LagrangeInterpolatingPolynomial.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      RowBox[{"f", "\[Element]", 
        RowBox[{
          StyleBox[\(C\^\(n + 1\)\),
            FontWeight->"Bold"], "[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  " and  ",
  Cell[BoxData[
      RowBox[{\(x\_k\), "\[Element]", 
        RowBox[{"[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[\(\(...\)\(.\)\),
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  "  are distinct  values.  Then \n\n\t",
  Cell[BoxData[
      \(f \((x)\) = \(P\_n\) \((x)\) + \(R\_n\) \((x)\)\)]],
  ",\n\t\nwhere ",
  Cell[BoxData[
      \(\(P\_n\) \((x)\)\)]],
  " is a polynomial that can be used to approximate  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  ", \n\n\t",
  Cell[BoxData[
      RowBox[{\(\(P\_n\) \((x)\)\), "=", 
        RowBox[{
          StyleBox[
            UnderoverscriptBox["\[Sum]", 
              StyleBox[\(k = 0\),
                FontSize->10], 
              StyleBox["n",
                FontSize->10]],
            
            FontSize->
              18], \(y\_k\ \(\(\(\((x\  - \ x\_0)\)\  ... \) \((x\  - \ \
x\_\(k - 1\))\)\ \((x\  - \ x\_\(k + 1\))\)\  ... \)\ \((x\  - \ \
x\_n)\)\)\/\(\(\(\((x\_k - x\_0)\)\  ... \) \((x\_k - x\_\(k - 1\))\)\ \
\((x\_k - x\_\(k + 1\))\)\  ... \)\ \((x\_k - x\_n)\)\)\)}]}]]],
  "  \n\nand we write  \n\n\t",
  Cell[BoxData[
      \(f \((x)\) \[TildeTilde] \(P\_n\) \((x)\)\)]],
  ".\n\nThe Lagrange polynomial goes through the ",
  Cell[BoxData[
      \(n + 1\)]],
  " points  ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          RowBox[{"(", 
            RowBox[{\(x\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y\_k\)}], ")"}], "}"}], \(k = 0\),
         "n"]]],
  ",  i.e.\n\n\t",
  Cell[BoxData[
      \(\(P\_n\) \((x\_k)\)\  = \ f \((x\_k)\)\)]],
  "    for   ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[\(\(...\)\(.\)\),
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ".  \n\nThe remainder term  ",
  Cell[BoxData[
      \(\(R\_n\) \((x)\)\)]],
  " has the form\n\n\t",
  Cell[BoxData[
      RowBox[{\(\(R\_n\) \((x)\)\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((n + 1)\),
                      Derivative],
                    
                    MultilineFunction->None], \((c)\)}], \(\((n + 
                      1)\)!\)], \((x - x\_0)\), " ", \((x - x\_1)\), 
              " ", \((x - x\_2)\)}], " ", 
            "..."}], \((x - x\_\(n - 1\))\), \((x - x\_n)\)}]}]]],
  ",\n\nfor some value ",
  Cell[BoxData[
      \(c = c \((x)\)\)]],
  " that lies in the interval ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LagrangePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LagrangePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThe cubic curve in the figure below illustrates a Lagrange polynomial of \
degree n = 3, which passes through the four points ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_k\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(y\_k\)}], ")"}]]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["2",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3"}]]],
  ".  \n\t\n\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.38778e-017 0.181818 -7.12863e-018 0.142857 [
[.18182 -0.0125 -3 -9 ]
[.18182 -0.0125 3 0 ]
[.36364 -0.0125 -3 -9 ]
[.36364 -0.0125 3 0 ]
[.54545 -0.0125 -3 -9 ]
[.54545 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[.90909 -0.0125 -3 -9 ]
[.90909 -0.0125 3 0 ]
[-0.0125 .14286 -6 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18182 0 m
.18182 .00625 L
s
[(1)] .18182 -0.0125 0 1 Mshowa
.36364 0 m
.36364 .00625 L
s
[(2)] .36364 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(3)] .54545 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(4)] .72727 -0.0125 0 1 Mshowa
.90909 0 m
.90909 .00625 L
s
[(5)] .90909 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(2)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(3)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(4)] -0.0125 .57143 1 0 Mshowa
0 0 m
0 .6 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.18182 .28571 m
.21132 .3448 L
.22668 .36912 L
.2435 .39103 L
.25932 .40737 L
.27372 .41884 L
.28866 .42754 L
.29688 .43099 L
.30058 .43225 L
.30465 .43342 L
.30822 .43428 L
.31205 .43502 L
.31417 .43535 L
.31611 .4356 L
.31807 .43582 L
.3199 .43597 L
.32157 .43608 L
.32251 .43612 L
.32335 .43615 L
.32429 .43618 L
.32529 .43619 L
.32625 .4362 L
.32712 .43619 L
.32794 .43618 L
.32871 .43616 L
.32956 .43613 L
.33046 .43609 L
.3323 .43598 L
.33398 .43585 L
.33765 .43544 L
.34155 .43486 L
.34856 .4334 L
.35609 .43126 L
.36441 .42826 L
.37919 .42137 L
.39511 .41188 L
.42653 .38781 L
.45679 .35936 L
.48589 .32867 L
.51686 .29409 L
.54668 .26054 L
.57837 .2264 L
.6089 .19671 L
.63827 .17271 L
.65315 .16275 L
.66952 .15381 L
.67701 .15048 L
.68507 .14749 L
.69267 .14525 L
.69961 .14371 L
Mistroke
.70326 .14311 L
.70526 .14283 L
.70715 .14262 L
.70891 .14246 L
.71082 .14232 L
.71166 .14227 L
.71255 .14222 L
.71336 .14219 L
.71414 .14217 L
.71512 .14215 L
.71602 .14214 L
.71699 .14215 L
.71754 .14215 L
.71805 .14216 L
.71889 .14218 L
.71981 .14222 L
.72078 .14226 L
.72169 .14232 L
.72377 .14247 L
.72568 .14266 L
.72997 .14326 L
.7336 .14393 L
.73748 .14484 L
.74445 .14696 L
.75275 .15033 L
.76027 .1542 L
.77495 .16409 L
.79084 .17847 L
.80605 .19601 L
.82213 .21882 L
.8511 .27175 L
.88195 .34622 L
.90909 .42857 L
Mfstroke
1 0 0 r
.02 w
.18182 .28571 Mdot
.36364 .42857 Mdot
.72727 .14286 Mdot
.90909 .42857 Mdot
0 g
gsave
.2 .28571 -61 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38182 .44286 -61 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72727 .12857 -90.5938 -17.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89091 .42857 -120.188 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 172.75},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000[1000`40O003h00Oogoo8Goo000mOol5
000[Ool4000^Ool2000_Ool3000/Ool2000OOol003moo`03001oogoo02]oo`03001oogoo02ioo`04
001oogoo000_Ool00`00Oomoo`0ZOol01000Oomoo`007Woo000oOol00`00Oomoo`0/Ool00`00Oomo
o`0_Ool00`00Oomoo`0[Ool5000^Ool00`00Oomoo`0LOol003moo`03001oogoo02eoo`03001oogoo
02moo`03001oogoo02Yoo`04001oogoo000]Ool2000OOol003moo`03001oogoo02]oo`04001oogoo
000]Ool01000Oomoo`00;Goo00<007oo0000;Goo00<007ooOol07Woo000nOol2000^Ool2000_Ool2
000_Ool2000]Ool3000NOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000?
Oooo000<0006Ool000moo`03001oogoo02eoo`03001oogoo02eoo`03001oogoo02ioo`03001oogoo
02eoo`03001oogoo02eoo`03001oogoo01eoo`003goo00<007ooOol0;Goo00<007ooOol0;Goo00<0
07ooOol0;Woo00<007ooOol0;Goo00<007ooOol0;Goo00<007ooOol07Goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0Z7oo00<007ooOol02Goo10002Woo
10001Woo10000Woo00<007ooOol0>Goo000?Ool00`00Oomoo`2WOol00`00Oomoo`0:Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0hOol000moo`03
001oogoo0:Moo`03001oogoo00]oo`03001oogoo00Aoo`8000Moo`03001oogoo00Eoo`03001oogoo
00=oo`03001oogoo03Qoo`003goo00<007ooOol0YWoo00<007ooOol00goo0`0000Aoo`00000000=o
o`03001oogoo00Aoo`03001oogoo00Eoo`8000Moo`03001oogoo00=oo`03001oogoo03Moo`003goo
00<007ooOol0YWoo00<007ooOol017oo00D007ooOomoo`00009oo`04001oogoo0005Ool20006Ool2
0005Ool01000Oomoo`0017oo00<007ooOol0=goo000?Ool00`00Oomoo`2VOol00`00Oomoo`05Ool0
0`00Ool00004Ool2000>Ool00`00Ool00005Ool20005Ool00`00Oomoo`0gOol000moo`03001oogoo
0:Ioo`03001oogoo00Ioo`8001Aoo`04001oogoo000;Ool00`00Oomoo`0gOol000moo`03001oogoo
0:Ioo`03001oogoo00Eoo`04001oogoo000COol01000Oomoo`002goo00<007ooOol0=goo000?Ool0
0`00Oomoo`2VOol00`00Oomoo`04Ool3000017oo0000000047oo0`0000Aoo`00000000Uoo`03001o
ogoo03Moo`003goo00<007ooOol0Ygoo00<007ooOol0:Goo00<007ooOol0>7oo000?Ool00`00Oomo
o`2WOol00`00Oomoo`0YOol00`00Oomoo`0hOol000moo`03001oogoo0:Qoo`03001oogoo02Moo`03
001oogoo03Uoo`003goo00<007ooOol0ogoo3goo0006Ool50004Ool00`00Oomoo`2mOol3O01>Ool0
00Qoo`03001oogoo00Aoo`03001oogoo0;aoo`El04eoo`0027oo00<007ooOol017oo0P00^7oo1@0O
1G`0CGoo0008Ool00`00Oomoo`04Ool00`00Oomoo`2cOol401l5Ool5O00301m:Ool000Qoo`03001o
ogoo00Aoo`03001oogoo0;5oo`807`Yoo`=l00Aoo`807dQoo`001goo0P001Woo00<007ooOol0[Woo
0`0O5Goo0P0OAWoo000?Ool00`00Oomoo`2/Ool201lJOol00`0OOomoo`13Ool000moo`03001oogoo
0:Yoo`807aeoo`807d=oo`003goo00<007ooOol0ZGoo00<07gooOol07goo00<07gooOol0@7oo000?
Ool00`00Oomoo`2WOol201lSOol00`0OOomoo`0oOol000moo`03001oogoo0:Ioo`0301moogoo02Ao
o`807cmoo`003goo00<007ooOol0YGoo00<07gooOol09goo00<07gooOol0?7oo000?Ool00`00Oomo
o`2TOol00`0OOomoo`0YOol00`0OOomoo`0kOol000moo`03001oogoo0:9oo`807beoo`0301moogoo
03Yoo`003goo00<007ooOol0XGoo00<07gooOol0;Goo00<07gooOol0>Woo000?Ool00`00Oomoo`2P
Ool00`0OOomoo`0_Ool00`0OOomoo`0iOol000moo`03001oogoo09moo`0301moogoo035oo`0301mo
ogoo03Qoo`003goo00<007ooOol0WWoo00<07gooOol0<goo00<07gooOol0=goo000?Ool00`00Oomo
o`2MOol00`0OOomoo`0dOol00`0OOomoo`0gOol000moo`03001oogoo09aoo`0301moogoo03Ioo`03
01moogoo03Ioo`003goo00<007ooOol0VWoo0P0O>Woo00<07gooOol0=Goo000?Ool00`00Oomoo`2I
Ool00`0OOomoo`0jOol00`0OOomoo`0eOol000moo`03001oogoo09Qoo`0301moogoo03aoo`0301mo
ogoo03Aoo`003goo00<007ooOol0Ugoo00<07gooOol0?Woo00<07gooOol0<goo000?Ool00`00Oomo
o`2FOol00`0OOomoo`0oOol00`0OOomoo`0cOol000moo`03001oogoo09Eoo`0301moogoo045oo`03
01moogoo039oo`003goo00<007ooOol0U7oo00<07gooOol0@Woo00<07gooOol0<Woo000?Ool00`00
Oomoo`2COol00`0OOomoo`14Ool00`0OOomoo`0aOol000moo`03001oogoo099oo`0301moogoo04Eo
o`0301moogoo035oo`003goo00<007ooOol0TWoo00<07gooOol0AWoo00<07gooOol0<7oo000?Ool0
0`00Oomoo`2AOol00`0OOomoo`18Ool00`0OOomoo`0_Ool000moo`03001oogoo091oo`0301moogoo
04Uoo`0301moogoo02moo`003goo00<007ooOol0Sgoo00<07gooOol0Bgoo00<07gooOol0;Woo000?
Ool00`00Oomoo`2>Ool00`0OOomoo`1<Ool00`0OOomoo`0^Ool000moo`03001oogoo08eoo`0301mo
ogoo04ioo`0301moogoo02eoo`003goo00<007ooOol0>Woo00<007ooOol05goo100037oo00<007oo
Ool09Goo00<07gooOol0Cgoo00<07gooOol0;Goo000?Ool00`00Oomoo`0iOol00`00Oomoo`0;Ool2
0004Ool00`00Oomoo`06Ool00`00Oomoo`05Ool20005Ool00`00Oomoo`0SOol00`0OOomoo`1AOol0
0`0OOomoo`0/Ool000moo`03001oogoo03Uoo`03001oogoo00Yoo`04001oogoo0003Ool20008Ool0
0`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol08Woo00<07gooOol0DWoo00<07gooOol0;7oo
0006Ool40005Ool00`00Oomoo`0/Ool3O009Ool00`00Oomoo`02Ool3000017oo000000000Woo00@0
07ooOol000Aoo`03001oogoo00Ioo`8000Aoo`04001oogoo0005Ool00`00Oomoo`0QOol00`0OOomo
o`1COol00`0OOomoo`0[Ool000Ioo`03001oogoo00Ioo`03001oogoo02]oo`El00Qoo`03001oogoo
00=oo`05001oogooOol00003Ool01000Oomoo`0017oo0P001goo0P0017oo00@007ooOol000Eoo`03
001oogoo021oo`0301moogoo05Aoo`0301moogoo02]oo`001goo00<007ooOol01Goo0P00;7oo1G`0
27oo00<007ooOol017oo00<007oo000017oo00@007ooOol000eoo`03001oo`0000=oo`04001oogoo
0005Ool00`00Oomoo`0OOol00`0OOomoo`1FOol00`0OOomoo`0ZOol000Qoo`03001oogoo00Aoo`03
001oogoo02]oo`El00Qoo`03001oogoo00Eoo`8000Eoo`8000ioo`04001oogoo0003Ool20006Ool0
0`00Oomoo`0NOol00`0OOomoo`1GOol00`0OOomoo`0ZOol000Ioo`04001oogoo0005Ool00`00Oomo
o`0/Ool3O009Ool00`00Oomoo`04Ool01000Oomoo`0057oo00@007ooOol000]oo`03001oogoo01eo
o`0301moogoo05Qoo`0301moogoo02Yoo`001goo0P001Woo00<007ooOol0;goo00<07gooOol01Woo
00<007ooOol00goo0`0000Aoo`000000015oo`<00004Ool000000009Ool00`00Oomoo`0LOol00`0O
Oomoo`1JOol00`0OOomoo`0YOol000moo`03001oogoo02moo`0301moogoo00Moo`03001oogoo02Uo
o`03001oogoo01aoo`0301moogoo05]oo`0301moogoo02Uoo`003goo00<007ooOol0<7oo00<07goo
Ool01Woo00<007ooOol0:Goo00<007ooOol06goo00<07gooOol0GGoo00<07gooOol0:7oo000?Ool0
0`00Oomoo`0`Ool00`0OOomoo`07Ool00`00Oomoo`0WOol00`00Oomoo`0KOol00`0OOomoo`1NOol0
0`0OOomoo`0XOol000moo`03001oogoo035oo`0301moogoo04ioo`0301moogoo05ioo`0301moogoo
02Qoo`003goo00<007ooOol0<Goo00<07gooOol0CGoo00<07gooOol0H7oo00<07gooOol09goo000?
Ool00`00Oomoo`0bOol00`0OOomoo`1;Ool00`0OOomoo`1QOol00`0OOomoo`0WOol000moo`03001o
ogoo039oo`0301moogoo04Yoo`0301moogoo06=oo`0301moogoo02Ioo`003goo00<007ooOol0<goo
00<07gooOol0B7oo00<07gooOol0I7oo00<07gooOol09Woo000?Ool00`00Oomoo`0cOol00`0OOomo
o`17Ool00`0OOomoo`1UOol00`0OOomoo`0VOol000moo`03001oogoo03Aoo`0301moogoo04Eoo`03
01moogoo06Moo`0301moogoo02Eoo`003goo00<007ooOol0=7oo00<07gooOol0A7oo00<07gooOol0
J7oo00<07gooOol09Goo000?Ool00`00Oomoo`0eOol00`0OOomoo`12Ool00`0OOomoo`1ZOol00`0O
Oomoo`0TOol000moo`03001oogoo03Eoo`0301moogoo049oo`0301moogoo06Yoo`0301moogoo02Ao
o`003goo00<007ooOol0=Woo00<07gooOol0@7oo00<07gooOol0Jgoo00<07gooOol097oo000?Ool0
0`00Oomoo`0fOol00`0OOomoo`0oOol00`0OOomoo`1]Ool00`0OOomoo`0SOol000moo`03001oogoo
03Moo`0301moogoo03eoo`0301moogoo06ioo`0301moogoo02=oo`003goo00<007ooOol0>7oo00<0
7gooOol0>goo00<07gooOol0Kgoo00<07gooOol08goo000?Ool00`00Oomoo`0hOol00`0OOomoo`0j
Ool00`0OOomoo`1aOol00`0OOomoo`0ROol000moo`03001oogoo03Uoo`0301moogoo03Qoo`0301mo
ogoo079oo`0301moogoo029oo`003goo00<007ooOol0>Woo00<07gooOol0=Woo00<07gooOol0Lgoo
00<07gooOol08Woo000?Ool00`00Oomoo`0kOol00`0OOomoo`0cOol201mgOol00`0OOomoo`0QOol0
00moo`03001oogoo03aoo`0301moogoo035oo`0301moogoo07Moo`0301moogoo025oo`003goo00<0
07ooOol0?7oo00<07gooOol0<7oo00<07gooOol0N7oo00<07gooOol08Goo000?Ool00`00Oomoo`0m
Ool00`0OOomoo`0^Ool00`0OOomoo`1jOol00`0OOomoo`0POol000moo`03001oogoo03ioo`0301mo
ogoo02aoo`0301moogoo07]oo`0301moogoo021oo`003goo00<007ooOol0?goo00<07gooOol0:Woo
00<07gooOol0O7oo00<07gooOol087oo000?Ool00`00Oomoo`10Ool00`0OOomoo`0XOol00`0OOomo
o`1mOol00`0OOomoo`0POol000moo`03001oogoo045oo`0301moogoo02Eoo`807h5oo`0301moogoo
01moo`003goo00<007ooOol0@Woo00<07gooOol08goo00<07gooOol0PGoo00<07gooOol07goo000?
Ool00`00Oomoo`13Ool00`0OOomoo`0QOol00`0OOomoo`1<Ool00`00Oomoo`0GOol4000<Ool00`00
Oomoo`09Ool00`0OOomoo`0OOol000moo`03001oogoo04Aoo`807b1oo`0301moogoo04aoo`03001o
ogoo00]oo`8000Eoo`03001oogoo00Eoo`03001oogoo00Ioo`8000Aoo`03001oogoo00Uoo`0301mo
ogoo01ioo`003goo00<007ooOol0AWoo00<07gooOol06goo0P0OCgoo00<007ooOol02Woo00@007oo
Ool000Aoo`8000Moo`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomoo`09Ool00`0OOomoo`0N
Ool000Moo`8000Ioo`03001oogoo04Moo`0301moogoo019oo`=l00=oo`807e1oo`03001oogoo00=o
o`<00004Ool000000003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool20007Ool00`00Oomoo`03Ool0
0`00Oomoo`08Ool3O00NOol000Ioo`04001oogoo0005Ool00`00Oomoo`18Ool201lAOol5O00201l8
Ool00`00Oomoo`0GOol4000<Ool00`00Oomoo`0MOol00`00Oomoo`04Ool01@00Oomoogoo00001Goo
00<007ooOol00goo0P001Woo0P0027oo00<007ooOol00Woo00<007ooOol01goo1G`07Goo0008Ool0
0`00Oomoo`04Ool2001;Ool00`0OOomoo`0>Ool5O009Ool00`00Oomoo`0:Ool50003Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool50002Ool00`00Oomoo`0LOol00`00Oomoo`05Ool00`00Ool00003Ool0
1000Oomoo`003Goo00<007oo000017oo00@007ooOol000Aoo`03001oogoo00Moo`El01eoo`002Goo
00<007ooOol00goo00<007ooOol0Bgoo1@0O2Goo0P0O1G`02Goo00<007ooOol037oo00<007ooOol0
0goo0P001goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol077oo00<007ooOol01Woo0P00
17oo0P003Woo00@007ooOol000Aoo`8000Eoo`03001oogoo00Moo`El01eoo`001Woo00@007ooOol0
00Eoo`03001oogoo051oo`T07`=oo`=l00Uoo`03001oogoo00=oo`<00004Ool000000003Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`0KOol00`00Oomoo`05
Ool01000Oomoo`004goo00@007ooOol000]oo`03001oogoo00Qoo`=l01ioo`001goo0P001Woo00<0
07ooOol0J7oo00<007ooOol017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`8000Ioo`8000Mo
o`03001oogoo00=oo`03001oogoo01]oo`03001oogoo00Aoo`<00004Ool00000000@Ool3000017oo
000000002Goo00<007ooOol0:Goo000?Ool00`00Oomoo`1XOol00`00Oomoo`05Ool00`00Ool00005
Ool00`00Oomoo`0<Ool00`00Ool00006Ool00`00Oomoo`03Ool00`00Oomoo`0LOol00`00Oomoo`0Y
Ool00`00Oomoo`0ZOol000moo`03001oogoo06Qoo`03001oogoo00Ioo`8000Aoo`8000ioo`04001o
ogoo0004Ool20005Ool00`00Oomoo`0LOol00`00Oomoo`0YOol00`00Oomoo`0ZOol000moo`03001o
ogoo06Qoo`03001oogoo00Eoo`04001oogoo000COol01000Oomoo`002goo00<007ooOol07Goo00<0
07ooOol09goo00<007ooOol0:goo000?Ool00`00Oomoo`1XOol00`00Oomoo`04Ool3000017oo0000
000047oo0`0000Aoo`00000000Uoo`03001oogoo07Eoo`003goo00<007ooOol0JGoo00<007ooOol0
:Goo00<007ooOol0MWoo000?Ool00`00Oomoo`1YOol00`00Oomoo`0YOol00`00Oomoo`1fOol000mo
o`03001oogoo06Yoo`03001oogoo02Moo`03001oogoo07Moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo0008
Ool30004Ool00`00Oomoo`3oOol?Ool000Uoo`03001oogoo00=oo`03001oogoo0?moo`moo`001Woo
1@0017oo0P00ogoo47oo0006Ool01000Oomoo`001Goo00<007ooOol0ogoo3goo0007Ool00`00Ool0
0005Ool00`00Oomoo`3oOol?Ool000Qoo`8000Eoo`03001oogoo0?moo`moo`003goo00<007ooOol0
ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0
ogoo3goo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {171.75, 0}} -> {0, 0, 0, 0}}]
}], "Text"],

Cell[BoxData[{
    \(x = 0; \ y = 0; \ \ Clear[p, t, x, y];\ \), "\[IndentingNewLine]", 
    \(\(p[
          t_] := \(y\_0\) \(\(\ \)\(\((t\  - \ x\_1)\)\ \((t\  - \ x\_2)\) \
\((t\  - \ x\_3)\)\)\)\/\(\((x\_0 - x\_1)\)\ \((x\_0 - x\_2)\)\ \((x\_0 - \
x\_3)\)\) + \(y\_1\) \(\((t\  - \ x\_0)\)\ \((t\  - \ x\_2)\) \((t\  - \ \
x\_3)\)\)\/\(\((x\_1 - x\_0)\)\ \ \((x\_1 - x\_2)\)\ \((x\_1 - x\_3)\)\) + \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \(y\_2\) \(\((t\  - \ x\_0)\)\ \
\((t\  - \ x\_1)\)\ \((t\  - \ x\_3)\)\)\/\(\((x\_2 - x\_0)\)\ \((x\_2 - \
x\_1)\)\ \ \((x\_2 - x\_3)\)\) + \(y\_3\) \(\((t\  - \ x\_0)\)\ \((t\  - \ \
x\_1)\)\ \((t\  - \ x\_2)\)\)\/\(\((x\_3 - x\_0)\)\ \((x\_3 - x\_1)\)\ \ \((x\
\_3 - x\_2)\)\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<p[\!\(x\_0\)] = \>\"", 
        p[x\_0], "\<\n\>", "\<\n\>", \*"\"\<p[\!\(x\_1\)] = \>\"", 
        p[x\_1], "\<\n\>", "\<\n\>", \*"\"\<p[\!\(x\_2\)] = \>\"", 
        p[x\_2], "\<\n\>", "\<\n\>", \*"\"\<p[\!\(x\_3\)] = \>\"", 
        p[x\_3]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Theorem.  (Error Bounds for Lagrange Interpolation, Equally \
Spaced Nodes)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox["  defined on",
    FontFamily->"Times New Roman"],
  " ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[",  which contains the equally spaced nodes  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_k = x\_0 + \ kh\)]],
  ".  Additionally, assume that  ",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "and the derivatives of",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "up to the order  ",
  Cell[BoxData[
      \(n + 1\)]],
  "  are continuous and bounded on the special subintervals  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_1\)}], "]"}]]],
  ", ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_2\)}], "]"}]]],
  ", ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_3\)}], "]"}]]],
  ", ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_4\)}], "]"}]]],
  ", and ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_5\)}], "]"}]]],
  ", respectively;  that is, \n\n\t",
  Cell[BoxData[
      RowBox[{"|", \(\(f\^\((n + 1)\)\) \((x)\)\), "|", " ", 
        RowBox[{"\[LessEqual]", "  ", 
          RowBox[{\(M\_\(n + 1\)\), "   ", 
            StyleBox["for",
              FontFamily->"Times New Roman"], "   ", \(x\_0\)}], "<", "x", 
          "<", \(x\_n\)}]}]]],
  ",  \n\nfor",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(n = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "4", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "5"}]]],
  ".  The error terms corresponding to these three cases have the following \
useful bounds on their magnitude  \n\n",
  StyleBox["(i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_1\) \((x)\)\)\(|\)\(\(\[LessEqual]\)\(\ \ \)\)\)\)]],
  Cell[BoxData[
      \(\(M\_2\/8\) h\^2\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_1\)}], "]"}]}]]],
  ",  \n\n",
  StyleBox["(ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_2\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\)\)\)]],
  Cell[BoxData[
      \(\(M\_3\/\(9\ \@3\)\) h\^3\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_2\)}], "]"}]}]]],
  ",  \n\n",
  StyleBox["(iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_3\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\)\)\)]],
  Cell[BoxData[
      \(\(M\_4\/24\) h\^4\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_3\)}], "]"}]}]]],
  ",  \n\n",
  StyleBox["(iv).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_4\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\)\)\)]],
  Cell[BoxData[
      \(\@\(4750 + 290\ \@145\)\/3000\ M\_5\ h\^5\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_4\)}], "]"}]}]]],
  ",  \n\n",
  StyleBox["(v).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_5\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\)\)\)]],
  Cell[BoxData[
      \(\(\(10 + 7\ \@7\)\/1215\) \(M\_6\) h\^6\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_5\)}], "]"}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LagrangePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LagrangePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://mathworld.wolfram.com/LagrangeInterpolatingPolynomial.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "To construct the Lagrange polynomial  \n\n\t",
  Cell[BoxData[
      RowBox[{\(P \((x)\)\), "=", 
        RowBox[{
          StyleBox[
            UnderoverscriptBox["\[Sum]", 
              StyleBox[\(k = 0\),
                FontSize->10], 
              StyleBox["n",
                FontSize->10]],
            FontSize->18], \(y\_k\ \(L\_\(n, k\)\) \((x)\)\)}]}]]],
  "  \n\t\nof degree ",
  Cell[BoxData[
      \(n\)]],
  ",  based on the ",
  Cell[BoxData[
      \(n + 1\)]],
  " points ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_k\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(y\_k\)}], ")"}]]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ".  The Lagrange coefficient polynomials  ",
  Cell[BoxData[
      \(\(L\_\(n, k\)\) \((x)\)\)]],
  "  for degree ",
  Cell[BoxData[
      \(n\)]],
  " are:  \n\n\t",
  Cell[BoxData[
      \(\(L\_\(n, 
              k\)\) \((x)\)\  = \ \(\(\(\((x\  - \ x\_0)\)\  ... \) \((x\  - \
\ x\_\(k - 1\))\)\ \((x\  - \ x\_\(k + 1\))\)\  ... \)\ \((x\  - \ \
x\_n)\)\)\/\(\(\(\((x\_k - x\_0)\)\  ... \) \((x\_k - x\_\(k - 1\))\)\ \
\((x\_k - x\_\(k + 1\))\)\  ... \)\ \((x\_k - x\_n)\)\)\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LagrangePolyProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LagrangePolyProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  "You can use the first ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine that does things in the \"traditional way\" or you are welcome \
to use the second subroutine that illustrates  \"Object Oriented Programming.\
\"  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (Lagrange Polynomial). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Traditional programming.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[
    \(\(\(Lagrange[
          XY_] := \[IndentingNewLine]Module[{j, k, n, prod, sum, term, X, 
            Y}, \[IndentingNewLine]n\  = \ 
            Length[XY] - 
              1; \ \[IndentingNewLine]X\  = \ \(Transpose[XY]\)\_\(\(\
\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]Y\  = \ \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\
\(\[RightDoubleBracket]\)\); \ \[IndentingNewLine]sum = 
            0; \ \[IndentingNewLine]For[\ k = 0, \ 
            k \[LessEqual] n, \ \(k++\), \[IndentingNewLine]prod\  = \ 
              1; \ \[IndentingNewLine]For[\ j = 0, \ 
              j \[LessEqual] n, \ \(j++\), \[IndentingNewLine]term\  = \ 
                Which[\ j \[Equal] k, \ 
                  1, \[IndentingNewLine]j \[NotEqual] 
                    k, \(x\  - \ X\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\
\[RightDoubleBracket]\)\)\)\/\(X\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\
\[RightDoubleBracket]\)\) - X\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\
\[RightDoubleBracket]\)\)\)\ ]; \ \[IndentingNewLine]prod\  = \ 
                prod\ \ \ term;\ ]; \ \[IndentingNewLine]sum\  = \ 
              sum\  + \ 
                Y\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\[RightDoubleBracket]\
\)\)\ prod;\ ]; \ \[IndentingNewLine]Return[sum];\ ];\)\(\ \)\)\)], "Input"],

Cell["\<\
The above algorithm is sufficient for understanding and/or constructing the \
Lagrange polynomial.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Object Oriented Programming.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Welcome to the brave new world of \"Object Oriented Programming.\"  Use \
the following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine which is \"programmed\" using the \"mathematical objects\"  ",
  Cell[BoxData[
      RowBox[{\(X\_k_\), ",", \(Y\_k_\), ",", 
        RowBox[{
          
          StyleBox[\(\[Sum]\+\(\[Placeholder] = \[Placeholder]\)\%\
\[Placeholder]\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["\[Placeholder]",
              FontWeight->"Bold"], "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", 
            
            StyleBox[\(\[Product]\+\(\[Placeholder] = \[Placeholder]\)\%\
\[Placeholder] \[Placeholder]\),
              FontWeight->"Bold"]}]}]}]]],
  ".  Templates for the objects are located by going to \"File\" then select \
\"Palettes\", then select \"BasicInput.\"  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (Lagrange Polynomial). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Object oriented programming.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[
    \(\(\(Lagrange[
          XY_] := \[IndentingNewLine]Module[{j, k, n, X, 
            Y}, \[IndentingNewLine]X\_k_\  := \ \(Transpose[XY]\)\_\(\(\
\[LeftDoubleBracket]\)\(1, k + 1\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]Y\_k_\  := \ \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\
\(2, k + 1\)\(\[RightDoubleBracket]\)\); \ \[IndentingNewLine]n\  = \ 
            Length[XY] - 1; \ \[IndentingNewLine]For[\ k = 0, \ 
            k \[LessEqual] 
              n, \ \(k++\), \[IndentingNewLine]\(L[n, k, 
                  x_]\  = \ \((\ \[Product]\+\(j = 0\)\%\(k - 1\)\(x - X\_j\)\
\/\(X\_k - X\_j\))\) \((\[Product]\+\(j = k + 1\)\%n\( x - X\_j\)\/\(X\_k - X\
\_j\))\);\)\ \ ]; \ \[IndentingNewLine]Return[\ \ \[Sum]\+\(k = 0\)\%n\( 
                    Y\_k\) L[n, k, x]\ ];\ ];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (Lagrange Polynomial). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Compact object oriented programming.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[
    \(\(\(Lagrange[
          XY_] := \[IndentingNewLine]Module[{j, k, n, X, 
            Y}, \[IndentingNewLine]X\_k_\  := \ \(Transpose[XY]\)\_\(\(\
\[LeftDoubleBracket]\)\(1, k + 1\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]Y\_k_\  := \ \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\
\(2, k + 1\)\(\[RightDoubleBracket]\)\); \ \[IndentingNewLine]n\  = \ 
            Length[XY] - 
              1; \ \[IndentingNewLine]Return[\ \ \[Sum]\+\(k = 0\)\%n Y\_k\ \
\((\ \[Product]\+\(j = 0\)\%\(k - 1\)\(x - X\_j\)\/\(X\_k - X\_j\))\) \((\
\[Product]\+\(j = k + 1\)\%n\( x - X\_j\)\/\(X\_k - X\_j\))\)\ ];\ ];\)\(\ \)\
\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Getting comfortable with objects.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The function form for a subscripted variable  ",
  Cell[BoxData[
      StyleBox[\(c\_n_\),
        FontWeight->"Bold"]]],
  ",  and the summation object  ",
  Cell[BoxData[
      StyleBox[\(\[Sum]\+\(\[Placeholder] = \[Placeholder]\)\%\[Placeholder] \
\[Placeholder]\),
        FontWeight->"Bold"]],
    GeneratedCell->True],
  "  can be used to construct a power series function.\nFor example, the \
coefficients for the exponential series are reciprocals of factorials. "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox[\(c\_n_\),
            FontWeight->"Bold"], "=", \(1\/\(n!\)\)}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(c\_n\) = \>\"", ",", 
            StyleBox[\(c\_n\),
              FontWeight->"Bold"]}], " ", "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", " ", 
          RowBox[{"Table", "[", 
            StyleBox[\(c\_n, {n, 0, 5}\),
              FontWeight->"Bold"], 
            StyleBox["]",
              FontWeight->"Bold"]}], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontWeight->"Bold"]}], 
        StyleBox[";",
          FontWeight->"Bold"]}], 
      StyleBox["  ",
        FontWeight->"Bold"]}]}], "Input"],

Cell[TextData[{
  "They can be used together to make a familiar polynomial approximation to \
",
  Cell[BoxData[
      \(\[ExponentialE]\^x\)]],
  "."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(p[x_]\), "=", 
          RowBox[{\(\[Sum]\+\(n = 0\)\%5\), 
            RowBox[{
              StyleBox[\(c\_n\),
                FontWeight->"Bold"], " ", \(x\^n\)}]}]}], ";"}], 
      "   "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), "  "}], "\[IndentingNewLine]",
   
    RowBox[{\(Plot[{p[x], \[ExponentialE]\^x}, {x, \(-5\), 5}, 
          PlotRange \[Rule] {{\(-5.2\), 5.2}, {\(-20\), 150}}, 
          PlotStyle \[Rule] {Blue, Red}];\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<y = \>", \[ExponentialE]\^x\ ];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<y = \>", p[x]\ ];\), "  "}]}], "Input"],

Cell[TextData[{
  "Our use of the function for a subscripted variable precludes some awkward \
subscripts in the list of data points which we want to label with the \
starting subscript zero, for example ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x\_k\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(y\_k\)}], ")"}]]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(XY\)\(=\)\(Table[{k, Sin[k]}, {k, 0, 4}]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Note that the \"points\" require a data structure that is a list of \
\"pairs\" of numbers. The mathematics we use uses individual values such as \
",
  Cell[BoxData[
      RowBox[{\(x\_k\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(y\_k\)}]]],
  ".  \n\nThe abscissas and ordinates are extracted with the assistance of \
the \"Transpose\" operator"
}], "Text"],

Cell[BoxData[
    \(\(\(Transpose[XY]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(Transpose[
          XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)\
\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(Transpose[
          XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\)\
\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Using the selection operation for matrices we can get the  ",
  Cell[BoxData[
      \(x\_2 = 1\)]],
  "  out of the \"list\" with the command"
}], "Text"],

Cell[BoxData[
    \(\(\(\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1, 
        2\)\(\[RightDoubleBracket]\)\)\)\(\ \ \)\)\)], "Input"],

Cell["\<\
That's o.k. but you need to add one to the \"matrix subscript\" to get the \
desired \"abscissa.\"  To make things nicer we used a function for a \
subscripted variable.\
\>", "Text"],

Cell[BoxData[{
    \(\(X\_k_\  := \ \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1, k + \
1\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\[IndentingNewLine]", 
    \(Table[X\_k, {k, 0, 4}]\ \ \)}], "Input"],

Cell["\<\
Compare this with the commands for working with \"matrix subscripts.\"  \
Notice the difference in the range: 0,1,2,3,4 for the subscripted variable \
and 1,2,3,4,5 for the \"table\" which is stored in a \"list.\"\
\>", "Text"],

Cell[BoxData[
    \(\(\(\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1, 
        Range[1, 5]\)\(\[RightDoubleBracket]\)\)\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "The product object ",
  Cell[BoxData[
      StyleBox[\(\[Product]\+\(\[Placeholder] = \[Placeholder]\)\%\
\[Placeholder] \[Placeholder]\),
        FontWeight->"Bold"]],
    GeneratedCell->True],
  "  is probably new to you.  It can be used to construct a polynomial with \
known roots."
}], "Text"],

Cell[BoxData[{
    \(\(p[
          x_] = \[Product]\+\(k = 1\)\%7\((x - 
              k)\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[p[x], {x, 0, 8}, 
        PlotStyle \[Rule] Magenta];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", Expand[p[x]]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "Construct three interpolating polynomials of degree  n=1  for the function \
 ",
  Cell[BoxData[
      \(f[x] = Cos[x]\)],
    AspectRatioFixed->False],
  "  over  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "1"}], "]"}]]],
  ".  \nUse the following sets of interpolation nodes.\n",
  StyleBox["1 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the nodes  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0.0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.0]\)}], "}"}], "  ", "and", "  ",
         
        RowBox[{"{", 
          RowBox[{"1.0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[1.0]\)}], "}"}]}]]],
  ".  \n",
  StyleBox["1 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the nodes  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0.1", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.1]\)}], "}"}], "  ", "and", "  ",
         
        RowBox[{"{", 
          RowBox[{"0.9", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.9]\)}], "}"}]}]]],
  ".  \n",
  StyleBox["1 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the nodes  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0.146447", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.146447]\)}], "}"}], "  ", "and",
         "  ", 
        RowBox[{"{", 
          RowBox[{"0.853553", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.853553]\)}], "}"}]}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["1 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Using the nodes  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0.0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.0]\)}], "}"}], " ", "and", " ", 
        
        RowBox[{"{", 
          RowBox[{"1.0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[1.0]\)}], "}"}]}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Cos[x];\)\ \ \), "\n", 
    \(\(XY = {{0.0, f[0.0]}, {1.0, f[1.0]}};\)\ \ \), "\n", 
    \(\(p\_1[x_] = Lagrange[XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\)[x] = \>\"", p\_1[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Now plot the function  ",
  Cell[BoxData[
      \(f[x]\)],
    AspectRatioFixed->False],
  "  and polynomial  ",
  Cell[BoxData[
      \(p\_1[x]\)],
    AspectRatioFixed->False],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[{f[x], p\_1[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Magenta, DarkGreen}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, dots, PlotRange \[Rule] {{0, 1.0}, {0.0, 1.15}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(p\_1\)[x] = \>\"", p\_1[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["1 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Using the nodes  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0.1", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.1]\)}], "}"}], " ", "and", " ", 
        
        RowBox[{"{", 
          RowBox[{"0.9", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.9]\)}], "}"}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Cos[x];\)\ \ \), "\n", 
    \(\(XY = {{0.1, f[0.1]}, {0.9, f[0.9]}};\)\ \ \), "\n", 
    \(\(q\_1[x_] = Lagrange[XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_1\)[x] = \>\"", q\_1[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Now plot the function  ",
  Cell[BoxData[
      \(f[x]\)],
    AspectRatioFixed->False],
  "  and polynomial  ",
  Cell[BoxData[
      \(q\_1[x]\)],
    AspectRatioFixed->False],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[{f[x], q\_1[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Magenta, DarkGreen}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, dots, PlotRange \[Rule] {{0, 1.0}, {0.0, 1.15}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(q\_1\)[x] = \>\"", q\_1[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["1 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Using the nodes  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{"0.146447", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.146447]\)}], "}"}], " ", "and", 
        " ", 
        RowBox[{"{", 
          RowBox[{"0.853553", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[0.853553]\)}], "}"}]}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Cos[x];\)\ \ \), "\n", 
    \(\(XY = {{0.146447, f[0.146447]}, {0.853553, 
            f[0.853553]}};\)\ \ \), "\n", 
    \(\(t\_1[x_] = Lagrange[XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(t\_1\)[x] = \>\"", t\_1[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Now plot the function  ",
  Cell[BoxData[
      \(f[x]\)],
    AspectRatioFixed->False],
  "  and polynomial  ",
  Cell[BoxData[
      \(t\_1[x]\)],
    AspectRatioFixed->False],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[{f[x], t\_1[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Magenta, DarkGreen}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, dots, PlotRange \[Rule] {{0, 1.0}, {0.0, 1.15}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(t\_1\)[x] = \>\"", t\_1[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Notice that the three polynomials of degree n = 1 were different.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(p\_1\)[x] = \>\"", 
        p\_1[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\)[x] = \>\"", 
        Expand[p\_1[x]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(q\_1\)[x] = \>\"", 
        q\_1[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_1\)[x] = \>\"", 
        Expand[q\_1[x]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(t\_1\)[x] = \>\"", 
        t\_1[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(t\_1\)[x] = \>\"", 
        Expand[t\_1[x]]\ ];\)\ \ \)}], "Input"],

Cell["Compare the various graphs.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gr3 = 
        Plot[{f[x], p\_1[x], q\_1[x], t\_1[x]}, {x, 0, 1}, 
          PlotRange \[Rule] {{0, 1.0}, {0.0, 1.15}}, 
          PlotStyle \[Rule] {Magenta, DarkGreen, Blue, 
              Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x]\>", f[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y = \!\(p\_1\)[x]\>\"", p\_1[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<y = \!\(q\_1\)[x]\>\"", q\_1[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<y = \!\(t\_1\)[x]\>\"", t\_1[x]\ ];\)\ \ \)}], "Input"],

Cell["\<\
Notice that the three polynomials of degree n = 1 are different.  The error \
in approximating  f[x]  will also be different.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(gr3 = 
        Plot[{f[x] - p\_1[x], f[x] - q\_1[x], f[x] - t\_1[x]}, {x, 0, 1}, 
          PlotStyle \[Rule] {DarkGreen, Blue, 
              Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y = Cos[x] - \!\(p\_1\)[x]\>\""];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<y = Cos[x] - \!\(q\_1\)[x]\>\""];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<y = Cos[x] - \!\(t\_1\)[x]\>\""];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Which polynomial has the smallest overall error on the entire interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "1"}], "]"}]],
    AspectRatioFixed->False],
  ".  Later we will discover that  ",
  Cell[BoxData[
      \(t\_1[x]\)]],
  "  was based on \"Chebyshev's nodes.\""
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["   ",
    FontWeight->"Bold"],
  "Form several Lagrange polynomials of degree  n = 2, 3, 4, and 5  for the \
function  ",
  Cell[BoxData[
      \(f[x] = Cos[x]\)],
    AspectRatioFixed->False],
  "  over the interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "1"}], "]"}]],
    AspectRatioFixed->False],
  "  using  n+1 equally spaced nodes.  Then compare the four Lagrange \
polynomials."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Construct the Lagrange interpolation polynomial ",
  Cell[BoxData[
      \(p\_2[x]\)]],
  ",  of degree n = 2.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[x_] = Cos[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(XY = 
        Table[{\(1.0\/n\) k, f[\(1.0\/n\) k]}, {k, 0, n}];\)\ \ \), "\n", 
    \(\(p\_2[x_] = Lagrange[XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Nodes = \>", 
        XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_2\)[x] = \>\"", 
        p\_2[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_2\)[x] = \>\"", 
        Expand[p\_2[x]]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Now graph the function and polynomial, and interpolation nodes.\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr2 = 
        Plot[{f[x], p\_2[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Magenta, Orange}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr2, dots, PlotRange \[Rule] {{0.0, 1.0}, {0, 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(p\_2\)[x] = \>\"", p\_2[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr2 = 
        Plot[{f[x], p\_2[x]}, {x, \(-1.5\), 2.2}, 
          PlotStyle \[Rule] {Magenta, Orange}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr2, dots, PlotRange \[Rule] {{\(-1.0\), 2.0}, {\(-0.7\), 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(p\_2\)[x] = \>\"", p\_2[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Construct the Lagrange interpolation polynomial ",
  Cell[BoxData[
      \(p\_3[x]\)]],
  ", of degree n = 3.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[x_] = Cos[x];\)\ \ \), "\n", 
    \(\(n = 3;\)\ \ \), "\[IndentingNewLine]", 
    \(\(XY = 
        Table[{\(1.0\/n\) k, f[\(1.0\/n\) k]}, {k, 0, 
            n}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(p\_3[x_] = Lagrange[XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_3\)[x] = \>\"", 
        p\_3[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_3\)[x] = \>\"", 
        Expand[p\_3[x]]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Now graph the function and polynomial, and interpolation nodes.\
\>", "Text"],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr3 = 
        Plot[{f[x], p\_3[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Magenta, Violet}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr3, dots, PlotRange \[Rule] {{0.0, 1.0}, {0.0, 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(p\_3\)[x] = \>\"", p\_3[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr3 = 
        Plot[{f[x], p\_3[x]}, {x, \(-1.5\), 2.2}, 
          PlotStyle \[Rule] {Magenta, Violet}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr3, dots, PlotRange \[Rule] {{\(-1.0\), 2.0}, {\(-0.7\), 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(p\_3\)[x] = \>\"", p\_3[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Construct the Lagrange interpolation polynomial ",
  Cell[BoxData[
      \(p\_4[x]\)]],
  ", of degree n = 4.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[x_] = Cos[x];\)\ \ \), "\n", 
    \(\(n = 4;\)\ \ \), "\[IndentingNewLine]", 
    \(\(XY = 
        Table[{\(1.0\/n\) k, f[\(1.0\/n\) k]}, {k, 0, n}];\)\ \ \), "\n", 
    \(\(p\_4[x_] = Lagrange[XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_4\)[x] = \>\"", 
        p\_4[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_4\)[x] = \>\"", 
        Expand[p\_4[x]]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Now graph the function and polynomial, and interpolation nodes.\
\>", "Text"],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr4 = 
        Plot[{f[x], p\_4[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Magenta, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr4, dots, PlotRange \[Rule] {{0.0, 1.0}, {0.0, 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(p\_4\)[x] = \>\"", p\_4[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr4 = 
        Plot[{f[x], p\_4[x]}, {x, \(-1.5\), 2.2}, 
          PlotStyle \[Rule] {Magenta, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr4, dots, PlotRange \[Rule] {{\(-1.0\), 2.0}, {\(-0.5\), 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(p\_4\)[x] = \>\"", p\_4[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (d).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Construct the Lagrange interpolation polynomial ",
  Cell[BoxData[
      \(p\_5[x]\)]],
  ", of degree n = 5.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, P5, Q5, x];\)\ \ \), "\n", 
    \(\(f[x_] = Cos[x];\)\ \ \), "\n", 
    \(\(n = 5;\)\ \ \), "\[IndentingNewLine]", 
    \(\(XY = 
        Table[{\(1.0\/n\) k, f[\(1.0\/n\) k]}, {k, 0, 
            n}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(p\_5[x_] = Lagrange[XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_5\)[x] = \>\"", 
        p\_5[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_5\)[x] = \>\"", 
        Expand[p\_5[x]]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Now graph the function and polynomial, and interpolation nodes.\
\>", "Text"],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr5 = 
        Plot[{f[x], p\_5[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Magenta, Green}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr5, dots, PlotRange \[Rule] {{0.0, 1.0}, {0.0, 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY, "\<\n\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(p\_5\)[x] = \>\"", p\_5[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr5 = 
        Plot[{f[x], p\_5[x]}, {x, \(-1.5\), 2.2}, 
          PlotStyle \[Rule] {Magenta, Green}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr5, dots, PlotRange \[Rule] {{\(-1.0\), 2.0}, {\(-0.7\), 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<\!\(p\_5\)[x] = \>\"", p\_5[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (e).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Show[gr2, gr3, gr4, gr5, dots, 
        PlotRange \[Rule] {{\(-1.5\), 2.2}, {\(-1.0\), 1.0}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(p\_2\)[x] = \>\"", 
        p\_2[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_3\)[x] = \>\"", 
        p\_3[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_4\)[x] = \>\"", 
        p\_4[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_5\)[x] = \>\"", p\_5[x]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Error Analysis.  Investigate the error for the Lagrange polynomial \
approximations ",
  "of degree  n = 2, 3, 4, and 5 ",
  "in Example 2."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Investigate the error for the Lagrange interpolation polynomial ",
  Cell[BoxData[
      \(p\_2[x]\)]],
  ",  of degree n = 2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(e\_2[x_] = f[x] - p\_2[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(maxerror2\  = \ 0.00329294;\)\), "\[IndentingNewLine]", 
    \(\(ge2 = 
        Plot[{0.00329, \(-0.00429\), e\_2[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Cyan, Cyan, Blue}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(p\_2\)[x] = \>\"", 
        p\_2[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<Graph of the error \!\(e\_2\)[x] = f[x] - \
\!\(p\_2\)[x]\>\""];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Looking at the above graph we make the following estimate for the error: \
",
  Cell[BoxData[
      \(\(\(|\)\(e\_2[x]\)\(|\)\(\(\[LessEqual]\)\(\ \)\(0.00329294\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Use formula (ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_2\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\)\)\)]],
  Cell[BoxData[
      \(\(M\_3\/\(9\ \@3\)\) h\^3\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_2\)}], "]"}]}]]],
  ",  and find the error bound for this example. "
}], "Text"],

Cell[BoxData[{\(h = 1\/2;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(M\_3\), " ", "=", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((3)\),
              Derivative],
            MultilineFunction->None], "[", "1", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((3)\),
                Derivative],
              MultilineFunction->None], "[", "x", "]"}], " ", 
          ",", \({x, 0, 1}\), ",", \(PlotStyle \[Rule] Green\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< \!\(
\*SuperscriptBox[\(f\), 
TagBox[\((3)\),
Derivative],
MultilineFunction->None]\)[x]  = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "[", "x", "]"}]}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print[\*"\"\<|\!\(f\^\((3)\)\)(x)| \
\[LessEqual]  \!\(M\_3\) = \>\"", M\_3, "\< = \>", 
        N[M\_3]];\), "\[IndentingNewLine]", \(Print["\<h = \>", 
        h];\), "\[IndentingNewLine]", \(Print[\*"\"\<The remainder term \!\(R\
\_2\)(x) has the form\>\""];\), "\[IndentingNewLine]", \
\(Print[\*"\"\<|\!\(R\_2\)(x)| \[LessEqual] \>\"", \*"\"\<\!\(M\_3\/\(9\\\ \
\@3\)\)\!\(h\^3\) = \>\"", \(M\_3\/\(9\ \@3\)\) h\^3, "\< = \>", 
        N[\(M\_3\/\(9\ \@3\)\) h\^3]];\)}], "Input"],

Cell[TextData[{
  "Thus,  ",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_2\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\(0.00674754860547359`\)\)\)\)]],
  "  is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{"0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], "]"}]}]]],
  ",  which is a little bit larger than the maximum error  ",
  StyleBox["0.00329294",
    FontFamily->"Courier New"],
  ".  After all, it is an error bound.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Investigate the error for the Lagrange interpolation polynomial ",
  Cell[BoxData[
      \(p\_3[x]\)]],
  ",  of degree n = 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(e\_3[x_] = f[x] - p\_3[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(maxerror3\  = \ 0.000463413;\)\ \), "\[IndentingNewLine]", 
    \(\(ge3 = 
        Plot[{\(-0.000463\), 0.000252, \(-0.000427\), e\_3[x]}, {x, 0.0, 
            1.0}, PlotStyle \[Rule] {Cyan, Cyan, Cyan, 
              Blue}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(p\_3\)[x] = \>\"", 
        p\_3[x]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<Graph of the error \!\(e\_3\)[x] = f[x] - \
\!\(p\_3\)[x]\>\""];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Looking at the above graph we make the following estimate for the error: \
",
  Cell[BoxData[
      \(\(\(|\)\(e\_3[
          x]\)\(|\)\(\(\[LessEqual]\)\(\ \
\)\(0.00046341275695549466`\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Use formula (iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_3\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\)\)\)]],
  Cell[BoxData[
      \(\(M\_4\/24\) h\^4\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_3\)}], "]"}]}]]],
  ",  and find the error bound for this example.  "
}], "Text"],

Cell[BoxData[{\(h = 1\/3;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(M\_4\), " ", "=", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((4)\),
              Derivative],
            MultilineFunction->None], "[", "0", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((4)\),
                Derivative],
              MultilineFunction->None], "[", "x", "]"}], " ", 
          ",", \({x, 0, 1}\), ",", \(PlotStyle \[Rule] Green\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\< \!\(
\*SuperscriptBox[\(f\), 
TagBox[\((4)\),
Derivative],
MultilineFunction->None]\)[x]  = \>\"", ",", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((4)\),
                  Derivative],
                MultilineFunction->None], "[", "x", "]"}]}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<|\!\(
\*SuperscriptBox[\(f\), 
TagBox[\((4)\),
Derivative],
MultilineFunction->None]\)[x]| \[LessEqual]  \!\(M\_4\) = \>\"", 
          ",", \(M\_4\), ",", "\"\< = \>\"", ",", \(N[M\_4]\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<h = \>", 
        h];\), "\[IndentingNewLine]", \(Print[\*"\"\<The remainder term \!\(R\
\_3\)(x) has the form\>\""];\), "\[IndentingNewLine]", \
\(Print[\*"\"\<|\!\(R\_3\)(x)| \[LessEqual] \>\"", \*"\"\<\!\(M\_4\/24\)\!\(h\
\^4\) = \>\"", \(M\_4\/24\) h\^4, "\< = \>", 
        N[\(M\_4\/24\) h\^4]];\)}], "Input"],

Cell[TextData[{
  "Thus,  ",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_3\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\(0.000514403\)\)\)\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{"0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], "]"}]}]]],
  ",  which is a little bit larger than the maximum error  ",
  StyleBox["0.000463413",
    FontFamily->"Courier New"],
  ".  After all, it is an error bound.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Investigate the error for the Lagrange interpolation polynomial ",
  Cell[BoxData[
      \(p\_4[x]\)]],
  ",  of degree n = 4."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(e\_4[x_] = f[x] - p\_4[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(maxerror4\  = \ \[InvisibleSpace]0.0000157713;\)\), "\
\[IndentingNewLine]", 
    \(\(ge4 = 
        Plot[{\(-0.0000122\), 0.00000527, \(-0.00000572\), 0.0000158, 
            e\_4[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Cyan, Cyan, Cyan, Cyan, Blue}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(p\_4\)[x] = \>\"", 
        p\_4[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<Graph of the error \!\(e\_4\)[x] = f[x] - \
\!\(p\_4\)[x]\>\""];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Looking at the above graph we make the following estimate for the error: \
",
  Cell[BoxData[
      \(\(\(|\)\(e\_4[
          x]\)\(|\)\(\(\[LessEqual]\)\(\ \)\(0.0000157712878811056`\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Use formula (iv).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_4\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\)\)\)]],
  Cell[BoxData[
      \(\@\(4750 + 290\ \@145\)\/3000\ M\_5\ h\^5\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_4\)}], "]"}]}]]],
  ",  and find the error bound for this example. "
}], "Text"],

Cell[BoxData[{\(h = 1\/4;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(M\_5\), " ", "=", 
        RowBox[{"Abs", "[", 
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((5)\),
                Derivative],
              MultilineFunction->None], "[", "1", "]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Abs", "[", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((5)\),
                  Derivative],
                MultilineFunction->None], "[", "x", "]"}], "]"}], " ", 
          ",", \({x, 0, 1}\), ",", \(PlotStyle \[Rule] Green\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<|\!\(
\*SuperscriptBox[\(f\), 
TagBox[\((5)\),
Derivative],
MultilineFunction->None]\)[x]| = \>\"", ",", 
            RowBox[{"Abs", "[", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((5)\),
                    Derivative],
                  MultilineFunction->None], "[", "x", "]"}], "]"}]}], "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<|\!\(
\*SuperscriptBox[\(f\), 
TagBox[\((5)\),
Derivative],
MultilineFunction->None]\)[x]| \[LessEqual]  \!\(M\_5\) = \>\"", 
          ",", \(M\_5\), ",", "\"\< = \>\"", ",", \(N[M\_5]\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<h = \>", 
        h];\), "\[IndentingNewLine]", \(Print[\*"\"\<The remainder term \!\(R\
\_4\)(x) has the form\>\""];\), "\[IndentingNewLine]", \
\(Print[\*"\"\<|\!\(R\_4\)(x)| \[LessEqual] \>\"", \*"\"\<\!\(\@\(4750 + \
290\\\ \@145\)\/3000\) \!\(M\_5\) \!\(h\^5\) = \>\"", \@\(4750 + 290\ \@145\)\
\/3000\ M\_5\ h\^5, "\< = \>", 
        N[\@\(4750 + 290\ \@145\)\/3000\ M\_5\ h\^5]];\)}], "Input"],

Cell[TextData[{
  "Thus,  ",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_4\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \ \
\)\(0.000024867715142468753`\)\)\)\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{"0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], "]"}]}]]],
  ",  which is a little bit larger than the maximum error  ",
  StyleBox["0.0000157713",
    FontFamily->"Courier New"],
  ".  After all, it is an error bound.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3 (d).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Investigate the error for the Lagrange interpolation polynomial ",
  Cell[BoxData[
      \(p\_5[x]\)]],
  ",  of degree n = 5."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(e\_5[x_] = f[x] - p\_5[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(maxerror5\  = \ 0.00000134999;\)\), "\[IndentingNewLine]", 
    \(\(ge5 = 
        Plot[{0.00000135, \(-0.000000398\), 0.000000273, \(-0.000000385\), 
            0.00000126, e\_5[x]}, {x, 0.0, 1.0}, 
          PlotStyle \[Rule] {Cyan, Cyan, Cyan, Cyan, Cyan, 
              Blue}];\)\ \ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(p\_5\)[x] = \>\"", 
        p\_5[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The interval for interpolation is [0.0,1.0].\>"];\)\ \ \), "\
\n", 
    \(\(Print[\*"\"\<Graph of the error \!\(e\_5\)[x] = f[x] - \
\!\(p\_5\)[x]\>\""];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Looking at the above graph we make the following estimate for the error: \
",
  Cell[BoxData[
      \(\(\(|\)\(e\_5[
          x]\)\(|\)\(\(\[LessEqual]\)\(\ \)\(0.00000134999\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Use formula (v).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_5\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \
\)\)\)\)]],
  Cell[BoxData[
      \(\(\(10 + 7\ \@7\)\/1215\) \(M\_6\) h\^6\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_5\)}], "]"}]}]]],
  ",  and find the error bound for this example. "
}], "Text"],

Cell[BoxData[{\(h = 1\/5;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(M\_6\), " ", "=", 
        RowBox[{"Abs", "[", 
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((6)\),
                Derivative],
              MultilineFunction->None], "[", "0", "]"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{"Abs", "[", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((6)\),
                  Derivative],
                MultilineFunction->None], "[", "x", "]"}], "]"}], " ", 
          ",", \({x, 0, 1}\), ",", \(PlotStyle \[Rule] Green\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<|\!\(
\*SuperscriptBox[\(f\), 
TagBox[\((6)\),
Derivative],
MultilineFunction->None]\)[x]| = \>\"", ",", 
            RowBox[{"Abs", "[", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((6)\),
                    Derivative],
                  MultilineFunction->None], "[", "x", "]"}], "]"}]}], "]"}], 
        ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{"\"\<|\!\(
\*SuperscriptBox[\(f\), 
TagBox[\((6)\),
Derivative],
MultilineFunction->None]\)[x]| \[LessEqual]  \!\(M\_6\) = \>\"", 
          ",", \(M\_6\), ",", "\"\< = \>\"", ",", \(N[M\_6]\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<h = \>", 
        h];\), "\[IndentingNewLine]", \(Print[\*"\"\<The remainder term \!\(R\
\_5\)(x) has the form\>\""];\), "\[IndentingNewLine]", \
\(Print[\*"\"\<|\!\(R\_5\)(x)| \[LessEqual] \>\"", \*"\"\<\!\(\(10 + 7 \@ 7\)\
\/1215\)\!\(M\_6\)\!\(h\^6\) = \>\"", \(\(10 + 7\ \@7\)\/1215\) \(M\_6\) 
          h\^6, "\< = \>", 
        N[\(\(10 + 7\ \@7\)\/1215\) \(M\_6\) h\^6]];\)}], "Input"],

Cell[TextData[{
  "Thus,  ",
  Cell[BoxData[
      \(\(\(|\)\(\(R\_5\) \((x)\)\)\(|\)\(\ \)\(\(\[LessEqual]\)\(\ \ \ \
\)\(1.5023017179892483`*^-6\)\)\)\)]],
  "   is valid for  ",
  Cell[BoxData[
      RowBox[{"x", "\[Element]", 
        RowBox[{"[", 
          RowBox[{"0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1"}], "]"}]}]]],
  ",  which is a little bit larger than the maximum error  ",
  Cell[BoxData[
      \(1.34999`*^-6\)]],
  ".  After all, it is an error bound.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Summary of the maximum error and the error bounds over the interval  [0, \
1] that were found in Example 3.\n",
  StyleBox["4 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(max\+\(o\  \[LessEqual] \ x\  \[LessEqual] \ 1\)\ {\(|\)\(f[x] - 
              p\_2[x]\)\(|\)}\)]],
  ".  \n",
  StyleBox["4 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(max\+\(o\  \[LessEqual] \ x\  \[LessEqual] \ 1\)\ {\(|\)\(f[x] - 
              p\_3[x]\)\(|\)}\)]],
  ".  \n",
  StyleBox["4 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(max\+\(o\  \[LessEqual] \ x\  \[LessEqual] \ 1\)\ {\(|\)\(f[x] - 
              p\_4[x]\)\(|\)}\)]],
  ".  \n",
  StyleBox["4 (d).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find  ",
  Cell[BoxData[
      \(max\+\(o\  \[LessEqual] \ x\  \[LessEqual] \ 1\)\ {\(|\)\(f[x] - 
              p\_5[x]\)\(|\)}\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(Show[ge2]; Show[ge3]; Show[ge4]; Show[ge5];\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<For \!\(p\_2\)[x] over the interval [0,1] we have  \
|\!\(e\_2\)[x]| \[LessEqual] \>\"", 
        maxerror2\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<For \!\(p\_3\)[x] over the interval [0,1] we have  \
|\!\(e\_3\)[x]| \[LessEqual] \>\"", 
        maxerror3\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<For \!\(p\_4\)[x] over the interval [0,1] we have  \
|\!\(e\_4\)[x]| \[LessEqual] \>\"", 
        maxerror4\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<For \!\(p\_5\)[x] over the interval [0,1] we have  \
|\!\(e\_5\)[x]| \[LessEqual] \>\"", maxerror5\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<The remainder term \!\(R\_n\)(x) has the \
form\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(R\_2\)(x)| \[LessEqual] \>\"", \*"\"\<\!\(M\_3\/\(9\
\\\ \@3\)\) \!\(h\^3\) = \>\"", 
        M\_3\/\(9\ \@3\), \*"\"\<(\!\(1\/2\)\!\(\()\^3\)\)\>\"", "\< = \>", 
        N[\(M\_3\/\(9\ \@3\)\) \((1\/2)\)\^3]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(R\_3\)(x)| \[LessEqual] \>\"", \
\*"\"\<\!\(M\_4\/24\) \!\(h\^4\) = \>\"", 
        M\_4\/24, \*"\"\<(\!\(1\/3\)\!\(\()\^4\)\)\>\"", "\< = \>", 
        N[\(M\_4\/24\) \((1\/3)\)\^4]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(R\_4\)(x)| \[LessEqual] \>\"", \*"\"\<\!\(\@\(4750 \
+ 290\\\ \@145\)\/3000\) \!\(M\_5\) \!\(h\^5\) = \>\"", \@\(4750 + 290\ \@145\
\)\/3000\ M\_5\ , \*"\"\<(\!\(1\/4\)\!\(\()\^5\)\)\>\"", "\< = \>", 
        N[\@\(4750 + 290\ \@145\)\/3000\ M\_5\ \((1\/4)\)\^5]];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(R\_5\)(x)| \[LessEqual] \>\"", \*"\"\<\!\(\(10 + \
7\\\ \@7\)\/1215\)\!\(M\_6\) \!\(h\^6\) = \>\"", \(\(10 + 7\ \@7\)\/1215\) 
          M\_6, \*"\"\<(\!\(1\/5\)\!\(\()\^6\)\)\>\"", "\< = \>", 
        N[\(\(10 + 7\ \@7\)\/1215\) \(M\_6\) \((1\/5)\)\^6]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<The maximum error is less than the error bound.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(e\_2\)[x]| \[LessEqual] \>\"", 
        maxerror2\ , "\<   \[LessEqual] \>", 
        N[\(M\_3\/\(9\ \@3\)\) \((1\/2)\)\^3]];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(e\_3\)[x]| \[LessEqual] \>\"", 
        maxerror3\ , "\<  \[LessEqual] \>", 
        N[\(M\_4\/24\) \((1\/3)\)\^4]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(e\_4\)[x]| \[LessEqual] \>\"", 
        maxerror4, "\< \[LessEqual] \>", 
        N[\@\(4750 + 290\ \@145\)\/3000\ M\_5\ \((1\/4)\)\^5]];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(e\_5\)[x]| \[LessEqual] \>\"", 
        maxerror5, "\< \[LessEqual] \>", 
        N[\(\(10 + 7\ \@7\)\/1215\) \(M\_6\) \((1\/5)\)\^6]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Various Scenarios and Animations for Lagrange \
Polynomials.",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = \@x\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([0, 2]\)\)]],
  ", ",
  Cell[BoxData[
      \(\([0, 8]\)\)]],
  ", and ",
  Cell[BoxData[
      \(\([0, 10]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \@x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 10.5;\)\ \), "\[IndentingNewLine]", 
    \(\(c = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(d = 3.5;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 2.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 2, 
      n \[LessEqual] 5, \(n++\), \[IndentingNewLine]aa = 
        0.0; \[IndentingNewLine]bb = 2.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \ \ \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[0, 10, 2], Range[0, 4, 1]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \[IndentingNewLine]Print["\
\<f[x] = \>", f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 4.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange04/Lagrangedd.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange04/Lagrangedd.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \@x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 4;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 10.5;\)\ \), "\[IndentingNewLine]", 
    \(\(c = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(d = 3.5;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 8.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 2, 
      n \[LessEqual] 5, \(n++\), \[IndentingNewLine]aa = 
        0.0; \[IndentingNewLine]bb = 8.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \ \ \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[0, 10, 2], Range[0, 4, 1]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 5.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange05/Lagrangeee.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange05/Lagrangeee.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \@x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 5;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 10.5;\)\ \), "\[IndentingNewLine]", 
    \(\(c = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(d = 3.5;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 10.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 2, 
      n \[LessEqual] 5, \(n++\), \[IndentingNewLine]aa = 
        0.0; \[IndentingNewLine]bb = 10.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \ \ \ \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[0, 10, 2], Range[0, 4, 1]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 6.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange06/Lagrangeff.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange06/Lagrangeff.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = 1\/\@\(1 - x\)\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-1.5\), 0.95]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 1\/\@\(1 - x\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-1.5\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1.5;\)\ \), "\[IndentingNewLine]", 
    \(\(c = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(d = 8.5;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-1.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 2, 
      n \[LessEqual] 
        5, \(n++\), \[IndentingNewLine]aa = \(-1.5\); \[IndentingNewLine]bb = 
        0.95; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \ \[IndentingNewLine]graph1 = 
        Plot[f[x], {x, \(-1.5\),  .9999}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]graph2 = 
        Plot[P[x], {x, \(-1.5\), 1.5}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph1, 
        graph2, Cdot, Rends, PlotRange \[Rule] {{a, b}, {c, d}}, 
        Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], Range[0, 5, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 7.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange07/Lagrangegg.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange07/Lagrangegg.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = 1\/\(1\  + \ 10  x\^2\)\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 1\/\(1 + 10  x\^2\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-1.5\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1.5;\)\ \), "\[IndentingNewLine]", 
    \(\(c = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(d = 1.25;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-1.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 3, 
      n \[LessEqual] 
        6, \(n++\), \[IndentingNewLine]aa = \(-1.0\); \[IndentingNewLine]bb = 
        1.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \ \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, \(-1.5\), 1.5}, 
          PlotStyle \[Rule] {Magenta, Blue}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, PlotRange \[Rule] {{a, b}, {c, d}}, 
        Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], Range[0, 1, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 8.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange08/Lagrangehh.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange08/Lagrangehh.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = Log[x]\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([0.02, 2]\)\)]],
  ", and ",
  Cell[BoxData[
      \(\([0.02, 4]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Log[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-0.5\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 4.1;\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-6.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = 3.0;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 2.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 2, 
      n \[LessEqual] 5, \(n++\), \[IndentingNewLine]aa = 
        0.02; \[IndentingNewLine]bb = 2.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \ \[IndentingNewLine]graph1 = 
        Plot[{f[x], P[x]}, {x, 0.001, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]graph2 = 
        Plot[P[x], {x, \(-0.5\), b}, PlotStyle \[Rule] {Magenta, Blue}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph1, 
        graph2, Cdot, Rends, PlotRange \[Rule] {{a, b}, {c, d}}, 
        Ticks \[Rule] {Range[\(-0.5\), 4.0, 0.5], Range[\(-5\), 0, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 9.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange09/Lagrangeii.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange09/Lagrangeii.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Log[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-0.5\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 4.1;\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-6.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = 3.0;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 4.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 2, 
      n \[LessEqual] 5, \(n++\), \[IndentingNewLine]aa = 
        0.02; \[IndentingNewLine]bb = 4.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \ \[IndentingNewLine]graph1 = 
        Plot[{f[x], P[x]}, {x, 0.001, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]graph2 = 
        Plot[P[x], {x, \(-0.5\), b}, PlotStyle \[Rule] {Magenta, Blue}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph1, 
        graph2, Cdot, Rends, PlotRange \[Rule] {{a, b}, {c, d}}, 
        Ticks \[Rule] {Range[\(-0.5\), 4.0, 0.5], Range[\(-6\), 0, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 10.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange10/Lagrangejj.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange10/Lagrangejj.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = Sin[x]\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-10\), 10]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-3\) \[Pi];\)\ \), "\[IndentingNewLine]", 
    \(\(b = 3  \[Pi];\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-1.3\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = \ 1.3;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-10\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 10;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        Graphics[{{Red, PointSize[0.02], 
              Point[{x0, f[x0]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[i = 2, 
      i \[LessEqual] 5, \(i++\), \[IndentingNewLine]n = 
        2  i + 4; \[IndentingNewLine]XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[\(-3\) \[Pi], 3  \[Pi], \[Pi]], 
              Range[\(-0.5\), 1, 0.5]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 12.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange12/Lagrangell.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange12/Lagrangell.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = Cos[x]\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-10\), 10]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Cos[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-3\) \[Pi];\)\ \), "\[IndentingNewLine]", 
    \(\(b = 3  \[Pi];\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-1.3\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = \ 1.3;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-10\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 10;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        Graphics[{{Red, PointSize[0.02], 
              Point[{x0, f[x0]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[i = 3, 
      i \[LessEqual] 6, \(i++\), \[IndentingNewLine]n = 
        2  i; \[IndentingNewLine]XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[\(-3\) \[Pi], 3  \[Pi], \[Pi]], 
              Range[\(-0.5\), 1, 0.5]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 13.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange13/Lagrangemm.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange13/Lagrangemm.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = Tan[x]\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-1.45\), 1.45]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Tan[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-\[Pi]\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \[Pi];\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-10\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = \ 10;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-1.45\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 1.45;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 3, 
      n \[LessEqual] 
        6, \(n++\), \[IndentingNewLine]aa = \(-1.45\); \[IndentingNewLine]bb \
= 1.45; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \[IndentingNewLine]graph1 = 
        Plot[f[x], {x, a, \(-\[Pi]\)\/2}, PlotStyle \[Rule] {Magenta}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]graph2 = 
        Plot[f[x], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, PlotStyle \[Rule] {Magenta}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]graph3 = 
        Plot[f[x], {x, \[Pi]\/2, b}, PlotStyle \[Rule] {Magenta}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]graph4 = 
        Plot[P[x], {x, \(-\[Pi]\), \[Pi]}, PlotStyle \[Rule] {Blue}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph1, 
        graph2, graph3, graph4, Cdot, Rends, 
        PlotRange \[Rule] {{a, b}, {c, d}}, 
        Ticks \[Rule] {Range[\(-\[Pi]\), \[Pi], \[Pi]\/2], 
            Range[\(-6\), 10, 2]}, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 14.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange14/Lagrangenn.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange14/Lagrangenn.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = \[ExponentialE]\^x\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-5\), 5]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \[ExponentialE]\^x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-2.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 3.0;\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-4.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = 20.5;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-5.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 5.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 2, 
      n \[LessEqual] 5, \(n++\), \[IndentingNewLine]XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \[IndentingNewLine]graph1 = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[\(-2\), 3, 1], Range[0, 20, 5]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]figure = 
        Show[graph1, Cdot, Rends, 
          DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 15.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange15/Lagrangeoo.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange15/Lagrangeoo.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = ArcTan[x]\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-2\), 2]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = ArcTan[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-2\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 2;\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-1.6\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = \ 1.6;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-2\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 3, 
      n \[LessEqual] 
        6, \(n++\), \[IndentingNewLine]aa = \(-2.0\); \[IndentingNewLine]bb = 
        2.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \ \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], 
              Range[\(-\[Pi]\)\/4, \[Pi]\/4, \[Pi]\/4]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 18.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange18/Lagrangerr.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange18/Lagrangerr.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = ArcSin[x]\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = ArcSin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-1.5\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1.5;\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-2.2\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = 2.2;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-1.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 3, 
      n \[LessEqual] 
        6, \(n++\), \[IndentingNewLine]aa = \(-1.0\); \[IndentingNewLine]bb = 
        1.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \ \[IndentingNewLine]graph1 = 
        Plot[{f[x], P[x]}, {x, \(-0.9999\), 0.9999}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]graph2 = 
        Plot[P[x], {x, \(-1.5\), 1.5}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph1, 
        graph2, Cdot, Rends, PlotRange \[Rule] {{a, b}, {c, d}}, 
        Ticks \[Rule] {Range[\(-1.5\), 1.5, 0.5], 
            Range[\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/4]}, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        P[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 19.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange19/Lagrangess.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange19/Lagrangess.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = BesselJ[0, x]\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-10\), 10]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = BesselJ[0, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-10.2\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = 10.2;\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-0.8\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = \ 1.3;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-11\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 11;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        Graphics[{{Red, PointSize[0.02], 
              Point[{x0, f[x0]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[n = 5, 
      n \[LessEqual] 
        8, \(n++\), \[IndentingNewLine]aa = \(-10\); \[IndentingNewLine]bb = 
        10; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[\(-10\), 10, 2], Range[\(-0.5\), 1, 0.5]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 20.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange20/Lagrangett.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange20/Lagrangett.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = \(1\/\@\(2  \[Pi]\)\) \[ExponentialE]\^\(\(-x\^2\)/2\)\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-3\), 3]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[
          x_] = \(1\/\@\(2  \[Pi]\)\) \[ExponentialE]\^\(\(-x\^2\)/2\);\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-3.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 3.0;\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-0.15\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = 0.5;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-4.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 4.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        Graphics[{{Red, PointSize[0.02], 
              Point[{x0, f[x0]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[i = 2, 
      i \[LessEqual] 5, \(i++\), \[IndentingNewLine]n = 
        2  i; \[IndentingNewLine]aa = \(-3.0\); \[IndentingNewLine]bb = 
        3.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 0.4, 0.1]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 22.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange22/Lagrangevv.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange22/Lagrangevv.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Lagrange polynomial approximation for  ",
  Cell[BoxData[
      \(f[x] = 1\/2\  + 1\/2\ Erf[x\/\@2]\)]],
  ", on the interval ",
  Cell[BoxData[
      \(\([\(-3\), 3]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 1\/2\  + 1\/2\ Erf[x\/\@2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(x0 = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-3.0\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 3.0;\)\ \), "\[IndentingNewLine]", 
    \(\(c = \(-0.25\);\)\ \), "\[IndentingNewLine]", 
    \(\(d = 1.25;\)\ \), "\[IndentingNewLine]", 
    \(\(a0 = \(-4. \);\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 4.0;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        Graphics[{{Red, PointSize[0.02], 
              Point[{x0, f[x0]}]}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Rends = 
        Graphics[{{Green, Line[{{a0, c}, {a0, d}}]}, {Red, 
              Line[{{x0, c}, {x0, d}}]}, {Green, 
              Line[{{b0, c}, {b0, d}}]}}];\)\ \), "\[IndentingNewLine]", 
    \(For[i = 2, 
      i \[LessEqual] 5, \(i++\), \[IndentingNewLine]n = 
        2  i; \[IndentingNewLine]aa = \(-3.0\); \[IndentingNewLine]bb = 
        3.0; \[IndentingNewLine]XY = 
        N[Table[{aa + \(\(bb - aa\)\/n\) k, 
              f[aa + \(\(bb - aa\)\/n\) k]}, {k, 0, 
              n}]]; \[IndentingNewLine]Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]P[x_] = 
        Lagrange[XY]; \[IndentingNewLine]graph = 
        Plot[{f[x], P[x]}, {x, a, b}, PlotStyle \[Rule] {Magenta, Blue}, 
          PlotRange \[Rule] {{a, b}, {c, d}}, 
          Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 0.8, 0.25]}, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[graph, 
        Cdot, Rends, 
        DisplayFunction \[Rule] $DisplayFunction]; \ \ \
\[IndentingNewLine]Print["\<f[x] = \>", 
        f[x], "\<\n\>", "\<\n\>", "\<P[x] = \>", 
        Chop[Expand[P[x]]]];\ \ \ ]\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 23.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange23/Lagrangeww.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange23/Lagrangeww.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Lagrange Polynomial Approximation",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial Approximation",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Interpolation/\
Lagrange/Lagrange.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Lagrange Polynomial Approximation",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/la.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomial Approximation",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/la.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LagrangePolyBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LagrangePolyBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 173, 4, 35, "Text"],
Cell[1952, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3431, 111, 101, 2, 30, "Text"],
Cell[3535, 115, 2650, 86, 71, "Text"],
Cell[6188, 203, 6666, 205, 431, "Text"],
Cell[12857, 410, 628, 21, 33, "Text"],
Cell[13488, 433, 26787, 782, 230, "Text"],
Cell[40278, 1217, 1115, 17, 142, "Input"],
Cell[41396, 1236, 8065, 257, 382, "Text"],
Cell[49464, 1495, 628, 21, 33, "Text"],
Cell[50095, 1518, 780, 24, 33, "Text"],
Cell[50878, 1544, 4262, 135, 154, "Text"],
Cell[55143, 1681, 614, 20, 33, "Text"],
Cell[55760, 1703, 272, 7, 33, "Text"],
Cell[56035, 1712, 258, 7, 33, "Text"],
Cell[56296, 1721, 1325, 22, 320, "Input"],
Cell[57624, 1745, 124, 3, 33, "Text"],
Cell[57751, 1750, 1034, 27, 52, "Text"],
Cell[58788, 1779, 262, 7, 33, "Text"],
Cell[59053, 1788, 833, 13, 236, "Input"],
Cell[59889, 1803, 270, 7, 33, "Text"],
Cell[60162, 1812, 655, 11, 170, "Input"],

Cell[CellGroupData[{
Cell[60842, 1827, 123, 2, 33, "Text"],
Cell[60968, 1831, 504, 13, 52, "Text"],
Cell[61475, 1846, 900, 29, 83, "Input"],
Cell[62378, 1877, 162, 6, 33, "Text"],
Cell[62543, 1885, 727, 16, 133, "Input"],
Cell[63273, 1903, 1727, 51, 33, "Text"],
Cell[65003, 1956, 89, 1, 30, "Input"],
Cell[65095, 1959, 619, 16, 71, "Text"],
Cell[65717, 1977, 62, 1, 30, "Input"],
Cell[65782, 1980, 139, 3, 31, "Input"],
Cell[65924, 1985, 139, 3, 31, "Input"],
Cell[66066, 1990, 173, 5, 33, "Text"],
Cell[66242, 1997, 138, 2, 31, "Input"],
Cell[66383, 2001, 193, 4, 33, "Text"],
Cell[66579, 2007, 203, 3, 51, "Input"],
Cell[66785, 2012, 237, 4, 33, "Text"],
Cell[67025, 2018, 148, 2, 31, "Input"],
Cell[67176, 2022, 317, 9, 33, "Text"],
Cell[67496, 2033, 435, 8, 133, "Input"]
}, Closed]],
Cell[67946, 2044, 3536, 110, 106, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[71507, 2158, 149, 4, 33, "Text",
  Evaluatable->False],
Cell[71659, 2164, 935, 29, 33, "Text"],
Cell[72597, 2195, 284, 5, 90, "Input"],
Cell[72884, 2202, 215, 10, 33, "Text"],
Cell[73102, 2214, 737, 14, 150, "Input"],
Cell[73842, 2230, 936, 29, 33, "Text"],
Cell[74781, 2261, 284, 5, 90, "Input"],
Cell[75068, 2268, 215, 10, 33, "Text"],
Cell[75286, 2280, 671, 13, 130, "Input"],
Cell[75960, 2295, 954, 29, 33, "Text"],
Cell[76917, 2326, 317, 6, 90, "Input"],
Cell[77237, 2334, 215, 10, 33, "Text"],
Cell[77455, 2346, 669, 13, 130, "Input"],
Cell[78127, 2361, 137, 4, 33, "Text",
  Evaluatable->False],
Cell[78267, 2367, 691, 14, 170, "Input"],
Cell[78961, 2383, 91, 2, 33, "Text",
  Evaluatable->False],
Cell[79055, 2387, 548, 9, 110, "Input"],
Cell[79606, 2398, 197, 5, 33, "Text",
  Evaluatable->False],
Cell[79806, 2405, 477, 8, 110, "Input"],
Cell[80286, 2415, 655, 20, 33, "Text",
  Evaluatable->False]
}, Closed]],
Cell[80956, 2438, 863, 28, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[81844, 2470, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[82000, 2476, 192, 7, 33, "Text",
  Evaluatable->False],
Cell[82195, 2485, 589, 12, 164, "Input"],
Cell[82787, 2499, 87, 2, 33, "Text"],
Cell[82877, 2503, 851, 16, 170, "Input"],
Cell[83731, 2521, 868, 16, 170, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[84636, 2542, 153, 4, 30, "Text",
  Evaluatable->False],
Cell[84792, 2548, 191, 7, 33, "Text",
  Evaluatable->False],
Cell[84986, 2557, 583, 12, 164, "Input"],
Cell[85572, 2571, 87, 2, 33, "Text"],
Cell[85662, 2575, 781, 15, 150, "Input"],
Cell[86446, 2592, 786, 15, 150, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[87269, 2612, 153, 4, 30, "Text",
  Evaluatable->False],
Cell[87425, 2618, 191, 7, 33, "Text",
  Evaluatable->False],
Cell[87619, 2627, 553, 11, 164, "Input"],
Cell[88175, 2640, 87, 2, 33, "Text"],
Cell[88265, 2644, 779, 15, 150, "Input"],
Cell[89047, 2661, 794, 15, 150, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[89878, 2681, 153, 4, 30, "Text",
  Evaluatable->False],
Cell[90034, 2687, 191, 7, 33, "Text",
  Evaluatable->False],
Cell[90228, 2696, 628, 13, 184, "Input"],
Cell[90859, 2711, 87, 2, 33, "Text"],
Cell[90949, 2715, 780, 15, 150, "Input"],
Cell[91732, 2732, 785, 15, 150, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[92554, 2752, 153, 4, 30, "Text",
  Evaluatable->False],
Cell[92710, 2758, 627, 12, 127, "Input"]
}, Closed]],
Cell[93352, 2773, 297, 10, 30, "Text"],

Cell[CellGroupData[{
Cell[93674, 2787, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[93830, 2793, 206, 7, 33, "Text",
  Evaluatable->False],
Cell[94039, 2802, 633, 12, 150, "Input"],
Cell[94675, 2816, 202, 5, 33, "Text"],
Cell[94880, 2823, 777, 24, 43, "Text"],
Cell[95660, 2849, 1548, 39, 206, "Input"],
Cell[97211, 2890, 759, 22, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[98007, 2917, 153, 4, 30, "Text",
  Evaluatable->False],
Cell[98163, 2923, 206, 7, 33, "Text",
  Evaluatable->False],
Cell[98372, 2932, 672, 13, 150, "Input"],
Cell[99047, 2947, 228, 7, 33, "Text"],
Cell[99278, 2956, 771, 24, 36, "Text"],
Cell[100052, 2982, 1686, 46, 199, "Input"],
Cell[101741, 3030, 752, 22, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[102530, 3057, 153, 4, 30, "Text",
  Evaluatable->False],
Cell[102686, 3063, 206, 7, 33, "Text",
  Evaluatable->False],
Cell[102895, 3072, 712, 14, 150, "Input"],
Cell[103610, 3088, 225, 6, 33, "Text"],
Cell[103838, 3096, 793, 24, 53, "Text"],
Cell[104634, 3122, 1917, 50, 212, "Input"],
Cell[106554, 3174, 768, 22, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[107359, 3201, 153, 4, 30, "Text",
  Evaluatable->False],
Cell[107515, 3207, 206, 7, 33, "Text",
  Evaluatable->False],
Cell[107724, 3216, 732, 14, 150, "Input"],
Cell[108459, 3232, 216, 6, 33, "Text"],
Cell[108678, 3240, 790, 24, 42, "Text"],
Cell[109471, 3266, 1910, 50, 206, "Input"],
Cell[111384, 3318, 750, 22, 33, "Text"]
}, Closed]],
Cell[112149, 3343, 1185, 40, 106, "Text"],

Cell[CellGroupData[{
Cell[113359, 3387, 101, 2, 33, "Text"],
Cell[113463, 3391, 733, 12, 110, "Input"],
Cell[114199, 3405, 1245, 19, 195, "Input"],
Cell[115447, 3426, 847, 16, 195, "Input"]
}, Closed]],
Cell[116309, 3445, 166, 4, 32, "Text"],
Cell[116478, 3451, 380, 17, 33, "Text"],

Cell[CellGroupData[{
Cell[116883, 3472, 105, 2, 33, "Text"],
Cell[116991, 3476, 1679, 31, 428, "Input"],
Cell[118673, 3509, 807, 26, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[119517, 3540, 105, 2, 30, "Text"],
Cell[119625, 3544, 1690, 32, 428, "Input"],
Cell[121318, 3578, 807, 26, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[122162, 3609, 105, 2, 30, "Text"],
Cell[122270, 3613, 1694, 32, 428, "Input"],
Cell[123967, 3647, 807, 26, 33, "Text"]
}, Closed]],
Cell[124789, 3676, 300, 11, 40, "Text"],

Cell[CellGroupData[{
Cell[125114, 3691, 101, 2, 33, "Text"],
Cell[125218, 3695, 1866, 34, 446, "Input"],
Cell[127087, 3731, 807, 26, 33, "Text"]
}, Closed]],
Cell[127909, 3760, 304, 11, 34, "Text"],

Cell[CellGroupData[{
Cell[128238, 3775, 101, 2, 33, "Text"],
Cell[128342, 3779, 1749, 33, 419, "Input"],
Cell[130094, 3814, 807, 26, 33, "Text"]
}, Closed]],
Cell[130916, 3843, 340, 14, 30, "Text"],

Cell[CellGroupData[{
Cell[131281, 3861, 105, 2, 33, "Text"],
Cell[131389, 3865, 1862, 33, 426, "Input"],
Cell[133254, 3900, 807, 26, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[134098, 3931, 105, 2, 30, "Text"],
Cell[134206, 3935, 1862, 33, 426, "Input"],
Cell[136071, 3970, 808, 26, 33, "Text"]
}, Closed]],
Cell[136894, 3999, 289, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[137208, 4014, 101, 2, 33, "Text"],
Cell[137312, 4018, 1785, 34, 426, "Input"],
Cell[139100, 4054, 808, 26, 33, "Text"]
}, Closed]],
Cell[139923, 4083, 290, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[140238, 4098, 102, 2, 33, "Text"],
Cell[140343, 4102, 1781, 34, 426, "Input"],
Cell[142127, 4138, 808, 26, 33, "Text"]
}, Closed]],
Cell[142950, 4167, 294, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[143269, 4182, 102, 2, 33, "Text"],
Cell[143374, 4186, 2214, 40, 533, "Input"],
Cell[145591, 4228, 808, 26, 33, "Text"]
}, Closed]],
Cell[146414, 4257, 300, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[146739, 4272, 102, 2, 33, "Text"],
Cell[146844, 4276, 1644, 30, 386, "Input"],
Cell[148491, 4308, 808, 26, 33, "Text"]
}, Closed]],
Cell[149314, 4337, 291, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[149630, 4352, 102, 2, 33, "Text"],
Cell[149735, 4356, 1767, 34, 439, "Input"],
Cell[151505, 4392, 808, 26, 33, "Text"]
}, Closed]],
Cell[152328, 4421, 291, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[152644, 4436, 102, 2, 33, "Text"],
Cell[152749, 4440, 1922, 36, 459, "Input"],
Cell[154674, 4478, 808, 26, 33, "Text"]
}, Closed]],
Cell[155497, 4507, 297, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[155819, 4522, 102, 2, 33, "Text"],
Cell[155924, 4526, 1813, 35, 446, "Input"],
Cell[157740, 4563, 808, 26, 33, "Text"]
}, Closed]],
Cell[158563, 4592, 336, 11, 40, "Text"],

Cell[CellGroupData[{
Cell[158924, 4607, 102, 2, 33, "Text"],
Cell[159029, 4611, 1892, 37, 486, "Input"],
Cell[160924, 4650, 808, 26, 33, "Text"]
}, Closed]],
Cell[161747, 4679, 308, 11, 40, "Text"],

Cell[CellGroupData[{
Cell[162080, 4694, 102, 2, 33, "Text"],
Cell[162185, 4698, 1853, 35, 486, "Input"],
Cell[164041, 4735, 808, 26, 33, "Text"]
}, Closed]],
Cell[164864, 4764, 806, 24, 30, "Text"],
Cell[165673, 4790, 729, 20, 33, "Text"],
Cell[166405, 4812, 158, 3, 35, "Text"],
Cell[166566, 4817, 571, 17, 33, "Text"],
Cell[167140, 4836, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

