(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42796,       1121]*)
(*NotebookOutlinePosition[     43793,       1154]*)
(*  CellTagsIndexPosition[     43749,       1150]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Module for ",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Cubic Splines",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Cubic Spline Interpolant",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["Definition (Cubic Spline).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Suppose that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\((x\_k, y\_k)\)}\_\(k = 0\)\%n\)]],
  "  are  n+1  points, where  ",
  Cell[BoxData[
      \(a = \(\(x\_0 < x\_0 <  ... \) < x\_n = b\)\)]],
  StyleBox[".  The function  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S \((x)\)\)]],
  "  ",
  StyleBox["is called a ",
    FontFamily->"Times New Roman"],
  ButtonBox["cubic spline",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CubicSpline.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" if there exists  n  cubic polynomials  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(S\_k\) \((x)\)\)]],
  StyleBox["  with coefficients  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(s\_\(k, 0\)\), ",", \(s\_\(k, 1\)\), ",", \(s\_\(k, 2\)\), 
        ",", " ", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman"], "  ", \(s\_\(k, 3\)\)}]}]]],
  StyleBox["  that satisfy the properties:\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["I.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S \((x)\)\  = \ \(S\_k\) \((x)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(s\_\(k, 0\) + \(s\_\(k, 1\)\) \((x - 
                x\_k)\) + \(s\_\(k, 2\)\) \((x - x\_k)\)\^2 + \(s\_\(k, 
                3\)\) \((x - x\_k)\)\^3\)\)\)\)]],
  "  \n\t",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"x", "\[Element]", 
            RowBox[{\([x\_k, x\_\(k + 1\)]\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman"], "  ", "k"}]}], "=", "0"}], 
        ",", "1", ",", "...", ",", \(n - 1\)}]]],
  StyleBox[".  \n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["II.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S \((x\_k)\)\  = \ y\_k\)]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(k = 0, 1,  ... , n\)]],
  StyleBox[".  \n\tThe spline passes through each data point.",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["III.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(S\_k\) \((x\_\(k + 1\))\) = \(S\_\(k + 
                1\)\) \((x\_\(k + 1\))\)\)]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(k = 0, 1,  ... , n - 2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["\tThe spline forms a continuous function over [a,b].\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["IV.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(S\_k\%'\) \((x\_\(k + 1\))\) = \(S\_\(k + 
                1\)\%'\) \((x\_\(k + 1\))\)\)]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(k = 0, 1,  ... , n - 2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["\tThe spline forms a smooth function.\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["IV.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(S\_k\%''\) \((x\_\(k + 1\))\) = \(S\_\(k + 
                1\)\%''\) \((x\_\(k + 1\))\)\)]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(k = 0, 1,  ... , n - 2\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["\tThe second derivative is continuous.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Lemma (Natural Spline).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  There exists a unique cubic spline with the free boundary \
conditions  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S'' \((a)\) = 0\)]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S'' \((b)\) = 0\)]],
  ". ",
  StyleBox[" ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CubicSplinesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CubicSplinesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["  The natural spline is the curve obtained by forcing a flexible \
elastic rod through the points but letting the slope at the ends be free to \
equilibrate to the position that minimizes the oscillatory behavior of the \
curve.  It is useful for fitting a curve to experimental data that is \
significant to several significant digits.  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CubicSplinesProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CubicSplinesProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Program",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" (Natural Cubic Spline).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To construct and evaluate the cubic spline interpolant ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S \((x)\)\)]],
  StyleBox[" for the  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(n + 1\)]],
  StyleBox[" data points  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\((x\_0, y\_0)\), \((x\_1, y\_1)\),  ... , \((x\_n, y\_n)\)\)]],
  ",  using the ",
  StyleBox["free boundary conditions  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S'' \((a)\) = 0\)]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S'' \((b)\) = 0\)]],
  ". ",
  StyleBox[" ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Natural Cubic Spline",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(NaturalSpline[XY0_]\), " ", ":=", " ", 
          RowBox[{"Module", "[", 
            RowBox[{\({XY = XY0}\), ",", " ", "\[IndentingNewLine]", 
              
              RowBox[{\(Differences := \ 
                  Module[{k}, \ \[IndentingNewLine]n\  = \ 
                      Length[XY] - 
                        1; \ \[IndentingNewLine]X\  = \ \(Transpose[XY]\)\_\(\
\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]Y\  = \ \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\
\(\[RightDoubleBracket]\)\); \ \[IndentingNewLine]h = \(d\  = \ 
                        Table[0, {n}]\); \ \[IndentingNewLine]m\  = \ 
                      Table[0, {n + 
                            1}]; \ \[IndentingNewLine]a = \(b = \(c = \(v\  = \
\ Table[0, {n - 1}]\)\)\); \ \[IndentingNewLine]s\  = \ 
                      Table[0, {n}, {4}]; \ \[IndentingNewLine]h\_\(\(\
\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\  = \ 
                      X\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                        X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]d\_\(\(\[LeftDoubleBracket]\)\
\(1\)\(\[RightDoubleBracket]\)\)\  = \ \(Y\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\  - \ Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\)\/h\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]For[\ k = 2, \ 
                      k \[LessEqual] 
                        n, \ \(k++\), \ \[IndentingNewLine]h\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\  = \ 
                        X\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                          X\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]d\_\(\(\[LeftDoubleBracket]\)\
\(k\)\(\[RightDoubleBracket]\)\)\  = \ \(Y\_\(\(\[LeftDoubleBracket]\)\(k + 1\
\)\(\[RightDoubleBracket]\)\)\  - \ Y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)\/h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]a\_\(\(\[LeftDoubleBracket]\)\
\(k - 1\)\(\[RightDoubleBracket]\)\)\  = \ 
                        h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]b\_\(\(\[LeftDoubleBracket]\)\
\(k - 1\)\(\[RightDoubleBracket]\)\)\  = \ 
                        2\ \((h\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\)\  + \ 
                              h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\))\); \ \
\[IndentingNewLine]c\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                        h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]v\_\(\(\[LeftDoubleBracket]\)\
\(k - 1\)\(\[RightDoubleBracket]\)\)\  = \ 
                        6\ \((d\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                              d\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\))\)];\ ]\), ";", " ", 
                "\n", \(TriDiagonal := 
                  Module[{k, 
                      t}, \ \[IndentingNewLine]m\_\(\(\[LeftDoubleBracket]\)\(\
1\)\(\[RightDoubleBracket]\)\)\  = \ 
                      0; \ \[IndentingNewLine]m\_\(\(\[LeftDoubleBracket]\)\(\
n + 1\)\(\[RightDoubleBracket]\)\)\  = \ 0; \[IndentingNewLine]For[\ k = 2, \ 
                      k \[LessEqual] 
                        n - 1, \ \(k++\), \ \[IndentingNewLine]t\  = \ 
                        a\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\)\/b\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]b\_\(\(\[LeftDoubleBracket]\)\
\(k\)\(\[RightDoubleBracket]\)\)\ \  = \ \ b\_\(\(\[LeftDoubleBracket]\)\(k\)\
\(\[RightDoubleBracket]\)\)\  - \ 
                          t\ \ c\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]v\_\(\(\[LeftDoubleBracket]\)\
\(k\)\(\[RightDoubleBracket]\)\)\ \  = \ \ v\_\(\(\[LeftDoubleBracket]\)\(k\)\
\(\[RightDoubleBracket]\)\)\  - \ 
                          t\ \ v\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\);\ ]; \ \[IndentingNewLine]m\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\ \  = \ \ v\_\(\(\
\[LeftDoubleBracket]\)\(n - 1\)\(\[RightDoubleBracket]\)\)\/b\_\(\(\
\[LeftDoubleBracket]\)\(n - 1\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]For[\ k = n - 2, \ 
                      1 \[LessEqual] 
                        k, \ \(k--\), \ \[IndentingNewLine]\(m\_\(\(\
\[LeftDoubleBracket]\)\(k + 1\)\(\[RightDoubleBracket]\)\)\  = \ \(v\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\  - \ c\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\ m\_\(\(\
\[LeftDoubleBracket]\)\(k + 2\)\(\[RightDoubleBracket]\)\)\)\/b\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\);\)\ ];\ ]\), ";", " ", 
                "\n", \(ComputeCoeff := 
                  Module[{k}, \ \[IndentingNewLine]\(For[\ k = 1, \ 
                        k \[LessEqual] 
                          n, \ \(k++\), \ \[IndentingNewLine]s\_\(\(\
\[LeftDoubleBracket]\)\(k, 1\)\(\[RightDoubleBracket]\)\)\  = \ 
                          Y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]s\_\(\(\[LeftDoubleBracket]\)\
\(k, 2\)\(\[RightDoubleBracket]\)\)\  = \ 
                          d\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                            1\/6\ h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\ \((2\ m\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\) + 
                                  m\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\
\[RightDoubleBracket]\)\))\); \ \
\[IndentingNewLine]s\_\(\(\[LeftDoubleBracket]\)\(k, 3\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                          m\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\/2; \ \
\[IndentingNewLine]s\_\(\(\[LeftDoubleBracket]\)\(k, 4\)\(\
\[RightDoubleBracket]\)\)\  = \ \(m\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\
\[RightDoubleBracket]\)\)\  - \ m\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)\/\(6\ h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\);\ ];\)\ ]\), ";", " ", 
                "\n", \(CS[t_] := 
                  Module[{j}, \ \[IndentingNewLine]For[\ j = 1, \ 
                      j \[LessEqual] 
                        n, \ \(j++\), \ \[IndentingNewLine]\(If[\ 
                          X\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\) \[LessEqual] t\  && \ 
                            t < X\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\
\[RightDoubleBracket]\)\), k = j\ ];\)\ ]; \ \[IndentingNewLine]If[
                      t < X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), k = 1\ ]; \ \[IndentingNewLine]If[
                      X\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\
\[RightDoubleBracket]\)\) \[LessEqual] t, 
                      k = n\ ]; \ \[IndentingNewLine]w\  = \ 
                      t\  - \ 
                        X\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]Return[\ \((\((s\_\(\(\
\[LeftDoubleBracket]\)\(k, 4\)\(\[RightDoubleBracket]\)\)\ w + 
                                    s\_\(\(\[LeftDoubleBracket]\)\(k, 3\)\(\
\[RightDoubleBracket]\)\))\)\ w + 
                              s\_\(\(\[LeftDoubleBracket]\)\(k, 2\)\(\
\[RightDoubleBracket]\)\))\)\ w + 
                        s\_\(\(\[LeftDoubleBracket]\)\(k, 1\)\(\
\[RightDoubleBracket]\)\)\ ];\ ]\), ";", " ", "\[IndentingNewLine]", 
                
                StyleBox[\( (*The\ main\ part\ of\ the\ program\ starts\ here*) \
\),
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[";",
                  FontColor->RGBColor[1, 0, 0]], "  ", "\[IndentingNewLine]", 
                "Differences", ";", " ", "\[IndentingNewLine]", "TriDiagonal",
                 ";", " ", "\[IndentingNewLine]", "ComputeCoeff", ";"}]}], 
            " ", "]"}]}], ";"}], " "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the natural cubic spline for the points ",
  Cell[BoxData[
      \(\((0, 1)\), \((1, 0)\), \((2, 0)\), \((3, 1)\), \((4, 2)\), \((5, 
        2)\), \((6, 1)\)\)]],
  "  that has the endpoint constraints   ",
  Cell[BoxData[
      RowBox[{\(S'' \((0)\)\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", \(S''\), \((6)\)}], " ", 
          "=", " ", "0"}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(XY = {{0. , 1. }, {1. , 0. }, {2. , 0. }, {3. , 1. }, {4. , 
            2. }, {5. , 2. }, {6. , 1. }};\)\ \ \), "\[IndentingNewLine]", 
    \(\(NaturalSpline[XY];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \ \), "\n", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[CS[x], {x, 0, 6}, PlotStyle \[Rule] {Magenta}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, dots, AxesLabel \[Rule] {"\<x\>", "\<y    \>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<Spline y = \>", S\_i, "\<[x]\>"];\)\ \ \), "\n", 
    \(\(Print["\<data points = \>", XY];\)\ \ \)}], "Input"],

Cell["\<\
If more information is needed, we can look at the coefficients that \
form the cubic spline.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<The spline coefficients are\>"];\)\ \ \ \), "\
\[IndentingNewLine]", 
    \(MatrixForm[Chop[s]]\ \ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the natural cubic spline for the points ",
  Cell[BoxData[
      \(\((0, 1)\), \((1, 0)\), \((2, 0)\), \((3, 1)\), \((4, 2)\), \((5, 
        2)\), \((6, 1)\)\)]],
  "  that has the endpoint constraints   ",
  Cell[BoxData[
      RowBox[{\(S'' \((0)\)\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", \(S''\), \((6)\)}], " ", 
          "=", " ", "0"}]}]]],
  ".  \nUse ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s procedure ",
  StyleBox["SplineFit",
    FontWeight->"Bold"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(XY = {{0. , 1. }, {1. , 0. }, {2. , 0. }, {3. , 1. }, {4. , 
            2. }, {5. , 2. }, {6. , 1. }};\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<NumericalMath`SplineFit`\>"];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\(spline = SplineFit[XY, Cubic];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[spline[t], {t, 0, 6}, PlotRange \[Rule] All, 
        Compiled \[Rule] False, PlotStyle \[Rule] Blue];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There are five popular types of splines: n",
  StyleBox["atural spline, clamped spline, extrapolated spline, parabolically \
terminated spline, endpoint curvature adjusted spline.\nWhen ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " constructs a cubic spline it uses the \"natural cubic spline.\"  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Clamped Spline.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Lemma (Clamped Spline).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  There exists a unique cubic spline with the first derivative \
boundary conditions  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S' \((a)\) = d\_0\)]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S' \((b)\) = d\_n\)]],
  ". ",
  StyleBox[" ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CubicSplinesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CubicSplinesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["A property of clamped cubic splines.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["\n\t",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["A practical feature of splines is the minimum of the oscillatory \
behavior they possess.  Consequently, among all functions f(x) which are \
twice continuously differentiable on [a,b] and interpolate a given set data \
points ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\((x\_k, f \((x\_k)\))\)}\_\(k = 0\)\%n\)]],
  StyleBox[" , the cubic spline has \"less wiggle.\"  The next result \
explains this phenomenon. ",
    FontFamily->"Times New Roman"],
  StyleBox["\n\n",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Theorem (Minimum property of clamped cubic splines).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \[Element] \(C\^2\)[a, b]\)]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S \((x)\)\)]],
  StyleBox["  is the unique clamped cubic spline interpolant for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox[" which passes through ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\((x\_k, f \((x\_k)\))\)}\_\(k = 0\)\%n\)]],
  StyleBox[" and satisfies the clamped end conditions  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S' \((a)\) = f' \((a)\)\)]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S' \((b)\) = f' \((b)\)\)]],
  StyleBox[".   Then\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(\[Integral]\_a\%b\ \(\((S'' \((x)\))\)\^2\) \[DifferentialD]x\)\(\
\ \ \)\(\[LessEqual]\)\(\ \ \)\)\)]],
  Cell[BoxData[
      \(\[Integral]\_a\%b\ \(\((f'' \((x)\))\)\^2\) \[DifferentialD]x\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CubicSplinesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CubicSplinesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CubicSplinesProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CubicSplinesProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Program",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" (Clamped Cubic Spline).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To construct and evaluate the cubic spline interpolant  S(x)  \
for the  n+1  data points  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\((x\_0, y\_0)\), \((x\_1, y\_1)\),  ... , \((x\_n, y\_n)\)\)]],
  ",  using the ",
  StyleBox["first derivative boundary conditions  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S' \((a)\) = d\_0\)]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(S' \((b)\) = d\_n\)]],
  ". ",
  StyleBox[" ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(ClampedSpline[XY0_, D1_, DN1_]\), " ", ":=", " ", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({XY = XY0, dx1 = D1, dxn1 = DN1}\), ",", " ", 
              "\[IndentingNewLine]", 
              
              RowBox[{\(Differences := \ 
                  Module[{k}, \ \[IndentingNewLine]n\  = \ 
                      Length[XY] - 
                        1; \ \[IndentingNewLine]X\  = \ \(Transpose[XY]\)\_\(\
\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]Y\  = \ \(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\
\(\[RightDoubleBracket]\)\); \ \[IndentingNewLine]h = \(d\  = \ 
                        Table[0, {n}]\); \ \[IndentingNewLine]m\  = \ 
                      Table[0, {n + 
                            1}]; \ \[IndentingNewLine]a = \(b = \(c = \(v\  = \
\ Table[0, {n - 1}]\)\)\); \ \[IndentingNewLine]s\  = \ 
                      Table[0, {n}, {4}]; \ \[IndentingNewLine]h\_\(\(\
\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\  = \ 
                      X\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                        X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]d\_\(\(\[LeftDoubleBracket]\)\
\(1\)\(\[RightDoubleBracket]\)\)\  = \ \(Y\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\  - \ Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\)\/h\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]For[\ k = 2, \ 
                      k \[LessEqual] 
                        n, \ \(k++\), \ \[IndentingNewLine]h\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\  = \ 
                        X\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                          X\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]d\_\(\(\[LeftDoubleBracket]\)\
\(k\)\(\[RightDoubleBracket]\)\)\  = \ \(Y\_\(\(\[LeftDoubleBracket]\)\(k + 1\
\)\(\[RightDoubleBracket]\)\)\  - \ Y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)\/h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]a\_\(\(\[LeftDoubleBracket]\)\
\(k - 1\)\(\[RightDoubleBracket]\)\)\  = \ 
                        h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]b\_\(\(\[LeftDoubleBracket]\)\
\(k - 1\)\(\[RightDoubleBracket]\)\)\  = \ 
                        2\ \((h\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\)\  + \ 
                              h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\))\); \ \
\[IndentingNewLine]c\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                        h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]v\_\(\(\[LeftDoubleBracket]\)\
\(k - 1\)\(\[RightDoubleBracket]\)\)\  = \ 
                        6\ \((d\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                              d\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\))\)];\ ]\), ";", "  ", 
                "\n", \(TriDiagonal := 
                  Module[{k, 
                      t}, \ \[IndentingNewLine]b\_\(\(\[LeftDoubleBracket]\)\(\
1\)\(\[RightDoubleBracket]\)\)\  = \ 
                      b\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                        h\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\/2; \ \
\[IndentingNewLine]v\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)\  = \ v\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\  - \ 
                        3 \((d\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                              dx1)\); \ \[IndentingNewLine]b\_\(\(\
\[LeftDoubleBracket]\)\(n - 1\)\(\[RightDoubleBracket]\)\)\  = \ 
                      b\_\(\(\[LeftDoubleBracket]\)\(n - 1\)\(\
\[RightDoubleBracket]\)\) - 
                        h\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\/2; \ \
\[IndentingNewLine]v\_\(\(\[LeftDoubleBracket]\)\(n - 1\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                      v\_\(\(\[LeftDoubleBracket]\)\(n - 1\)\(\
\[RightDoubleBracket]\)\) - 
                        3 \((dxn1 - 
                              d\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\))\); \ \[IndentingNewLine]For[\ k = 2, \ 
                      k \[LessEqual] 
                        n - 1, \ \(k++\), \ \[IndentingNewLine]t\  = \ 
                        a\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\)\/b\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]b\_\(\(\[LeftDoubleBracket]\)\
\(k\)\(\[RightDoubleBracket]\)\)\ \  = \ \ b\_\(\(\[LeftDoubleBracket]\)\(k\)\
\(\[RightDoubleBracket]\)\)\  - \ 
                          t\ \ c\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]v\_\(\(\[LeftDoubleBracket]\)\
\(k\)\(\[RightDoubleBracket]\)\)\ \  = \ \ v\_\(\(\[LeftDoubleBracket]\)\(k\)\
\(\[RightDoubleBracket]\)\)\  - \ 
                          t\ \ v\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\);\ ]; \ \[IndentingNewLine]m\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\ \  = \ \ v\_\(\(\
\[LeftDoubleBracket]\)\(n - 1\)\(\[RightDoubleBracket]\)\)\/b\_\(\(\
\[LeftDoubleBracket]\)\(n - 1\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]For[\ k = n - 2, \ 
                      1 \[LessEqual] 
                        k, \ \(k--\), \ \[IndentingNewLine]\(m\_\(\(\
\[LeftDoubleBracket]\)\(k + 1\)\(\[RightDoubleBracket]\)\)\  = \ \(v\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\  - \ c\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\ m\_\(\(\
\[LeftDoubleBracket]\)\(k + 2\)\(\[RightDoubleBracket]\)\)\)\/b\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\);\)\ ];\ ]\), ";", "  ",
                 "\n", \(ComputeCoeff := 
                  Module[{k}, \ \[IndentingNewLine]\(For[\ k = 1, \ 
                        k \[LessEqual] 
                          n, \ \(k++\), \ \[IndentingNewLine]m\_\(\(\
\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\  = \ \(3\ \((d\_\(\(\
\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\  - \ \
dx1)\)\)\/h\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\  - \ 
                            m\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\/2; \ \
\[IndentingNewLine]m\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\
\[RightDoubleBracket]\)\)\  = \ \(3\ \((dxn1\  - \ \
d\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\))\)\)\/h\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\  - \ 
                            m\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\/2; \ \
\[IndentingNewLine]s\_\(\(\[LeftDoubleBracket]\)\(k, 1\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                          Y\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]s\_\(\(\[LeftDoubleBracket]\)\
\(k, 2\)\(\[RightDoubleBracket]\)\)\  = \ 
                          d\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\  - \ 
                            1\/6\ h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\ \((2\ m\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\) + 
                                  m\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\
\[RightDoubleBracket]\)\))\); \ \
\[IndentingNewLine]s\_\(\(\[LeftDoubleBracket]\)\(k, 3\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                          m\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\/2; \ \
\[IndentingNewLine]s\_\(\(\[LeftDoubleBracket]\)\(k, 4\)\(\
\[RightDoubleBracket]\)\)\  = \ \(m\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\
\[RightDoubleBracket]\)\)\  - \ m\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\)\/\(6\ h\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\)\);\ ];\)\ ]\), ";", "  ", 
                "\n", \(CS[t_] := 
                  Module[{j}, \ \[IndentingNewLine]For[\ j = 1, \ 
                      j \[LessEqual] 
                        n, \ \(j++\), \ \[IndentingNewLine]\(If[\ 
                          X\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\) \[LessEqual] t\  && \ 
                            t < X\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\
\[RightDoubleBracket]\)\), k = j\ ];\)\ ]; \ \[IndentingNewLine]If[
                      t < X\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), k = 1\ ]; \ \[IndentingNewLine]If[
                      X\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\
\[RightDoubleBracket]\)\) \[LessEqual] t, 
                      k = n\ ]; \ \[IndentingNewLine]w\  = \ 
                      t\  - \ 
                        X\_\(\(\[LeftDoubleBracket]\)\(k\)\(\
\[RightDoubleBracket]\)\); \ \[IndentingNewLine]Return[\ \((\((s\_\(\(\
\[LeftDoubleBracket]\)\(k, 4\)\(\[RightDoubleBracket]\)\)\ w + 
                                    s\_\(\(\[LeftDoubleBracket]\)\(k, 3\)\(\
\[RightDoubleBracket]\)\))\)\ w + 
                              s\_\(\(\[LeftDoubleBracket]\)\(k, 2\)\(\
\[RightDoubleBracket]\)\))\)\ w + 
                        s\_\(\(\[LeftDoubleBracket]\)\(k, 1\)\(\
\[RightDoubleBracket]\)\)\ ];\ ]\), ";", " ", "\[IndentingNewLine]", 
                
                StyleBox[\( (*The\ main\ part\ of\ the\ program\ starts\ here*) \
\),
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[";",
                  FontColor->RGBColor[1, 0, 0]], "  ", "\[IndentingNewLine]", 
                "Differences", ";", " ", "\[IndentingNewLine]", "TriDiagonal",
                 ";", " ", "\[IndentingNewLine]", "ComputeCoeff", ";"}]}], 
            " ", "]"}]}], ";"}], "  "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the clamped cubic spline for the points ",
  Cell[BoxData[
      \(\((0, 1)\), \((1, 0)\), \((2, 0)\), \((3, 1)\), \((4, 2)\), \((5, 
        2)\), \((6, 1)\)\)]],
  "  that has the endpoint constraints   ",
  Cell[BoxData[
      RowBox[{\(S' \((0)\)\), "=", 
        RowBox[{
          RowBox[{\(-0.2\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", \(S'\), \((6)\)}], " ", 
          "=", " ", \(-2.5\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(XY = {{0. , 1. }, {1. , 0. }, {2. , 0. }, {3. , 1. }, {4. , 
            2. }, {5. , 2. }, {6. , 1. }};\)\ \ \), "\[IndentingNewLine]", 
    \(\(ClampedSpline[
        XY, \(-0.2\), \(-2.5\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(dots = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr = 
        Plot[CS[x], {x, 0, 6}, PlotStyle \[Rule] {Magenta}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr, dots, DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<x\>", "\<y    \>"}];\)\ \ \), "\n", 
    \(\(Print["\<Spline y = \>", S\_i, "\<[x]\>"];\)\ \ \), "\n", 
    \(\(Print["\<data points = \>", XY];\)\ \ \)}], "Input"],

Cell["\<\
If more information is needed, we can look at the coefficients that \
form the cubic spline.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<The spline coefficients are\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(MatrixForm[Chop[s]]\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CubicSplinesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cubic Splines",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CubicSplinesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 310, 11, 35, "Text"],
Cell[2089, 66, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3568, 118, 4765, 154, 363, "Text"],
Cell[8336, 274, 491, 17, 33, "Text"],
Cell[8830, 293, 726, 25, 33, "Text"],
Cell[9559, 320, 531, 11, 52, "Text"],
Cell[10093, 333, 606, 21, 33, "Text"],
Cell[10702, 356, 969, 32, 52, "Text"],
Cell[11674, 390, 371, 11, 33, "Text"],
Cell[12048, 403, 8282, 142, 1066, "Input"],
Cell[20333, 547, 627, 19, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20985, 570, 101, 2, 33, "Text"],
Cell[21089, 574, 814, 14, 170, "Input"],
Cell[21906, 590, 116, 3, 33, "Text"],
Cell[22025, 595, 147, 3, 50, "Input"]
}, Closed]],
Cell[22187, 601, 762, 25, 68, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22974, 630, 101, 2, 33, "Text"],
Cell[23078, 634, 455, 7, 90, "Input"]
}, Closed]],
Cell[23548, 644, 509, 13, 49, "Text",
  Evaluatable->False],
Cell[24060, 659, 203, 7, 33, "Text"],
Cell[24266, 668, 507, 17, 33, "Text"],
Cell[24776, 687, 726, 25, 33, "Text"],
Cell[25505, 714, 2152, 62, 183, "Text"],
Cell[27660, 778, 726, 25, 33, "Text"],
Cell[28389, 805, 606, 21, 33, "Text"],
Cell[28998, 828, 821, 25, 52, "Text"],
Cell[29822, 855, 10019, 175, 1220, "Input"],
Cell[39844, 1032, 635, 19, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[40504, 1055, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[40657, 1061, 841, 15, 170, "Input"],
Cell[41501, 1078, 116, 3, 33, "Text"],
Cell[41620, 1083, 143, 3, 50, "Input"]
}, Closed]],
Cell[41778, 1089, 158, 3, 32, "Text"],
Cell[41939, 1094, 557, 17, 33, "Text"],
Cell[42499, 1113, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

