(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    136889,       4056]*)
(*NotebookOutlinePosition[    137573,       4080]*)
(*  CellTagsIndexPosition[    137529,       4076]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Module for the ",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["B\[EAcute]zier Curve",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \n\n\tThe ",
  ButtonBox["B\[EAcute]zier Curve",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BezierCurve.html"], None},
    ButtonStyle->"Hyperlink"],
  " is the original computer generated \"French Curve\" and it's discovery is \
attributed to the French engineer, ",
  ButtonBox["Pierre B\[EAcute]zier",
    ButtonData:>{
      URL[ "http://rocbo.chez.tiscali.fr/Max/culture/bezier/bezier.htm"], 
      None},
    ButtonStyle->"Hyperlink"],
  ".  Let us first review ideas concerning the cubic polynomial of degree 3 \
passes through the 4  points ",
  Cell[BoxData[
      \(\((x\_k, y\_k)\)\)]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3"}]]],
  "  and is shown in Figure 1.  \n\n\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.38778e-017 0.181818 -7.12863e-018 0.142857 [
[.18182 -0.0125 -3 -9 ]
[.18182 -0.0125 3 0 ]
[.36364 -0.0125 -3 -9 ]
[.36364 -0.0125 3 0 ]
[.54545 -0.0125 -3 -9 ]
[.54545 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[.90909 -0.0125 -3 -9 ]
[.90909 -0.0125 3 0 ]
[-0.0125 .14286 -6 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18182 0 m
.18182 .00625 L
s
[(1)] .18182 -0.0125 0 1 Mshowa
.36364 0 m
.36364 .00625 L
s
[(2)] .36364 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(3)] .54545 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(4)] .72727 -0.0125 0 1 Mshowa
.90909 0 m
.90909 .00625 L
s
[(5)] .90909 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(2)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(3)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(4)] -0.0125 .57143 1 0 Mshowa
0 0 m
0 .6 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.18182 .28571 m
.21132 .3448 L
.22668 .36912 L
.2435 .39103 L
.25932 .40737 L
.27372 .41884 L
.28866 .42754 L
.29688 .43099 L
.30058 .43225 L
.30465 .43342 L
.30822 .43428 L
.31205 .43502 L
.31417 .43535 L
.31611 .4356 L
.31807 .43582 L
.3199 .43597 L
.32157 .43608 L
.32251 .43612 L
.32335 .43615 L
.32429 .43618 L
.32529 .43619 L
.32625 .4362 L
.32712 .43619 L
.32794 .43618 L
.32871 .43616 L
.32956 .43613 L
.33046 .43609 L
.3323 .43598 L
.33398 .43585 L
.33765 .43544 L
.34155 .43486 L
.34856 .4334 L
.35609 .43126 L
.36441 .42826 L
.37919 .42137 L
.39511 .41188 L
.42653 .38781 L
.45679 .35936 L
.48589 .32867 L
.51686 .29409 L
.54668 .26054 L
.57837 .2264 L
.6089 .19671 L
.63827 .17271 L
.65315 .16275 L
.66952 .15381 L
.67701 .15048 L
.68507 .14749 L
.69267 .14525 L
.69961 .14371 L
Mistroke
.70326 .14311 L
.70526 .14283 L
.70715 .14262 L
.70891 .14246 L
.71082 .14232 L
.71166 .14227 L
.71255 .14222 L
.71336 .14219 L
.71414 .14217 L
.71512 .14215 L
.71602 .14214 L
.71699 .14215 L
.71754 .14215 L
.71805 .14216 L
.71889 .14218 L
.71981 .14222 L
.72078 .14226 L
.72169 .14232 L
.72377 .14247 L
.72568 .14266 L
.72997 .14326 L
.7336 .14393 L
.73748 .14484 L
.74445 .14696 L
.75275 .15033 L
.76027 .1542 L
.77495 .16409 L
.79084 .17847 L
.80605 .19601 L
.82213 .21882 L
.8511 .27175 L
.88195 .34622 L
.90909 .42857 L
Mfstroke
1 0 0 r
.02 w
.18182 .28571 Mdot
.36364 .42857 Mdot
.72727 .14286 Mdot
.90909 .42857 Mdot
0 g
gsave
.2 .28571 -61 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38182 .44286 -61 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72727 .12857 -90.5938 -17.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89091 .42857 -120.188 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 172.75},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000[1000`40O003h00Oogoo8Goo000mOol5
000[Ool4000^Ool2000_Ool3000/Ool2000OOol003moo`03001oogoo02]oo`03001oogoo02ioo`04
001oogoo000_Ool00`00Oomoo`0ZOol01000Oomoo`007Woo000oOol00`00Oomoo`0/Ool00`00Oomo
o`0_Ool00`00Oomoo`0[Ool5000^Ool00`00Oomoo`0LOol003moo`03001oogoo02eoo`03001oogoo
02moo`03001oogoo02Yoo`04001oogoo000]Ool2000OOol003moo`03001oogoo02]oo`04001oogoo
000]Ool01000Oomoo`00;Goo00<007oo0000;Goo00<007ooOol07Woo000nOol2000^Ool2000_Ool2
000_Ool2000]Ool3000NOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000?
Oooo000<0006Ool000moo`03001oogoo02eoo`03001oogoo02eoo`03001oogoo02ioo`03001oogoo
02eoo`03001oogoo02eoo`03001oogoo01eoo`003goo00<007ooOol0;Goo00<007ooOol0;Goo00<0
07ooOol0;Woo00<007ooOol0;Goo00<007ooOol0;Goo00<007ooOol07Goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0Z7oo00<007ooOol02Goo10002Woo
10001Woo10000Woo00<007ooOol0>Goo000?Ool00`00Oomoo`2WOol00`00Oomoo`0:Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0hOol000moo`03
001oogoo0:Moo`03001oogoo00]oo`03001oogoo00Aoo`8000Moo`03001oogoo00Eoo`03001oogoo
00=oo`03001oogoo03Qoo`003goo00<007ooOol0YWoo00<007ooOol00goo0`0000Aoo`00000000=o
o`03001oogoo00Aoo`03001oogoo00Eoo`8000Moo`03001oogoo00=oo`03001oogoo03Moo`003goo
00<007ooOol0YWoo00<007ooOol017oo00D007ooOomoo`00009oo`04001oogoo0005Ool20006Ool2
0005Ool01000Oomoo`0017oo00<007ooOol0=goo000?Ool00`00Oomoo`2VOol00`00Oomoo`05Ool0
0`00Ool00004Ool2000>Ool00`00Ool00005Ool20005Ool00`00Oomoo`0gOol000moo`03001oogoo
0:Ioo`03001oogoo00Ioo`8001Aoo`04001oogoo000;Ool00`00Oomoo`0gOol000moo`03001oogoo
0:Ioo`03001oogoo00Eoo`04001oogoo000COol01000Oomoo`002goo00<007ooOol0=goo000?Ool0
0`00Oomoo`2VOol00`00Oomoo`04Ool3000017oo0000000047oo0`0000Aoo`00000000Uoo`03001o
ogoo03Moo`003goo00<007ooOol0Ygoo00<007ooOol0:Goo00<007ooOol0>7oo000?Ool00`00Oomo
o`2WOol00`00Oomoo`0YOol00`00Oomoo`0hOol000moo`03001oogoo0:Qoo`03001oogoo02Moo`03
001oogoo03Uoo`003goo00<007ooOol0ogoo3goo0006Ool50004Ool00`00Oomoo`2mOol3O01>Ool0
00Qoo`03001oogoo00Aoo`03001oogoo0;aoo`El04eoo`0027oo00<007ooOol017oo0P00^7oo1@0O
1G`0CGoo0008Ool00`00Oomoo`04Ool00`00Oomoo`2cOol401l5Ool5O00301m:Ool000Qoo`03001o
ogoo00Aoo`03001oogoo0;5oo`807`Yoo`=l00Aoo`807dQoo`001goo0P001Woo00<007ooOol0[Woo
0`0O5Goo0P0OAWoo000?Ool00`00Oomoo`2/Ool201lJOol00`0OOomoo`13Ool000moo`03001oogoo
0:Yoo`807aeoo`807d=oo`003goo00<007ooOol0ZGoo00<07gooOol07goo00<07gooOol0@7oo000?
Ool00`00Oomoo`2WOol201lSOol00`0OOomoo`0oOol000moo`03001oogoo0:Ioo`0301moogoo02Ao
o`807cmoo`003goo00<007ooOol0YGoo00<07gooOol09goo00<07gooOol0?7oo000?Ool00`00Oomo
o`2TOol00`0OOomoo`0YOol00`0OOomoo`0kOol000moo`03001oogoo0:9oo`807beoo`0301moogoo
03Yoo`003goo00<007ooOol0XGoo00<07gooOol0;Goo00<07gooOol0>Woo000?Ool00`00Oomoo`2P
Ool00`0OOomoo`0_Ool00`0OOomoo`0iOol000moo`03001oogoo09moo`0301moogoo035oo`0301mo
ogoo03Qoo`003goo00<007ooOol0WWoo00<07gooOol0<goo00<07gooOol0=goo000?Ool00`00Oomo
o`2MOol00`0OOomoo`0dOol00`0OOomoo`0gOol000moo`03001oogoo09aoo`0301moogoo03Ioo`03
01moogoo03Ioo`003goo00<007ooOol0VWoo0P0O>Woo00<07gooOol0=Goo000?Ool00`00Oomoo`2I
Ool00`0OOomoo`0jOol00`0OOomoo`0eOol000moo`03001oogoo09Qoo`0301moogoo03aoo`0301mo
ogoo03Aoo`003goo00<007ooOol0Ugoo00<07gooOol0?Woo00<07gooOol0<goo000?Ool00`00Oomo
o`2FOol00`0OOomoo`0oOol00`0OOomoo`0cOol000moo`03001oogoo09Eoo`0301moogoo045oo`03
01moogoo039oo`003goo00<007ooOol0U7oo00<07gooOol0@Woo00<07gooOol0<Woo000?Ool00`00
Oomoo`2COol00`0OOomoo`14Ool00`0OOomoo`0aOol000moo`03001oogoo099oo`0301moogoo04Eo
o`0301moogoo035oo`003goo00<007ooOol0TWoo00<07gooOol0AWoo00<07gooOol0<7oo000?Ool0
0`00Oomoo`2AOol00`0OOomoo`18Ool00`0OOomoo`0_Ool000moo`03001oogoo091oo`0301moogoo
04Uoo`0301moogoo02moo`003goo00<007ooOol0Sgoo00<07gooOol0Bgoo00<07gooOol0;Woo000?
Ool00`00Oomoo`2>Ool00`0OOomoo`1<Ool00`0OOomoo`0^Ool000moo`03001oogoo08eoo`0301mo
ogoo04ioo`0301moogoo02eoo`003goo00<007ooOol0>Woo00<007ooOol05goo100037oo00<007oo
Ool09Goo00<07gooOol0Cgoo00<07gooOol0;Goo000?Ool00`00Oomoo`0iOol00`00Oomoo`0;Ool2
0004Ool00`00Oomoo`06Ool00`00Oomoo`05Ool20005Ool00`00Oomoo`0SOol00`0OOomoo`1AOol0
0`0OOomoo`0/Ool000moo`03001oogoo03Uoo`03001oogoo00Yoo`04001oogoo0003Ool20008Ool0
0`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol08Woo00<07gooOol0DWoo00<07gooOol0;7oo
0006Ool40005Ool00`00Oomoo`0/Ool3O009Ool00`00Oomoo`02Ool3000017oo000000000Woo00@0
07ooOol000Aoo`03001oogoo00Ioo`8000Aoo`04001oogoo0005Ool00`00Oomoo`0QOol00`0OOomo
o`1COol00`0OOomoo`0[Ool000Ioo`03001oogoo00Ioo`03001oogoo02]oo`El00Qoo`03001oogoo
00=oo`05001oogooOol00003Ool01000Oomoo`0017oo0P001goo0P0017oo00@007ooOol000Eoo`03
001oogoo021oo`0301moogoo05Aoo`0301moogoo02]oo`001goo00<007ooOol01Goo0P00;7oo1G`0
27oo00<007ooOol017oo00<007oo000017oo00@007ooOol000eoo`03001oo`0000=oo`04001oogoo
0005Ool00`00Oomoo`0OOol00`0OOomoo`1FOol00`0OOomoo`0ZOol000Qoo`03001oogoo00Aoo`03
001oogoo02]oo`El00Qoo`03001oogoo00Eoo`8000Eoo`8000ioo`04001oogoo0003Ool20006Ool0
0`00Oomoo`0NOol00`0OOomoo`1GOol00`0OOomoo`0ZOol000Ioo`04001oogoo0005Ool00`00Oomo
o`0/Ool3O009Ool00`00Oomoo`04Ool01000Oomoo`0057oo00@007ooOol000]oo`03001oogoo01eo
o`0301moogoo05Qoo`0301moogoo02Yoo`001goo0P001Woo00<007ooOol0;goo00<07gooOol01Woo
00<007ooOol00goo0`0000Aoo`000000015oo`<00004Ool000000009Ool00`00Oomoo`0LOol00`0O
Oomoo`1JOol00`0OOomoo`0YOol000moo`03001oogoo02moo`0301moogoo00Moo`03001oogoo02Uo
o`03001oogoo01aoo`0301moogoo05]oo`0301moogoo02Uoo`003goo00<007ooOol0<7oo00<07goo
Ool01Woo00<007ooOol0:Goo00<007ooOol06goo00<07gooOol0GGoo00<07gooOol0:7oo000?Ool0
0`00Oomoo`0`Ool00`0OOomoo`07Ool00`00Oomoo`0WOol00`00Oomoo`0KOol00`0OOomoo`1NOol0
0`0OOomoo`0XOol000moo`03001oogoo035oo`0301moogoo04ioo`0301moogoo05ioo`0301moogoo
02Qoo`003goo00<007ooOol0<Goo00<07gooOol0CGoo00<07gooOol0H7oo00<07gooOol09goo000?
Ool00`00Oomoo`0bOol00`0OOomoo`1;Ool00`0OOomoo`1QOol00`0OOomoo`0WOol000moo`03001o
ogoo039oo`0301moogoo04Yoo`0301moogoo06=oo`0301moogoo02Ioo`003goo00<007ooOol0<goo
00<07gooOol0B7oo00<07gooOol0I7oo00<07gooOol09Woo000?Ool00`00Oomoo`0cOol00`0OOomo
o`17Ool00`0OOomoo`1UOol00`0OOomoo`0VOol000moo`03001oogoo03Aoo`0301moogoo04Eoo`03
01moogoo06Moo`0301moogoo02Eoo`003goo00<007ooOol0=7oo00<07gooOol0A7oo00<07gooOol0
J7oo00<07gooOol09Goo000?Ool00`00Oomoo`0eOol00`0OOomoo`12Ool00`0OOomoo`1ZOol00`0O
Oomoo`0TOol000moo`03001oogoo03Eoo`0301moogoo049oo`0301moogoo06Yoo`0301moogoo02Ao
o`003goo00<007ooOol0=Woo00<07gooOol0@7oo00<07gooOol0Jgoo00<07gooOol097oo000?Ool0
0`00Oomoo`0fOol00`0OOomoo`0oOol00`0OOomoo`1]Ool00`0OOomoo`0SOol000moo`03001oogoo
03Moo`0301moogoo03eoo`0301moogoo06ioo`0301moogoo02=oo`003goo00<007ooOol0>7oo00<0
7gooOol0>goo00<07gooOol0Kgoo00<07gooOol08goo000?Ool00`00Oomoo`0hOol00`0OOomoo`0j
Ool00`0OOomoo`1aOol00`0OOomoo`0ROol000moo`03001oogoo03Uoo`0301moogoo03Qoo`0301mo
ogoo079oo`0301moogoo029oo`003goo00<007ooOol0>Woo00<07gooOol0=Woo00<07gooOol0Lgoo
00<07gooOol08Woo000?Ool00`00Oomoo`0kOol00`0OOomoo`0cOol201mgOol00`0OOomoo`0QOol0
00moo`03001oogoo03aoo`0301moogoo035oo`0301moogoo07Moo`0301moogoo025oo`003goo00<0
07ooOol0?7oo00<07gooOol0<7oo00<07gooOol0N7oo00<07gooOol08Goo000?Ool00`00Oomoo`0m
Ool00`0OOomoo`0^Ool00`0OOomoo`1jOol00`0OOomoo`0POol000moo`03001oogoo03ioo`0301mo
ogoo02aoo`0301moogoo07]oo`0301moogoo021oo`003goo00<007ooOol0?goo00<07gooOol0:Woo
00<07gooOol0O7oo00<07gooOol087oo000?Ool00`00Oomoo`10Ool00`0OOomoo`0XOol00`0OOomo
o`1mOol00`0OOomoo`0POol000moo`03001oogoo045oo`0301moogoo02Eoo`807h5oo`0301moogoo
01moo`003goo00<007ooOol0@Woo00<07gooOol08goo00<07gooOol0PGoo00<07gooOol07goo000?
Ool00`00Oomoo`13Ool00`0OOomoo`0QOol00`0OOomoo`1<Ool00`00Oomoo`0GOol4000<Ool00`00
Oomoo`09Ool00`0OOomoo`0OOol000moo`03001oogoo04Aoo`807b1oo`0301moogoo04aoo`03001o
ogoo00]oo`8000Eoo`03001oogoo00Eoo`03001oogoo00Ioo`8000Aoo`03001oogoo00Uoo`0301mo
ogoo01ioo`003goo00<007ooOol0AWoo00<07gooOol06goo0P0OCgoo00<007ooOol02Woo00@007oo
Ool000Aoo`8000Moo`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomoo`09Ool00`0OOomoo`0N
Ool000Moo`8000Ioo`03001oogoo04Moo`0301moogoo019oo`=l00=oo`807e1oo`03001oogoo00=o
o`<00004Ool000000003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool20007Ool00`00Oomoo`03Ool0
0`00Oomoo`08Ool3O00NOol000Ioo`04001oogoo0005Ool00`00Oomoo`18Ool201lAOol5O00201l8
Ool00`00Oomoo`0GOol4000<Ool00`00Oomoo`0MOol00`00Oomoo`04Ool01@00Oomoogoo00001Goo
00<007ooOol00goo0P001Woo0P0027oo00<007ooOol00Woo00<007ooOol01goo1G`07Goo0008Ool0
0`00Oomoo`04Ool2001;Ool00`0OOomoo`0>Ool5O009Ool00`00Oomoo`0:Ool50003Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool50002Ool00`00Oomoo`0LOol00`00Oomoo`05Ool00`00Ool00003Ool0
1000Oomoo`003Goo00<007oo000017oo00@007ooOol000Aoo`03001oogoo00Moo`El01eoo`002Goo
00<007ooOol00goo00<007ooOol0Bgoo1@0O2Goo0P0O1G`02Goo00<007ooOol037oo00<007ooOol0
0goo0P001goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol077oo00<007ooOol01Woo0P00
17oo0P003Woo00@007ooOol000Aoo`8000Eoo`03001oogoo00Moo`El01eoo`001Woo00@007ooOol0
00Eoo`03001oogoo051oo`T07`=oo`=l00Uoo`03001oogoo00=oo`<00004Ool000000003Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`0KOol00`00Oomoo`05
Ool01000Oomoo`004goo00@007ooOol000]oo`03001oogoo00Qoo`=l01ioo`001goo0P001Woo00<0
07ooOol0J7oo00<007ooOol017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`8000Ioo`8000Mo
o`03001oogoo00=oo`03001oogoo01]oo`03001oogoo00Aoo`<00004Ool00000000@Ool3000017oo
000000002Goo00<007ooOol0:Goo000?Ool00`00Oomoo`1XOol00`00Oomoo`05Ool00`00Ool00005
Ool00`00Oomoo`0<Ool00`00Ool00006Ool00`00Oomoo`03Ool00`00Oomoo`0LOol00`00Oomoo`0Y
Ool00`00Oomoo`0ZOol000moo`03001oogoo06Qoo`03001oogoo00Ioo`8000Aoo`8000ioo`04001o
ogoo0004Ool20005Ool00`00Oomoo`0LOol00`00Oomoo`0YOol00`00Oomoo`0ZOol000moo`03001o
ogoo06Qoo`03001oogoo00Eoo`04001oogoo000COol01000Oomoo`002goo00<007ooOol07Goo00<0
07ooOol09goo00<007ooOol0:goo000?Ool00`00Oomoo`1XOol00`00Oomoo`04Ool3000017oo0000
000047oo0`0000Aoo`00000000Uoo`03001oogoo07Eoo`003goo00<007ooOol0JGoo00<007ooOol0
:Goo00<007ooOol0MWoo000?Ool00`00Oomoo`1YOol00`00Oomoo`0YOol00`00Oomoo`1fOol000mo
o`03001oogoo06Yoo`03001oogoo02Moo`03001oogoo07Moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo0008
Ool30004Ool00`00Oomoo`3oOol?Ool000Uoo`03001oogoo00=oo`03001oogoo0?moo`moo`001Woo
1@0017oo0P00ogoo47oo0006Ool01000Oomoo`001Goo00<007ooOol0ogoo3goo0007Ool00`00Ool0
0005Ool00`00Oomoo`3oOol?Ool000Qoo`8000Eoo`03001oogoo0?moo`moo`003goo00<007ooOol0
ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0
ogoo3goo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {171.75, 0}} -> {0, 0, 0, 0}}],
  "     "
}], "Text"],

Cell[TextData[StyleBox["\t\tFigure 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the cubic polynomial or that ",
  StyleBox["passes through the four points",
    FontColor->RGBColor[1, 0, 1]],
  " \n",
  Cell[BoxData[
      \(\((1, 2)\), \((3\/2, 31\/16)\), \((5\/2, 11\/16)\), \((3, 1)\)\)]],
  "  and satisfies \n\t\t",
  Cell[BoxData[{
      \(\ p \((1)\) = 2\), "\n", 
      \(p \((3\/2)\) = 31\/16\), "\n", 
      \(p \((5\/2)\) = 11\/16\), "\n", 
      \(\ p \((3)\) = 1\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for a general cubic equation.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(pts = {{1, 2}, {3\/2, 31\/16}, {5\/2, 11\/16}, {3, 
            1}};\)\ \ \), "\[IndentingNewLine]", 
    \(\(p[x_]\  = \ a\ x\^3\  + \ b\ x\^2\  + \ c\ x\  + \ d;\)\ \ \), "\n", 
    \(\(Print["\<p[x] = \>", p[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["\<\
Set up four equations using the information at each of the four points.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(eq1\  = \ \ \(\(p[1]\)\(\ \)\(\[Equal]\)\(\ \)\(2\)\(\ \ \)\)\), "\n", 
    \(eq2\  = \ p[3\/2]\  \[Equal] \ 31\/\(\(16\)\(\ \ \ \)\)\), "\n", 
    \(eq3\  = \ p[5\/2]\  \[Equal] \ 11\/\(\(16\)\(\ \ \ \)\)\), "\n", 
    \(eq4\  = \ \ \(\(p[
          3]\)\(\ \)\(\[Equal]\)\(\ \)\(1\)\(\ \ \ \)\)\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Then find the solution set to this linear system and store it in the \
variable ",
  StyleBox["solset",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(eqns\  = \ {eq1, eq2, eq3, eq4};\)\ \ \), "\n", 
    \(\(vars\  = \ {a, b, c, d};\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[eqns, vars];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve and get\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Use the solution given above for the coefficients and form the cubic \
function.  \nRemember that we must dig out one set of braces using ",
  " ",
  Cell[BoxData[
      \(solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)],
    
    AspectRatioFixed->False,
    FontWeight->"Bold"],
  "  before we can use the ",
  StyleBox["ReplaceAll",
    FontWeight->"Bold"],
  " command.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(p[x_]\)\(\ \)\(=\)\(\ \)\(ReplaceAll[\ p[x], 
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ ]\
\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Now form the cubic polynomial function  ",
  Cell[BoxData[
      \(p\_3[x]\)],
    AspectRatioFixed->False],
  " and plot a graph.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(p\_3[x_]\  = \ 
        ReplaceAll[p[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ \
];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(dots = 
        ListPlot[pts, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(gr = 
        Plot[p\_3[x], {x, 1.0, 3.0}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(graph1 = 
        Show[gr, dots, PlotRange \[Rule] {{0, 3.5}, {0, 3}}, 
          Ticks \[Rule] {Range[0, 3, 1], Range[0, 3, 1]}, 
          DisplayFunction \[Rule] $DisplayFunction];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(p\_3\)[x] = \>\"", Expand[p\_3[x]]];\)\ \ \), "\n", 
    \(\(Print["\<Nodes = \>", pts];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[1] = \>", p[1], \*"\"\<,  p[\!\(3\/2\)] = \>\"", 
        p[3\/2]\ , \*"\"\<,  p[\!\(5\/2\)] = \>\"", 
        p[5\/2]\ , \ "\<,  p[3] = \>", p[3]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
  StyleBox["Background for Hermite Interpolating Polynomial.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \n\n\tThe cubic Hermite polynomial  p(x)  has the interpolative \
properties  ",
  Cell[BoxData[
      RowBox[{\(p \((x\_0)\) = y\_0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"]}]]],
  "   ",
  Cell[BoxData[
      RowBox[{\(p \((x\_3)\) = y\_3\), 
        StyleBox[",",
          FontFamily->"Times New Roman"]}]]],
  "   ",
  Cell[BoxData[
      RowBox[{\(p' \((x\_0)\) = d\_0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(p' \((x\_3)\) = d\_3\), 
        StyleBox[",",
          FontFamily->"Times New Roman"]}]]],
  "  both the function values and their derivatives are known at the ",
  StyleBox["endpoints",
    FontColor->RGBColor[1, 0, 1]],
  " of the interval  ",
  Cell[BoxData[
      \(\([x\_0, x\_3]\)\)]],
  ".  The Hermite polynomial is referred to as a \"clamped cubic,\" where \
\"clamped\" refers to the slope at the endpoints being fixed.  This situation \
is illustrated in Figure 2.  \n\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.38778e-017 0.181818 -7.12863e-018 0.142857 [
[.18182 -0.0125 -3 -9 ]
[.18182 -0.0125 3 0 ]
[.36364 -0.0125 -3 -9 ]
[.36364 -0.0125 3 0 ]
[.54545 -0.0125 -3 -9 ]
[.54545 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[.90909 -0.0125 -3 -9 ]
[.90909 -0.0125 3 0 ]
[-0.0125 .14286 -6 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18182 0 m
.18182 .00625 L
s
[(1)] .18182 -0.0125 0 1 Mshowa
.36364 0 m
.36364 .00625 L
s
[(2)] .36364 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(3)] .54545 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(4)] .72727 -0.0125 0 1 Mshowa
.90909 0 m
.90909 .00625 L
s
[(5)] .90909 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(2)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(3)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(4)] -0.0125 .57143 1 0 Mshowa
0 0 m
0 .6 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.18182 .28571 m
.19618 .29585 L
.21132 .30413 L
.22668 .31015 L
.23539 .31256 L
.23928 .3134 L
.2435 .31417 L
.24766 .31477 L
.25151 .31519 L
.25341 .31535 L
.25519 .31547 L
.25704 .31557 L
.25803 .31561 L
.25909 .31565 L
.26003 .31567 L
.2609 .31568 L
.26186 .31569 L
.2624 .3157 L
.26289 .3157 L
.26378 .31569 L
.26475 .31568 L
.26566 .31566 L
.2665 .31564 L
.26807 .31558 L
.26979 .31549 L
.27327 .31525 L
.27728 .31485 L
.28107 .31436 L
.28817 .31316 L
.29582 .31148 L
.30414 .30919 L
.31924 .30392 L
.33529 .29687 L
.36411 .28096 L
.39481 .26035 L
.42436 .238 L
.45577 .21272 L
.48603 .18803 L
.51513 .16501 L
.54611 .14241 L
.57592 .1236 L
.59113 .11547 L
.60761 .10799 L
.6235 .10225 L
.63106 .10007 L
.63814 .09838 L
.64505 .09706 L
.6486 .09652 L
.65247 .09604 L
.65466 .09581 L
Mistroke
.6567 .09563 L
.6588 .09549 L
.66071 .09538 L
.66161 .09534 L
.66259 .09531 L
.66351 .09528 L
.66435 .09526 L
.66525 .09525 L
.66624 .09524 L
.66674 .09524 L
.66727 .09524 L
.66823 .09525 L
.66917 .09526 L
.6697 .09528 L
.6702 .09529 L
.67129 .09533 L
.67228 .09537 L
.67408 .09546 L
.67602 .0956 L
.68015 .09599 L
.68448 .09656 L
.69183 .09791 L
.69986 .09995 L
.70772 .10253 L
.71486 .1054 L
.73087 .11371 L
.74555 .12373 L
.76144 .13732 L
.79273 .17301 L
.82286 .21955 L
.85183 .27658 L
.88268 .35165 L
.90909 .42857 L
Mfstroke
1 0 0 r
0 .14286 m
.04425 .17763 L
.09252 .21555 L
.13785 .25117 L
.18144 .28542 L
.22784 .32187 L
.2725 .35697 L
.31998 .39427 L
.36572 .43021 L
.40972 .46478 L
.45653 .50156 L
.5016 .53697 L
.54494 .57103 L
s
.54494 .57103 m
.58182 .6 L
s
.77273 0 m
.81851 .14389 L
.86333 .28476 L
.91096 .43445 L
.95686 .57869 L
s
.95686 .57869 m
.96364 .6 L
s
.02 w
.18182 .28571 Mdot
.90909 .42857 Mdot
0 g
gsave
.23636 .25714 -90.5938 -17.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.90909 .42857 -120.188 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 172.75},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000[1000`40O003h00Oogoo8Goo000mOol5
000[Ool4000^Ool2000_Ool3000/Ool2000OOol003moo`03001oogoo02]oo`03001oogoo02ioo`04
001oogoo000_Ool00`00Oomoo`0ZOol01000Oomoo`007Woo000oOol00`00Oomoo`0/Ool00`00Oomo
o`0_Ool00`00Oomoo`0[Ool5000^Ool00`00Oomoo`0LOol003moo`03001oogoo02eoo`03001oogoo
02moo`03001oogoo02Yoo`04001oogoo000]Ool2000OOol003moo`03001oogoo02]oo`04001oogoo
000]Ool01000Oomoo`00;Goo00<007oo0000;Goo00<007ooOol07Woo000nOol2000^Ool2000_Ool2
000_Ool2000]Ool3000NOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000?
Ooo=00000g`00000000k0006Ool000moo`03001oogoo02eoo`03001oogoo02eoo`03001oogoo02io
o`03001oogoo02eoo`03001oogoo00Uoo`03O01oogoo025oo`03001oogoo01eoo`003goo00<007oo
Ool0;Goo00<007ooOol0;Goo00<007ooOol0;Woo00<007ooOol0;Goo00<007ooOol02Woo00=l07oo
Ool087oo00<007ooOol07Goo000?Ool00`00Oomoo`3;Ool00g`0Oomoo`10Ool000moo`03001oogoo
0<]oo`03O01oogoo041oo`003goo00<007ooOol0c7oo00=l07ooOol0?goo000?Ool00`00Oomoo`3<
Ool00g`0Oomoo`0oOol000moo`03001oogoo0<aoo`03O01oogoo03moo`003goo00<007ooOol0cGoo
00=l07ooOol0?Woo000?Ool00`00Oomoo`3=Ool00g`0Oomoo`0nOol000moo`03001oogoo0<eoo`03
O01oogoo03ioo`003goo00<007ooOol0cGoo00=l07ooOol0?Woo000?Ool00`00Oomoo`3>Ool00g`0
Oomoo`0mOol000moo`03001oogoo0<ioo`03O01oogoo03eoo`003goo00<007ooOol0cWoo00=l07oo
Ool0?Goo000?Ool00`00Oomoo`3?Ool00g`0Oomoo`0lOol000moo`03001oogoo0<moo`03O01oogoo
03aoo`003goo00<007ooOol0cgoo00=l07ooOol0?7oo000?Ool00`00Oomoo`3@Ool00g`0Oomoo`0k
Ool000moo`03001oogoo0=1oo`03O01oogoo03]oo`003goo00<007ooOol0d7oo00=l07ooOol0>goo
000?Ool00`00Oomoo`3AOol00g`0Oomoo`0jOol000moo`03001oogoo0=5oo`03O01oogoo03Yoo`00
3goo00<007ooOol0dGoo00=l07ooOol0>Woo000?Ool00`00Oomoo`3BOol00g`0Oomoo`0iOol000mo
o`03001oogoo0:]oo`H07b5oo`03O01oogoo03Uoo`003goo00<007ooOol0YWoo1P0O1Goo1@0O77oo
00=l07ooOol0>Goo000?Ool00`00Oomoo`2ROol401l@Ool401lIOol00g`0Oomoo`0hOol000moo`03
001oogoo0:1oo`807aQoo`807aMoo`03O01oogoo03Qoo`003goo00<007ooOol0WWoo0P0O77oo0P0O
5Goo00=l07ooOol0>7oo000?Ool00`00Oomoo`2LOol201lPOol201lCOol00g`0Oomoo`0hOol000mo
o`03001oogoo09Yoo`807bAoo`0301moogoo015oo`03O01oogoo03Moo`003goo00<007ooOol0V7oo
0P0O9goo0P0O4Goo00=l07ooOol0=goo000?Ool00`00Oomoo`2FOol201l[Ool00`0OOomoo`0>Ool0
0g`0Oomoo`0gOol000moo`03001oogoo09Aoo`807bioo`0301moogoo00ioo`03O01oogoo03Ioo`00
3goo00<007ooOol0Tgoo00<07gooOol0;goo00<07gooOol03Goo00=l07ooOol0=Woo0006Ool50004
Ool00`00Oomoo`2AOol201lcOol00`0OOomoo`0<Ool00g`0Oomoo`0fOol000Qoo`03001oogoo00Ao
o`03001oogoo08moo`807cIoo`0301moogoo00aoo`03O01oogoo03Eoo`0027oo00<007ooOol017oo
00=l0000Ool0SWoo00<07gooOol0=goo00<07gooOol02goo00=l07ooOol0=Goo0008Ool00`00Oomo
o`04Ool00`00O01oo`2=Ool00`0OOomoo`0iOol00`0OOomoo`0:Ool00g`0Oomoo`0eOol000Qoo`03
001oogoo00Aoo`04001oog`0O02:Ool201lmOol00`0OOomoo`0:Ool00g`0Oomoo`0dOol000Moo`80
00Ioo`05001oogooOoml0028Ool00`0OOomoo`0nOol00`0OOomoo`09Ool00g`0Oomoo`0dOol000mo
o`03001oogoo009oo`03O01oogoo08Aoo`0301moogoo03moo`0301moogoo00Uoo`03O01oogoo03Ao
o`003goo00<007ooOol00goo0W`0PWoo0P0O@goo00<07gooOol02Goo00=l07ooOol0<goo000?Ool0
0`00Oomoo`05Ool00g`0Oomoo`1nOol00`0OOomoo`14Ool00`0OOomoo`08Ool00g`0Oomoo`0cOol0
00moo`03001oogoo00Ioo`03O01oogoo07aoo`0301moogoo04Ioo`0301moogoo00Moo`03O01oogoo
03=oo`003goo00<007ooOol01goo0W`0NWoo0P0OBWoo00<07gooOol01goo00=l07ooOol0<Woo000?
Ool00`00Oomoo`09Ool00g`0Oomoo`1fOol00`0OOomoo`1;Ool00`0OOomoo`06Ool00g`0Oomoo`0b
Ool000moo`03001oogoo00Yoo`03O01oogoo07Aoo`0301moogoo04aoo`0301moogoo00Ioo`03O01o
ogoo039oo`003goo00<007ooOol02goo00=l07ooOol0LGoo0P0OD7oo00<07gooOol01Goo00=l07oo
Ool0<Woo000?Ool00`00Oomoo`0<Ool2O01`Ool00`0OOomoo`1AOol00`0OOomoo`05Ool00g`0Oomo
o`0aOol000moo`03001oogoo00ioo`03O01oogoo06aoo`0301moogoo059oo`0301moogoo00Eoo`03
O01oogoo035oo`003goo00<007ooOol03goo00=l07ooOol0JWoo00<07gooOol0E7oo00<07gooOol0
17oo00=l07ooOol0<Goo000?Ool00`00Oomoo`0@Ool00g`0Oomoo`1XOol00`0OOomoo`1FOol00`0O
Oomoo`04Ool00g`0Oomoo`0`Ool000moo`03001oogoo015oo`03O01oogoo06Eoo`807eUoo`0301mo
ogoo00Aoo`03O01oogoo031oo`003goo00<007ooOol04Woo0W`0I7oo00<07gooOol0FWoo00<07goo
Ool00goo00=l07ooOol0<7oo000?Ool00`00Oomoo`0DOol00g`0Oomoo`1POol00`0OOomoo`1LOol0
0`0OOomoo`03Ool00g`0Oomoo`0_Ool000moo`03001oogoo01Eoo`03O01oogoo00ioo`03001oogoo
01Moo`@000aoo`03001oogoo02=oo`0301moogoo05eoo`0301moogoo00=oo`03O01oogoo02moo`00
3goo00<007ooOol05Woo00=l07ooOol037oo00<007ooOol02goo0P0017oo00<007ooOol01Woo00<0
07ooOol01Goo0P001Goo00<007ooOol08Goo00<07gooOol0Ggoo00<07gooOol00Woo00=l07ooOol0
;goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0;Ool00`00Oomoo`0:Ool01000Oomoo`000goo0P00
27oo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo01moo`807f=oo`0301moogoo009oo`03
O01oogoo02ioo`003goo00<007ooOol067oo0W`02Woo00<007ooOol00goo0`0000Ioo`00000007oo
0002Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20004Ool01000Oomoo`001Goo00<007ooOol07Goo
00<07gooOol0Hgoo00<07gooOol00Woo00=l07ooOol0;Woo000?Ool00`00Oomoo`0JOol00g`0Oomo
o`07Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00@007ooOol000Aoo`8000Moo`8000Aoo`04
001oogoo0005Ool00`00Oomoo`0LOol00`0OOomoo`1UOol01@0OOomoogooO000<7oo000?Ool00`00
Oomoo`0KOol00g`0Oomoo`06Ool00`00Oomoo`05Ool00`00Ool00003Ool01000Oomoo`003Goo00<0
07oo00000goo00@007ooOol000Eoo`03001oogoo01Yoo`807fQoo`0301moogoo009oo`03O01oogoo
02eoo`003goo00<007ooOol077oo00=l07ooOol01Goo00<007ooOol01Woo0P0017oo0P003Woo00@0
07ooOol000=oo`8000Ioo`03001oogoo01Uoo`0301moogoo06Uoo`0501moogooOoml000_Ool000mo
o`03001oogoo01eoo`03O01oogoo00Aoo`03001oogoo00Eoo`04001oogoo000COol01000Oomoo`00
2goo00<007ooOol067oo00<07gooOol0JWoo00D07gooOomoog`002moo`003goo00<007ooOol07Woo
0W`017oo00<007ooOol017oo0`0000Aoo`000000011oo`<00004Ool000000009Ool00`00Oomoo`0F
Ool201m^Ool01@0OOomoogooO000;Woo000?Ool00`00Oomoo`0POol00g`0Oomoo`02Ool00`00Oomo
o`0YOol00`00Oomoo`0FOol00`0OOomoo`1^Ool01@0OOomoogooO000;Woo000?Ool00`00Oomoo`0Q
Ool01G`0Oomoogoo0000:goo00<007ooOol05Goo00<07gooOol0L7oo00@07gooOoml02ioo`003goo
00<007ooOol08Woo00El07ooOomoo`0002Uoo`03001oogoo01Aoo`807g=oo`0401moogooO00^Ool0
00moo`03001oogoo02=oo`9l045oo`0301moogoo07Aoo`0401moogooO00]Ool000moo`03001oogoo
02Eoo`03O01oogoo03eoo`0301moogoo07Eoo`0401moogooO00]Ool000moo`03001oogoo02Ioo`03
O01oogoo03Yoo`807gUoo`0301moog`002eoo`003goo00<007ooOol09goo0W`0>Goo00<07gooOol0
NGoo00@07gooOoml02aoo`003goo00<007ooOol0:Goo00=l07ooOol0=Goo00<07gooOol0Ngoo00<0
7gooO000;7oo0006Ool40005Ool00`00Oomoo`0ZOol00g`0Ooml0002O00`Ool201mnOol00`0OOoml
000/Ool000Ioo`03001oogoo00Ioo`03001oogoo02]oo`El02ioo`0301moogoo07ioo`0401moogoo
O00[Ool000Moo`03001oogoo00Eoo`8002aoo`El02aoo`807h9oo`0301moog`002]oo`0027oo00<0
07ooOol017oo00<007ooOol0:goo1G`0:Woo0P0OQ7oo00<07gooO000:goo0006Ool01000Oomoo`00
1Goo00<007ooOol0;7oo17`000<07gooOol09Goo0P0OQgoo00<07gooO000:Woo0007Ool20006Ool0
0`00Oomoo`0`Ool2O00TOol201n9Ool00`0OOoml000ZOol000moo`03001oogoo039oo`03O0007goo
01moo`807h]oo`0301moog`002Yoo`003goo00<007ooOol0<goo00Al000O01l07aYoo`<07hioo`03
01moog`002Uoo`003goo00<007ooOol0=7oo00=l07ooOol00`0O4goo100OTGoo00<07gooO000:Goo
000?Ool00`00Oomoo`0eOol00g`0Oomoo`02Ool301l<Ool401nFOol00`0OO01oo`0XOol000moo`03
001oogoo03Ioo`9l00Eoo``07iYoo`0301moog`002Qoo`003goo00<007ooOol0>7oo00=l07ooOol0
Z7oo00<07gooO000:7oo000?Ool00`00Oomoo`0iOol00g`0Oomoo`2XOol00`0OO01oo`0WOol000mo
o`03001oogoo03Yoo`03O01oogoo0:Moo`0301moog`002Moo`003goo00<007ooOol0>goo0W`0Z7oo
00<07g`0Ool09Woo000?Ool00`00Oomoo`0mOol00g`0Oomoo`2UOol00`0OO01oo`0VOol000moo`03
001oogoo03ioo`03O01oogoo0:Aoo`0301moog`002Ioo`003goo00<007ooOol0?goo0W`0YGoo00<0
7g`0Ool09Goo000?Ool00`00Oomoo`11Ool00g`0Oomoo`2ROol00`0OO01oo`0UOol000moo`03001o
ogoo049oo`03O01oogoo0:9oo`0301ml07oo02Aoo`003goo00<007ooOol0@goo0W`0XWoo00<07g`0
Ool097oo000?Ool00`00Oomoo`15Ool00g`0Oomoo`2OOol00`0OO01oo`0TOol000moo`03001oogoo
04Ioo`03O01oogoo09moo`0301ml07oo02=oo`003goo00<007ooOol0Agoo0W`0Wgoo00<07g`0Ool0
8goo000?Ool00`00Oomoo`19Ool00g`0Oomoo`2LOol00`0OO01oo`0SOol000moo`03001oogoo04Yo
o`03O01oogoo09aoo`03O01oogoo029oo`003goo00<007ooOol0Bgoo0W`0W7oo00<07g`0Ool08Woo
000?Ool00`00Oomoo`1=Ool00g`0Oomoo`2IOol00`0OO01oo`0ROol000moo`03001oogoo04ioo`03
O01oogoo09Uoo`03O01oogoo025oo`003goo00<007ooOol0Cgoo0W`0VGoo00<07g`0Ool08Goo000?
Ool00`00Oomoo`1AOol00g`0Oomoo`2GOol00g`0Oomoo`0POol000moo`03001oogoo059oo`03O01o
ogoo09Ioo`03O01oogoo021oo`003goo00<007ooOol0Dgoo00=l07ooOol0UGoo00<07g`0Ool087oo
000?Ool00`00Oomoo`1DOol2O02FOol00g`0Oomoo`0OOol000moo`03001oogoo05Ioo`03O01oogoo
09=oo`03O01oogoo01moo`003goo00<007ooOol0Egoo00=l07ooOol0HGoo00<007ooOol05goo1000
37oo00<007ooOol017oo00<07g`0Ool07goo000?Ool00`00Oomoo`1HOol2O01POol00`00Oomoo`0;
Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`05Ool20005Ool00`00Oomoo`04Ool00g`0Oomoo`0N
Ool000moo`03001oogoo05Yoo`03O01oogoo05eoo`03001oogoo00Yoo`04001oogoo0004Ool20007
Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol017oo00=l07ooOol07Woo0007Ool20006
Ool00`00Oomoo`1KOol00g`0Oomoo`1KOol00`00Oomoo`03Ool3000017oo000000000goo00<007oo
Ool017oo00<007ooOol01Goo0P001Woo00<007ooOol017oo00<007ooOol00goo0g`07Woo0006Ool0
1000Oomoo`001Goo00<007ooOol0G7oo0W`0Fgoo00<007ooOol017oo00D007ooOomoo`0000Eoo`03
001oogoo00=oo`8000Ioo`8000Moo`03001oogoo00=oo`03001oogoo009oo`El01eoo`0027oo00<0
07ooOol017oo0P00Ggoo00=l07ooOol0F7oo00<007ooOol01Goo00<007oo00000goo00@007ooOol0
00eoo`03001oo`0000=oo`04001oogoo0005Ool00`00Oomoo`02Ool5O00MOol000Uoo`03001oogoo
00=oo`03001oogoo05moo`03O01oogoo05Moo`03001oogoo00Ioo`8000Aoo`8000ioo`04001oogoo
0003Ool20006Ool00`00Oomoo`02Ool5O00MOol000Ioo`04001oogoo0005Ool00`00Oomoo`1POol0
0g`0Oomoo`1FOol00`00Oomoo`05Ool01000Oomoo`004goo00@007ooOol000]oo`03001oogoo00=o
o`=l01ioo`001goo0P001Woo00<007ooOol0HGoo0W`0EWoo00<007ooOol017oo0`0000Aoo`000000
011oo`<00004Ool000000009Ool00`00Oomoo`05Ool00g`0Oomoo`0LOol000moo`03001oogoo06=o
o`03O01oogoo05Aoo`03001oogoo02Uoo`03001oogoo00Moo`03O01oogoo01]oo`003goo00<007oo
Ool0I7oo00=l07ooOol0Dgoo00<007ooOol0:Goo00<007ooOol01goo00=l07ooOol06goo000?Ool0
0`00Oomoo`1UOol00g`0Oomoo`1COol00`00Oomoo`0WOol00`00Oomoo`08Ool00g`0Oomoo`0KOol0
00moo`03001oogoo06Ioo`03O01oogoo08Qoo`03O01oogoo01Yoo`003goo00<007ooOol0Igoo0W`0
R7oo00=l07ooOol06Woo000?Ool00`00Oomoo`1YOol00g`0Oomoo`25Ool00g`0Oomoo`0JOol000mo
o`03001oogoo06Yoo`03O01oogoo08Eoo`03O01oogoo01Uoo`003goo00<007ooOol0Jgoo00=l07oo
Ool0Q7oo00=l07ooOol06Goo000?Ool00`00Oomoo`1/Ool2O024Ool00g`0Oomoo`0IOol000moo`03
001oogoo06ioo`03O01oogoo085oo`03O01oogoo01Uoo`003goo00<007ooOol0Kgoo00=l07ooOol0
PGoo00=l07ooOol067oo000?Ool00`00Oomoo`1`Ool2O021Ool00g`0Oomoo`0HOol000moo`03001o
ogoo079oo`03O01oogoo07ioo`03O01oogoo01Qoo`003goo00<007ooOol0Lgoo00=l07ooOol0OWoo
00=l07ooOol05goo000?Ool00`00Oomoo`1dOol2O01nOol00g`0Oomoo`0GOol000moo`03001oogoo
07Ioo`03O01oogoo07]oo`03O01oogoo01Moo`003goo00<007ooOol0Mgoo00=l07ooOol0Ngoo00=l
07ooOol05Woo000?Ool00`00Oomoo`1hOol00g`0Oomoo`1jOol00g`0Oomoo`0FOol000moo`03001o
ogoo07Uoo`9l07Yoo`03O01oogoo01Ioo`003goo00<007ooOol0Ngoo00=l07ooOol0N7oo00=l07oo
Ool05Goo000?Ool00`00Oomoo`1lOol00g`0Oomoo`1gOol00g`0Oomoo`0EOol000moo`03001oogoo
07eoo`03O01oogoo07Ioo`03O01oogoo01Eoo`003goo00<007ooOol0OWoo00=l07ooOol0MWoo00=l
07ooOol057oo000?Ool00`00Oomoo`1oOol2O01fOol00g`0Oomoo`0DOol000moo`03001oogoo085o
o`03O01oogoo07=oo`03O01oogoo01Aoo`003goo00<007ooOol0PWoo00=l07ooOol0Lgoo00=l07oo
Ool04goo000?Ool00`00Oomoo`23Ool00g`0Oomoo`1bOol00g`0Oomoo`0COol000moo`03001oogoo
08Aoo`9l079oo`03O01oogoo01=oo`003goo00<007ooOol0QWoo00=l07ooOol0Kgoo00=l07ooOol0
4goo000?Ool00`00Oomoo`27Ool00g`0Oomoo`1_Ool00g`0Oomoo`0BOol000moo`03001oogoo08Qo
o`9l06moo`03O01oogoo019oo`003goo00<007ooOol0RWoo00=l07ooOol0K7oo00=l07ooOol04Woo
0008Ool30004Ool00`00Oomoo`2;Ool00g`0Oomoo`1/Ool00g`0Oomoo`0AOol000Uoo`03001oogoo
00=oo`03001oogoo08aoo`9l06aoo`03O01oogoo015oo`001Woo1@0017oo0P00Sgoo00=l07ooOol0
JGoo00=l07ooOol04Goo0006Ool01000Oomoo`001Goo00<007ooOol0Sgoo00=l07ooOol0JGoo00=l
07ooOol047oo0007Ool00`00Ool00005Ool00`00Oomoo`2@Ool2O01YOol00g`0Oomoo`0@Ool000Qo
o`8000Eoo`03001oogoo099oo`03O01oogoo06Ioo`03O01oogoo011oo`003goo00<007ooOol0Tgoo
00=l07ooOol0IWoo00=l07ooOol03goo000?Ool00`00Oomoo`2DOol2O01VOol00g`0Oomoo`0?Ool0
00moo`03001oogoo09Ioo`03O01oogoo06Aoo`03O01oogoo00ioo`003goo00<007ooOol0Ugoo00=l
07ooOol0Hgoo00=l07ooOol03Woo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {171.75, 0}} -> {0, 0, 0, 0}}],
  "     \n"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["\t\tFigure 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the cubic Hermite polynomial or \"clamped cubic\" that satisfies  \n\
\t\t",
  Cell[BoxData[{
      \(\ \ \ p \((1)\) = 2\), "\n", 
      \(p' \((1)\) = 1\), "\n", 
      \(\ \ \ p \((3)\) = 1\), "\n", 
      \(p' \((3)\) = 2\)}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for a general cubic equation.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(p[x_]\  = \ a\ x\^3\  + \ b\ x\^2\  + \ c\ x\  + \ d;\)\ \ \), "\n", 
    \(\(Print["\<p[x] = \>", p[x]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use symbolic differentiation to find  ",
  Cell[BoxData[
      \(\(p'\)[x]\)],
    AspectRatioFixed->False],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(Print["\<p'[x] = \>", \(p'\)[x]\ ];\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell["\<\
Set up four equations using the prescribed endpoint conditions.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(eq1\  = \ \ \ \ \(\(p[
          1]\)\(\ \)\(\[Equal]\)\(\ \)\(2\)\(\ \ \)\)\), "\n", 
    \(eq2\  = \ \(\(\(p'\)[
          1]\)\(\ \)\(\[Equal]\)\(\ \)\(1\)\(\ \ \ \)\)\), "\n", 
    \(eq3\  = \ \ \ \ \(\(p[
          3]\)\(\ \)\(\[Equal]\)\(\ \)\(1\)\(\ \ \ \)\)\), "\n", 
    \(eq4\  = \ \(\(\(p'\)[
          3]\)\(\ \)\(\[Equal]\)\(\ \)\(2\)\(\ \ \ \)\)\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Then find the solution set to this linear system and store it in the \
variable ",
  StyleBox["solset",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(eqns\  = \ {eq1, eq2, eq3, eq4};\)\ \ \), "\n", 
    \(\(vars\  = \ {a, b, c, d};\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[eqns, vars];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve and get\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Use the solution given above for the coefficients and form the cubic \
function.  \nRemember that we must dig out one set of braces using ",
  " ",
  Cell[BoxData[
      \(solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)],
    
    AspectRatioFixed->False,
    FontWeight->"Bold"],
  "  before we can use the ",
  StyleBox["ReplaceAll",
    FontWeight->"Bold"],
  " command.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(p[x_]\)\(\ \)\(=\)\(\ \)\(ReplaceAll[\ p[x], 
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ ]\
\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Now form the cubic polynomial function  ",
  Cell[BoxData[
      \(p[x]\)],
    AspectRatioFixed->False],
  " and plot a graph.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(p[x_]\  = \ 
        ReplaceAll[p[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ \
];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(xy = {\ {1, p[1]}, {3, p[3]}\ };\)\ \ \), "\n", 
    \(\(dots\  = \ 
        ListPlot[xy, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] 
            Identity\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(p1[x_] = \ 
        p[1] + \(p'\)[1] \((x - 1)\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(p2[x_] = \ 
        p[3] + \(p'\)[3] \((x - 3)\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr1\  = 
        Plot[p[x], {x, 1, 3}, PlotRange \[Rule] {{0, 3.5}, {0, 3}}, 
          PlotStyle \[Rule] Blue, AspectRatio \[Rule] 2.2\/3, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr2\  = 
        Plot[{p1[x], p2[x]}, {x, 0, 3.5}, 
          PlotRange \[Rule] {{0, 3.5}, {0, 3}}, PlotStyle \[Rule] {Red}, 
          AspectRatio \[Rule] 2.2\/3, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        Show[gr1, gr2, dots, Ticks \[Rule] {Range[0, 3, 1], Range[0, 3, 1]}, 
          DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\n", 
    \(\(Print["\<y = p[x] = \>", p[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< p[1] = \>", p[1], "\<,      p[3] = \>", 
        p[3]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<p'[1] = \>", \(p'\)[1]\ , \ "\<,     p'[3] = \>", \(p'\)[
          3]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Remark.",
    FontColor->RGBColor[1, 0, 1]],
  "  The graphs in examples 1 and 2 are the same, the method of construction \
is different."
}], "Text"],

Cell[BoxData[
    \(\(Show[GraphicsArray[{graph1, graph2}]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(Show[GraphicsArray[{{graph1}, {graph2}}]];\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(Show[graph1, graph2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_3\)[x] = \>\"", 
        Expand[p\_3[x]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< p[x] = \>", p[x]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The B\[EAcute]zier Curve",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe B\[EAcute]zier curve was originally used by  ",
  ButtonBox["Pierre B\[EAcute]zier",
    ButtonData:>{
      URL[ "http://rocbo.chez.tiscali.fr/Max/culture/bezier/bezier.htm"], 
      None},
    ButtonStyle->"Hyperlink"],
  "  for CAD/CAM operations at Renault motor car company.  B\[EAcute]zier \
curves are the basis of the entire Adobe PostScript drawing model which is \
used in the software products: Adobe Illustrator, Macromedia Freehand and \
Fontographer.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Construction of the B\[EAcute]zier Curve",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tA cubic B\[EAcute]zier curve is defined by four points. Two of the \
points are endpoints to the curve, ",
  Cell[BoxData[
      \({x\_0, y\_0}\)]],
  " is the starting point and  ",
  Cell[BoxData[
      \({x\_3, y\_3}\)]],
  "is the destination point. The points ",
  Cell[BoxData[
      RowBox[{\({x\_1, y\_1}\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \({x\_2, y\_2}\)}]]],
  " are control points or \"handles.\"  A parametric formula for the curve is \
 \n\t\n\t",
  Cell[BoxData[
      \(R[t] = {x[t], y[t]}\)]],
  " where ",
  Cell[BoxData[
      RowBox[{\(x[t]\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(y[t]\)}]]],
  " are cubic equations defined in the interval ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  "  as shown in Figure 3. "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.38778e-017 0.181818 -7.12863e-018 0.142857 [
[.18182 -0.0125 -3 -9 ]
[.18182 -0.0125 3 0 ]
[.36364 -0.0125 -3 -9 ]
[.36364 -0.0125 3 0 ]
[.54545 -0.0125 -3 -9 ]
[.54545 -0.0125 3 0 ]
[.72727 -0.0125 -3 -9 ]
[.72727 -0.0125 3 0 ]
[.90909 -0.0125 -3 -9 ]
[.90909 -0.0125 3 0 ]
[-0.0125 .14286 -6 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18182 0 m
.18182 .00625 L
s
[(1)] .18182 -0.0125 0 1 Mshowa
.36364 0 m
.36364 .00625 L
s
[(2)] .36364 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(3)] .54545 -0.0125 0 1 Mshowa
.72727 0 m
.72727 .00625 L
s
[(4)] .72727 -0.0125 0 1 Mshowa
.90909 0 m
.90909 .00625 L
s
[(5)] .90909 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(2)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(3)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(4)] -0.0125 .57143 1 0 Mshowa
0 0 m
0 .6 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.18182 .28571 m
0 .14286 L
s
.72727 0 m
.90909 .42857 L
s
0 0 1 r
.18182 .28571 m
.1721 .27726 L
.16408 .26837 L
.15821 .25941 L
.15586 .25438 L
.15503 .25214 L
.15429 .24972 L
.15371 .24734 L
.1535 .24629 L
.15331 .24515 L
.15317 .24414 L
.15305 .24306 L
.153 .24247 L
.15296 .24193 L
.15293 .24141 L
.15291 .24087 L
.15289 .24033 L
.15288 .23985 L
.15288 .23937 L
.15289 .23891 L
.1529 .23838 L
.15292 .23789 L
.15294 .23736 L
.15298 .23679 L
.15306 .23584 L
.15316 .23496 L
.15346 .23296 L
.1539 .23085 L
.15451 .22858 L
.15597 .22448 L
.15783 .22055 L
.15992 .21695 L
.16542 .2096 L
.1732 .20177 L
.18287 .19414 L
.19321 .18748 L
.21797 .17517 L
.24833 .16427 L
.2817 .15565 L
.30028 .15199 L
.32108 .14872 L
.33158 .14736 L
.34319 .14609 L
.3534 .14515 L
.36481 .1443 L
.37609 .14365 L
.38155 .14341 L
.38678 .14322 L
.38962 .14313 L
.39273 .14305 L
Mistroke
.3956 .14299 L
.39821 .14294 L
.40132 .1429 L
.40303 .14288 L
.40381 .14288 L
.40464 .14287 L
.40614 .14286 L
.40752 .14286 L
.409 .14286 L
.40985 .14286 L
.41064 .14286 L
.41209 .14286 L
.41282 .14287 L
.41363 .14287 L
.41507 .14288 L
.41641 .1429 L
.41945 .14293 L
.42272 .14299 L
.42873 .14313 L
.43426 .14331 L
.44488 .14377 L
.45613 .14444 L
.47973 .14641 L
.50186 .149 L
.52671 .15275 L
.54933 .15699 L
.59796 .16892 L
.64417 .18419 L
.69203 .20479 L
.73624 .22912 L
.77642 .25689 L
.81607 .29143 L
.85056 .32976 L
.88262 .37622 L
.90835 .42683 L
.90909 .42857 L
Mfstroke
1 0 0 r
.02 w
.18182 .28571 Mdot
0 .14286 Mdot
.72727 0 Mdot
.90909 .42857 Mdot
0 g
gsave
.18182 .28571 -61 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
0 .11429 -61 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.74545 .04286 -61 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.90909 .42857 -120.188 -10.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.688 moveto
(H) show
71.438 13.688 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
86.375 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
94.813 13.688 moveto
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
103.250 15.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.750 13.688 moveto
(L) show
118.188 13.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 172.75},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000[1000`40O003h00Oogoo8Goo000mOol5
000[Ool4000^Ool2000_Ool3000/Ool2000OOol003moo`03001oogoo02]oo`03001oogoo02ioo`04
001oogoo000_Ool00`00Oomoo`0ZOol01000Oomoo`007Woo000oOol00`00Oomoo`0/Ool00`00Oomo
o`0_Ool00`00Oomoo`0[Ool5000^Ool00`00Oomoo`0LOol003moo`03001oogoo02eoo`03001oogoo
02moo`03001oogoo02Yoo`04001oogoo000]Ool2000OOol003moo`03001oogoo02]oo`04001oogoo
000]Ool01000Oomoo`00;Goo00<007oo0000;Goo00<007ooOol07Woo000nOol2000^Ool2000_Ool2
000_Ool2000]Ool3000NOol00?moob5oo`00ogoo8Goo003oOolQOol00<moo`=l04ioo`00cWoo1G`0
CGoo000?Oono0005O0170006Ool000moo`03001oogoo02eoo`03001oogoo02eoo`03001oogoo02io
o`03001oogoo02]oo`El02eoo`03001oogoo01eoo`003goo00<007ooOol0;Goo00<007ooOol0;Goo
00<007ooOol0;Woo00<007ooOol0;7oo0g`0;Woo00<007ooOol07Goo000?Ool00`00Oomoo`2oOol0
0g`0Oomoo`1<Ool000moo`03001oogoo0<1oo`03O01oogoo04]oo`003goo00<007ooOol0`7oo00=l
07ooOol0Bgoo000?Ool00`00Oomoo`31Ool00g`0Oomoo`1:Ool000moo`03001oogoo0<5oo`03O01o
ogoo00Moo`03001oogoo00Uoo`@000Yoo`@000Eoo`@000=oo`03001oogoo01Ioo`003goo00<007oo
Ool0`Goo00=l07ooOol01Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol01Woo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol05Goo000?Ool00`00Oomoo`32Ool00g`0Oomoo`05Ool0
0`00Oomoo`0;Ool00`00Oomoo`03Ool20008Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`0EOol000moo`03001oogoo0<9oo`03O01oogoo00Aoo`03001oogoo009oo`<00004Ool000000004
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`0DOol000mo
o`03001oogoo0<=oo`03O01oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01000Oomo
o`0017oo0P001goo0P0017oo00@007ooOol000Eoo`03001oogoo01Aoo`003goo00<007ooOol0`goo
00=l07ooOol00goo00<007ooOol017oo00<007oo00001Goo0P003Woo00<007oo000017oo0P001Woo
00<007ooOol057oo000?Ool00`00Oomoo`33Ool00g`0Oomoo`03Ool00`00Oomoo`05Ool2000EOol0
1000Oomoo`002goo00<007ooOol057oo000?Ool00`00Oomoo`34Ool00g`0Oomoo`02Ool00`00Oomo
o`04Ool01000Oomoo`0057oo00@007ooOol000]oo`03001oogoo01Aoo`003goo00<007ooOol0a7oo
00=l07ooOol00Woo00<007ooOol00goo0`0000Aoo`000000015oo`<00004Ool000000009Ool00`00
Oomoo`0DOol000moo`03001oogoo0<Eoo`03O01oogoo009oo`03001oogoo02Uoo`03001oogoo01Eo
o`003goo00<007ooOol0aGoo00=l07ooOol00Woo00<007ooOol0:Goo00<007ooOol05Goo000?Ool0
0`00Oomoo`36Ool00g`0Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`0FOol000moo`03001oogoo
0<Ioo`03O01oogoo04Eoo`003goo00<007ooOol0aWoo00=l07ooOol0AGoo000?Ool00`00Oomoo`37
Ool00g`0Oomoo`14Ool000moo`03001oogoo0<Moo`03O01oogoo04Aoo`003goo00<007ooOol0b7oo
00=l07ooOol0@goo000?Ool00`00Oomoo`38Ool00g`0Oomoo`13Ool000moo`03001oogoo0<Uoo`03
O01oogoo049oo`003goo00<007ooOol01Goo00<007ooOol02Goo1@002Goo10001Goo1@000Woo00<0
07ooOol0Ugoo00=l07ooOol0@Woo000?Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`2FOol00g`0Oomoo`12
Ool000moo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo009oo`8000Qoo`03001oogoo00Eo
o`03001oogoo00=oo`03001oogoo09Moo`03O01oogoo045oo`003goo00<007ooOol00goo00<007oo
Ool00Woo0`0000Aoo`00000000Aoo`03001oogoo00=oo`03001oogoo00Ioo`8000Ioo`03001oogoo
00Aoo`03001oogoo09Ioo`03O01oogoo045oo`003goo00<007ooOol00goo00<007ooOol00goo00D0
07ooOomoo`0000Eoo`03001oogoo00=oo`8000Moo`8000Ioo`03001oogoo00Aoo`03001oogoo09Mo
o`03O01oogoo041oo`003goo00<007ooOol00goo00<007ooOol017oo00<007oo00001Goo0P003Woo
00<007oo000017oo0P001Woo00<007ooOol0Ugoo00=l07ooOol0@7oo000?Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool2000EOol01000Oomoo`002goo00<007ooOol0Ugoo00=l07ooOol0@7oo000?Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`0057oo00@007ooOol000]oo`03001oogoo09Qo
o`03O01oogoo03moo`003goo00<007ooOol00goo00<007ooOol00goo0`0000Aoo`000000015oo`<0
0004Ool000000009Ool00`00Oomoo`2HOol00g`0Oomoo`0oOol000moo`03001oogoo00Aoo`03001o
ogoo02Uoo`03001oogoo09Yoo`03O01oogoo03ioo`001Woo1@000goo0g`01Goo00<007ooOol0:Goo
00<007ooOol0VWoo00=l07ooOol0?Woo0008Ool00`00Oomoo`02Ool5O005Ool00`00Oomoo`0WOol0
0`00Oomoo`2LOol00g`0Oomoo`0mOol000Qoo`03001oogoo009oo`El05eooa`07eEoo`03O01oogoo
03eoo`0027oo00<007ooOol00Woo1G`0E7oo2@0O77oo1P0OCgoo00=l07ooOol0?Goo0008Ool00`00
Oomoo`03Ool5O01:Ool901l[Ool701m9Ool00g`0Oomoo`0lOol000Moo`8000Ioo`05001oogooOoml
0015Ool401lkOol601m3Ool00g`0Oomoo`0lOol000moo`03001oogoo009oo`03O01oogoo03moo`<0
7dEoo`H07cioo`03O01oogoo03]oo`003goo00<007ooOol00goo00=l07ooOol0>goo0`0OCWoo100O
>Woo00=l07ooOol0>goo000?Ool00`00Oomoo`04Ool2O00hOol301mEOol401lgOol00g`0Oomoo`0j
Ool000moo`03001oogoo00Ioo`03O01oogoo03=oo`807eaoo`@07c=oo`03O01oogoo03Yoo`003goo
00<007ooOol01goo00=l07ooOol0;goo0`0OHWoo0`0O<7oo00=l07ooOol0>Woo000?Ool00`00Oomo
o`08Ool00g`0Oomoo`0[Ool301mXOol301l^Ool00g`0Oomoo`0iOol000moo`03001oogoo00Uoo`9l
02Uoo`807fioo`<07b]oo`03O01oogoo03Uoo`003goo00<007ooOol02goo00=l07ooOol097oo0P0O
Lgoo0`0O:Goo00=l07ooOol0>7oo000?Ool00`00Oomoo`0<Ool00g`0Oomoo`0QOol201mhOol201lW
Ool00g`0Oomoo`0hOol000moo`03001oogoo00eoo`9l01moo`807gaoo`<07bAoo`03O01oogoo03Qo
o`003goo00<007ooOol03goo00=l07ooOol06goo00<07gooOol0Ogoo0`0O8Woo00=l07ooOol0=goo
000?Ool00`00Oomoo`0@Ool00g`0Oomoo`0IOol00`0OOomoo`23Ool201lPOol00g`0Oomoo`0gOol0
00moo`03001oogoo015oo`03O01oogoo01Moo`0301moogoo08Ioo`807amoo`03O01oogoo03Ioo`00
3goo00<007ooOol04Woo0W`05Woo00<07gooOol0RGoo0P0O7Goo00=l07ooOol0=Woo000?Ool00`00
Oomoo`0DOol00g`0Oomoo`0BOol00`0OOomoo`2<Ool00`0OOomoo`0KOol00g`0Oomoo`0eOol000mo
o`03001oogoo01Eoo`03O01oogoo011oo`0301moogoo08ioo`807a]oo`03O01oogoo03Eoo`003goo
00<007ooOol05Woo00=l07ooOol03Woo00<07gooOol0TGoo0P0O6Goo00=l07ooOol0=Goo000?Ool0
0`00Oomoo`0GOol2O00>Ool00`0OOomoo`2COol00`0OOomoo`0GOol00g`0Oomoo`0dOol000moo`03
001oogoo01Uoo`03O01oogoo00Yoo`0301moogoo09Eoo`807aMoo`03O01oogoo03Aoo`003goo00<0
07ooOol06Woo00=l07ooOol02Goo00<07gooOol0Ugoo00<07gooOol05Goo00=l07ooOol0<goo000?
Ool00`00Oomoo`0KOol00g`0Oomoo`08Ool00`0OOomoo`2HOol201lEOol00g`0Oomoo`0cOol000mo
o`03001oogoo01aoo`9l00Moo`807iaoo`0301moogoo01=oo`03O01oogoo039oo`003goo00<007oo
Ool07Woo00=l07ooOol017oo00<07gooOol0W7oo0P0O4goo00=l07ooOol0<Woo000?Ool00`00Oomo
o`0OOol00g`0Oomoo`03Ool201nOOol201lAOol00g`0Oomoo`0bOol000moo`03001oogoo021oo`03
O01oogoo00=oo`0301moogoo09moo`0301moogoo00moo`03O01oogoo035oo`003goo00<007ooOol0
8Goo0W`00goo00<07gooOol0X7oo0P0O3goo00=l07ooOol0<Goo000?Ool00`00Oomoo`0SOol017`0
Oomoo`0OY7oo00<07gooOol03Goo00=l07ooOol0<7oo000?Ool00`00Oomoo`0TOol017`0Oomoo`0O
Y7oo00<07gooOol037oo00=l07ooOol0<7oo000?Ool00`00Oomoo`0UOol2O0000goo01moo`2SOol0
0`0OOomoo`0;Ool00g`0Oomoo`0`Ool000moo`03001oogoo02Moo`03O0007goo00]oo`03001oogoo
01Moo`@000aoo`03001oogoo06aoo`0301moogoo00]oo`03O01oogoo02moo`003goo00<007ooOol0
:7oo00=l000OOol02Goo00<007ooOol02goo0P0017oo00<007ooOol01Woo00<007ooOol01Goo0P00
1Goo00<007ooOol0K7oo00<07gooOol02Woo00=l07ooOol0;goo000?Ool00`00Oomoo`0YOol00g`0
01moo`08Ool00`00Oomoo`0:Ool01000Oomoo`000goo0P0027oo00<007ooOol00goo00@007ooOol0
00Aoo`03001oogoo06eoo`807`]oo`03O01oogoo02ioo`001Woo10001Goo00<007ooOol0:Woo00=l
000OO0000W`017oo00<007ooOol00goo0`0000Ioo`00000007oo0002Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool20004Ool01000Oomoo`001Goo00<007ooOol0KWoo00<07gooOol027oo00=l07ooOol0
;Woo0006Ool00`00Oomoo`06Ool00`00Oomoo`0[Ool5O003Ool00`00Oomoo`04Ool01@00Oomoogoo
00000Woo00@007ooOol000Aoo`8000Moo`8000Aoo`04001oogoo0005Ool00`00Oomoo`1_Ool00`0O
Oomoo`08Ool00g`0Oomoo`0]Ool000Moo`03001oogoo00Eoo`8002aoo`El00=oo`03001oogoo00Eo
o`03001oo`0000=oo`04001oogoo000=Ool00`00Ool00003Ool01000Oomoo`001Goo00<007ooOol0
L7oo00<07gooOol01goo00=l07ooOol0;Goo0008Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool5O003
Ool00`00Oomoo`06Ool20004Ool2000>Ool01000Oomoo`000goo0P001Woo00<007ooOol0LGoo00<0
7gooOol01Woo00=l07ooOol0;Goo0006Ool01000Oomoo`001Goo00<007ooOol0;7oo0g`017oo00<0
07ooOol01Goo00@007ooOol001=oo`04001oogoo000;Ool00`00Oomoo`1bOol00`0OOomoo`06Ool0
0g`0Oomoo`0/Ool000Moo`8000Ioo`03001oogoo03=oo`03001oogoo00Aoo`<00004Ool00000000@
Ool3000017oo000000002Goo00<007ooOol0Lgoo00<07gooOol01Goo00=l07ooOol0;7oo000?Ool0
0`00Oomoo`0dOol00`00Oomoo`0YOol00`00Oomoo`1eOol00`0OOomoo`05Ool00g`0Oomoo`0[Ool0
00moo`03001oogoo03Aoo`03001oogoo02Uoo`03001oogoo07Ioo`0301moogoo00Aoo`03O01oogoo
02]oo`003goo00<007ooOol0=Goo00<007ooOol09goo00<007ooOol0N7oo00<07gooOol017oo00=l
07ooOol0:Woo000?Ool00`00Oomoo`3KOol00`0OOomoo`03Ool00g`0Oomoo`0ZOol000moo`03001o
ogoo0=]oo`0301moogoo00=oo`03O01oogoo02Yoo`003goo00<007ooOol0g7oo00<07gooOol00goo
00=l07ooOol0:Goo000?Ool00`00Oomoo`3MOol00`0OOomoo`02Ool00g`0Oomoo`0YOol000moo`03
001oogoo0=ioo`0301moogoo009oo`03O01oogoo02Qoo`003goo00<007ooOol0ggoo00D07gooOomo
og`002Yoo`003goo00<007ooOol0h7oo00@07gooOoml02Yoo`003goo00<007ooOol0h7oo00D07goo
Oomoog`002Uoo`003goo00<007ooOol0hGoo00@07gooOoml02Uoo`003goo00<007ooOol0hWoo00@0
7gooOoml02Qoo`003goo00<007ooOol0hWoo00@07gooOoml02Qoo`003goo00<007ooOol0hgoo00@0
7gooOoml02Moo`003goo00<007ooOol0i7oo00<07gooO0009goo000?Ool00`00Oomoo`3TOol00`0O
Ooml000WOol000moo`03001oogoo0>Eoo`0301moog`002Ioo`003goo00<007ooOol0iWoo00<07g`0
Ool09Goo000?Ool00`00Oomoo`3VOol00`0OOoml000UOol000moo`03001oogoo0>Moo`0301ml07oo
02Aoo`003goo00<007ooOol0j7oo00<07g`0Ool08goo000?Ool00`00Oomoo`3XOol00`0OO01oo`0S
Ool000moo`03001oogoo0>Uoo`0301moogoo029oo`003goo00<007ooOol0jGoo00<07g`0Ool08Woo
000?Ool00`00Oomoo`3ZOol00`0OOomoo`0QOol000moo`03001oogoo0>Yoo`0301ml07oo025oo`00
3goo00<007ooOol0jgoo00<07gooOol087oo000?Ool00`00Oomoo`3[Ool00`0OOomoo`0POol000mo
o`03001oogoo0;]oo`03001oogoo01Moo`@000aoo`03001oogoo00Aoo`0301moogoo01moo`003goo
00<007ooOol0^Woo00<007ooOol02goo0P001Goo00<007ooOol01Goo00<007ooOol01Goo0P001Goo
00<007ooOol00goo00<07gooOol07goo000?Ool00`00Oomoo`2jOol00`00Oomoo`0:Ool01000Oomo
o`0017oo0P001goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo00Aoo`0301moogoo01io
o`001goo0P001Woo00<007ooOol0^Goo00<007ooOol00goo0`0000Aoo`00000000=oo`03001oogoo
00Aoo`03001oogoo00Eoo`8000Ioo`03001oogoo00Aoo`03001oogoo00=oo`=l01ioo`001Woo00@0
07ooOol000Eoo`03001oogoo0;Uoo`03001oogoo00Aoo`05001oogooOol00005Ool00`00Oomoo`03
Ool20006Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`02Ool5O00MOol000Qoo`03001oogoo00Ao
o`800;Yoo`03001oogoo00Eoo`03001oo`0000=oo`04001oogoo000=Ool00`00Ool00003Ool01000
Oomoo`001Goo00<007ooOol00Woo1G`07Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2iOol00`00
Oomoo`06Ool20004Ool2000>Ool01000Oomoo`000goo0P001Woo00<007ooOol00Woo1G`07Goo0006
Ool01000Oomoo`001Goo00<007ooOol0^Goo00<007ooOol01Goo00@007ooOol001=oo`04001oogoo
000;Ool00`00Oomoo`03Ool3O00NOol000Moo`8000Ioo`03001oogoo0;Uoo`03001oogoo00Aoo`<0
0004Ool00000000@Ool3000017oo000000002Goo00<007ooOol097oo000?Ool00`00Oomoo`2jOol0
0`00Oomoo`0YOol00`00Oomoo`0UOol000moo`03001oogoo0;Yoo`03001oogoo02Uoo`03001oogoo
02Eoo`003goo00<007ooOol0^goo00<007ooOol09goo00<007ooOol09Woo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`0027oo0`0017oo00<007ooOol0ogoo3goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol?Ool000Ioo`D000Aoo`800?mooa1oo`001Woo00@007ooOol000Eo
o`03001oogoo0?moo`moo`001goo00<007oo00001Goo00<007ooOol0ogoo3goo0008Ool20005Ool0
0`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool0
0`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {171.75, 0}} -> {0, 0, 0, 0}}],
  "     "
}], "Text"],

Cell[TextData[StyleBox["\t\tFigure 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Theorem (B\[EAcute]zier Curve).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The ",
  StyleBox["parametric equations",
    FontColor->RGBColor[0, 0, 1]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(x[t]\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(y[t]\)}]]],
  " for the B\[EAcute]zier curve  ",
  Cell[BoxData[
      \(R[t] = {x[t], y[t]}\)]],
  " are given by   \n\n\t",
  Cell[BoxData[
      \(x[t] = 
        x\_0 + 3\ t\ \((x\_1 - x\_0)\) + 
          3\ t\^2\ \((x\_0 + x\_2 - 2\ x\_1)\) + 
          t\^3\ \((x\_3 - x\_0 + 3\ x\_1 - 3\ x\_2)\)\)]],
  ",  \nand\n\t",
  Cell[BoxData[
      \(y[t] = 
        y\_0 + 3\ t\ \((y\_1 - y\_0)\) + 
          3\ \(t\^2\) \((y\_0 + y\_2 - 2\ y\_1)\) + 
          t\^3\ \((y\_3 - y\_0 + 3\ y\_1 - 3\ y\_2)\)\)]],
  "    for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["The B\[EAcute]zier Curve",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/BezierCurveProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The B\[EAcute]zier Curve",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BezierCurveProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the B\[EAcute]zier curve which has the starting at the point ",
  Cell[BoxData[
      \({x\_0, y\_0} = {2, 2}\)]],
  " and destination point ",
  Cell[BoxData[
      \({x\_3, y\_3} = {4, 1}\)]],
  " which has the control points ",
  Cell[BoxData[
      \({x\_1, y\_1} = {1, 1.5}\)]],
  " and ",
  Cell[BoxData[
      \({x\_2, y\_2} = {3.5, 0}\)]],
  ", respectively.  Use the parametric equations to form the  B\[EAcute]zier \
curve."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(R[
          t_] := {x\_0 - 3\ t\ \((x\_0 - x\_1)\) + 
            3\ t\^2\ \((x\_0 - 2\ x\_1 + x\_2)\) + 
            t\^3\ \((\(-x\_0\) + 3\ x\_1 - 3\ x\_2 + 
                  x\_3)\), \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
y\_0 - 3\ t\ \((y\_0 - y\_1)\) - 3\ t\^2\ \((\(-y\_0\) + 2\ y\_1 - y\_2)\) + 
            t\^3\ \((\(-y\_0\) + 3\ y\_1 - 3\ y\_2 + 
                  y\_3)\)};\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<R[t] = \>", MatrixForm[R[t]]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Replace the values in  ",
  Cell[BoxData[
      \(R[t]\)]],
  " and call it  ",
  Cell[BoxData[
      \(P\&\[RightVector]\_1[t]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(values = {x\_0 \[Rule] 2, y\_0 \[Rule] 2, x\_1 \[Rule] 1, \ 
          y\_1 \[Rule] 1.5, \ x\_2 \[Rule] 3.5, \ y\_2 \[Rule] 0, \ 
          x\_3 \[Rule] 4, \ y\_3 \[Rule] 1};\)\ \ \), "\[IndentingNewLine]", 
    \(\(P\&\[RightVector]\_1[t_] = 
        ReplaceAll[\ R[t], values\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\&\[RightVector]\_1\)[t] = \>\"", 
        P\&\[RightVector]\_1[t]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Graph the curve  ",
  Cell[BoxData[
      \(P\&\[RightVector]\_1[t]\)]],
  ",  remember that the interval for this parametric curve is  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(pts = 
        ReplaceAll[{\ {x\_0, y\_0}, {x\_1, y\_1}, {x\_2, y\_2}, {x\_3, 
              y\_3}\ }, values];\)\ \ \), "\n", 
    \(\(lin = 
        ReplaceAll[\ {{Red, Line[\ {{x\_0, y\_0}, {x\_1, y\_1}}]}, {Red, 
              Line[\ {{x\_2, y\_2}, {x\_3, y\_3}}]}}, 
          values];\)\ \ \), "\[IndentingNewLine]", 
    \(\(cont = \ Graphics[lin];\)\ \ \), "\[IndentingNewLine]", 
    \(\(dots1\  = \ 
        ListPlot[pts, PlotStyle \[Rule] {Red, PointSize[0.02]}, \ 
          DisplayFunction \[Rule] Identity];\)\ \ \ \), "\n", 
    \(\(gr1 = 
        ParametricPlot[\ Evaluate[P\&\[RightVector]\_1[t]], {t, 0, 1}, 
          PlotStyle \[Rule] Blue, \ 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[cont, gr1, dots1, PlotRange \[Rule] {{0, 4}, {\(-1\), 2}}, 
        Axes \[Rule] True, 
        Ticks \[Rule] {Range[0, 4, 1], Range[\(-1\), 2, 1]}, \ 
        AspectRatio \[Rule] 2\/5, \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\&\[RightVector]\_1\)[t] = \>\"", 
        P\&\[RightVector]\_1[t]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["More background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIf a control point is chosen farther away from a endpoint, (but in \
the same direction), then the ",
  "B\[EAcute]zier",
  " curve will more closely approximate the tangent line near that endpoint.  \
"
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the B\[EAcute]zier curve which starts at ",
  Cell[BoxData[
      \({x\_0, y\_0} = {2, 2}\)]],
  " and ends at ",
  Cell[BoxData[
      \({x\_3, y\_3} = {4, 1}\)]],
  " which has the control points ",
  Cell[BoxData[
      \({x\_1, y\_1} = {0, 1}\)]],
  " and ",
  Cell[BoxData[
      \({x\_2, y\_2} = {3, \(-1\)}\)]],
  ", respectively.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Replace the values in  ",
  Cell[BoxData[
      \(R[t]\)]],
  " and call it  ",
  Cell[BoxData[
      \(P\&\[RightVector]\_2[t]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(values = {x\_0 \[Rule] 2, y\_0 \[Rule] 2, x\_1 \[Rule] 0, \ 
          y\_1 \[Rule] 1, \ x\_2 \[Rule] 3, \ y\_2 \[Rule] \(-1\), \ 
          x\_3 \[Rule] 4, \ y\_3 \[Rule] 1};\)\ \ \), "\[IndentingNewLine]", 
    \(\(P\&\[RightVector]\_2[t_] = 
        ReplaceAll[R[t], values];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\&\[RightVector]\_2\)[t] = \>\"", 
        P\&\[RightVector]\_2[t]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Graph the curve  ",
  Cell[BoxData[
      \(P\&\[RightVector]\_2[t]\)]],
  "  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(pts = 
        ReplaceAll[{\ {x\_0, y\_0}, {x\_1, y\_1}, {x\_2, y\_2}, {x\_3, 
              y\_3}\ }, values];\)\ \ \), "\n", 
    \(\(lin = 
        ReplaceAll[\ {{Red, Line[\ {{x\_0, y\_0}, {x\_1, y\_1}}]}, {Red, 
              Line[\ {{x\_2, y\_2}, {x\_3, y\_3}}]}}, 
          values];\)\ \ \), "\[IndentingNewLine]", 
    \(\(cont = \ Graphics[lin];\)\ \ \), "\n", 
    \(\(dots2\  = \ 
        ListPlot[pts, PlotStyle \[Rule] {Red, PointSize[0.02]}, \ 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr2 = 
        ParametricPlot[\ Evaluate[P\&\[RightVector]\_2[t]], {t, 0, 1}, 
          PlotStyle \[Rule] Purple, \ 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[cont, gr2, dots2, PlotRange \[Rule] {{0, 4}, {\(-1\), 2}}, 
        Axes \[Rule] True, 
        Ticks \[Rule] {Range[0, 4, 1], Range[\(-1\), 2, 1]}, \ 
        AspectRatio \[Rule] 2\/5, \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\&\[RightVector]\_2\)[t] = \>\"", 
        P\&\[RightVector]\_2[t]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compare the B\[EAcute]zier curve which starts at ",
  Cell[BoxData[
      \({x\_0, y\_0} = {2, 2}\)]],
  " and ends at ",
  Cell[BoxData[
      \({x\_3, y\_3} = {4, 1}\)]],
  " given in examples 3 and 4.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Show[cont, gr1, gr2, dots1, dots2, 
        PlotRange \[Rule] {{0, 4}, {\(-1\), 2}}, Axes \[Rule] True, 
        Ticks \[Rule] {Range[0, 4, 1], Range[\(-1\), 2, 1]}, \ 
        AspectRatio \[Rule] 2\/5, \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\&\[RightVector]\_1\)[t] = \>\"", 
        P\&\[RightVector]\_1[t]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\&\[RightVector]\_2\)[t] = \>\"", 
        P\&\[RightVector]\_2[t]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Bernstein polynomials.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["Definition (Bernstein Polynomials).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The ",
  ButtonBox["Bernstein polynomials",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BernsteinPolynomial.html"], None},
    ButtonStyle->"Hyperlink"],
  " of degree ",
  Cell[BoxData[
      \(n\)]],
  " are  \n\t\n\t",
  Cell[BoxData[
      RowBox[{\(\(B\_\(i, n\)\) \((t)\)\), " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"n"},
                {"i"}
                }], ")"}], \(t\^i\), \(\((1 - t)\)\^\(n - 1\)\)}]}]]],
  ", for ",
  Cell[BoxData[
      RowBox[{\(i = 0\), ",", "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ",  where ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"n"},
                {"i"}
                }], ")"}], 
          "=", \(\(n!\)\/\(\(i!\) \(\((n - i)\)!\)\)\)}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear[i, n, t];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(B\_\(i_, n_\)[t_]\  := \ 
          Binomial[n, i] \(t\^i\) \((1 - t)\)\^\(n - i\);\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", "\"\<\!\(B\_\(i, n\)\)[t] = ( \!\(\*GridBox[{
{\(n\)},
{\(i\)}
}]\) ) \!\(t\^i\)\!\(\((1 - t)\)\^\(n - i\)\)\>\"", "]"}], ";"}], 
      " "}]}], "Input"],

Cell[TextData[{
  "Graphs of the Bernstein polynomials of degree  ",
  Cell[BoxData[
      RowBox[{\(n = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "3"}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(For[n = 1, 
        n \[LessEqual] 3, \(n++\), \ \[IndentingNewLine]funs = 
          Table[B\_\(i, n\)[t], {i, 0, n}]; \ \[IndentingNewLine]Plot[
          Evaluate[funs], {t, 0, 1}, 
          PlotStyle \[Rule] {Red, Blue, Magenta, 
              Green}]; \ \[IndentingNewLine]Print["\<The Bernstein \
polynomials of degree \>", n]; \ \[IndentingNewLine]For[i = 0, 
          i \[LessEqual] 
            n, \(i++\), \[IndentingNewLine]\(Print["\<B\>"\_\(i, n\), "\<[t] \
= \>", B\_\(i, n\)[
                t]];\)\ ]; \ \[IndentingNewLine]Print["\<\>"];\ \ ];\)\ \ \
\)}], "Input"],

Cell[TextData[{
  StyleBox["Observations.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["(i)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tThe Bernstein polynomials are non-negative over the interval ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  \n\n",
  StyleBox["(ii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t",
  Cell[BoxData[
      \(\[Sum]\+\(i = 0\)\%n\ B\_\(i, n\)[t]\  = \ 1\)]],
  ",  which we can easily verify for the case ",
  Cell[BoxData[
      \(n = 3\)]],
  ";"
}], "Text"],

Cell[BoxData[
    \(B\_\(0, 3\)[t] + B\_\(1, 3\)[t] + B\_\(2, 3\)[t] + 
        B\_\(3, 3\)[
          t] \[Equal] \(\(\((1 - 
                t)\)\^3\)\(+\)\(3\ \((1 - t)\)\^2\ t\)\(+\)\(3\ \((1 - 
              t)\)\ t\^2\)\(+\)\(t\^3\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(B\_\(0, 3\)[t] + B\_\(1, 3\)[t] + B\_\(2, 3\)[t] + 
        B\_\(3, 3\)[
          t]\)\(\[Equal]\)\(\((\((1 - t)\) + t)\)\^3\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Expand[
        B\_\(0, 3\)[t] + B\_\(1, 3\)[t] + B\_\(2, 3\)[t] + 
          B\_\(3, 3\)[
            t]]\)\(\[Equal]\)\(\((\((1 - t)\) + 
              t)\)\^3\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Property (ii) is merely the simplification  ",
  Cell[BoxData[
      \(\((\((1 - t)\) + t)\)\^3 = \(\((1 - t + t)\)\^3 = \(\((1)\)\^3 = 
            1\)\)\)]],
  "  \n\n",
  StyleBox["(iii)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\tThe Bernstein polynomials of degree ",
  Cell[BoxData[
      \(n\)]],
  " form a basis of the subspace of continuous functions spanned by ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{"1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "t", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(t\^2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(t\^\(n - 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(t\^n\)}], "}"}]]],
  ".  \n\tFor our purposes we only need this fact for degree ",
  Cell[BoxData[
      \(n = 3\)]],
  ".  \n\t\n\tThat is, the span of  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(B\_\(0, 3\)[t]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(B\_\(1, 3\)[t]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(B\_\(2, 3\)[t]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(B\_\(3, 3\)[t]\)}], "}"}]]],
  " and the span of ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{"1", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "t", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(t\^2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(t\^3\)}], "}"}]]],
  " are the same.  It will suffice to show that each of the functions ",
  Cell[BoxData[
      RowBox[{"1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "t", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\^2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(t\^3\)}]]],
  " is a linear combination of the Bernstein polynomials.  Observation (ii) \
shows that 1 is a linear combination, and by definition ",
  Cell[BoxData[
      \(t\^3\)]],
  " is in both set.   We need to check out ",
  Cell[BoxData[
      RowBox[{"t", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(t\^2\)}]]],
  ".   We find that   \n\t\n\t",
  Cell[BoxData[
      \(\((1 - t)\)\^2\ t\  + \ 2\ \((1 - t)\)\ t\^2\  + \ t\^3\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(t - 2\ t\^2 + t\^3\  + \ 2\ t\^2 - 
            2\ t\^3\  + \ t\^3\  = \ t\)\)\)\)]],
  ",    \nand  \n\t",
  Cell[BoxData[
      \(\((1 - t)\)\ t\^2\  + \ t\^3\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(t\^2 - t\^3\  + \ t\^3\  = \ t\^2\)\)\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Construction of the B\[EAcute]zier Curve using Bernstein \
polynomials.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe coordinate functions  ",
  Cell[BoxData[
      \(x[t]\)]],
  " and  ",
  Cell[BoxData[
      \(y[t]\)]],
  " for the  B\[EAcute]zier curve we are using can written as a linear \
combinations of the Bernstein polynomials \n",
  Cell[BoxData[
      \({B\_\(0, 3\)[t], B\_\(1, 3\)[t], B\_\(2, 3\)[t], B\_\(3, 3\)[t]}\)]],
  ":     \n\n\t\t",
  Cell[BoxData[
      \(X[t]\  = \ \[Sum]\+\(i = 0\)\%3\ x\_i\ B\_\(i, 3\)[t]\)]],
  ",  \n\tand\n\t\t",
  Cell[BoxData[
      \(Y[t]\  = \ \[Sum]\+\(i = 0\)\%3\ y\_i\ B\_\(i, 3\)[t]\)]],
  ".  \n\nVerify that the two functions  ",
  Cell[BoxData[
      \(x[t]\)]],
  "  and ",
  Cell[BoxData[
      \(X[t]\)]],
  " are the same.  "
}], "Text"],

Cell[BoxData[{
    \(x[t]\ \ \), "\[IndentingNewLine]", 
    \(X[t_]\  = \ \[Sum]\+\(i = 0\)\%3\ \(\(x\_i\)\(\ \)\(B\_\(i, 3\)[
            t]\)\(\ \)\)\)}], "Input"],

Cell[BoxData[{
    \(Expand[x[t]]\ \ \), "\[IndentingNewLine]", 
    \(Expand[X[t]]\ \ \), "\[IndentingNewLine]", 
    \(Expand[x[t]]\  \[Equal] \ Expand[X[t]]\ \ \)}], "Input"],

Cell[TextData[{
  "Similarly, the two functions  ",
  Cell[BoxData[
      \(y[t]\)]],
  "  and  ",
  Cell[BoxData[
      \(Y[t]\)]],
  " are the same.  \nTo verify we have the correct end conditions, we can \
evaluate  ",
  Cell[BoxData[
      \(X[t]\)]],
  "  and its derivative at ",
  Cell[BoxData[
      \(t = 0\)]],
  " and ",
  Cell[BoxData[
      \(t = 1\)]],
  ",  and see if it has the required properties.  "
}], "Text"],

Cell[BoxData[{
    \(\(X[t_]\  = \ \[Sum]\+\(i = 0\)\%3\ 
          x\_i\ B\_\(i, 3\)[t]\ ;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< X[t] = \>", X[t]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< X[0] = \>", X[0]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< X[1] = \>", X[1]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<X'[t] = \>", \(X'\)[t]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<X'[0] = \>", 
        Factor[\(X'\)[0]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<X'[1] = \>", Factor[\(X'\)[1]]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Recall that this is what we wanted in the first construction.  \n\t",
  Cell[BoxData[
      \(eq5\  = \ \(x'\)[0] \[Equal] 3 \((x\_1 - x\_0)\)\)]],
  "   \n\t",
  Cell[BoxData[
      \(eq7\  = \ \(x'\)[1] \[Equal] \(-3\) \((x\_2 - x\_3)\)\)]],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Justification for the factor 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tSince we want the two constructions of the B\[EAcute]zier curve to \
be the same, it is common practice to use the term ",
  Cell[BoxData[
      \(3 \((x\_1 - \ x\_0)\)\)]],
  " in the development of the parametric equations.  Similarly the term  ",
  Cell[BoxData[
      \(\(-3\) \((x\_2 - x\_3)\)\)]],
  " is justified.  "
}], "Text"],

Cell["\<\
\tThe construction of a B\[EAcute]zier curve using Bernstein polynomials is \
more appealing mathematically because the coefficients in the linear \
combination are just the coordinates of the given four points.  \
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the B\[EAcute]zier curve which starts at ",
  Cell[BoxData[
      \({x\_0, y\_0} = {2, 2}\)]],
  " and ends at ",
  Cell[BoxData[
      \({x\_3, y\_3} = {4, 1}\)]],
  " which has the control points ",
  Cell[BoxData[
      \({x\_1, y\_1} = {0, 1}\)]],
  " and ",
  Cell[BoxData[
      \({x\_2, y\_2} = {3, \(-1\)}\)]],
  ", respectively. \n Use Bernstein polynomials.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Formulate the B\[EAcute]zier curve as linear combinations of Bernstein \
polynomials and call it  ",
  Cell[BoxData[
      \(R[t]\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    \(\(R[
          t_]\  = \ {\ \[Sum]\+\(i = 0\)\%3\ 
            x\_i\ Binomial[3, 
                i] \(t\^i\) \((1 - t)\)\^\(3 - i\), \ \[Sum]\+\(i = 0\)\%3\ 
            y\_i\ Binomial[3, 
                i] \(t\^i\) \((1 - t)\)\^\(3 - i\)\ };\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<R[t] = \>", R[t]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Replace the values in  ",
  Cell[BoxData[
      \(R[t]\)]],
  " and call it  ",
  Cell[BoxData[
      \(P\&\[RightVector]\_3[t]\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    \(\(values = {x\_0 \[Rule] 2, y\_0 \[Rule] 2, x\_1 \[Rule] 0, \ 
          y\_1 \[Rule] 1, \ x\_2 \[Rule] 3, \ y\_2 \[Rule] \(-1\), \ 
          x\_3 \[Rule] 4, \ y\_3 \[Rule] 1};\)\ \ \), "\[IndentingNewLine]", 
    \(\(P\&\[RightVector]\_3[t_] = 
        ReplaceAll[R[t], values];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\&\[RightVector]\_3\)[t] = \>\"", 
        P\&\[RightVector]\_3[t]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Graph the curve  ",
  Cell[BoxData[
      \(P\&\[RightVector]\_3[t]\)]],
  "  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(pts = 
        ReplaceAll[{\ {x\_0, y\_0}, {x\_1, y\_1}, {x\_2, y\_2}, {x\_3, 
              y\_3}\ }, values];\)\ \), "\n", 
    \(\(lin = 
        ReplaceAll[\ {{Red, Line[\ {{x\_0, y\_0}, {x\_1, y\_1}}]}, {Red, 
              Line[\ {{x\_2, y\_2}, {x\_3, y\_3}}]}}, 
          values];\)\ \), "\[IndentingNewLine]", 
    \(\(cont = \ Graphics[lin];\)\ \), "\n", 
    \(\(dots\  = \ 
        ListPlot[pts, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr3 = 
        ParametricPlot[\ Evaluate[P\&\[RightVector]\_3[t]], {t, 0, 1}, 
          PlotRange \[Rule] {{0, 5}, {\(-1\), 3}}, PlotStyle \[Rule] Blue, \ 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(Show[cont, gr3, dots, PlotRange \[Rule] {{0, 4}, {\(-1\), 2}}, 
        Axes \[Rule] True, 
        Ticks \[Rule] {Range[0, 4, 1], Range[\(-1\), 2, 1]}, 
        AspectRatio \[Rule] 2\/5, \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\&\[RightVector]\_3\)[t] = \>\"", 
        P\&\[RightVector]\_3[t]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["The B\[EAcute]zier Curve",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/BezierCurveProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The B\[EAcute]zier Curve",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BezierCurveProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["B\[EAcute]zier Curve).",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Construct the B\[EAcute]zier given endpoints ",
  Cell[BoxData[
      \({x\_0, y\_0}\)]],
  " and  ",
  Cell[BoxData[
      \({x\_3, y\_3}\)]],
  "and control points ",
  Cell[BoxData[
      RowBox[{\({x\_1, y\_1}\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \({x\_2, y\_2}\)}]]],
  ".  \nFor illustration purposes the variables ",
  StyleBox["pts",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ctr",
    FontWeight->"Bold"],
  " and ",
  StyleBox["lin",
    FontWeight->"Bold"],
  " are used to help form dots and control lines for the graph we will draw.  \
  \nThis is for pedagogical purposes, and usually they would not be \
necessary.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(BezierCurve[V_] := 
        Module[{Bez, x, 
            y}, \[IndentingNewLine]{x\_0, y\_0, x\_1, \ y\_1, \ x\_2, \ 
              y\_2, \ x\_3, \ y\_3} = 
            V; \ \[IndentingNewLine]Bez = {\[Sum]\+\(i = 0\)\%3 x\_i\ \
Binomial[3, 
                    i] \(t\^i\) \((1 - t)\)\^\(3 - i\), \[Sum]\+\(i = 0\)\%3 \
y\_i\ Binomial[3, 
                    i] \(t\^i\) \((1 - t)\)\^\(3 - i\)}; \ \ \
\[IndentingNewLine]pnt = {\ {x\_0, y\_0}, {x\_3, 
                y\_3}\ }; \ \[IndentingNewLine]ctr = {\ {x\_1, y\_1}, {x\_2, 
                y\_2}\ }; \ \[IndentingNewLine]lin = {{Green, 
                Line[\ {{x\_0, y\_0}, {x\_1, y\_1}}]}, {Green, 
                Line[\ {{x\_2, y\_2}, {x\_3, 
                      y\_3}}]}}; \ \[IndentingNewLine]Return[
            Bez];\ \ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find composite B\[EAcute]zier curve for the data given below. \n\n",
  Cell[BoxData[
      \(\(\(V\)\(=\)\({\ {\(-9\), 0, \(-8\), 1, \(-8\), 2.5, \(-4\), 
            2.5}, \[IndentingNewLine]\ \ \ \ \ \ {\(-4\), 2.5, \(-3\), 
            3.5, \(-1\), 4, 0, 4}, \[IndentingNewLine]\ \ \ \ \ \ {0, 4, 2, 
            4, 3, 4, 5, 2}, \ \[IndentingNewLine]\ \ \ \ \ \ {5, 2, 6, 2, 20, 
            3, 18, 0}\ }\)\(\ \ \)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "For each B\[EAcute]zier curve, the eight numbers ",
  Cell[BoxData[
      \({x\_0, y\_0, x\_1, \ y\_1, \ x\_2, \ y\_2, \ x\_3, \ y\_3}\)]],
  " are entered in a row vector, i.e.\nthe first one is ",
  Cell[BoxData[
      \({x\_0, y\_0, x\_1, \ y\_1, \ x\_2, \ y\_2, \ x\_3, \ y\_3} = {\(-9\), 
          0, \(-8\), 1, \(-8\), 2.5, \(-4\), 2.5}\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(V\)\(=\)\({{\(-9\), 0, \(-8\), 1, \(-8\), 2.5, \(-4\), 
          2.5}, {\(-4\), 2.5, \(-3\), 3.5, \(-1\), 4, 0, 4}, {0, 4, 2, 4, 3, 
          4, 5, 2}, {5, 2, 6, 2, 20, 3, 18, 0}}\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Construct the four B\[EAcute]zier pieces, i.e. sets of parametric \
equations, and store them in the table ",
  StyleBox["P",
    FontWeight->"Bold"],
  ".  \nPrint out the four B\[EAcute]zier pieces ",
  Cell[BoxData[
      RowBox[{\(P\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          
          "StrikeThrough"->
            False}], \(P\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          
          "StrikeThrough"->
            False}], \(P\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["  ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            
            "StrikeThrough"->
              False}], \(P\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)\)}]}]]]
}], "Text"],

Cell[BoxData[{
    \(\(P = Table[0, {Length[V]}];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(pnts\  = \ \(ctrs\  = \ \(lins\  = \ {}\)\);\)\ \ \ \), "\
\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[V], \(i++\), \
\[IndentingNewLine]P\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\
\) = BezierCurve[
            V\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]; \ \
\ \[IndentingNewLine]pnts\  = \ 
          Union[pnts, pnt]; \ \ \[IndentingNewLine]ctrs\  = \ 
          Union[ctrs, ctr]; \ \ \[IndentingNewLine]lins\  = \ 
          Union[lins, 
            lin]; \ \ \[IndentingNewLine]Print["\<P\>"\_i, "\<[t] =  \>", 
          P\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)];\ ];\
\)\ \ \)}], "Input"],

Cell[TextData[{
  "Graph all the curve, which is stored in the vector  ",
  Cell[BoxData[
      \(P\)]],
  "  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 1\)]],
  ".   \n",
  StyleBox["Notice.",
    FontWeight->"Bold"],
  "  The command  ",
  StyleBox["Evaluate[P]",
    FontWeight->"Bold"],
  "  must be used in order for the \"functions\" to be sent to the graphics \
subroutine. \nAn alternate command that will work is  ",
  StyleBox["Release[P]",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(cont = \ Graphics[lins];\)\ \ \), "\n", 
    \(\(dots\  = \ 
        ListPlot[pnts, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(hand\  = \ 
        ListPlot[ctrs, PlotStyle \[Rule] {Green, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ParametricPlot[\ Evaluate[P], {t, 0, 1}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[dots, hand, cont, gr2, PlotRange \[Rule] All, 
        Ticks \[Rule] {Range[\(-10\), 20, 5], Range[0, 4, 1]}, 
        AspectRatio \[Rule] 2\/5, \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[V], \(i++\), \[IndentingNewLine]\(Print["\<P\>"\_i, "\<[t] = \
 \>", P\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)];\)\ ];\)\
\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s B\[EAcute]zier curve fit procedure. \nThe following example is found in \
the  \"Help\"  menu under  Add-ons;  Standard Packages;  NumericalMath;  \
SplineFit.  \nFind the \"spline fit\" through  (0,0), (1,2), (-1,3), (0,1), \
(3,0).  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["This command loads the package.  ", "Text"],

Cell[BoxData[{
    \(\(Needs["\<NumericalMath`SplineFit`\>"];\)\ \ \), \
"\[IndentingNewLine]", 
    \(\(pts = {{0, 0}, {1, 2}, {\(-1\), 3}, {0, 1}, {3, 
            0}};\)\ \ \)}], "Input"],

Cell[TextData[{
  "This generates a cubic spline from ",
  StyleBox["pts",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(spline\)\(=\)\(SplineFit[pts, Cubic]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Four splines are required, so the parameterization is chosen to be the \
interval [0,4]. "
}], "Text"],

Cell["Here is a graph of the curve.", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(b1 = 
        ParametricPlot[\ spline[u], {u, 0, 4}, Compiled \[Rule] False, 
          PlotStyle \[Rule] Magenta, 
          PlotRange \[Rule] {{\(-1.2\), 3}, {0, 3.2}}, 
          Ticks \[Rule] {Range[\(-1\), 3, 1], Range[0, 3, 1]}, 
          DisplayFunction \[Rule] $DisplayFunction];\)\ \ \ \ \)}], "Input"],

Cell[TextData[{
  "Here is the internal form of the cubic spline function generated from ",
  StyleBox["pts",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(InputForm[spline]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Observe, that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " returns a list of four vectors, each of which contains two four element \
list, just right number of coefficients for forming eight cubic equations. "
}], "Text"],

Cell[BoxData[
    \(\(\({{{0, 111/56, 0, \(-55\)/56}, {0, 57/28, 
          0, \(-1\)/28}}, \[IndentingNewLine]{{1, \(-27\)/28, \(-165\)/56, 
          107/56}, {2, 
          27/14, \(-3\)/28, \(-23\)/28}}, \[IndentingNewLine]{{\(-1\), \(-9\)/
            8, 39/14, \(-37\)/56}, {3, \(-3\)/4, \(-18\)/7, 
          37/28}}, \[IndentingNewLine]{{0, 69/28, 
          45/56, \(-15\)/56}, {1, \(-27\)/14, 
          39/28, \(-13\)/28}}}\)\(\ \ \)\)\)], "Input"],

Cell["\<\
By luck, they are in \"standard form\" and we can use the coefficient \
vectors;  change some commas to  +  signs;  fill in the powers of  t  \
necessary to form the cubics. \
\>", "Text"],

Cell[BoxData[
    \(\(\(P\&\[RightVector][
        t_]\)\(=\)\({{\(111\ t\)\/56 - \(55\ t\^3\)\/56, \(57\ t\)\/28 - 
            t\^3\/28}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {1 - \
\(27\ t\)\/28 - \(165\ t\^2\)\/56 + \(107\ t\^3\)\/56, 
          2 + \(27\ t\)\/14 - \(3\ t\^2\)\/28 - \(23\ t\^3\)\/28}, \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {\(-1\) - \(9\ t\)\/8 + \(39\
\ t\^2\)\/14 - \(37\ t\^3\)\/56, 
          3 - \(3\ t\)\/4 - \(18\ t\^2\)\/7 + \(37\ t\^3\)\/28}, \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {\(69\ t\)\/28 + \(45\ \
t\^2\)\/56 - \(15\ t\^3\)\/56, 
          1 - \(27\ t\)\/14 + \(39\ t\^2\)\/28 - \(13\ t\^3\)\/28}}\)\(\ \ \)\
\)\)], "Input"],

Cell[BoxData[
    \(\(\(b2 = 
        ParametricPlot[Evaluate[P\&\[RightVector][t]], {t, 0, 1}, 
          PlotStyle \[Rule] Blue, 
          PlotRange \[Rule] {{\(-1.2\), 3}, {0, 3.2}}, 
          Ticks \[Rule] {Range[\(-1\), 3, 1], Range[0, 3, 1]}, 
          DisplayFunction \[Rule] $DisplayFunction];\)\(\ \ \)\)\)], "Input"],

Cell["Are the two constructions the same ?", "Text"],

Cell[BoxData[
    \(\(\(Show[b1, b2];\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  What is the nature of the  \"spline fit\"  constructed by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ?"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Let's look at  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(P\&\[RightVector]\),
            FontWeight->"Bold"], "[", "t", "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox[\(P\&\[RightVector]\),
                FontWeight->"Bold"], "'"}], "[", "t", "]"}], " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["  ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{
            RowBox[{
              StyleBox[\(P\&\[RightVector]\),
                FontWeight->"Bold"], "''"}], "[", "t", "]"}]}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(P\&\[RightVector][t]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(P\&\[RightVector]'\)[t]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(P\&\[RightVector]''\)[t]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Let's look at  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(P\&\[RightVector]\),
            FontWeight->"Bold"], "[", "0", "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          StyleBox[\(P\&\[RightVector]\),
            FontWeight->"Bold"], "[", "1", "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], "'"}], "[", "0", "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox[\(P\&\[RightVector]\),
              FontWeight->"Bold"], "'"}], "[", "1", "]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox[\(P\&\[RightVector]\),
                FontWeight->"Bold"], "''"}], "[", "0", "]"}], "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", 
          RowBox[{
            RowBox[{
              StyleBox[\(P\&\[RightVector]\),
                FontWeight->"Bold"], "''"}], "[", "1", "]"}]}]}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(P\&\[RightVector][0]\ \ \), "\n", 
    \(P\&\[RightVector][1]\ \ \)}], "Input"],

Cell[TextData[{
  "Observe that the second through fourth elements of  ",
  Cell[BoxData[
      \(\(P\& \[RightVector] \)[0]\)]],
  " agree with the first through third elements of  ",
  Cell[BoxData[
      \(\(P\& \[RightVector] \)[1]\)]],
  ".  \nHence the spline is a continuous curve.  "
}], "Text"],

Cell[BoxData[{
    \(\(P\&\[RightVector]'\)[0]\ \ \), "\n", 
    \(\(P\&\[RightVector]'\)[1]\ \ \)}], "Input"],

Cell[TextData[{
  "Observe that the second through fourth elements of  ",
  Cell[BoxData[
      \(\(\(P\& \[RightVector] \)'\)[0]\)]],
  " agree with the first through third elements of  ",
  Cell[BoxData[
      \(\(\(P\& \[RightVector] \)'\)[1]\)]],
  ".  \nHence the spline is a smooth curve.  "
}], "Text"],

Cell[BoxData[{
    \(\(P\&\[RightVector]''\)[0]\ \ \), "\n", 
    \(\(P\&\[RightVector]''\)[1]\ \ \)}], "Input"],

Cell[TextData[{
  "Observe that the second through fourth elements of  ",
  Cell[BoxData[
      \(\(\(P\& \[RightVector] \)''\)[0]\)]],
  " agree with the first through third elements of  ",
  Cell[BoxData[
      \(\(\(P\& \[RightVector] \)''\)[1]\)]],
  ".   \nHence the second derivatives agree at all of the interpolation \
knots.  Also, the second derivative is zero in both coordinates at both \
endpoints.   "
}], "Text"],

Cell[TextData[{
  "Thus, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is using a \"Natural B\[EAcute]zier curve\" which is a \"natural cubic \
spline\" in each coordinate. "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The B\[EAcute]zier Curve",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/BezierCurveBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The B\[EAcute]zier Curve",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BezierCurveBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 746},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 283, 10, 35, "Text"],
Cell[2062, 65, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3541, 117, 26763, 781, 284, "Text"],
Cell[30307, 900, 103, 2, 33, "Text"],
Cell[30413, 904, 579, 19, 139, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[31017, 927, 101, 2, 33, "Text"],
Cell[31121, 931, 112, 2, 33, "Text",
  Evaluatable->False],
Cell[31236, 935, 287, 5, 83, "Input"],
Cell[31526, 942, 146, 4, 33, "Text",
  Evaluatable->False],
Cell[31675, 948, 358, 6, 118, "Input"],
Cell[32036, 956, 214, 8, 33, "Text",
  Evaluatable->False],
Cell[32253, 966, 389, 6, 130, "Input"],
Cell[32645, 974, 477, 15, 52, "Text",
  Evaluatable->False],
Cell[33125, 991, 174, 3, 30, "Input"],
Cell[33302, 996, 213, 8, 33, "Text",
  Evaluatable->False],
Cell[33518, 1006, 1076, 21, 183, "Input"]
}, Closed]],
Cell[34609, 1030, 21945, 604, 303, "Text",
  Evaluatable->False],
Cell[56557, 1636, 103, 2, 33, "Text"],
Cell[56663, 1640, 409, 14, 107, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[57097, 1658, 101, 2, 33, "Text"],
Cell[57201, 1662, 112, 2, 33, "Text",
  Evaluatable->False],
Cell[57316, 1666, 177, 3, 50, "Input"],
Cell[57496, 1671, 196, 8, 33, "Text",
  Evaluatable->False],
Cell[57695, 1681, 111, 2, 30, "Input"],
Cell[57809, 1685, 138, 4, 33, "Text",
  Evaluatable->False],
Cell[57950, 1691, 421, 9, 90, "Input"],
Cell[58374, 1702, 214, 8, 33, "Text",
  Evaluatable->False],
Cell[58591, 1712, 389, 6, 130, "Input"],
Cell[58983, 1720, 477, 15, 52, "Text",
  Evaluatable->False],
Cell[59463, 1737, 174, 3, 30, "Input"],
Cell[59640, 1742, 210, 8, 33, "Text",
  Evaluatable->False],
Cell[59853, 1752, 1631, 32, 278, "Input"],
Cell[61487, 1786, 178, 5, 33, "Text"],
Cell[61668, 1793, 75, 1, 30, "Input"],
Cell[61746, 1796, 89, 1, 30, "Input"],
Cell[61838, 1799, 238, 4, 70, "Input"]
}, Closed]],
Cell[62091, 1806, 606, 14, 87, "Text"],
Cell[62700, 1822, 1396, 41, 128, "Text"],
Cell[64099, 1865, 25444, 747, 192, "Text"],
Cell[89546, 2614, 103, 2, 33, "Text"],
Cell[89652, 2618, 1145, 37, 109, "Text"],
Cell[90800, 2657, 634, 21, 33, "Text"],
Cell[91437, 2680, 556, 18, 52, "Text"],

Cell[CellGroupData[{
Cell[92018, 2702, 101, 2, 33, "Text"],
Cell[92122, 2706, 522, 9, 72, "Input"],
Cell[92647, 2717, 171, 8, 33, "Text"],
Cell[92821, 2727, 454, 7, 73, "Input"],
Cell[93278, 2736, 244, 8, 33, "Text"],
Cell[93525, 2746, 1207, 24, 209, "Input"]
}, Closed]],
Cell[94747, 2773, 329, 9, 68, "Text"],
Cell[95079, 2784, 462, 17, 52, "Text"],

Cell[CellGroupData[{
Cell[95566, 2805, 101, 2, 33, "Text"],
Cell[95670, 2809, 171, 8, 33, "Text"],
Cell[95844, 2819, 451, 7, 73, "Input"],
Cell[96298, 2828, 186, 8, 33, "Text"],
Cell[96487, 2838, 1190, 24, 209, "Input"]
}, Closed]],
Cell[97692, 2865, 323, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[98040, 2880, 101, 2, 33, "Text"],
Cell[98144, 2884, 561, 10, 109, "Input"]
}, Closed]],
Cell[98720, 2897, 1859, 61, 114, "Text"],

Cell[CellGroupData[{
Cell[100604, 2962, 102, 2, 33, "Text"],
Cell[100709, 2966, 429, 11, 83, "Input"],
Cell[101141, 2979, 685, 21, 33, "Text"],
Cell[101829, 3002, 678, 13, 170, "Input"],
Cell[102510, 3017, 619, 23, 109, "Text"],
Cell[103132, 3042, 261, 5, 30, "Input"],
Cell[103396, 3049, 174, 3, 30, "Input"],
Cell[103573, 3054, 210, 5, 30, "Input"],
Cell[103786, 3061, 5969, 169, 223, "Text"]
}, Closed]],
Cell[109770, 3233, 857, 28, 201, "Text"],
Cell[110630, 3263, 166, 3, 73, "Input"],
Cell[110799, 3268, 177, 3, 70, "Input"],
Cell[110979, 3273, 430, 18, 52, "Text"],
Cell[111412, 3293, 639, 10, 193, "Input"],
Cell[112054, 3305, 282, 8, 71, "Text"],
Cell[112339, 3315, 466, 12, 90, "Text"],
Cell[112808, 3329, 237, 4, 52, "Text"],
Cell[113048, 3335, 492, 17, 71, "Text"],

Cell[CellGroupData[{
Cell[113565, 3356, 101, 2, 33, "Text"],
Cell[113669, 3360, 174, 6, 33, "Text"],
Cell[113846, 3368, 358, 8, 73, "Input"],
Cell[114207, 3378, 172, 8, 33, "Text"],
Cell[114382, 3388, 451, 7, 73, "Input"],
Cell[114836, 3397, 186, 8, 33, "Text"],
Cell[115025, 3407, 1215, 24, 209, "Input"]
}, Closed]],
Cell[116255, 3434, 626, 21, 30, "Text"],
Cell[116884, 3457, 1258, 40, 71, "Text"],
Cell[118145, 3499, 902, 17, 197, "Input"],
Cell[119050, 3518, 540, 11, 124, "Text"],

Cell[CellGroupData[{
Cell[119615, 3533, 101, 2, 33, "Text"],
Cell[119719, 3537, 387, 9, 52, "Text"],
Cell[120109, 3548, 230, 3, 30, "Input"],
Cell[120342, 3553, 2274, 67, 52, "Text"],
Cell[122619, 3622, 785, 16, 170, "Input"],
Cell[123407, 3640, 514, 18, 71, "Text"],
Cell[123924, 3660, 1051, 21, 184, "Input"]
}, Closed]],
Cell[124990, 3684, 422, 11, 68, "Text"],

Cell[CellGroupData[{
Cell[125437, 3699, 101, 2, 33, "Text"],
Cell[125541, 3703, 49, 0, 33, "Text"],
Cell[125593, 3705, 190, 4, 50, "Input"],
Cell[125786, 3711, 119, 5, 33, "Text"],
Cell[125908, 3718, 85, 1, 30, "Input"],
Cell[125996, 3721, 202, 6, 33, "Text"],
Cell[126201, 3729, 45, 0, 33, "Text"],
Cell[126249, 3731, 405, 7, 70, "Input"],
Cell[126657, 3740, 154, 5, 33, "Text"],
Cell[126814, 3747, 66, 1, 30, "Input"],
Cell[126883, 3750, 254, 6, 33, "Text"],
Cell[127140, 3758, 459, 8, 90, "Input"],
Cell[127602, 3768, 198, 4, 33, "Text"],
Cell[127803, 3774, 701, 12, 156, "Input"],
Cell[128507, 3788, 329, 6, 53, "Input"],
Cell[128839, 3796, 52, 0, 33, "Text"],
Cell[128894, 3798, 62, 1, 30, "Input"]
}, Closed]],
Cell[128971, 3802, 236, 8, 30, "Text"],

Cell[CellGroupData[{
Cell[129232, 3814, 101, 2, 33, "Text"],
Cell[129336, 3818, 1357, 41, 33, "Text"],
Cell[130696, 3861, 69, 1, 31, "Input"],
Cell[130768, 3864, 74, 1, 31, "Input"],
Cell[130845, 3867, 75, 1, 31, "Input"],
Cell[130923, 3870, 3339, 100, 33, "Text"],
Cell[134265, 3972, 100, 2, 52, "Input"],
Cell[134368, 3976, 303, 8, 52, "Text"],
Cell[134674, 3986, 110, 2, 52, "Input"],
Cell[134787, 3990, 309, 8, 52, "Text"],
Cell[135099, 4000, 112, 2, 52, "Input"],
Cell[135214, 4004, 427, 10, 52, "Text"],
Cell[135644, 4016, 199, 6, 33, "Text"]
}, Closed]],
Cell[135858, 4025, 158, 3, 32, "Text"],
Cell[136019, 4030, 570, 16, 33, "Text"],
Cell[136592, 4048, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

