(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    275604,       7210]*)
(*NotebookOutlinePosition[    276349,       7236]*)
(*  CellTagsIndexPosition[    276305,       7232]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Aitken's and Neville's Interpolation \
Methods",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  StyleBox["Numerical Methods Using Mathematica \nComplementary Supplement \n\
for ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Numerical Analysis - Numerical Methods",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" \n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["(c) ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2005",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  TextAlignment->Center]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWe will now study the iterated interpolation methods of Aitken and \
Neville.  ",
  ButtonBox["Alexander Craig Aitken",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Aitken.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " (1895-1967) was one of  New Zealand's prominent mathematicians.  ",
  ButtonBox["Eric Harold Neville",
    ButtonData:>{
      URL[ "http://www.library.rdg.ac.uk/colls/special/collsindex.html#n"], 
      None},
    ButtonStyle->"Hyperlink"],
  " (1889-1961) was a mathematics professor at University of Reading, \
Berkshire, U.K.  The algorithms we seek are remarkably similar:\n\t\n\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(For\ \ i = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "k"}], "  "}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "     ", \(P\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\) = 
          f[X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\), 
        " ", "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(For\ \ i = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(k - 1\)}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(For\ \ j = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "i"}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{\(P\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
            j + 1\)\(\[RightDoubleBracket]\)\)\), "=", " ", 
        RowBox[{\(1\/\(X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\
\[RightDoubleBracket]\)\) - 
                X\_\(\(\[LeftDoubleBracket]\)\(i - j + 1\)\(\
\[RightDoubleBracket]\)\)\)\), "|", GridBox[{
              {\(P\_\(\(\[LeftDoubleBracket]\)\(i, 
                    j\)\(\[RightDoubleBracket]\)\)\), \(X\_\(\(\
\[LeftDoubleBracket]\)\(i - j + 1\)\(\[RightDoubleBracket]\)\) - z\)},
              {\(P\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
                    j\)\(\[RightDoubleBracket]\)\)\), \(X\_\(\(\
\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\) - z\)}
              }], "|"}]}]}]],
  "\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(For\ \ i = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "k"}], " "}], "\[IndentingNewLine]", 
      RowBox[{
        "     ", \(Q\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\) = 
          f[X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        RowBox[{\(For\ \ i = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{
            StyleBox["k",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "-", "1"}]}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(For\ \ j = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "i"}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{\(Q\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
            j + 1\)\(\[RightDoubleBracket]\)\)\), "=", " ", 
        RowBox[{\(1\/\(X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\
\[RightDoubleBracket]\)\) - 
                X\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\)\
\)\), "|", GridBox[{
              {\(Q\_\(\(\[LeftDoubleBracket]\)\(j, 
                    j\)\(\[RightDoubleBracket]\)\)\), \(X\_\(\(\
\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) - z\)},
              {\(Q\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
                    j\)\(\[RightDoubleBracket]\)\)\), \(X\_\(\(\
\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\) - z\)}
              }], "|"}]}]}]],
  "  \n\t\n\tTo assist with understanding these algorithms we must study \
iterated polynomial interpolation.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Existence and Uniqueness",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["Theorem (Polynomial Existence and Uniqueness).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given a set  ",
  StyleBox["n+1",
    FontFamily->"Courier New"],
  "  of distinct nodes  ",
  Cell[BoxData[
      \({x\_i}\_\(i = 0\)\%n\)]],
  "   (where ",
  Cell[BoxData[
      \(x\_i \[NotEqual] x\_j\)]],
  " whenever ",
  Cell[BoxData[
      \(i \[NotEqual] j\)]],
  ").  There is a unique polynomial of degree ",
  Cell[BoxData[
      \(n\)]],
  "   \n\n\t\t",
  Cell[BoxData[
      \(\(P\_n\) \((x)\)\  = \ \[Sum]\+\(i = 0\)\%n\(\( 
                a\_i\) \(x\^i\)\(\ \ \)\)\)]],
  "\n\t\t\nthat passes through the  ",
  StyleBox["n+1",
    FontFamily->"Courier New"],
  "  points  ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          RowBox[{"(", 
            RowBox[{\(x\_i\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y\_i\)}], ")"}], "}"}], \(i = 0\),
         "n"]]],
  ",  i.e.   \n\n\t\t",
  Cell[BoxData[
      \(\(P\_n\) \((x\_i)\)\ \  = \ \ y\_i\)]],
  "    for    ",
  Cell[BoxData[
      RowBox[{\(i = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Aitken and Neville Methods",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Iterated Interpolation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWe now discuss some heuristic methods of constructing interpolation \
polynomials recursively.  The methods of ",
  ButtonBox["Aitken",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/AitkenInterpolation.html"], None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["Neville",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NevillesAlgorithm.html"], None},
    ButtonStyle->"Hyperlink"],
  " are examples of how iteration is used to construct a sequence of \
polynomial approximating of increasing order. "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Selected Interpolation).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given the function  ",
  Cell[BoxData[
      \(y\  = \ f[x]\)]],
  "  that is to be approximated, and the set of nodes:  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\({x\_i}\_\(i = 0\)\%n\), " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_2\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_i\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_\(n - 1\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_n\)}], "}"}]}]]],
  ". \n\nFor any subset of  ",
  StyleBox["k",
    FontFamily->"Courier New"],
  "  nodes \n\n\t\t",
  Cell[BoxData[
      RowBox[{\({x\_\(i\_j\)}\_\(j = 1\)\%k\), " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{\(x\_\(i\_1\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_\(i\_2\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_\(i\_3\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_\(i\_\(k - 1\)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_\(i\_k\)\)}], "}"}]}]]],
  "  \n\nthe polynomial that agrees with  ",
  StyleBox["f[x]",
    FontFamily->"Courier New"],
  "  at the points ",
  Cell[BoxData[
      \({x\_\(i\_j\)}\_\(j = 1\)\%k\)]],
  " is denoted  \n\n\t\t",
  Cell[BoxData[
      \(P\_\(i\_1, i\_2,  ... , i\_k\)[x]\)]],
  ".\n\nThe polynomial  ",
  Cell[BoxData[
      \(P\_\(i\_1, i\_2,  ... , i\_k\)[x]\)]],
  "  of degree  ",
  StyleBox["k-1",
    FontFamily->"Courier New"],
  "  agrees with  ",
  StyleBox["f[x]",
    FontFamily->"Courier New"],
  "  at these knots ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", " ", 
          RowBox[{"(", 
            RowBox[{\(x\_\(i\_j\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(f[x\_\(i\_j\)]\)}], ")"}], " ", 
          "}"}], \(j = 1\), "k"]]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(P\_\(i\_1, i\_2,  ... , i\_k\)[x\_\(i\_j\)]\ \  = \ \ f[
          x\_\(i\_j\)]\)]],
  "    for    ",
  Cell[BoxData[
      RowBox[{\(j = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "k"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Exploration",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Aitken and Neville Methods",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Scroll down to this exploration. "
}], "Text"],

Cell[TextData[{
  StyleBox["Successive Interpolation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tConsider polynomial interpolation based on equally spaced nodes \n\t\
\n\t\t",
  Cell[BoxData[
      RowBox[{\({x\_i = x\_i + i*h}\_\(i = 0\)\%n\), " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_0 + h\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_0 + 2  h\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_0 + i*h\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_0 + \((n - 1)\) h\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_0 + n*h\)}], "}"}]}]]],
  "  \n\nIf all  ",
  Cell[BoxData[
      \(n + 1\)]],
  "  nodes are used then a loose claim is that the interpolating polynomial  \
",
  Cell[BoxData[
      \(P\_\(0, 1,  ... , n - 1, n\)[x]\)]],
  "  will have order of approximation  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold"], \((h\^\(n + 1\))\)}]]],
  ".  Usually there is an abundance of nodes (think 50, 100,...) and the \
degree of the interpolating polynomial is small (think 2, 3, 4, 5 or 6).  \
Polynomials of smaller degree  ",
  Cell[BoxData[
      \(k < n\)]],
  "  are of practical value:  \n\n\t\t",
  Cell[BoxData[GridBox[{
          {
            
            StyleBox[\(k = \(\(2\)\(:\)\(\ \ \)\(Linear\)\(\ \ \ \ \ \ \)\)\),
              
              FontWeight->"Bold",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[
              RowBox[{
                StyleBox[\(P\_\(i\_1, i\_2\)[x]\),
                  FontWeight->"Bold"], "               "}],
              FontWeight->"Bold"]},
          {
            StyleBox[\(k = 3 : \ \ Quadratic\),
              FontWeight->"Bold",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[
              RowBox[{
                StyleBox[\(P\_\(i\_1, i\_2, i\_3\)[x]\),
                  FontWeight->"Bold"], "          "}],
              FontWeight->"Bold"]},
          {
            
            StyleBox[\(k = \(\(4\)\(:\)\(\ \ \)\(Cubic\)\(\ \ \ \ \ \ \ \ \ \
\)\)\),
              FontWeight->"Bold",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[\(\(P\_\(i\_1, i\_2, i\_3, i\_4\)[x]\)\(\ \ \ \ \ \)\),
              FontWeight->"Bold"]},
          {
            StyleBox[\(k = \(\(5\)\(:\)\(\ \ \)\(Quartic\)\(\ \ \ \ \)\)\),
              FontWeight->"Bold",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[\(\(P\_\(i\_1, i\_2, i\_3, i\_4\)[x]\)\(\ \ \ \ \ \)\),
              FontWeight->"Bold"]},
          {
            StyleBox[\(k = \(\(6\)\(:\)\(\ \ \)\(Quintic\)\(\ \ \ \ \)\)\),
              FontWeight->"Bold",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[\(P\_\(i\_1, i\_2, i\_3, i\_4, i\_5\)[x]\),
              FontWeight->"Bold"]}
          }]]],
  "  "
}], "Text"],

Cell["\<\
\tThe accuracy of interpolation increases with the degree of the polynomial.  \
Since the polynomial constructions are unique the following theorem applies \
for the Lagrange Polynomial, Newton polynomial and the polynomials \
constructed with both Aitken's method and Neville's method too. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem (Remainder Term).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      RowBox[{"f", "\[Element]", 
        RowBox[{
          StyleBox[\(C\^\(n + 1\)\),
            FontWeight->"Bold"], "[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  " and  ",
  Cell[BoxData[
      RowBox[{\(x\_k\), "\[Element]", 
        RowBox[{"[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[\(\(...\)\(.\)\),
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  "  are distinct  values.  Then   ",
  Cell[BoxData[
      \(f \((x)\) = \(P\_n\) \((x)\) + \(R\_n\) \((x)\)\)]],
  ",  where ",
  Cell[BoxData[
      \(\(P\_n\) \((x)\)\)]],
  " is a polynomial that can be used to approximate  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  ",  for example, the Lagrange polynomial   ",
  Cell[BoxData[
      RowBox[{\(\(P\_n\) \((x)\)\), "=", 
        RowBox[{
          StyleBox[
            UnderoverscriptBox["\[Sum]", 
              StyleBox[\(k = 0\),
                FontSize->10], 
              StyleBox["n",
                FontSize->10]],
            
            FontSize->
              14], \(y\_k\ \(\(\(\((x\  - \ x\_0)\)\  ... \) \((x\  - \ \
x\_\(k - 1\))\)\ \((x\  - \ x\_\(k + 1\))\)\  ... \)\ \((x\  - \ \
x\_n)\)\)\/\(\(\(\((x\_k - x\_0)\)\  ... \) \((x\_k - x\_\(k - 1\))\)\ \
\((x\_k - x\_\(k + 1\))\)\  ... \)\ \((x\_k - x\_n)\)\)\)}]}]]],
  ",  and we write  \n\n\t",
  Cell[BoxData[
      \(f \((x)\) \[TildeTilde] \(P\_n\) \((x)\)\)]],
  ".\n\nThe Lagrange polynomial goes through the ",
  Cell[BoxData[
      \(n + 1\)]],
  " points  ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          RowBox[{"(", 
            RowBox[{\(x\_k\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y\_k\)}], ")"}], "}"}], \(k = 0\),
         "n"]]],
  ",  i.e.\n\n\t",
  Cell[BoxData[
      \(\(P\_n\) \((x\_k)\)\  = \ f \((x\_k)\)\)]],
  "    for   ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[\(\(...\)\(.\)\),
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "n"}]]],
  ".  \n\nThe remainder term  ",
  Cell[BoxData[
      \(\(R\_n\) \((x)\)\)]],
  " has the form\n\n\t",
  Cell[BoxData[
      RowBox[{\(\(R\_n\) \((x)\)\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((n + 1)\),
                      Derivative],
                    
                    MultilineFunction->None], \((c)\)}], \(\((n + 
                      1)\)!\)], \((x - x\_0)\), " ", \((x - x\_1)\), 
              " ", \((x - x\_2)\)}], " ", 
            "..."}], \((x - x\_\(n - 1\))\), \((x - x\_n)\)}]}]]],
  ",  for some value ",
  Cell[BoxData[
      \(c = c \((x)\)\)]],
  " that lies in the interval ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["See",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Lagrange Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LagrangePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["The Main Results",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIn practice the subset of  ",
  Cell[BoxData[
      \(k\)]],
  "  nodes ",
  Cell[BoxData[
      \({x\_\(i\_j\)}\_\(j = 1\)\%k\)]],
  " is not chosen at random over the larger set ",
  Cell[BoxData[
      \({x\_i}\_\(i = 0\)\%n\)]],
  ".  Instead, the nodes are clustered near a specific value of  ",
  StyleBox["x",
    FontFamily->"Courier New"],
  "  at which the function   ",
  StyleBox["f[x]",
    FontFamily->"Courier New"],
  "  is to be approximated by  ",
  Cell[BoxData[
      \(P\_\(i\_1, i\_2,  ... , i\_k\)[x]\)]],
  ".  Often times it is a sequential subset of nodes  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(x\_j\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(j + 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(j + k\)\)}], "}"}]]],
  " with  ",
  Cell[BoxData[
      \(x\_j < x < x\_\(j + k\)\)]],
  ".   It is desired to have the ability to use permutations of the list ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(x\_j\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(j + 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(j + k\)\)}], "}"}]]],
  " when constructing the interpolating polynomial.  It is also useful to use \
a sequence of polynomial approximations with increasing degree.  The \
following theorem gives the recursive step for generating such a sequence.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Recursive Polynomial Construction).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given the function  ",
  Cell[BoxData[
      \(y\  = \ f[x]\)]],
  "  that is to be approximated, and the set of ",
  Cell[BoxData[
      \(k + 1\)]],
  " distinct nodes  \n\n\t",
  Cell[BoxData[
      RowBox[{"S", "=", " ", 
        RowBox[{"{", 
          RowBox[{\(x\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_2\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_i\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_j\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_\(k - 1\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\_k\)}], "}"}]}]]],
  ".  \n\nFor any pair of nodes  ",
  Cell[BoxData[
      \(x\_i, x\_j\  \[Element] \ S\)]],
  ",  suppose that we have constructed the polynomials: \n\n\t",
  Cell[BoxData[
      \(P\_\(0, 1,  ... , i - 1, i + 1,  ... , k\)[x]\)]],
  "  which agrees with ",
  Cell[BoxData[
      \(f[x]\)]],
  " at the nodes  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(i - 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(i + 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(k - 1\)\), ",", \(x\_k\)}], 
        "}"}]]],
  ",  \n\n\t",
  Cell[BoxData[
      \(P\_\(0, 1,  ... , j - 1, j + 1,  ... , k\)[x]\)]],
  "  which agrees with ",
  Cell[BoxData[
      \(f[x]\)]],
  " at the nodes  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(j - 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(j + 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(k - 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_k\)}], "}"}]]],
  ".  \n\nThen   ",
  Cell[BoxData[
      \(P\_\(0, 1,  ... , i,  ... , j,  ... , k\)[x]\)]],
  "   is formed by making a combination of the above two polynomials \n\n\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{\(P\_\(0, 1,  ... , i,  ... , j,  ... , k\)[x]\), "  ", "=", 
          "  ", 
          RowBox[{\(1\/\(x\_i - x\_j\)\), "|", GridBox[{
                {\(P\_\(0, 1,  ... , i - 1, i + 1,  ... , k\)[x]\), \(x\_j - 
                    x\)},
                {\(P\_\(0, 1,  ... , j - 1, j + 1,  ... , k\)[x]\), \(x\_i - 
                    x\)}
                }], "|"}]}],
        FontWeight->"Bold"]]],
  ", \n\tor\n\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(0, 1,  ... , i,  ... , j,  ... , k\)[x]\),
          FontWeight->"Bold"], 
        StyleBox["  ",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontWeight->"Bold"], 
        StyleBox["  ",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox[\(1\/\(x\_j - x\_i\)\),
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Bold"], 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["(",
                    FontWeight->"Bold"], 
                  RowBox[{"x", 
                    StyleBox["-",
                      FontWeight->"Bold"], 
                    StyleBox[\(x\_i\),
                      FontWeight->"Bold"]}], 
                  StyleBox[")",
                    FontWeight->"Bold"]}], 
                StyleBox[\(P\_\(0, 1,  ... , i - 1, i + 1,  ... , k\)[x]\),
                  FontWeight->"Bold"]}], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["-",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              RowBox[{
                RowBox[{
                  StyleBox["(",
                    FontWeight->"Bold"], 
                  RowBox[{"x", 
                    StyleBox["-",
                      FontWeight->"Bold"], 
                    StyleBox[\(x\_j\),
                      FontWeight->"Bold"]}], 
                  StyleBox[")",
                    FontWeight->"Bold"]}], 
                StyleBox[" ",
                  FontWeight->"Bold"], 
                StyleBox[\(P\_\(0, 1,  ... , j - 1, j + 1,  ... , k\)[x]\),
                  FontWeight->"Bold"]}]}], 
            StyleBox[")",
              FontWeight->"Bold"]}]}]}]]],
  ", \n\nand it agrees with ",
  Cell[BoxData[
      \(f[x]\)]],
  " at all the nodes  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_i\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_j\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(k - 1\)\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_k\)}], "}"}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " Other equivalent ways to write  ",
  Cell[BoxData[
      \(P\_\(0, 1,  ... , i,  ... , j,  ... , k\)[x]\)]],
  " are \n\n\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{\(P\_\(0, 1,  ... , i,  ... , j,  ... , k\)[x]\), "  ", "=", 
          "  ", 
          RowBox[{\(1\/\(x\_i - x\_j\)\), "|", GridBox[{
                {\(x - x\_j\), \(P\_\(0, 1,  ... , i - 1, i + 1,  ... , k\)[
                    x]\)},
                {\(x - x\_i\), \(P\_\(0, 1,  ... , j - 1, j + 1,  ... , k\)[
                    x]\)}
                }], "|"}]}],
        FontWeight->"Bold"]]],
  ", \n\tor\n\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{\(P\_\(0, 1,  ... , i,  ... , j,  ... , k\)[x]\), "  ", "=", 
          "  ", 
          RowBox[{
            RowBox[{
              FractionBox[
                RowBox[{"x", 
                  StyleBox["-",
                    FontWeight->"Bold"], 
                  StyleBox[\(x\_i\),
                    FontWeight->"Bold"]}], \(x\_j - 
                  x\_i\)], \(P\_\(0, 1,  ... , i - 1, i + 1,  ... , k\)[
                x]\)}], " ", "+", " ", 
            RowBox[{
              FractionBox[
                RowBox[{"x", 
                  StyleBox["-",
                    FontWeight->"Bold"], 
                  StyleBox[\(x\_j\),
                    FontWeight->"Bold"]}], \(x\_i - x\_j\)], 
              " ", \(P\_\(0, 1,  ... , j - 1, j + 1,  ... , k\)[x]\)}]}]}],
        FontWeight->"Bold"]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Aitken and Neville Methods",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Scroll down to this theorem.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given the three distinct nodes  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(x\_0 = 0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_1 = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_2 = 2\)}], "}"}]]],
  "  and the function  ",
  Cell[BoxData[
      \(f[x] = \ \[ExponentialE]\^x\)]],
  ".  \nUse recursion to construct the polynomial  ",
  Cell[BoxData[
      \(P\_\(0, 1, 2\)[x]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  There are three ways to construct  ",
  Cell[BoxData[
      \(P\_\(0, 1, 2\)[x]\)]],
  "  and we will explore all three of them.  To prevent confusion, the latter \
two will be named ",
  Cell[BoxData[
      \(Q\_\(0, 1, 2\)[x]\)]],
  "  and  ",
  Cell[BoxData[
      \(R\_\(0, 1, 2\)[x]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \ \[ExponentialE]\^x;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotStyle \[Rule] Magenta, 
        PlotRange \[Rule] {{0, 2}, {0, 7.4}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], 
            Range[0, 7, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      \(P\_i[t]\  = \ \(f[x\_i] = i\)\)]],
  "  "
}], "Text"],

Cell[BoxData[{
    \(P = \(t = \(x = 0\)\); \ Remove[P, t, x]; \ 
    Clear[i];\ \), "\[IndentingNewLine]", 
    \(\(x\_i_ = i;\)\), "\[IndentingNewLine]", 
    \(\(P\_i_[t_] := f[x\_i];\)\)}], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      \(P\_\(0, 1\)[t]\)]],
  "  using  ",
  Cell[BoxData[
      \(P\_0[t]\)]],
  " and ",
  Cell[BoxData[
      \(P\_1[t]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(P\_\(0, 1\)[t_]\), ":=", 
          RowBox[{\(1\/\(x\_1 - x\_0\)\), 
            RowBox[{"Det", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_0[t]\), \(x\_0 - t\)},
                    {\(P\_1[t]\), \(x\_1 - t\)}
                    }], ")"}], "]"}]}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Needs["\<Graphics`Colors`\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(dots = 
          ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}}, 
            PlotStyle \[Rule] {Red, PointSize[0.02]}, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(gr1\  = \ 
          Plot[{f[x], P\_\(0, 1\)[x]}, {x, 0, 2}, 
            PlotRange \[Rule] {{0, 2}, {0, 7.6}}, 
            PlotStyle \[Rule] {Magenta, Cyan}, 
            Ticks \[Rule] {Range[0, 2, 0.5], {1, 2, \[ExponentialE], 4, 5, 
                  6, {\[ExponentialE]\^2, "\<\[ExponentialE]^2\>"}}}, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", \(Show[gr1, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<  f[x] = \>", f[x]];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(0, 1\)\)[x] = \>\"", 
          Simplify[P\_\(0, 1\)[x]]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(0, 1\)\)[\>\"", x\_0, "\<] = \>", 
          Simplify[P\_\(0, 1\)[x\_0]]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(0, 1\)\)[\>\"", x\_1, "\<] = \>", 
          Simplify[P\_\(0, 1\)[x\_1]]\ ];\), " "}]}], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      \(P\_\(0, 2\)[t]\)]],
  "  using  ",
  Cell[BoxData[
      \(P\_0[t]\)]],
  " and ",
  Cell[BoxData[
      \(P\_2[t]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(P\_\(0, 2\)[t_]\), ":=", 
          RowBox[{\(1\/\(x\_2 - x\_0\)\), 
            RowBox[{"Det", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_0[t]\), \(x\_0 - t\)},
                    {\(P\_2[t]\), \(x\_2 - t\)}
                    }], ")"}], "]"}]}]}], ";"}], " "}], "\[IndentingNewLine]",
   
    RowBox[{\(dots = 
          ListPlot[{{x\_0, f[x\_0]}, {x\_2, f[x\_2]}}, 
            PlotStyle \[Rule] {Red, PointSize[0.02]}, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", \(gr2 = 
        Plot[{f[x], P\_\(0, 2\)[x]}, {x, 0, 2}, 
          PlotRange \[Rule] {{0, 2}, {0, 7.6}}, 
          PlotStyle \[Rule] {Magenta, Brown}, 
          Ticks \[Rule] {Range[0, 2, 0.5], {1, 2, \[ExponentialE], 4, 5, 
                6, {\[ExponentialE]\^2, "\<\[ExponentialE]^2\>"}}}, 
          DisplayFunction \[Rule] Identity];\), "\[IndentingNewLine]", \(Show[
        gr2, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<  f[x] = \>", f[x]];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(0, 2\)\)[x] = \>\"", 
          Simplify[P\_\(0, 2\)[x]]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(0, 2\)\)[\>\"", x\_0, "\<] = \>", 
          Simplify[P\_\(0, 2\)[x\_0]]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(0, 2\)\)[\>\"", x\_2, "\<] = \>", 
          Simplify[P\_\(0, 2\)[x\_2]]\ ];\), " "}]}], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      \(P\_\(1, 2\)[t]\)]],
  "  using  ",
  Cell[BoxData[
      \(P\_1[t]\)]],
  " and ",
  Cell[BoxData[
      \(P\_2[t]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(P\_\(1, 2\)[t_]\), ":=", 
          RowBox[{\(1\/\(x\_2 - x\_1\)\), 
            RowBox[{"Det", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_1[t]\), \(x\_1 - t\)},
                    {\(P\_2[t]\), \(x\_2 - t\)}
                    }], ")"}], "]"}]}]}], ";"}], " "}], "\[IndentingNewLine]",
   
    RowBox[{\(dots = 
          ListPlot[{{x\_1, f[x\_1]}, {x\_2, f[x\_2]}}, 
            PlotStyle \[Rule] {Red, PointSize[0.02]}, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", \(gr3\  = \ 
        Plot[{f[x], P\_\(1, 2\)[x]}, {x, 0, 2}, 
          PlotRange \[Rule] {{0, 2}, {0, 7.6}}, 
          PlotStyle \[Rule] {Magenta, Green}, 
          Ticks \[Rule] {Range[0, 2, 0.5], {1, 2, \[ExponentialE], 4, 5, 
                6, {\[ExponentialE]\^2, "\<\[ExponentialE]^2\>"}}}, 
          DisplayFunction \[Rule] Identity];\), "\[IndentingNewLine]", \(Show[
        gr3, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<  f[x] = \>", f[x]];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(1, 2\)\)[x] = \>\"", 
          Simplify[P\_\(1, 2\)[x]]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(1, 2\)\)[\>\"", x\_1, "\<] = \>", 
          Simplify[P\_\(1, 2\)[x\_1]]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(1, 2\)\)[\>\"", x\_2, "\<] = \>", 
          Simplify[P\_\(1, 2\)[x\_2]]\ ];\), " "}]}], "Input"],

Cell[TextData[{
  StyleBox["1 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Define  ",
  Cell[BoxData[
      \(P\_\(0, 1, 2\)[t]\)]],
  "  using  ",
  Cell[BoxData[
      \(P\_\(0, 1\)[t]\)]],
  "  and  ",
  Cell[BoxData[
      \(P\_\(1, 2\)[t]\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(P\_\(0, 1, 2\)[t_]\), ":=", 
          RowBox[{\(1\/\(x\_2 - x\_0\)\), 
            RowBox[{"Det", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_\(0, 1\)[t]\), \(x\_0 - t\)},
                    {\(P\_\(1, 2\)[t]\), \(x\_2 - t\)}
                    }], ")"}], "]"}]}]}], ";"}], " "}], "\[IndentingNewLine]",
   
    RowBox[{\(dots = 
          ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}}, 
            PlotStyle \[Rule] {Red, PointSize[0.02]}, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", \(gr4\  = \ 
        Plot[{f[x], P\_\(0, 1, 2\)[x], P\_\(0, 1\)[x], P\_\(1, 2\)[x]}, {x, 
            0, 2}, PlotRange \[Rule] {{0, 2}, {0, 7.6}}, 
          PlotStyle \[Rule] {Magenta, Red, Cyan, Green}, 
          Ticks \[Rule] {Range[0, 2, 0.5], {1, 2, \[ExponentialE], 4, 5, 
                6, {\[ExponentialE]\^2, "\<\[ExponentialE]^2\>"}}}, 
          DisplayFunction \[Rule] Identity];\), "\[IndentingNewLine]", \(Show[
        gr4, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<   f[x] = \>", f[x]];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(Print[\*"\"\< \!\(P\_\(0, 1\)\)[x] = \>\"", 
          P\_\(0, 1\)[x]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\< \!\(P\_\(1, 2\)\)[x] = \>\"", 
          P\_\(1, 2\)[x]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(P\_\(0, 1, 2\)\)[x] = \>\"", 
          P\_\(0, 1, 2\)[x]\ ];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Where\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(P\_\(0, 1, 2\)\)[x] = \!\(1\/\(\(\\\ \)\(x\_2 - x\_0\)\)\) \
Det[(\!\(\*GridBox[{
{\(P\_\(0, 1\)[x]\), \(x\_0 - x\)},
{\(P\_\(1, 2\)[x]\), \(x\_2 - x\)}
}]\))] = \>\"", ",", \(1\/\(x\_2 - x\_0\)\), ",", "\"\< Det[\>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_\(0, 1\)[x]\), \(x\_0 - x\)},
                    {\(P\_\(1, 2\)[x]\), \(x\_2 - x\)}
                    }], ")"}], "]"}], ",", "\"\<]\>\""}], "]"}], ";"}], 
      " "}]}], "Input"],

Cell[TextData[{
  StyleBox["1 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Define  ",
  Cell[BoxData[
      \(Q\_\(0, 1, 2\)[t]\)]],
  "  using  ",
  Cell[BoxData[
      \(P\_\(0, 1\)[t]\)]],
  "  and  ",
  Cell[BoxData[
      \(P\_\(0, 2\)[t]\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(Q\_\(0, 1, 2\)[t_]\), ":=", 
          RowBox[{\(1\/\(x\_2 - x\_1\)\), 
            RowBox[{"Det", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_\(0, 1\)[t]\), \(x\_1 - t\)},
                    {\(P\_\(0, 2\)[t]\), \(x\_2 - t\)}
                    }], ")"}], "]"}]}]}], ";"}], " "}], "\[IndentingNewLine]",
   
    RowBox[{\(dots = 
          ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}}, 
            PlotStyle \[Rule] {Red, PointSize[0.02]}, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", \(gr5\  = \ 
        Plot[{f[x], Q\_\(0, 1, 2\)[x], P\_\(0, 1\)[x], P\_\(0, 2\)[x]}, {x, 
            0, 2}, PlotRange \[Rule] {{0, 2}, {0, 7.6}}, 
          PlotStyle \[Rule] {Magenta, Red, Cyan, Brown}, 
          Ticks \[Rule] {Range[0, 2, 0.5], {1, 2, \[ExponentialE], 4, 5, 
                6, {\[ExponentialE]\^2, "\<\[ExponentialE]^2\>"}}}, 
          DisplayFunction \[Rule] Identity];\), "\[IndentingNewLine]", \(Show[
        gr5, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<   f[x] = \>", f[x]];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(Print[\*"\"\< \!\(P\_\(0, 1\)\)[x] = \>\"", 
          P\_\(0, 1\)[x]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\< \!\(P\_\(0, 2\)\)[x] = \>\"", 
          P\_\(0, 2\)[x]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(Q\_\(0, 1, 2\)\)[x] = \>\"", 
          Q\_\(0, 1, 2\)[x]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Where\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(Q\_\(0, 1, 2\)\)[x] = \!\(1\/\(x\_2 - x\_1\)\) \
Det[(\!\(\*GridBox[{
{\(P\_\(0, 1\)[x]\), \(x\_1 - x\)},
{\(P\_\(0, 2\)[x]\), \(x\_2 - x\)}
}]\))] = \>\"", ",", \(1\/\(x\_2 - x\_1\)\), ",", "\"\< Det[\>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_\(0, 1\)[x]\), \(x\_1 - x\)},
                    {\(P\_\(0, 2\)[x]\), \(x\_2 - x\)}
                    }], ")"}], "]"}], ",", "\"\<]\>\""}], "]"}], ";"}], 
      " "}]}], "Input"],

Cell[TextData[{
  StyleBox["1 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Define  ",
  Cell[BoxData[
      \(R\_\(0, 1, 2\)[t]\)]],
  "  using  ",
  Cell[BoxData[
      \(P\_\(0, 2\)[t]\)]],
  "  and  ",
  Cell[BoxData[
      \(P\_\(1, 2\)[t]\)]],
  ".   "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(R\_\(0, 1, 2\)[t_]\), ":=", 
          RowBox[{\(1\/\(x\_1 - x\_0\)\), 
            RowBox[{"Det", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_\(0, 2\)[t]\), \(x\_0 - t\)},
                    {\(P\_\(1, 2\)[t]\), \(x\_1 - t\)}
                    }], ")"}], "]"}]}]}], ";"}], " "}], "\[IndentingNewLine]",
   
    RowBox[{\(dots = 
          ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}}, 
            PlotStyle \[Rule] {Red, PointSize[0.02]}, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", \(gr6\  = \ 
        Plot[{f[x], R\_\(0, 1, 2\)[x], P\_\(0, 2\)[x], P\_\(1, 2\)[x]}, {x, 
            0, 2}, PlotRange \[Rule] {{0, 2}, {0, 7.6}}, 
          PlotStyle \[Rule] {Magenta, Red, Brown, Green}, 
          Ticks \[Rule] {Range[0, 2, 0.5], {1, 2, \[ExponentialE], 4, 5, 
                6, {\[ExponentialE]\^2, "\<\[ExponentialE]^2\>"}}}, 
          DisplayFunction \[Rule] Identity];\), "\[IndentingNewLine]", \(Show[
        gr6, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<   f[x] = \>", f[x]];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(Print[\*"\"\< \!\(P\_\(0, 1\)\)[x] = \>\"", 
          P\_\(0, 2\)[x]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\< \!\(P\_\(0, 2\)\)[x] = \>\"", 
          P\_\(1, 2\)[x]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(R\_\(0, 1, 2\)\)[x] = \>\"", 
          R\_\(0, 1, 2\)[x]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Where\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(R\_\(0, 1, 2\)\)[x] = \!\(1\/\(x\_1 - x\_0\)\) \
Det[(\!\(\*GridBox[{
{\(P\_\(0, 2\)[x]\), \(x\_0 - x\)},
{\(P\_\(1, 2\)[x]\), \(x\_1 - x\)}
}]\))] = \>\"", ",", "\"\< Det[\>\"", ",", 
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {\(P\_\(0, 2\)[x]\), \(x\_0 - x\)},
                    {\(P\_\(1, 2\)[x]\), \(x\_1 - x\)}
                    }], ")"}], "]"}], ",", "\"\<]\>\""}], "]"}], ";"}], 
      " "}]}], "Input"],

Cell[TextData[{
  StyleBox["Conclusion.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nThe three different methods of constructing  ",
  Cell[BoxData[
      \(P\_\(0, 1, 2\)[x]\)]],
  " produce algebraically equivalent answers.  Only the first two methods are \
used in practice.  They are the methods of Aitken and Neville, respectively."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2\)\)[x] = \>\"", 
        P\_\(0, 1, 2\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2\)\)[x] = \>\"", 
        Q\_\(0, 1, 2\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(R\_\(0, 1, 2\)\)[x] = \>\"", 
        R\_\(0, 1, 2\)[x]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[P\_\(0, 1, 2\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1, 2\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(R\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[R\_\(0, 1, 2\)[x]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Interpolation Tableau",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe methods of Aitken and Neville use recursive polynomial \
construction.  The following tables indicate how the two constructions are \
made.  The extra column at the right (the values ",
  Cell[BoxData[
      \(x\_i - x\)]],
  ")  have been included to assist with performing hand calculations.  This \
extra column is not necessary for hand computations.  It will be revealed \
that the diagonals are equivalent.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Neville's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NevillesAlgorithm.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  In each new elements is computed using the element in the {same row, \
preceding column} and {preceding row, preceding column}. \n\n\t",
  Cell[BoxData[GridBox[{
          {
            StyleBox[GridBox[{
                  {
                    SubscriptBox["x", 
                      RowBox[{"0", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"1", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"2", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"3", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"4", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"5", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]}
                  }],
              FontWeight->"Bold"], 
            StyleBox[GridBox[{
                  {\(P\_0\), " ", " ", " ", " ", " "},
                  {\(P\_1\), \(P\_\(0, 1\)\), " ", " ", " ", " "},
                  {\(P\_2\), \(P\_\(1, 2\)\), \(P\_\(0, 1, 2\)\), " ", " ", 
                    " "},
                  {\(P\_3\), \(P\_\(2, 3\)\), \(P\_\(1, 2, 3\)\), \(P\_\(0, 
                        1, 2, 3\)\), " ", " "},
                  {\(P\_4\), \(P\_\(3, 4\)\), \(P\_\(2, 3, 4\)\), \(P\_\(1, 
                        2, 3, 4\)\), \(P\_\(0, 1, 2, 3, 4\)\), " "},
                  {\(P\_5\), \(P\_\(4, 5\)\), \(P\_\(3, 4, 5\)\), \(P\_\(2, 
                        3, 4, 5\)\), \(P\_\(1, 2, 3, 4, 5\)\), \(P\_\(0, 1, 
                        2, 3, 4, 5\)\)}
                  }],
              FontWeight->"Bold"], 
            StyleBox[GridBox[{
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"0", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"1", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"2", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"3", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"4", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"5", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]}
                  }],
              FontWeight->"Bold"]}
          },
        ColumnLines->True]]],
  "  \n\t\n",
  StyleBox["Table 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  ButtonBox["Neville's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NevillesAlgorithm.html"], None},
    ButtonStyle->"Hyperlink"],
  "   ",
  Cell[BoxData[
      StyleBox[
        RowBox[{\(P\_\(j, j + 1,  ... , i - 1, i\)\), " ", "=", " ", 
          RowBox[{\(1\/\(x\_i - x\_j\)\), "|", GridBox[{
                {\(P\_\(j + 1,  ... , i - 1, i\)\), \(x\_j - x\)},
                {\(P\_\(j, j + 1,  ... , i - 1\)\), \(x\_i - x\)}
                }], "|"}]}],
        FontWeight->"Bold"]]],
  "    for    ",
  Cell[BoxData[
      StyleBox[\(1 < j \[LessEqual] i\),
        FontWeight->"Bold"]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Aitken's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/AitkenInterpolation.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  In each new elements is computed using the element in the {same row, \
preceding column} and {top row, preceding column}. \n \n\n\t",
  Cell[BoxData[GridBox[{
          {
            StyleBox[GridBox[{
                  {
                    SubscriptBox["x", 
                      RowBox[{"0", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"1", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"2", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"3", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"4", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"5", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]}
                  }],
              FontWeight->"Bold"], 
            StyleBox[GridBox[{
                  {\(Q\_0\), " ", " ", " ", " ", " "},
                  {\(Q\_1\), \(Q\_\(0, 1\)\), " ", " ", " ", " "},
                  {\(Q\_2\), \(Q\_\(0, 2\)\), \(Q\_\(0, 1, 2\)\), " ", " ", 
                    " "},
                  {\(Q\_3\), \(Q\_\(0, 3\)\), \(Q\_\(0, 1, 3\)\), \(Q\_\(0, 
                        1, 2, 3\)\), " ", " "},
                  {\(Q\_4\), \(Q\_\(0, 4\)\), \(Q\_\(0, 1, 4\)\), \(Q\_\(0, 
                        1, 2, 4\)\), \(Q\_\(0, 1, 2, 3, 4\)\), " "},
                  {\(Q\_5\), \(Q\_\(0, 5\)\), \(Q\_\(0, 1, 5\)\), \(Q\_\(0, 
                        1, 2, 5\)\), \(Q\_\(0, 1, 2, 3, 5\)\), \(Q\_\(0, 1, 
                        2, 3, 4, 5\)\)}
                  }],
              FontWeight->"Bold"], 
            StyleBox[GridBox[{
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"0", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"1", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"2", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"3", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"4", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"5", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", "x"}]}
                  }],
              FontWeight->"Bold"]}
          },
        ColumnLines->True]]],
  "  \n\t\n",
  StyleBox["Table 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  ButtonBox["Aitken's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/AitkenInterpolation.html"], None},
    ButtonStyle->"Hyperlink"],
  "   ",
  Cell[BoxData[
      StyleBox[
        RowBox[{\(Q\_\(0, 1,  ... , j - 1, j, i\)\), " ", "=", " ", 
          RowBox[{\(1\/\(x\_i - x\_j\)\), "|", GridBox[{
                {\(Q\_\(0, 1,  ... , j - 1, j\)\), \(x\_j - x\)},
                {\(Q\_\(0, 1,  ... , j - 1, i\)\), \(x\_i - x\)}
                }], "|"}]}],
        FontWeight->"Bold"]]],
  "    for    ",
  Cell[BoxData[
      StyleBox[\(1 < j \[LessEqual] i\),
        FontWeight->"Bold"]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Exploration",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Aitken and Neville Methods",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Scroll down to this exploration. "
}], "Text"],

Cell[TextData[{
  StyleBox["Recursive Programming",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tAitken's and Neville's polynomials can be programmed recursively \
with the following subroutines. "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Aitken's and Neville's Interpolation Methods",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Neville Polynomials).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[{
    RowBox[{\(P = 0; \ Remove[P];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"NevillePoly", " ", ":=", " ", 
        RowBox[{"Mod", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Clear[i, j, k, l, m, n, P, t]\), ";", " ", 
              "\[IndentingNewLine]", \(P\_i_[t_] := f[x\_i]\), ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(P\_\(i_, j_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_j - x\_i\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(P\_i[t]\), \(x\_i - t\)},
                          {\(P\_j[t]\), \(x\_j - t\)}
                          }], ")"}], "]"}]}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(P\_\(i_, j_, k_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_k - x\_i\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(P\_\(i, j\)[t]\), \(x\_i - t\)},
                          {\(P\_\(j, k\)[t]\), \(x\_k - t\)}
                          }], ")"}], "]"}]}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(P\_\(i_, j_, k_, l_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_l - x\_i\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(P\_\(i, j, k\)[t]\), \(x\_i - t\)},
                          {\(P\_\(j, k, l\)[t]\), \(x\_l - t\)}
                          }], ")"}], "]"}]}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(P\_\(i_, j_, k_, l_, m_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_m - x\_i\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(P\_\(i, j, k, l\)[t]\), \(x\_i - t\)},
                          {\(P\_\(j, k, l, m\)[t]\), \(x\_m - t\)}
                          }], ")"}], "]"}]}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(P\_\(i_, j_, k_, l_, m_, n_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_n - x\_i\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(P\_\(i, j, k, l, m\)[t]\), \(x\_i - t\)},
                          {\(P\_\(j, k, l, m, n\)[t]\), \(x\_n - t\)}
                          }], ")"}], "]"}]}]}], ";"}]}], " ", "]"}]}], 
      ";"}]}], "Input"],

Cell[TextData[StyleBox["Mathematica Subroutine (Aitken Polynomials).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[{
    RowBox[{\(Q = 0; \ Remove[Q];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"AitkenPoly", " ", ":=", " ", 
        RowBox[{"Mod", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Clear[i, j, Q, t]\), ";", " ", 
              "\[IndentingNewLine]", \(Q\_i_[t_] := f[x\_i]\), ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(Q\_\(0, i_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_i - x\_0\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(Q\_0[t]\), \(x\_0 - t\)},
                          {\(Q\_i[t]\), \(x\_i - t\)}
                          }], ")"}], "]"}]}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(Q\_\(0, 1, i_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_i - x\_1\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(Q\_\(0, 1\)[t]\), \(x\_1 - t\)},
                          {\(Q\_\(0, i\)[t]\), \(x\_i - t\)}
                          }], ")"}], "]"}]}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(Q\_\(0, 1, 2, i_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_i - x\_2\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(Q\_\(0, 1, 2\)[t]\), \(x\_2 - t\)},
                          {\(Q\_\(0, 1, i\)[t]\), \(x\_i - t\)}
                          }], ")"}], "]"}]}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(Q\_\(0, 1, 2, 3, i_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_i - x\_3\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(Q\_\(0, 1, 2, 3\)[t]\), \(x\_3 - t\)},
                          {\(Q\_\(0, 1, 2, i\)[t]\), \(x\_i - t\)}
                          }], ")"}], "]"}]}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{\(Q\_\(0, 1, 2, 3, 4, i_\)[t_]\), ":=", 
                RowBox[{\(1\/\(x\_i - x\_4\)\), 
                  RowBox[{"Det", "[", 
                    RowBox[{"(", GridBox[{
                          {\(Q\_\(0, 1, 2, 3, 4\)[t]\), \(x\_4 - t\)},
                          {\(Q\_\(0, 1, 2, 3, i\)[t]\), \(x\_i - t\)}
                          }], ")"}], "]"}]}]}], ";"}]}], " ", "]"}]}], 
      ";"}]}], "Input"],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(f[x] = \ \[ExponentialE]\^x\)]],
  "  and the nodes ",
  Cell[BoxData[
      \({x\_i = 1 + i\/4}\_\(i = 0\)\%3\)]],
  " compute the entries in Aitken's tableau and Neville's tableau for \
evaluating  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  at  ",
  Cell[BoxData[
      \(x\&^\  = \ 1.6\)]],
  "  \nShow the details for the computations. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold"]], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell["Enter the function and nodes and point of evaluation.  ", "Text"],

Cell[BoxData[{
    \(\(f[x_] = \ \[ExponentialE]\^x;\)\ \), "\[IndentingNewLine]", 
    \(\(x\_i_ = 1.0 + i\/4;\)\ \), "\[IndentingNewLine]", 
    \(\(x\&^\  = \ 1.6;\)\ \), "\[IndentingNewLine]", 
    \(\(nodes = Table[x\_i, {i, 0, 3}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Approximate\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], \*"\"\<  at the point  \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the nodes\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_i\)} = \>\"", nodes];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["2 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox["Compute the values for Neville's tableau.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " "
}], "Text"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_i[t]\),
          FontWeight->"Plain"], 
        StyleBox[" ",
          FontWeight->"Bold"], "=", " ", \(f[x\_i]\)}]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(NevillePoly;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<The Neville's tableau is\>"];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"TableForm", "[", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(x\_0\), \(P\_0[x\&^]\), "\"\<\>\"", "\"\<\>\"", 
                      "\"\<\>\""},
                    {\(x\_1\), \(P\_1[x\&^]\), \(P\_\(0, 1\)[x\&^]\), 
                      "\"\<\>\"", "\"\<\>\""},
                    {\(x\_2\), \(P\_2[x\&^]\), \(P\_\(1, 2\)[
                        x\&^]\), \(P\_\(0, 1, 2\)[x\&^]\), "\"\<\>\""},
                    {\(x\_3\), \(P\_3[x\&^]\), \(P\_\(2, 3\)[
                        x\&^]\), \(P\_\(1, 2, 3\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3\)[x\&^]\)}
                    }], ")"}], " ", 
              ",", \(TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \
\!\(x\_i\)\>\"", \*"\"\<\!\(P\_i\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(P\_\(i, j\)\
\)\>\"", \*"\"\<\!\(p\_\(i, j, k\)\)\>\""}}\)}], "]"}], "]"}], ";"}], 
      " "}]}], "Input"],

Cell[TextData[StyleBox["Details for Neville's tableau.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(0, 1\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_0\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_1\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".  \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(P\_0\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " ", " ", 
                      " "},
                    {
                      StyleBox[\(P\_1\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(P\_\(0, 1\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(P\_\(0, 1\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"", 
            ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_1\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_0\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(P\_0\),
                          FontColor->RGBColor[0, 1, 0]], 
                        StyleBox["[",
                          FontColor->GrayLevel[0]], 
                        StyleBox[\(x\&^\),
                          FontColor->GrayLevel[0]], 
                        StyleBox["]",
                          FontColor->GrayLevel[0]]}], 
                      StyleBox[\(x\_0 - x\&^\),
                        FontColor->RGBColor[0, 1, 0],
                        Background->None]},
                    {
                      RowBox[{
                        StyleBox[\(P\_1\),
                          FontColor->RGBColor[0, 1, 1]], 
                        StyleBox["[",
                          FontColor->GrayLevel[0]], 
                        StyleBox[\(x\&^\),
                          FontColor->GrayLevel[0]], 
                        StyleBox["]",
                          FontColor->GrayLevel[0]]}], 
                      StyleBox[\(x\_1 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[P\_\(0, 1\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(1, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_1\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_2\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".  \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(P\_1\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " ", " ", 
                      " "},
                    {
                      StyleBox[\(P\_2\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(P\_\(1, 2\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(P\_\(1, 2\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"", 
            ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_2\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_1\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(P\_1\),
                          FontColor->RGBColor[0, 1, 0]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_1 - x\&^\),
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      RowBox[{
                        StyleBox[\(P\_2\),
                          FontColor->RGBColor[0, 1, 1]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_2 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[P\_\(1, 2\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(2, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_2\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_3\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".  \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"3", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(P\_2\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " ", " ", 
                      " "},
                    {
                      StyleBox[\(P\_3\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(P\_\(2, 3\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"3", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(P\_\(2, 3\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"", 
            ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_3\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_2\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(P\_2\),
                          FontColor->RGBColor[0, 1, 0]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_2 - x\&^\),
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      RowBox[{
                        StyleBox[\(P\_3\),
                          FontColor->RGBColor[0, 1, 1]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_3 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[P\_\(2, 3\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(0, 1, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(0, 1\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(1, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".   \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(P\_0\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      " ", " ", " ", " ", " "},
                    {
                      StyleBox[\(P\_1\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(0, 1\)\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " ", " "},
                    {
                      StyleBox[\(P\_2\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(1, 2\)\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(P\_\(0, 1, 2\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(P\_\(0, 1, 2\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"",
             ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_2\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_0\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(P\_\(0, 1\)\),
                          FontColor->RGBColor[0, 1, 0]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_0 - x\&^\),
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      RowBox[{
                        StyleBox[\(P\_\(1, 2\)\),
                          FontColor->RGBColor[0, 1, 1]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_2 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[P\_\(0, 1, 2\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(1, 2, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(1, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(2, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".   \n\n",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"3", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(P\_1\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      " ", " ", " ", " ", " "},
                    {
                      StyleBox[\(P\_2\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(1, 2\)\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " ", " "},
                    {
                      StyleBox[\(P\_3\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(2, 3\)\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(P\_\(1, 2, 3\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"3", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(P\_\(1, 2, 3\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"",
             ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_3\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_1\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(P\_\(1, 2\)\),
                          FontColor->RGBColor[0, 1, 0]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_1 - x\&^\),
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      RowBox[{
                        StyleBox[\(P\_\(2, 3\)\),
                          FontColor->RGBColor[0, 1, 1]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_3 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[P\_\(1, 2, 3\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(0, 1, 2, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(0, 1, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(P\_\(1, 2, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".   \n\n",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"3", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(P\_0\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[" ",
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      " ", " ", " ", " "},
                    {
                      StyleBox[\(P\_1\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(0, 1\)\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      " ", " ", " ", " "},
                    {
                      StyleBox[\(P\_2\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(1, 2\)\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(0, 1, 2\)\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " "},
                    {
                      StyleBox[\(P\_3\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(2, 3\)\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(P\_\(1, 2, 3\)\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(P\_\(0, 1, 2, 3\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"3", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(P\_\(0, 1, 2, 3\)\)[\>\"", ",", \(x\&^\), ",", 
            "\"\<] = \>\"", ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_3\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_0\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(P\_\(0, 1, 2\)\),
                          FontColor->RGBColor[0, 1, 0]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_0 - x\&^\),
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      RowBox[{
                        StyleBox[\(P\_\(1, 2, 3\)\),
                          FontColor->RGBColor[0, 1, 1]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_3 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[P\_\(0, 1, 2, 3\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[BoxData[{
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<We have the approximation\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<f[\>", x\&^, "\<] \[TildeTilde] \>", 
        P\_\(0, 1, 2, 3\)[x\&^]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is close to the true value\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\&^, "\<] = \>", f[x\&^]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["2 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox["Compute the values for Aitken's tableau.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " "
}], "Text"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      \(Q\_i[t]\  = \ f[x\_i]\)]],
  "  "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(AitkenPoly;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<The Aitken's tableau is\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"TableForm", "[", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(x\_0\), \(Q\_0[x\&^]\), "\"\<\>\"", "\"\<\>\"", 
                      "\"\<\>\""},
                    {\(x\_1\), \(Q\_1[x\&^]\), \(Q\_\(0, 1\)[x\&^]\), 
                      "\"\<\>\"", "\"\<\>\""},
                    {\(x\_2\), \(Q\_2[x\&^]\), \(Q\_\(0, 2\)[
                        x\&^]\), \(Q\_\(0, 1, 2\)[x\&^]\), "\"\<\>\""},
                    {\(x\_3\), \(Q\_3[x\&^]\), \(Q\_\(0, 3\)[
                        x\&^]\), \(Q\_\(0, 1, 3\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3\)[x\&^]\)}
                    }], ")"}], " ", 
              ",", \(TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \
\!\(x\_i\)\>\"", \*"\"\<\!\(Q\_i\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(Q\_\(0, i\)\
\)\>\"", \*"\"\<\!\(Q\_\(0, 1, i\)\)\>\""}}\)}], "]"}], "]"}], ";"}], 
      " "}]}], "Input"],

Cell[TextData[StyleBox["Details for Aitken's tableau.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 1\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_0\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_1\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".  \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(Q\_0\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " ", " ", 
                      " "},
                    {
                      StyleBox[\(Q\_1\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(Q\_\(0, 1\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(Q\_\(0, 1\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"", 
            ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_1\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_0\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(Q\_0\),
                          FontColor->RGBColor[0, 1, 0]], 
                        StyleBox["[",
                          FontColor->GrayLevel[0]], 
                        StyleBox[\(x\&^\),
                          FontColor->GrayLevel[0]], 
                        StyleBox["]",
                          FontColor->GrayLevel[0]]}], 
                      StyleBox[\(x\_0 - x\&^\),
                        FontColor->RGBColor[0, 1, 0],
                        Background->None]},
                    {
                      RowBox[{
                        StyleBox[\(Q\_1\),
                          FontColor->RGBColor[0, 1, 1]], 
                        StyleBox["[",
                          FontColor->GrayLevel[0]], 
                        StyleBox[\(x\&^\),
                          FontColor->GrayLevel[0]], 
                        StyleBox["]",
                          FontColor->GrayLevel[0]]}], 
                      StyleBox[\(x\_1 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[Q\_\(0, 1\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_0\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_2\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".  \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(Q\_0\),
                        FontColor->RGBColor[0, 1, 0]], 
                      RowBox[{
                        StyleBox[" ",
                          FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                        
                        StyleBox[\(Q\_\(0, 0\)\),
                          FontColor->GrayLevel[1]]}], " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_1\),
                        FontColor->RGBColor[1, 1, 0]], 
                      StyleBox[\(Q\_\(0, 1\)\),
                        FontColor->GrayLevel[1]], " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_2\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(Q\_\(0, 2\)\),
                        FontColor->RGBColor[0, 0, 1]], 
                      StyleBox[" ",
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(Q\_\(0, 2\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"", 
            ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_2\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_0\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(Q\_0\),
                          FontColor->RGBColor[0, 1, 0]], 
                        StyleBox["[",
                          FontColor->GrayLevel[0]], 
                        StyleBox[\(x\&^\),
                          FontColor->GrayLevel[0]], 
                        StyleBox["]",
                          FontColor->GrayLevel[0]]}], 
                      StyleBox[\(x\_0 - x\&^\),
                        FontColor->RGBColor[0, 1, 0],
                        Background->None]},
                    {
                      RowBox[{
                        StyleBox[\(Q\_2\),
                          FontColor->RGBColor[0, 1, 1]], 
                        StyleBox["[",
                          FontColor->GrayLevel[0]], 
                        StyleBox[\(x\&^\),
                          FontColor->GrayLevel[0]], 
                        StyleBox["]",
                          FontColor->GrayLevel[0]]}], 
                      StyleBox[\(x\_2 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[Q\_\(0, 2\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_0\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_3\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".  \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"3", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(Q\_0\),
                        FontColor->RGBColor[0, 1, 0]], 
                      RowBox[{
                        StyleBox[\(Q\_\(0, 0\)\),
                          FontColor->GrayLevel[1]], 
                        StyleBox[" ",
                          FontColor->RGBColor[0.996109, 0.500008, 
                          0.500008]]}], " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_1\),
                        FontColor->RGBColor[1, 1, 0]], 
                      RowBox[{
                        StyleBox[\(Q\_\(0, 1\)\),
                          FontColor->GrayLevel[1]], 
                        StyleBox[" ",
                          FontColor->RGBColor[0.996109, 0.500008, 
                          0.500008]]}], " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_2\),
                        FontColor->RGBColor[1, 1, 0]], 
                      RowBox[{
                        StyleBox[\(Q\_\(0, 2\)\),
                          FontColor->GrayLevel[1]], 
                        StyleBox[" ",
                          FontColor->RGBColor[0.996109, 0.500008, 
                          0.500008]]}], 
                      StyleBox[" ",
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " "},
                    {
                      StyleBox[\(Q\_3\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(Q\_\(0, 3\)\),
                        FontColor->RGBColor[0, 0, 1]], 
                      StyleBox[" ",
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[" ",
                        FontColor->RGBColor[0, 0, 1]], " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"3", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(Q\_\(0, 3\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"", 
            ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_3\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_0\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(Q\_0\),
                          FontColor->RGBColor[0, 1, 0]], 
                        StyleBox["[",
                          FontColor->GrayLevel[0]], 
                        StyleBox[\(x\&^\),
                          FontColor->GrayLevel[0]], 
                        StyleBox["]",
                          FontColor->GrayLevel[0]]}], 
                      StyleBox[\(x\_0 - x\&^\),
                        FontColor->RGBColor[0, 1, 0],
                        Background->None]},
                    {
                      RowBox[{
                        StyleBox[\(Q\_3\),
                          FontColor->RGBColor[0, 1, 1]], 
                        StyleBox["[",
                          FontColor->GrayLevel[0]], 
                        StyleBox[\(x\&^\),
                          FontColor->GrayLevel[0]], 
                        StyleBox["]",
                          FontColor->GrayLevel[0]]}], 
                      StyleBox[\(x\_3 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[Q\_\(0, 3\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 1, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 1\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".    \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(Q\_0\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[" ",
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_1\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 1\)\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_2\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 2\)\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(Q\_\(0, 1, 2\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(Q\_\(0, 1, 2\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"",
             ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_2\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_1\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(Q\_\(0, 1\)\),
                          FontColor->RGBColor[0, 1, 0]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_1 - x\&^\),
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      RowBox[{
                        StyleBox[\(Q\_\(0, 2\)\),
                          FontColor->RGBColor[0, 1, 1]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_2 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[Q\_\(0, 1, 2\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 1, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 1\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".   \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"3", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(Q\_0\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[" ",
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_1\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 1\)\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_2\),
                        FontColor->RGBColor[1, 1, 0]], 
                      StyleBox[\(Q\_\(0, 2\)\),
                        FontColor->RGBColor[1, 1, 0]], " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_3\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 3\)\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(Q\_\(0, 1, 3\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"3", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(Q\_\(0, 1, 3\)\)[\>\"", ",", \(x\&^\), ",", "\"\<] = \>\"",
             ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_3\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_1\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(Q\_\(0, 1\)\),
                          FontColor->RGBColor[0, 1, 0]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_1 - x\&^\),
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      RowBox[{
                        StyleBox[\(Q\_\(0, 3\)\),
                          FontColor->RGBColor[0, 1, 1]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_3 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[Q\_\(0, 1, 3\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 1, 2, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 0, 1]], "[", "t", "]"}]]],
  "  using  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 1, 2\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Q\_\(0, 1, 3\)\),
          FontWeight->"Bold",
          FontColor->RGBColor[0, 1, 1]], "[", "t", "]"}]]],
  ".   \n\n\t",
  Cell[BoxData[
      RowBox[{GridBox[{
            {
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"0", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"1", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"2", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 1]]},
                    {
                      StyleBox[
                        SubscriptBox["x", 
                          RowBox[{"3", 
                            StyleBox[",",
                              FontColor->GrayLevel[1]]}]],
                        FontColor->RGBColor[1, 0, 0]]}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[\(Q\_0\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[" ",
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_1\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 1\)\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      " ", " ", " ", " "},
                    {
                      StyleBox[\(Q\_2\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 2\)\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 1, 2\)\),
                        FontColor->RGBColor[0, 1, 0]], " ", " ", " "},
                    {
                      StyleBox[\(Q\_3\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 3\)\),
                        FontColor->RGBColor[0.996109, 0.500008, 0.500008]], 
                      StyleBox[\(Q\_\(0, 1, 3\)\),
                        FontColor->RGBColor[0, 1, 1]], 
                      StyleBox[\(Q\_\(0, 1, 2, 3\)\),
                        FontColor->RGBColor[0, 0, 1]], " ", " "}
                    }],
                FontWeight->"Bold"], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"0", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"1", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->GrayLevel[1]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"2", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      StyleBox[
                        RowBox[{
                          SubscriptBox["x", 
                            RowBox[{"3", 
                              StyleBox[",",
                                FontColor->GrayLevel[1]]}]], "-", "t"}],
                        FontColor->RGBColor[0, 1, 1]]}
                    }],
                FontWeight->"Bold"]}
            },
          ColumnLines->True], "  "}]]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\!\(Q\_\(0, 1, 2, 3\)\)[\>\"", ",", \(x\&^\), ",", 
            "\"\<] = \>\"", ",", 
            FractionBox["1", 
              RowBox[{
                StyleBox[\(x\_3\),
                  FontColor->RGBColor[1, 0, 0]], "-", 
                StyleBox[\(x\_2\),
                  FontColor->RGBColor[1, 0, 1]]}]], ",", "\"\< Det\>\"", ",", 
            
            RowBox[{"MatrixForm", "[", 
              RowBox[{"(", GridBox[{
                    {
                      RowBox[{
                        StyleBox[\(Q\_\(0, 1, 2\)\),
                          FontColor->RGBColor[0, 1, 0]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_2 - x\&^\),
                        FontColor->RGBColor[0, 1, 0]]},
                    {
                      RowBox[{
                        StyleBox[\(Q\_\(0, 1, 3\)\),
                          FontColor->RGBColor[0, 1, 1]], "[", \(x\&^\), "]"}],
                       
                      StyleBox[\(x\_3 - x\&^\),
                        FontColor->RGBColor[0, 1, 1]]}
                    }], ")"}], "]"}], ",", "\"\< = \>\"", 
            ",", \(Simplify[Q\_\(0, 1, 2, 3\)[x\&^]]\)}], " ", "]"}], ";"}], 
      " "}]], "Input"],

Cell[BoxData[{
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<We have the approximation\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<f[\>", x\&^, "\<] \[TildeTilde] \>", 
        Q\_\(0, 1, 2, 3\)[x\&^]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is close to the true value\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\&^, "\<] = \>", f[x\&^]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nThe entries on the diagonal are equivalent."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<  \!\(P\_\(0, 1\)\)[\!\(x\&^\)] = \>\"", 
        P\_\(0, 1\)[x\&^], \ "\<   Neville\>"\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(Q\_\(0, 1\)\)[\!\(x\&^\)] = \>\"", 
        Q\_\(0, 1\)[x\&^], \ "\<   Aitken\>", "\<\n\>"\ \ ];\)\ \ \), "\n", 
    \(\(Print[\*"\"\< \!\(P\_\(0, 1, 2\)\)[\!\(x\&^\)] = \>\"", 
        P\_\(0, 1, 2\)[x\&^], \ "\<   Neville\>"\ \ ];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)] = \>\"", 
        Q\_\(0, 1, 2\)[x\&^], \ "\<   Aitken\>", "\<\n\>"\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2, 3\)\)[\!\(x\&^\)] = \>\"", 
        P\_\(0, 1, 2, 3\)[x\&^], \ "\<   Neville\>"\ \ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2, 3\)\)[\!\(x\&^\)] = \>\"", 
        Q\_\(0, 1, 2, 3\)[x\&^], \ "\<   Aitken\>"\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Conclusion.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nThe methods of Aitken and Neville are similar and the latter is more \
popular today.  The reader must research the literature carefully in order to \
determine which one is appropriate.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(f[x] = \ \[ExponentialE]\^x\)]],
  "  and the nodes ",
  Cell[BoxData[
      \({x\_i = 1 + i\/4}\_\(i = 0\)\%5\)]],
  " compute the entries in Aitken's tableau and Neville's tableau for \
evaluating  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  at  ",
  Cell[BoxData[
      \(x\&^\  = \ 1.8\)]],
  "  \nUse the recursive subroutines. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold"]], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell["Enter the function and nodes and point of evaluation.  ", "Text"],

Cell[BoxData[{
    \(\(f[x_] = \ \[ExponentialE]\^x;\)\ \), "\[IndentingNewLine]", 
    \(\(x\_i_ = 1.0 + i\/4;\)\ \), "\[IndentingNewLine]", 
    \(\(x\&^\  = \ 1.8;\)\ \), "\[IndentingNewLine]", 
    \(\(nodes = Table[x\_i, {i, 0, 5}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Approximate\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], \*"\"\<  at the point  \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the nodes\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_i\)} = \>\"", nodes];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["3 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Neville's tableau. "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(NevillePoly;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Neville's tableau is\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"TableForm", "[", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", \(x\_0\), \(P\_0[x\&^]\), "\"\<\>\"", "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {"1", \(x\_1\), \(P\_1[x\&^]\), \(P\_\(0, 1\)[x\&^]\), 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {
                      "2", \(x\_2\), \(P\_2[x\&^]\), \(P\_\(1, 2\)[
                        x\&^]\), \(P\_\(0, 1, 2\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\""},
                    {
                      "3", \(x\_3\), \(P\_3[x\&^]\), \(P\_\(2, 3\)[
                        x\&^]\), \(P\_\(1, 2, 3\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\""},
                    {
                      "4", \(x\_4\), \(P\_4[x\&^]\), \(P\_\(3, 4\)[
                        x\&^]\), \(P\_\(2, 3, 4\)[
                        x\&^]\), \(P\_\(1, 2, 3, 4\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3, 4\)[x\&^]\), "\"\<\>\""},
                    {
                      "5", \(x\_5\), \(P\_5[x\&^]\), \(P\_\(4, 5\)[
                        x\&^]\), \(P\_\(3, 4, 5\)[
                        x\&^]\), \(P\_\(2, 3, 4, 5\)[
                        x\&^]\), \(P\_\(1, 2, 3, 4, 5\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3, 4, 5\)[x\&^]\)}
                    }], ")"}], 
              ",", \(TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \
\!\(x\_i\)\>\"", \*"\"\<\!\(P\_i\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(P\_\(i, j\)\
\)\>\"", \*"\"\<\!\(p\_\(i, j, k\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, \
l\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, l, m\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, \
l, m, n\)\)\>\""}}\)}], "]"}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print["\<f[x] = \>", 
        f[x]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<We have the Neville approximation\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", 
        NumberForm[P\_\(0, 1, 2, 3, 4, 5\)[x\&^], 
          7]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<It is close to the true value\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", x\&^, "\<] = \>", 
        NumberForm[f[x\&^], 7]\ ];\)}], "Input"],

Cell[TextData[{
  "\tThe accuracy of the computations in Neville's tableau  improves as you \
go down the table and to the right. Without knowing where ",
  Cell[BoxData[
      \(x\&^\)]],
  " lies in relation to the nodes  ",
  Cell[BoxData[
      \({x\_i}\_\(i = 0\)\%4\)]],
  " it is difficult to determine whether the diagonal approximations are \
converging faster or the bottom row.  For illustration, consider the sequence \
",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(P\_0[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3, 4\)[x\&^]\)}], 
        "}"}]]],
  " on the diagonal. "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The sequence of Neville approximations\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(P\_0\)[\!\(x\&^\)],\!\(P\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(P\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[{P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
          P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
          P\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And the error\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\&^\)]-\!\(P\_0\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(\
P\_\(0, 1\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2\)\)[\!\(x\&^\)],f[\!\
\(x\&^\)]-\!\(P\_\(0, 1, 2, 3\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2, \
3, 4\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2, 3, 4, 5\)\)[\!\(x\&^\)]} \
= \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        f[x\&^] - {P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
            P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
            P\_\(0, 1, 2, 3, 4, 5\)[
              x\&^]}, "\< \[Rule] 0\>"\ ];\)\)}], "Input"],

Cell[TextData[{
  "The Neville polynomials  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(P\_0[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3, 4\)[x]\)}], "}"}]]],
  "  are converging to  ",
  Cell[BoxData[
      \(f[x]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}}, 
          PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr7\  = \ 
        Plot[{f[x], P\_0[x], P\_\(0, 1\)[x], P\_\(0, 1, 2\)[x], 
            P\_\(0, 1, 2, 3\)[x]}, {x, 1, 2.25}, 
          PlotStyle \[Rule] {Magenta, Red, Cyan, Green, Blue}, 
          AxesOrigin \[Rule] {1, \[ExponentialE]}, 
          Ticks \[Rule] {Range[1, 2.25, 0.25], Range[3, 9, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr7, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<    f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(P\_0\)[x] = \>\"", 
        P\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(P\_\(0, 1\)\)[x] = \>\"", 
        Expand[P\_\(0, 1\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(P\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[P\_\(0, 1, 2\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2, 3\)\)[x] = \>\"", 
        Expand[P\_\(0, 1, 2, 3\)[x]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["3 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Aitken's tableau. "
}], "Text"],

Cell[BoxData[{\(AitkenPoly;\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Aitken's tableau is\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"TableForm", "[", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", \(x\_0\), \(Q\_0[x\&^]\), "\"\<\>\"", "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {"1", \(x\_1\), \(Q\_1[x\&^]\), \(Q\_\(0, 1\)[x\&^]\), 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {
                      "2", \(x\_2\), \(Q\_2[x\&^]\), \(Q\_\(0, 2\)[
                        x\&^]\), \(Q\_\(0, 1, 2\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\""},
                    {
                      "3", \(x\_3\), \(Q\_3[x\&^]\), \(Q\_\(0, 3\)[
                        x\&^]\), \(Q\_\(0, 1, 3\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\""},
                    {
                      "4", \(x\_4\), \(Q\_4[x\&^]\), \(Q\_\(0, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 4\)[x\&^]\), "\"\<\>\""},
                    {
                      "5", \(x\_5\), \(Q\_5[x\&^]\), \(Q\_\(0, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]\)}
                    }], ")"}], 
              ",", \(TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \
\!\(x\_i\)\>\"", \*"\"\<\!\(Q\_i\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(Q\_\(0, i\)\
\)\>\"", \*"\"\<\!\(Q\_\(0, 1, i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, \
i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, 3, i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, \
3, 4, i\)\)\>\""}}\)}], "]"}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print["\<f[x] = \>", 
        f[x]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<We have the Aitken approximation\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", 
        NumberForm[Q\_\(0, 1, 2, 3, 4, 5\)[x\&^], 
          7]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<It is close to the true value\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", x\&^, "\<] = \>", 
        NumberForm[f[x\&^], 7]\ ];\)}], "Input"],

Cell[TextData[{
  "\tThe accuracy of the computations in Aitken's tableau  improves as you go \
down the table and to the right. Without knowing where ",
  Cell[BoxData[
      \(x\&^\)]],
  " lies in relation to the nodes  ",
  Cell[BoxData[
      \({x\_i}\_\(i = 0\)\%4\)]],
  " it is difficult to determine whether the diagonal approximations are \
converging faster or the bottom row.  For illustration, consider the sequence \
",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(Q\_0[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3, 4\)[x\&^]\)}], 
        "}"}]]],
  " on the diagonal. "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The sequence of Aitken approximations\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(Q\_0\)[\!\(x\&^\)],\!\(Q\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[{Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
          Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
          Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And the error\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\&^\)]-\!\(Q\_0\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(\
Q\_\(0, 1\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)],f[\!\
\(x\&^\)]-\!\(Q\_\(0, 1, 2, 3\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2, \
3, 4\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2, 3, 4, 5\)\)[\!\(x\&^\)]} \
= \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        f[x\&^] - {Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
            Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
            Q\_\(0, 1, 2, 3, 4, 5\)[
              x\&^]}, "\< \[Rule] 0\>"\ ];\)\)}], "Input"],

Cell[TextData[{
  "The Aitken polynomials  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(Q\_0[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3, 4\)[x]\)}], "}"}]]],
  "  are converging to  ",
  Cell[BoxData[
      \(f[x]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}}, 
          PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr8\  = \ 
        Plot[{f[x], Q\_0[x], Q\_\(0, 1\)[x], Q\_\(0, 1, 2\)[x], 
            Q\_\(0, 1, 2, 3\)[x]}, {x, 1, 2.25}, 
          PlotStyle \[Rule] {Magenta, Red, Cyan, Green, Blue}, 
          AxesOrigin \[Rule] {1, \[ExponentialE]}, 
          Ticks \[Rule] {Range[1, 2.25, 0.25], Range[3, 9, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr8, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<    f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(Q\_0\)[x] = \>\"", 
        Q\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(Q\_\(0, 1\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(Q\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1, 2\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2, 3\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1, 2, 3\)[x]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Observation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  \n\nIt is easy verify that the entries on the diagonal are the same  \n\
",
  Cell[BoxData[
      \(P\_0[x\&^] = Q\_0[x\&^]\)]],
  ", ",
  Cell[BoxData[
      \(P\_\(0, 1\)[x\&^] = Q\_\(0, 1\)[x\&^]\)]],
  ", ",
  Cell[BoxData[
      \(P\_\(0, 1, 2\)[x\&^] = Q\_\(0, 1, 2\)[x\&^]\)]],
  ",",
  Cell[BoxData[
      \(P\_\(0, 1, 2, 3\)[x\&^] = Q\_\(0, 1, 2, 3\)[x\&^]\)]],
  ", and ",
  Cell[BoxData[
      \(P\_\(0, 1, 2, 3, 4\)[x\&^] = Q\_\(0, 1, 2, 3, 4\)[x\&^]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<{\!\(P\_0\)[\!\(x\&^\)],\!\(P\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(P\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\n", 
    \(\(Print[{P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
          P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
          P\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\), "\n", 
    \(\(Print[\*"\"\<{\!\(Q\_0\)[\!\(x\&^\)],\!\(Q\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\n", 
    \(\(Print[{Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
          Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
          Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Observation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  \n\nIt is easy verify that the entries on the diagonal are the same  ",
  Cell[BoxData[
      \(P\_0[x] = Q\_0[x]\)]],
  ", ",
  Cell[BoxData[
      \(P\_\(0, 1\)[x] = Q\_\(0, 1\)[x]\)]],
  ", ",
  Cell[BoxData[
      \(P\_\(0, 1, 2\)[x] = Q\_\(0, 1, 2\)[x]\)]],
  ",",
  Cell[BoxData[
      \(P\_\(0, 1, 2, 3\)[x] = Q\_\(0, 1, 2, 3\)[x]\)]],
  ", ",
  Cell[BoxData[
      \(P\_\(0, 1, 2, 3, 4\)[x] = Q\_\(0, 1, 2, 3, 4\)[x]\)]],
  ", and ",
  Cell[BoxData[
      \(P\_\(0, 1, 2, 3, 4, 5\)[x] = Q\_\(0, 1, 2, 3, 4, 5\)[x]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(P\_0\)[x] = \>\"", 
        P\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_0\)[x] = \>\"", 
        Q\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(P\_0\)[x] \[Equal] \!\(Q\_0\)[x] ?  \>\"", \ 
        ExpandAll[
          P\_0[x] \[Equal] 
            Q\_0[x]], "\<\n\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1\)\)[x] = \>\"", 
        P\_\(0, 1\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1\)\)[x] = \>\"", 
        Q\_\(0, 1\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(P\_\(0, 1\)\)[x] \[Equal] \!\(Q\_\(0, 1\)\)[x] \
?  \>\"", \ 
        ExpandAll[
          P\_\(0, 1\)[x] \[Equal] 
            Q\_\(0, 1\)[x]], "\<\n\>"\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2\)\)[x] = \>\"", 
        P\_\(0, 1, 2\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2\)\)[x] = \>\"", 
        Q\_\(0, 1, 2\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(P\_\(0, 1, 2\)\)[x] \[Equal] \!\(Q\_\(0, 1, 2\)\
\)[x] ?  \>\"", \ 
        ExpandAll[
          P\_\(0, 1, 2\)[x] \[Equal] 
            Q\_\(0, 1, 2\)[x]], "\<\n\>"\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2, 3\)\)[x] = \>\"", 
        P\_\(0, 1, 2, 3\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2, 3\)\)[x] = \>\"", 
        Q\_\(0, 1, 2, 3\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(P\_\(0, 1, 2, 3\)\)[x] \[Equal] \!\(Q\_\(0, 1, \
2, 3\)\)[x] ?  \>\"", \ 
        Chop[ExpandAll[
            P\_\(0, 1, 2, 3\)[x] - Q\_\(0, 1, 2, 3\)[x] \[Equal] 
              0]], "\<\n\>"\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2, 3, 4\)\)[x] = \>\"", 
        P\_\(0, 1, 2, 3, 4\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2, 3, 4\)\)[x] = \>\"", 
        Q\_\(0, 1, 2, 3, 4\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(P\_\(0, 1, 2, 3, 4\)\)[x] \[Equal] \!\(Q\_\(0, \
1, 2, 3, 4\)\)[x] ?  \>\"", \ 
        Chop[ExpandAll[
            P\_\(0, 1, 2, 3, 4\)[x] - Q\_\(0, 1, 2, 3, 4\)[x] \[Equal] 
              0]], "\<\n\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2, 3, 4, 5\)\)[x] = \>\"", 
        P\_\(0, 1, 2, 3, 4, 5\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2, 3, 4, 5\)\)[x] = \>\"", 
        Q\_\(0, 1, 2, 3, 4, 5\)[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(P\_\(0, 1, 2, 3, 4, 5\)\)[x] \[Equal] \
\!\(Q\_\(0, 1, 2, 3, 4, 5\)\)[x] ?  \>\"", \ 
        Chop[ExpandAll[
            P\_\(0, 1, 2, 3, 4, 5\)[x] - Q\_\(0, 1, 2, 3, 4, 5\)[x] \[Equal] 
              0]]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(f[x] = \ BesselJ[0, x]\)]],
  "  and the nodes ",
  Cell[BoxData[
      \({x\_i\  = \ i*0.5}\_\(i = 0\)\%5\)]],
  " compute the entries in Aitken's tableau and Neville's tableau for \
evaluating  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  at  ",
  Cell[BoxData[
      \(x\&^\  = \ 1.8\)]],
  "  \nUse the recursive subroutines. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold"]], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell["Enter the function and nodes and point of evaluation.  ", "Text"],

Cell[BoxData[{
    \(\(f[x_] = \ BesselJ[0, x];\)\ \), "\[IndentingNewLine]", 
    \(\(x\_i_ = 0.0 + i*0.5;\)\ \), "\[IndentingNewLine]", 
    \(\(x\&^\  = \ 1.8;\)\ \), "\[IndentingNewLine]", 
    \(\(nodes = Table[x\_i, {i, 0, 5}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Approximate\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], \*"\"\<  at the point  \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the nodes\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_i\)} = \>\"", nodes];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["4 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Neville's tableau. "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(NevillePoly;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Neville's tableau is\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"TableForm", "[", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", \(x\_0\), \(P\_0[x\&^]\), "\"\<\>\"", "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {"1", \(x\_1\), \(P\_1[x\&^]\), \(P\_\(0, 1\)[x\&^]\), 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {
                      "2", \(x\_2\), \(P\_2[x\&^]\), \(P\_\(1, 2\)[
                        x\&^]\), \(P\_\(0, 1, 2\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\""},
                    {
                      "3", \(x\_3\), \(P\_3[x\&^]\), \(P\_\(2, 3\)[
                        x\&^]\), \(P\_\(1, 2, 3\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\""},
                    {
                      "4", \(x\_4\), \(P\_4[x\&^]\), \(P\_\(3, 4\)[
                        x\&^]\), \(P\_\(2, 3, 4\)[
                        x\&^]\), \(P\_\(1, 2, 3, 4\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3, 4\)[x\&^]\), "\"\<\>\""},
                    {
                      "5", \(x\_5\), \(P\_5[x\&^]\), \(P\_\(4, 5\)[
                        x\&^]\), \(P\_\(3, 4, 5\)[
                        x\&^]\), \(P\_\(2, 3, 4, 5\)[
                        x\&^]\), \(P\_\(1, 2, 3, 4, 5\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3, 4, 5\)[x\&^]\)}
                    }], ")"}], 
              ",", \(TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \
\!\(x\_i\)\>\"", \*"\"\<\!\(P\_i\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(P\_\(i, j\)\
\)\>\"", \*"\"\<\!\(p\_\(i, j, k\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, \
l\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, l, m\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, \
l, m, n\)\)\>\""}}\)}], "]"}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print["\<f[x] = \>", 
        f[x]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<We have the Neville approximation\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", 
        P\_\(0, 1, 2, 3, 4, 5\)[x\&^]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<It is close to the true value\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", x\&^, "\<] = \>", 
        f[x\&^]\ ];\)}], "Input"],

Cell[TextData[{
  "\tThe accuracy of the computations in Neville's tableau  improves as you \
go down the table and to the right. Without knowing where ",
  Cell[BoxData[
      \(x\&^\)]],
  " lies in relation to the nodes  ",
  Cell[BoxData[
      \({x\_i}\_\(i = 0\)\%4\)]],
  " it is difficult to determine whether the diagonal approximations are \
converging faster or the bottom row.  For illustration, consider the sequence \
",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(P\_0[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3, 4\)[x\&^]\)}], 
        "}"}]]],
  " on the diagonal. "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The sequence of Neville approximations\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(P\_0\)[\!\(x\&^\)],\!\(P\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(P\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[{P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
          P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
          P\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And the error\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\&^\)]-\!\(P\_0\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(\
P\_\(0, 1\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2\)\)[\!\(x\&^\)],f[\!\
\(x\&^\)]-\!\(P\_\(0, 1, 2, 3\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2, \
3, 4\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2, 3, 4, 5\)\)[\!\(x\&^\)]} \
= \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        f[x\&^] - {P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
            P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
            P\_\(0, 1, 2, 3, 4, 5\)[
              x\&^]}, "\< \[Rule] 0\>"\ ];\)\)}], "Input"],

Cell[TextData[{
  "The Neville polynomials  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(P\_0[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3, 4\)[x]\)}], "}"}]]],
  "  are converging to  ",
  Cell[BoxData[
      \(f[x]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}, {x\_3, 
              f[x\_3]}, {x\_4, f[x\_4]}}, 
          PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr9\  = \ 
        Plot[{f[x], P\_0[x], P\_\(0, 1\)[x], P\_\(0, 1, 2\)[x], 
            P\_\(0, 1, 2, 3\)[x], P\_\(0, 1, 2, 3, 4\)[x]}, {x, 0, 3.5}, 
          PlotStyle \[Rule] {Magenta, Green, Blue, Red, Green, Blue}, 
          PlotRange \[Rule] {{0, 3.5}, {\(-0.5\), 1}}, 
          Ticks \[Rule] {Range[0, 3.5, 0.5], Range[\(-0.5\), 1.0, 0.25]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr9, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<      f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(P\_0\)[x] = \>\"", 
        P\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(P\_\(0, 1\)\)[x] = \>\"", 
        Expand[P\_\(0, 1\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(P\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[P\_\(0, 1, 2\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(P\_\(0, 1, 2, 3\)\)[x] = \>\"", 
        Expand[P\_\(0, 1, 2, 3\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2, 3, 4\)\)[x] = \>\"", 
        Expand[P\_\(0, 1, 2, 3, 4\)[x]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["4 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Aitken's tableau. "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(AitkenPoly;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Aitken's tableau is\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"TableForm", "[", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", \(x\_0\), \(Q\_0[x\&^]\), "\"\<\>\"", "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {"1", \(x\_1\), \(Q\_1[x\&^]\), \(Q\_\(0, 1\)[x\&^]\), 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {
                      "2", \(x\_2\), \(Q\_2[x\&^]\), \(Q\_\(0, 2\)[
                        x\&^]\), \(Q\_\(0, 1, 2\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\""},
                    {
                      "3", \(x\_3\), \(Q\_3[x\&^]\), \(Q\_\(0, 3\)[
                        x\&^]\), \(Q\_\(0, 1, 3\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\""},
                    {
                      "4", \(x\_4\), \(Q\_4[x\&^]\), \(Q\_\(0, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 4\)[x\&^]\), "\"\<\>\""},
                    {
                      "5", \(x\_5\), \(Q\_5[x\&^]\), \(Q\_\(0, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]\)}
                    }], ")"}], 
              ",", \(TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \
\!\(x\_i\)\>\"", \*"\"\<\!\(Q\_i\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(Q\_\(0, i\)\
\)\>\"", \*"\"\<\!\(Q\_\(0, 1, i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, \
i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, 3, i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, \
3, 4, i\)\)\>\""}}\)}], "]"}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print["\<f[x] = \>", 
        f[x]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<We have the Aitken approximation\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", 
        Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<It is close to the true value\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", x\&^, "\<] = \>", 
        f[x\&^]\ ];\)}], "Input"],

Cell[TextData[{
  "\tThe accuracy of the computations in Aitken's tableau  improves as you go \
down the table and to the right. Without knowing where ",
  Cell[BoxData[
      \(x\&^\)]],
  " lies in relation to the nodes  ",
  Cell[BoxData[
      \({x\_i}\_\(i = 0\)\%4\)]],
  " it is difficult to determine whether the diagonal approximations are \
converging faster or the bottom row.  For illustration, consider the sequence \
",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(Q\_0[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3, 4\)[x\&^]\)}], 
        "}"}]]],
  " on the diagonal. "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The sequence of Aitken approximations\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(Q\_0\)[\!\(x\&^\)],\!\(Q\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[{Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
          Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
          Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And the error\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\&^\)]-\!\(Q\_0\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(\
Q\_\(0, 1\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)],f[\!\
\(x\&^\)]-\!\(Q\_\(0, 1, 2, 3\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2, \
3, 4\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2, 3, 4, 5\)\)[\!\(x\&^\)]} \
= \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        f[x\&^] - {Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
            Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
            Q\_\(0, 1, 2, 3, 4, 5\)[
              x\&^]}, "\< \[Rule] 0\>"\ ];\)\)}], "Input"],

Cell[TextData[{
  "The Aitken polynomials  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(Q\_0[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3, 4\)[x]\)}], "}"}]]],
  "  are converging to  ",
  Cell[BoxData[
      \(f[x]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}, {x\_3, 
              f[x\_3]}, {x\_4, f[x\_4]}}, 
          PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr10\  = \ 
        Plot[{f[x], Q\_0[x], Q\_\(0, 1\)[x], Q\_\(0, 1, 2\)[x], 
            Q\_\(0, 1, 2, 3\)[x], Q\_\(0, 1, 2, 3, 5\)[x]}, {x, 0, 3.5}, 
          PlotStyle \[Rule] {Magenta, Green, Blue, Red, Green, Blue}, 
          PlotRange \[Rule] {{0, 3.5}, {\(-0.6\), 1}}, 
          Ticks \[Rule] {Range[0, 3.5, 0.5], Range[\(-0.5\), 1.0, 0.25]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr10, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<      f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<     \!\(Q\_0\)[x] = \>\"", 
        Q\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<    \!\(Q\_\(0, 1\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(Q\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1, 2\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(Q\_\(0, 1, 2, 3\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1, 2, 3\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2, 3, 5\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1, 2, 3, 5\)[x]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Observation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  \n\nIt is easy verify that the entries on the diagonal are the same   \n\
",
  Cell[BoxData[
      \(P\_0[x\&^] = Q\_0[x\&^]\)]],
  ", ",
  Cell[BoxData[
      \(P\_\(0, 1\)[x\&^] = Q\_\(0, 1\)[x\&^]\)]],
  ", ",
  Cell[BoxData[
      \(P\_\(0, 1, 2\)[x\&^] = Q\_\(0, 1, 2\)[x\&^]\)]],
  ",",
  Cell[BoxData[
      \(P\_\(0, 1, 2, 3\)[x\&^] = Q\_\(0, 1, 2, 3\)[x\&^]\)]],
  ", and ",
  Cell[BoxData[
      \(P\_\(0, 1, 2, 3, 4\)[x\&^] = Q\_\(0, 1, 2, 3, 4\)[x\&^]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<{\!\(P\_0\)[\!\(x\&^\)],\!\(P\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(P\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\n", 
    \(\(Print[{P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
          P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
          P\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\), "\n", 
    \(\(Print[\*"\"\<{\!\(Q\_0\)[\!\(x\&^\)],\!\(Q\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\n", 
    \(\(Print[{Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
          Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
          Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Rearranged Nodes",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tAitken's and Neville's methods agree on the diagonal, and one \
usually tests for convergence of these values.  If  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  is to be approximated at  ",
  Cell[BoxData[
      \(x = x\&^\)]],
  "  then one improvement that can be made is to rearrange the nodes so that \
they are \"closer to ",
  Cell[BoxData[
      \(x\&^\)]],
  "\" in the sense that is explained in the following result.  \n\t\n",
  StyleBox["Theorem(Rearrangement of Nodes).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   Given the function  ",
  Cell[BoxData[
      \(y\  = \ f[x]\)]],
  ",  and the set of  ",
  Cell[BoxData[
      \(k + 1\)]],
  " distinct nodes  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_i\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_\(k - 1\)\), ",", \(x\_k\)}], 
        "}"}]]],
  ".  If  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  is to be approximated at the point  ",
  Cell[BoxData[
      \(x\  = x\&^\)]],
  " ,  then let  \n\n\t",
  Cell[BoxData[
      RowBox[{\(S\&^\), "=", " ", 
        RowBox[{"{", 
          RowBox[{\(x\&^\_0\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\&^\_1\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\&^\_2\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\&^\_i\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\&^\_\(k - 1\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(x\&^\_k\)}], "}"}]}]]],
  "  \n\t\nbe the rearrangement of  ",
  Cell[BoxData[
      \(S\)]],
  " such that ",
  Cell[BoxData[
      \({\(|\)\(x\&^\_i - x\&^\)\(|\)}\_\(i = 0\)\%k\)]],
  " is an increasing sequence.  Then the diagonal terms  \n\n\t",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(P\_0[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2,  ... , k - 1\)[x\&^]\), 
          
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2,  ... , k - 1, k\)[
            x\&^]\)}], "}"}]]],
  "  \n\nwill converge to  ",
  Cell[BoxData[
      \(f[x\&^]\)]],
  "  faster than any other rearrangement of the nodes."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(f[x] = \ \[ExponentialE]\^x\)]],
  "  and the nodes ",
  Cell[BoxData[
      \({x\_i = 1 + i\/4}\_\(i = 0\)\%5\)]],
  " compute the entries in Aitken's tableau and Neville's tableau for \
evaluating  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  at  ",
  Cell[BoxData[
      \(x\&^\  = \ 1.8\)]],
  "  \nUse the rearrangement of the nodes ",
  Cell[BoxData[
      RowBox[{\({x\_i}\_\(i = 0\)\%5\), " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{"1.75", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.5", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2.0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.25", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2.25", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.0"}], "}"}]}]]],
  " and the recursive subroutines. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold"]], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell["Enter the function and nodes and point of evaluation.  ", "Text"],

Cell[BoxData[{
    \(\(f[x_] = \ \[ExponentialE]\^x;\)\ \), "\[IndentingNewLine]", 
    \(\(X = {1.75, 2.0, 1.5, 2.25, 1.25, 1.0};\)\), "\[IndentingNewLine]", 
    \(\(x\_i_ := 
        X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\);\)\ \
\), "\[IndentingNewLine]", 
    \(\(x\&^\  = \ 1.8;\)\ \), "\[IndentingNewLine]", 
    \(\(nodes = Table[x\_i, {i, 0, 5}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Approximate\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], \*"\"\<  at the point  \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the nodes\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_i\)} = \>\"", 
        nodes];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Where\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{|\!\(x\_i\)-\!\(x\&^\)|} = \>\"", 
        Abs[X - x\&^]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["5 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Neville's tableau. "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(NevillePoly;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Neville's tableau is\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"TableForm", "[", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", \(x\_0\), \(P\_0[x\&^]\), "\"\<\>\"", "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {"1", \(x\_1\), \(P\_1[x\&^]\), \(P\_\(0, 1\)[x\&^]\), 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {
                      "2", \(x\_2\), \(P\_2[x\&^]\), \(P\_\(1, 2\)[
                        x\&^]\), \(P\_\(0, 1, 2\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\""},
                    {
                      "3", \(x\_3\), \(P\_3[x\&^]\), \(P\_\(2, 3\)[
                        x\&^]\), \(P\_\(1, 2, 3\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\""},
                    {
                      "4", \(x\_4\), \(P\_4[x\&^]\), \(P\_\(3, 4\)[
                        x\&^]\), \(P\_\(2, 3, 4\)[
                        x\&^]\), \(P\_\(1, 2, 3, 4\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3, 4\)[x\&^]\), "\"\<\>\""},
                    {
                      "5", \(x\_5\), \(P\_5[x\&^]\), \(P\_\(4, 5\)[
                        x\&^]\), \(P\_\(3, 4, 5\)[
                        x\&^]\), \(P\_\(2, 3, 4, 5\)[
                        x\&^]\), \(P\_\(1, 2, 3, 4, 5\)[
                        x\&^]\), \(P\_\(0, 1, 2, 3, 4, 5\)[x\&^]\)}
                    }], ")"}], 
              ",", \(TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \
\!\(x\_i\)\>\"", \*"\"\<\!\(P\_i\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(P\_\(i, j\)\
\)\>\"", \*"\"\<\!\(p\_\(i, j, k\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, \
l\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, l, m\)\)\>\"", \*"\"\<\!\(p\_\(i, j, k, \
l, m, n\)\)\>\""}}\)}], "]"}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print["\<f[x] = \>", 
        f[x]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<We have the Neville approximation\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", 
        NumberForm[P\_\(0, 1, 2, 3, 4, 5\)[x\&^], 
          7]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<It is close to the true value\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", x\&^, "\<] = \>", 
        NumberForm[f[x\&^], 7]\ ];\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Notice the ordering of the nodes in the second column. "
}], "Text"],

Cell[TextData[{
  "\tThe accuracy of the computations in Neville's tableau  improves as you \
go down the table and to the right. Without knowing where ",
  Cell[BoxData[
      \(x\&^\)]],
  " lies in relation to the nodes  ",
  Cell[BoxData[
      \({x\_i}\_\(i = 0\)\%4\)]],
  " it is difficult to determine whether the diagonal approximations are \
converging faster or the bottom row.  For illustration, consider the sequence \
",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(P\_0[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(P\_\(0, 1, 2, 3, 4\)[x\&^]\)}], 
        "}"}]]],
  " on the diagonal. "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The sequence of Neville approximations\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(P\_0\)[\!\(x\&^\)],\!\(P\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(P\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(P\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[{P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
          P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
          P\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And the error\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\&^\)]-\!\(P\_0\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(\
P\_\(0, 1\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2\)\)[\!\(x\&^\)],f[\!\
\(x\&^\)]-\!\(P\_\(0, 1, 2, 3\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2, \
3, 4\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(P\_\(0, 1, 2, 3, 4, 5\)\)[\!\(x\&^\)]} \
= \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        f[x\&^] - {P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
            P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
            P\_\(0, 1, 2, 3, 4, 5\)[
              x\&^]}, "\< \[Rule] 0\>"\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The convergence is slightly faster than in Example 3 (a) where the nodes \
were chosen in ascending order  ",
  Cell[BoxData[
      RowBox[{\({x\_i}\_\(i = 0\)\%4\), " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{"1.0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.25`", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.5`", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.75`", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2.0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2.25"}], "}"}]}]]],
  "  and the  entries on the diagonal were:  "
}], "Text"],

Cell[BoxData[
    RowBox[{\({P\_0[x\&^], P\_\(0, 1\)[x\&^], P\_\(0, 1, 2\)[x\&^], 
        P\_\(0, 1, 2, 3\)[x\&^], P\_\(0, 1, 2, 3, 4\)[x\&^], 
        P\_\(0, 1, 2, 3, 4, 5\)[x\&^]}\), "  ", "=", " ", 
      "\[IndentingNewLine]", 
      StyleBox[\({2.71828, 5.18888, 5.96076, 6.04845, 6.0497, 
            6.04964}\  \[Rule] \ 6.04965\),
        FontWeight->"Plain"]}]], "Input",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{\({f[x\&^] - P\_0[x\&^], f[x\&^] - P\_\(0, 1\)[x\&^], 
        f[x\&^] - P\_\(0, 1, 2\)[x\&^], f[x\&^] - P\_\(0, 1, 2, 3\)[x\&^], 
        f[x\&^] - P\_\(0, 1, 2, 3, 4\)[x\&^], 
        f[x\&^] - P\_\(0, 1, 2, 3, 4, 5\)[x\&^]}\), " ", "=", " ", 
      "\[IndentingNewLine]", 
      StyleBox[\({3.33137, 0.86077, 0.0888869, 0.00119311, \(-0.0000522557\), 
            4.3387\[Times]10\^\(-6\)}\  \[Rule] \ 0\),
        FontWeight->"Plain"]}]], "Input",
  Evaluatable->False],

Cell[TextData[{
  "The Neville polynomials  ",
  Cell[BoxData[
      \({P\_0[x], P\_\(0, 1\)[x], P\_\(0, 1, 2\)[x], P\_\(0, 1, 2, 3\)[x], 
        P\_\(0, 1, 2, 3, 4\)[x]}\)]],
  "  are converging to  ",
  Cell[BoxData[
      \(f[x]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(dots = 
        ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}}, 
          PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr7\  = \ 
        Plot[{f[x], P\_0[x], P\_\(0, 1\)[x], P\_\(0, 1, 2\)[x]}, {x, 1, 
            2.25}, PlotStyle \[Rule] {Magenta, Red, Green, Blue}, 
          AxesOrigin \[Rule] {1, 0}, 
          Ticks \[Rule] {Range[1, 2.25, 0.25], Range[0, 9, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr7, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<   f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(P\_0\)[x] = \>\"", 
        P\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(P\_\(0, 1\)\)[x] = \>\"", 
        Expand[P\_\(0, 1\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(P\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[P\_\(0, 1, 2\)[x]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["5 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Aitken's tableau. "
}], "Text"],

Cell[BoxData[{\(AitkenPoly;\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Aitken's tableau is\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"TableForm", "[", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"0", \(x\_0\), \(Q\_0[x\&^]\), "\"\<\>\"", "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {"1", \(x\_1\), \(Q\_1[x\&^]\), \(Q\_\(0, 1\)[x\&^]\), 
                      "\"\<\>\"", "\"\<\>\"", "\"\<\>\"", "\"\<\>\""},
                    {
                      "2", \(x\_2\), \(Q\_2[x\&^]\), \(Q\_\(0, 2\)[
                        x\&^]\), \(Q\_\(0, 1, 2\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\"", "\"\<\>\""},
                    {
                      "3", \(x\_3\), \(Q\_3[x\&^]\), \(Q\_\(0, 3\)[
                        x\&^]\), \(Q\_\(0, 1, 3\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3\)[x\&^]\), "\"\<\>\"", 
                      "\"\<\>\""},
                    {
                      "4", \(x\_4\), \(Q\_4[x\&^]\), \(Q\_\(0, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 4\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 4\)[x\&^]\), "\"\<\>\""},
                    {
                      "5", \(x\_5\), \(Q\_5[x\&^]\), \(Q\_\(0, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 5\)[
                        x\&^]\), \(Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]\)}
                    }], ")"}], 
              ",", \(TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \
\!\(x\_i\)\>\"", \*"\"\<\!\(Q\_i\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(Q\_\(0, i\)\
\)\>\"", \*"\"\<\!\(Q\_\(0, 1, i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, \
i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, 3, i\)\)\>\"", \*"\"\<\!\(Q\_\(0, 1, 2, \
3, 4, i\)\)\>\""}}\)}], "]"}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", \(Print["\<f[x] = \>", 
        f[x]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<We have the Aitken approximation\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", 
        NumberForm[Q\_\(0, 1, 2, 3, 4, 5\)[x\&^], 
          7]\ ];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<It is close to the true value\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<f[\>", x\&^, "\<] = \>", 
        NumberForm[f[x\&^], 7]\ ];\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Notice the ordering of the nodes in the second column. "
}], "Text"],

Cell[TextData[{
  "\tThe accuracy of the computations in Aitken's tableau  improves as you go \
down the table and to the right. Without knowing where ",
  Cell[BoxData[
      \(x\&^\)]],
  " lies in relation to the nodes  ",
  Cell[BoxData[
      \({x\_i}\_\(i = 0\)\%4\)]],
  " it is difficult to determine whether the diagonal approximations are \
converging faster or the bottom row.  For illustration, consider the sequence \
",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(Q\_0[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3\)[x\&^]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3, 4\)[x\&^]\)}], 
        "}"}]]],
  " on the diagonal. "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The sequence of Aitken approximations\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(Q\_0\)[\!\(x\&^\)],\!\(Q\_\(0, 1\)\)[\!\(x\&^\)],\!\
\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, \
3\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, 4\)\)[\!\(x\&^\)],\!\(Q\_\(0, 1, 2, 3, \
4, 5\)\)[\!\(x\&^\)]} = \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[{Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
          Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
          Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]}, "\< \[Rule] \>", 
        f[x\&^]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And the error\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\&^\)]-\!\(Q\_0\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(\
Q\_\(0, 1\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2\)\)[\!\(x\&^\)],f[\!\
\(x\&^\)]-\!\(Q\_\(0, 1, 2, 3\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2, \
3, 4\)\)[\!\(x\&^\)],f[\!\(x\&^\)]-\!\(Q\_\(0, 1, 2, 3, 4, 5\)\)[\!\(x\&^\)]} \
= \>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        f[x\&^] - {Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
            Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
            Q\_\(0, 1, 2, 3, 4, 5\)[
              x\&^]}, "\< \[Rule] 0\>"\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The convergence is slightly faster than in Example 3 (b) where the nodes \
were chosen in ascending order  ",
  Cell[BoxData[
      RowBox[{\({x\_i}\_\(i = 0\)\%4\), " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{"1.0", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.25`", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.5`", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "1.75`", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "2.0"}], "}"}]}]]],
  "  and the  entries on the diagonal were:  "
}], "Text"],

Cell[BoxData[
    RowBox[{\({Q\_0[x\&^], Q\_\(0, 1\)[x\&^], Q\_\(0, 1, 2\)[x\&^], 
        Q\_\(0, 1, 2, 3\)[x\&^], Q\_\(0, 1, 2, 3, 4\)[x\&^], 
        Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]}\), " ", "=", " ", 
      "\[IndentingNewLine]", 
      StyleBox[\({2.71828, 5.18888, 5.96076, 6.04845, 6.0497, 
            6.04964}\  \[Rule] \ 6.04965\),
        FontWeight->"Plain"]}]], "Input",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{\({f[x\&^] - Q\_0[x\&^], f[x\&^] - Q\_\(0, 1\)[x\&^], 
        f[x\&^] - Q\_\(0, 1, 2\)[x\&^], f[x\&^] - Q\_\(0, 1, 2, 3\)[x\&^], 
        f[x\&^] - Q\_\(0, 1, 2, 3, 4\)[x\&^], 
        f[x\&^] - Q\_\(0, 1, 2, 3, 4, 5\)[x\&^]}\), " ", "=", " ", 
      "\[IndentingNewLine]", 
      StyleBox[\({3.33137, 0.86077, 0.0888869, 0.00119311, \(-0.0000522557\), 
            4.3387\[Times]10\^\(-6\)}\  \[Rule] \ 0\),
        FontWeight->"Plain"]}]], "Input",
  Evaluatable->False],

Cell[TextData[{
  "The Aitken polynomials  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(Q\_0[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3\)[x]\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(Q\_\(0, 1, 2, 3, 4\)[x]\)}], "}"}]]],
  "  are converging to  ",
  Cell[BoxData[
      \(f[x]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(dots = 
        ListPlot[{{x\_0, f[x\_0]}, {x\_1, f[x\_1]}, {x\_2, f[x\_2]}}, 
          PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr8\  = \ 
        Plot[{f[x], Q\_0[x], Q\_\(0, 1\)[x], Q\_\(0, 1, 2\)[x]}, {x, 1, 2}, 
          PlotStyle \[Rule] {Magenta, Red, Green, Blue}, 
          AxesOrigin \[Rule] {1, 0}, 
          Ticks \[Rule] {Range[0, 2, 0.25], Range[0, 9, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr8, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<   f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(Q\_0\)[x] = \>\"", 
        Q\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(Q\_\(0, 1\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1\)[x]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Q\_\(0, 1, 2\)\)[x] = \>\"", 
        Expand[Q\_\(0, 1, 2\)[x]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Improved Interpolation Tableau",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe tables for Aitken's and Neville's methods can be stored in a \
two-dimensional array and do not need long subscript lists as shown in the \
following tables.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Neville's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NevillesAlgorithm.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  In each new elements is computed using the element in the {same row, \
preceding column} and {preceding row, preceding column}. \n\n\t",
  Cell[BoxData[GridBox[{
          {
            StyleBox[GridBox[{
                  {
                    SubscriptBox["x", 
                      RowBox[{"0", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"1", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"2", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"3", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"4", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"5", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]}
                  }],
              FontWeight->"Bold"], 
            StyleBox[GridBox[{
                  {\(p\_\(0, 0\)\), " ", " ", " ", " ", " "},
                  {\(p\_\(1, 0\)\), \(p\_\(1, 1\)\), " ", " ", " ", " "},
                  {\(p\_\(2, 0\)\), \(p\_\(2, 1\)\), \(p\_\(2, 2\)\), " ", 
                    " ", " "},
                  {\(p\_\(3, 0\)\), \(p\_\(3, 1\)\), \(p\_\(3, 
                        2\)\), \(p\_\(3, 3\)\), " ", " "},
                  {\(p\_\(4, 0\)\), \(p\_\(4, 1\)\), \(p\_\(4, 
                        2\)\), \(p\_\(4, 3\)\), \(p\_\(4, 4\)\), " "},
                  {\(p\_\(5, 0\)\), \(p\_\(5, 1\)\), \(p\_\(5, 
                        2\)\), \(p\_\(5, 3\)\), \(p\_\(5, 4\)\), \(p\_\(5, 
                        5\)\)}
                  }],
              FontWeight->"Bold"], 
            StyleBox[GridBox[{
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"0", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"1", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"2", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"3", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"4", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"5", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]}
                  }],
              FontWeight->"Bold"]}
          },
        ColumnLines->True]]],
  "   \n\t\n",
  StyleBox["Table 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  ButtonBox["Neville's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NevillesAlgorithm.html"], None},
    ButtonStyle->"Hyperlink"],
  "   ",
  Cell[BoxData[
      StyleBox[
        RowBox[{\(p\_\(i, j\)\), " ", "=", " ", 
          RowBox[{\(1\/\(x\_i - x\_\(i - j\)\)\), "|", GridBox[{
                {\(p\_\(i - 1, j - 1\)\), \(x\_\(i - j\) - x\&^\)},
                {\(p\_\(i, j - 1\)\), \(x\_i - x\&^\)}
                }], "|"}]}],
        FontWeight->"Bold"]]],
  "    for    ",
  Cell[BoxData[
      StyleBox[\(1 < j \[LessEqual] i\),
        FontWeight->"Bold"]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Aitken's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/AitkenInterpolation.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  In each new elements is computed using the element in the {same row, \
preceding column} and {top row, preceding column}. \n\n\t",
  Cell[BoxData[GridBox[{
          {
            StyleBox[GridBox[{
                  {
                    SubscriptBox["x", 
                      RowBox[{"0", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"1", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"2", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"3", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"4", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]},
                  {
                    SubscriptBox["x", 
                      RowBox[{"5", 
                        StyleBox[",",
                          FontColor->GrayLevel[1]]}]]}
                  }],
              FontWeight->"Bold"], 
            StyleBox[GridBox[{
                  {\(q\_\(0, 0\)\), " ", " ", " ", " ", " "},
                  {\(q\_\(1, 0\)\), \(q\_\(1, 1\)\), " ", " ", " ", " "},
                  {\(q\_\(2, 0\)\), \(q\_\(2, 1\)\), \(q\_\(2, 2\)\), " ", 
                    " ", " "},
                  {\(q\_\(3, 0\)\), \(q\_\(3, 1\)\), \(q\_\(3, 
                        2\)\), \(q\_\(3, 3\)\), " ", " "},
                  {\(q\_\(4, 0\)\), \(q\_\(4, 1\)\), \(q\_\(4, 
                        2\)\), \(q\_\(4, 3\)\), \(q\_\(4, 4\)\), " "},
                  {\(q\_\(5, 0\)\), \(q\_\(5, 1\)\), \(q\_\(5, 
                        2\)\), \(q\_\(5, 3\)\), \(q\_\(5, 4\)\), \(q\_\(5, 
                        5\)\)}
                  }],
              FontWeight->"Bold"], 
            StyleBox[GridBox[{
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"0", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"1", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"2", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"3", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"4", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]},
                  {
                    RowBox[{
                      SubscriptBox["x", 
                        RowBox[{"5", 
                          StyleBox[",",
                            FontColor->GrayLevel[1]]}]], "-", \(x\&^\)}]}
                  }],
              FontWeight->"Bold"]}
          },
        ColumnLines->True]]],
  "   \n\t\n",
  StyleBox["Table 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  ButtonBox["Aitken's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/AitkenInterpolation.html"], None},
    ButtonStyle->"Hyperlink"],
  "   ",
  Cell[BoxData[
      StyleBox[
        RowBox[{\(q\_\(i, j\)\), " ", "=", " ", 
          RowBox[{\(1\/\(x\_i - x\_\(j - 1\)\)\), "|", GridBox[{
                {\(q\_\(j - 1, j - 1\)\), \(x\_\(j - 1\) - x\&^\)},
                {\(q\_\(i, j - 1\)\), \(x\_i - x\&^\)}
                }], "|"}]}],
        FontWeight->"Bold"]]],
  "    for    ",
  Cell[BoxData[
      StyleBox[\(1 < j \[LessEqual] i\),
        FontWeight->"Bold"]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Aitken's and Neville's Interpolation Methods",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Neville Interpolation).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(NevilleInterpolation[X0_, z_]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({i, j, n = Length[X0] - 1, X = X0}\), ",", 
            "\[IndentingNewLine]", 
            
            RowBox[{\(x\_i_ := 
                X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\
\)\)\), ";", "\[IndentingNewLine]", \(p\_\(i_, 0\) := f[x\_i]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
                
                RowBox[{\(i = 1\), ",", \(i \[LessEqual] \ n\), ",", \(i++\), 
                  ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"For", "[", 
                      
                      RowBox[{\(j = 1\), ",", \(j \[LessEqual] \ i\), 
                        ",", \(j++\), ",", "\[IndentingNewLine]", 
                        RowBox[{
                          RowBox[{\(p\_\(i, j\)\), ":=", 
                            RowBox[{"Release", "[", " ", 
                              RowBox[{\(1\/\(x\_i - x\_\(i - j\)\)\), 
                                RowBox[{"Det", "[", 
                                  RowBox[{"(", GridBox[{
                                        {\(p\_\(i - 1, 
                                        j - 1\)\), \(x\_\(i - j\) - z\)},
                                        {\(p\_\(i, j - 1\)\), \(x\_i - z\)}
                                        }], ")"}], "]"}]}], "]"}]}], ";"}]}], 
                      " ", "]"}], ";"}]}], "  ", "]"}], ";", "  ", 
              "\[IndentingNewLine]", \(k = i - 1\), ";"}]}], "]"}]}], 
      ";"}]], "Input"],

Cell[TextData[StyleBox["Mathematica Subroutine (Aitken Interpolation).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(AitkenInterpolation[X0_, z_]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({i, j, n = Length[X0] - 1, X = X0}\), ",", 
            "\[IndentingNewLine]", 
            
            RowBox[{\(x\_i_ := 
                X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\
\)\)\), ";", "\[IndentingNewLine]", \(q\_\(i_, 0\) := f[x\_i]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
                
                RowBox[{\(i = 1\), ",", \(i \[LessEqual] \ n\), ",", \(i++\), 
                  ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"For", "[", 
                      
                      RowBox[{\(j = 1\), ",", \(j \[LessEqual] \ i\), 
                        ",", \(j++\), ",", "\[IndentingNewLine]", 
                        RowBox[{
                          RowBox[{\(q\_\(i, j\)\), ":=", " ", 
                            RowBox[{"Release", "[", 
                              RowBox[{\(1\/\(x\_i - x\_\(j - 1\)\)\), 
                                RowBox[{"Det", "[", 
                                  RowBox[{"(", GridBox[{
                                        {\(q\_\(j - 1, 
                                        j - 1\)\), \(x\_\(j - 1\) - z\)},
                                        {\(q\_\(i, j - 1\)\), \(x\_i - z\)}
                                        }], ")"}], "]"}]}], "]"}]}], ";"}]}], 
                      " ", "]"}], ";"}]}], "  ", "]"}], ";", "  ", 
              "\[IndentingNewLine]", \(k = i - 1\), ";"}]}], "]"}]}], 
      ";"}]], "Input"],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(f[x] = \ BesselJ[0, x]\)]],
  "  and the nodes ",
  Cell[BoxData[
      \({x\_i\  = \ i*0.5}\_\(i = 0\)\%5\)]],
  " compute the entries in Aitken's tableau and Neville's tableau for \
evaluating  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  at  ",
  Cell[BoxData[
      \(x\&^\  = \ 1.8\)]],
  "  \nUse the improved interpolation subroutines. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold"]], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell["Enter the function and nodes and point of evaluation.  ", "Text"],

Cell[BoxData[{
    \(\(f[x_] = \ BesselJ[0, x];\)\ \), "\[IndentingNewLine]", 
    \(\(X = Table[0.0 + i*0.5, {i, 0, 5}];\)\ \), "\[IndentingNewLine]", 
    \(\(x\&^\  = \ 1.8;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Approximate\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], \*"\"\<  at the point  \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the nodes\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_i\)} = \>\"", X];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["6 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Neville's tableau. "
}], "Text"],

Cell[BoxData[{
    \(\(NevilleInterpolation[X, x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Ntable = 
        Table["\<\>", {i, 1, 6}, {j, 1, 6}];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          6, \(i++\), \[IndentingNewLine]\(For[j = 1, 
            j \[LessEqual] 
              i, \(j++\), \ \(Ntable\_\(\(\[LeftDoubleBracket]\)\(i, j\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                p\_\(i - 1, j - 1\);\)\ ];\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(sub = Table[{i}, {i, 1, 6}];\)\ \), "\[IndentingNewLine]", 
    \(\(Ntable = 
        AppendRows[sub, 
          AppendRows[Partition[X, 1], Ntable]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Neville's tableau is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[Ntable, 
          TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \!\(x\_i\)\>\"", \*"\
\"\<\!\(p\_\(i, 0\)\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(p\_\(i, 1\)\)\>\"", \
\*"\"\<\!\(p\_\(i, 2\)\)\>\"", \*"\"\<\!\(p\_\(i, 3\)\)\>\"", \
\*"\"\<\!\(p\_\(i, 4\)\)\>\"", \*"\"\<\!\(p\_\(i, 5\)\)\>\""}}]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<We have the Neville approximation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", "\<p\>"\_\(5, 5\), "\< = \>", 
        p\_\(5, 5\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It is close to the true value\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\&^, "\<] = \>", f[x\&^]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["6 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Aitken's tableau. "
}], "Text"],

Cell[BoxData[{
    \(\(AitkenInterpolation[X, x\&^\ ];\)\), "\n", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Atable = 
        Table["\<\>", {i, 1, 6}, {j, 1, 6}];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          6, \(i++\), \[IndentingNewLine]\(For[j = 1, 
            j \[LessEqual] 
              i, \(j++\), \ \(Atable\_\(\(\[LeftDoubleBracket]\)\(i, j\)\(\
\[RightDoubleBracket]\)\)\  = \ 
                q\_\(i - 1, j - 1\);\)\ ];\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(sub = Table[{i}, {i, 1, 6}];\)\ \), "\[IndentingNewLine]", 
    \(\(Atable = 
        AppendRows[sub, 
          AppendRows[Partition[X, 1], Atable]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Aitken's tableau is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[Atable, 
          TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \!\(x\_i\)\>\"", \*"\
\"\<\!\(p\_\(i, 0\)\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(p\_\(i, 1\)\)\>\"", \
\*"\"\<\!\(p\_\(i, 2\)\)\>\"", \*"\"\<\!\(p\_\(i, 3\)\)\>\"", \
\*"\"\<\!\(p\_\(i, 4\)\)\>\"", \*"\"\<\!\(p\_\(i, 5\)\)\>\""}}]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<We have the Aitken approximation\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", "\<q\>"\_\(5, 5\), "\< = \>", 
        q\_\(5, 5\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It is close to the true value\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\&^, "\<] = \>", f[x\&^]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Improved Subroutines using Matrices",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe subroutines for Aitken's and Neville's methods can be modified \
to use matrices, this is the final improvement. "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (Neville Interpolation).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   Given the nodes ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          
          RowBox[{\(X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[
              X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\)\
}], "}"}], \(i = 1\), "k"]]],
  " the Neville interpolation at ",
  Cell[BoxData[
      \(x = z\)]],
  " is  ",
  Cell[BoxData[
      \(P\_\(\(\[LeftDoubleBracket]\)\(k, k\)\(\[RightDoubleBracket]\)\)\)]],
  " where we compute: \n\n\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(For\ \ i = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "k"}], "  "}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "     ", \(P\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\) = 
          f[X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\), 
        " ", "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(For\ \ i = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(k - 1\)}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{"     ", 
        RowBox[{\(For\ \ j = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "i"}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{"          ", 
        RowBox[{\(P\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
              j + 1\)\(\[RightDoubleBracket]\)\)\), "=", " ", 
          
          RowBox[{\(1\/\(X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\
\[RightDoubleBracket]\)\) - 
                  X\_\(\(\[LeftDoubleBracket]\)\(i - j + 1\)\(\
\[RightDoubleBracket]\)\)\)\), "|", GridBox[{
                {\(P\_\(\(\[LeftDoubleBracket]\)\(i, 
                      j\)\(\[RightDoubleBracket]\)\)\), \(X\_\(\(\
\[LeftDoubleBracket]\)\(i - j + 1\)\(\[RightDoubleBracket]\)\) - z\)},
                {\(P\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
                      j\)\(\[RightDoubleBracket]\)\)\), \(X\_\(\(\
\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\) - z\)}
                }], "|"}]}]}]}]],
  "    "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Neville Interpolation",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Neville Interpolation).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Neville[X_, z_]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({i, j, k = Length[X]}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(P = Table["\<\>", {k}, {k}]\), ";", 
              "\[IndentingNewLine]", \(For[i = 1, 
                i \[LessEqual] 
                  k, \(i++\), \ \ \(P\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\) = 
                    f[X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)];\)\ ]\), ";", "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
                
                RowBox[{\(i = 1\), ",", \(i \[LessEqual] \ k - 1\), 
                  ",", \(i++\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"For", "[", 
                      
                      RowBox[{\(j = 1\), ",", \(j \[LessEqual] \ i\), 
                        ",", \(j++\), ",", "\[IndentingNewLine]", 
                        RowBox[{
                          
                          RowBox[{\(P\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
                                j + 1\)\(\[RightDoubleBracket]\)\)\), "=", 
                            " ", 
                            
                            RowBox[{\(1\/\(X\_\(\(\[LeftDoubleBracket]\)\(i + \
1\)\(\[RightDoubleBracket]\)\) - 
                                    X\_\(\(\[LeftDoubleBracket]\)\(i - j + \
1\)\(\[RightDoubleBracket]\)\)\)\), 
                              RowBox[{"Det", "[", 
                                RowBox[{"(", GridBox[{
                                      {\(P\_\(\(\[LeftDoubleBracket]\)\(i, 
                                        j\)\(\[RightDoubleBracket]\)\)\), \(X\
\_\(\(\[LeftDoubleBracket]\)\(i - j + 1\)\(\[RightDoubleBracket]\)\) - z\)},
                                      {\(P\_\(\(\[LeftDoubleBracket]\)\(i + 
                                        1, j\)\(\[RightDoubleBracket]\)\)\), \
\(X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\) - z\)}
                                      }], ")"}], "]"}]}]}], ";"}]}], " ", 
                      "]"}], ";"}]}], "  ", "]"}], ";"}]}], "  ", "]"}]}], 
      ";"}]], "Input"],

Cell[TextData[{
  StyleBox["Algorithm (Aitken Interpolation).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "   Given the nodes ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          
          RowBox[{\(X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\)\), 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(f[
              X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\)\
}], "}"}], \(i = 1\), "k"]]],
  " the Aitken interpolation at ",
  Cell[BoxData[
      \(x = z\)]],
  " is  ",
  Cell[BoxData[
      \(Q\_\(\(\[LeftDoubleBracket]\)\(k, k\)\(\[RightDoubleBracket]\)\)\)]],
  " where we compute: \n\n\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(For\ \ i = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["k",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], " "}], "\[IndentingNewLine]", 
      RowBox[{
        "     ", \(Q\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\) = 
          f[X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\), 
        "\[IndentingNewLine]"}], "\n", 
      RowBox[{
        RowBox[{\(For\ \ i = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          RowBox[{
            StyleBox["k",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "-", "1"}]}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{"     ", 
        RowBox[{\(For\ \ j = 1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "2", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "i"}], " "}], 
    "\[IndentingNewLine]", 
      RowBox[{"          ", 
        RowBox[{\(Q\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
              j + 1\)\(\[RightDoubleBracket]\)\)\), "=", " ", 
          
          RowBox[{\(1\/\(X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\
\[RightDoubleBracket]\)\) - 
                  X\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\)\)\), "|", GridBox[{
                {\(Q\_\(\(\[LeftDoubleBracket]\)\(j, 
                      j\)\(\[RightDoubleBracket]\)\)\), \(X\_\(\(\
\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) - z\)},
                {\(Q\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
                      j\)\(\[RightDoubleBracket]\)\)\), \(X\_\(\(\
\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\) - z\)}
                }], "|"}]}]}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Aitken Interpolation",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Aitken Interpolation).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Aitken[X_, z_]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({i, j, k = Length[X]}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Q = Table["\<\>", {k}, {k}]\), ";", 
              "\[IndentingNewLine]", \(For[i = 1, 
                i \[LessEqual] 
                  k, \(i++\), \ \ \(Q\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\) = 
                    f[X\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)];\)\ ]\), ";", "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
                
                RowBox[{\(i = 1\), ",", \(i \[LessEqual] \ k - 1\), 
                  ",", \(i++\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"For", "[", 
                      
                      RowBox[{\(j = 1\), ",", \(j \[LessEqual] \ i\), 
                        ",", \(j++\), ",", "\[IndentingNewLine]", 
                        RowBox[{
                          
                          RowBox[{\(Q\_\(\(\[LeftDoubleBracket]\)\(i + 1, 
                                j + 1\)\(\[RightDoubleBracket]\)\)\), "=", 
                            " ", 
                            
                            RowBox[{\(1\/\(X\_\(\(\[LeftDoubleBracket]\)\(i + \
1\)\(\[RightDoubleBracket]\)\) - 
                                    X\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\)\)\), 
                              RowBox[{"Det", "[", 
                                RowBox[{"(", GridBox[{
                                      {\(Q\_\(\(\[LeftDoubleBracket]\)\(j, 
                                        j\)\(\[RightDoubleBracket]\)\)\), \(X\
\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) - z\)},
                                      {\(Q\_\(\(\[LeftDoubleBracket]\)\(i + 
                                        1, j\)\(\[RightDoubleBracket]\)\)\), \
\(X\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\) - z\)}
                                      }], ")"}], "]"}]}]}], ";"}]}], " ", 
                      "]"}], ";"}]}], "  ", "]"}], ";"}]}], "  ", "]"}]}], 
      ";"}]], "Input"],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(f[x] = \ BesselJ[0, x]\)]],
  "  and the nodes ",
  Cell[BoxData[
      \({x\_i\  = \ i*0.5}\_\(i = 0\)\%5\)]],
  " compute the entries in Aitken's tableau and Neville's tableau for \
evaluating  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  at  ",
  Cell[BoxData[
      \(x\&^\  = \ 1.8\)]],
  "  \nUse the improved interpolation subroutines with matrices. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold"]], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell["Enter the function and nodes and point of evaluation.  ", "Text"],

Cell[BoxData[{
    \(\(f[x_] = \ BesselJ[0, x];\)\ \), "\[IndentingNewLine]", 
    \(\(X = Table[0.0 + i*0.5, {i, 0, 5}];\)\ \), "\[IndentingNewLine]", 
    \(\(x\&^\  = \ 1.8;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Approximate\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], \*"\"\<  at the point  \!\(x\&^\) = \>\"", 
        x\&^\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the nodes\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\_i\)} = \>\"", X];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["7 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Neville's tableau. "
}], "Text"],

Cell[BoxData[{
    \(\(Neville[X, x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\n", 
    \(\(sub = Table[{i}, {i, 1, 6}];\)\ \), "\[IndentingNewLine]", 
    \(\(Ntable = 
        AppendRows[sub, 
          AppendRows[Partition[X, 1], P]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Neville's tableau is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[Ntable, 
          TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \!\(x\_i\)\>\"", \*"\
\"\<\!\(P\_\(i, 1\)\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(P\_\(i, 2\)\)\>\"", \
\*"\"\<\!\(P\_\(i, 3\)\)\>\"", \*"\"\<\!\(P\_\(i, 4\)\)\>\"", \
\*"\"\<\!\(P\_\(i, 5\)\)\>\"", \*"\"\<\!\(P\_\(i, 6\)\)\>\""}}]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<We have the Neville approximation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", "\<P\>"\_\(6, 6\), "\< = \>", 
        P\_\(\(\[LeftDoubleBracket]\)\(6, 6\)\(\[RightDoubleBracket]\)\)\ \
];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It is close to the true value\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\&^, "\<] = \>", f[x\&^]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["7 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compute the values for Aitken's tableau. "
}], "Text"],

Cell[BoxData[{
    \(\(Aitken[X, x\&^\ ];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\n", 
    \(\(sub = Table[{i}, {i, 1, 6}];\)\ \), "\[IndentingNewLine]", 
    \(\(Atable = 
        AppendRows[sub, 
          AppendRows[Partition[X, 1], Q]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Aitken's tableau is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[Atable, 
          TableHeadings \[Rule] {None, {"\<i\>", \*"\"\< \!\(x\_i\)\>\"", \*"\
\"\<\!\(Q\_\(i, 1\)\)=f[\!\(x\_i\)]\>\"", \*"\"\<\!\(Q\_\(i, 2\)\)\>\"", \
\*"\"\<\!\(Q\_\(i, 3\)\)\>\"", \*"\"\<\!\(Q\_\(i, 4\)\)\>\"", \
\*"\"\<\!\(Q\_\(i, 5\)\)\>\"", \*"\"\<\!\(Q\_\(i, 6\)\)\>\""}}]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<We have the Aitken approximation\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", 
        x\&^, "\<] \[TildeTilde] \>", "\<Q\>"\_\(6, 6\), "\< = \>", 
        Q\_\(\(\[LeftDoubleBracket]\)\(6, 6\)\(\[RightDoubleBracket]\)\)\ \
];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<It is close to the true value\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[\>", x\&^, "\<] = \>", f[x\&^]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Aitken's and Neville's Methods",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/NevilleAlgorithmBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{991, 641},
WindowMargins->{{Automatic, 9}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 224, 6, 35, "Text"],
Cell[2003, 61, 1133, 38, 140, "Text"]
}, Closed]],
Cell[3151, 102, 8886, 231, 274, "Text"],
Cell[12040, 335, 2859, 92, 187, "Text"],
Cell[14902, 429, 349, 13, 33, "Text"],
Cell[15254, 444, 669, 17, 90, "Text"],
Cell[15926, 463, 6449, 181, 316, "Text"],
Cell[22378, 646, 388, 13, 33, "Text"],
Cell[22769, 661, 4791, 127, 274, "Text"],
Cell[27563, 790, 315, 5, 52, "Text"],
Cell[27881, 797, 6365, 193, 256, "Text"],
Cell[34249, 992, 564, 19, 33, "Text"],
Cell[34816, 1013, 3013, 84, 133, "Text"],
Cell[37832, 1099, 13017, 364, 357, "Text"],
Cell[50852, 1465, 1574, 44, 129, "Text"],
Cell[52429, 1511, 379, 13, 33, "Text"],
Cell[52811, 1526, 1012, 31, 52, "Text"],

Cell[CellGroupData[{
Cell[53848, 1561, 101, 2, 33, "Text"],
Cell[53952, 1565, 413, 15, 33, "Text"],
Cell[54368, 1582, 411, 7, 90, "Input"],
Cell[54782, 1591, 107, 5, 33, "Text"],
Cell[54892, 1598, 202, 4, 72, "Input"],
Cell[55097, 1604, 193, 11, 33, "Text"],
Cell[55293, 1617, 1663, 32, 227, "Input"],
Cell[56959, 1651, 193, 11, 33, "Text"],
Cell[57155, 1664, 1564, 30, 207, "Input"],
Cell[58722, 1696, 193, 11, 33, "Text"],
Cell[58918, 1709, 1568, 30, 207, "Input"],
Cell[60489, 1741, 295, 14, 33, "Text"],
Cell[60787, 1757, 2278, 48, 264, "Input"],
Cell[63068, 1807, 295, 14, 33, "Text"],
Cell[63366, 1823, 2277, 47, 264, "Input"],
Cell[65646, 1872, 295, 14, 33, "Text"],
Cell[65944, 1888, 2249, 47, 264, "Input"],
Cell[68196, 1937, 372, 9, 90, "Text"],
Cell[68571, 1948, 349, 6, 70, "Input"],
Cell[68923, 1956, 373, 6, 70, "Input"]
}, Closed]],
Cell[69311, 1965, 555, 12, 106, "Text"],
Cell[69869, 1979, 4762, 124, 205, "Text"],
Cell[74634, 2105, 4758, 124, 224, "Text"],
Cell[79395, 2231, 388, 13, 33, "Text"],
Cell[79786, 2246, 232, 6, 71, "Text"],
Cell[80021, 2254, 384, 12, 33, "Text"],
Cell[80408, 2268, 149, 2, 33, "Text"],
Cell[80560, 2272, 2492, 49, 282, "Input"],
Cell[83055, 2323, 148, 2, 33, "Text"],
Cell[83206, 2327, 2464, 49, 278, "Input"],
Cell[85673, 2378, 491, 18, 55, "Text"],

Cell[CellGroupData[{
Cell[86189, 2400, 101, 2, 33, "Text"],
Cell[86293, 2404, 71, 0, 33, "Text"],
Cell[86367, 2406, 598, 9, 184, "Input"],
Cell[86968, 2417, 236, 9, 33, "Text"],
Cell[87207, 2428, 262, 11, 33, "Text"],
Cell[87472, 2441, 1114, 22, 134, "Input"],
Cell[88589, 2465, 120, 2, 33, "Text"],
Cell[88712, 2469, 2614, 73, 83, "Text"],
Cell[91329, 2544, 1804, 43, 45, "Input"],
Cell[93136, 2589, 2614, 73, 83, "Text"],
Cell[95753, 2664, 1292, 32, 45, "Input"],
Cell[97048, 2698, 2614, 73, 83, "Text"],
Cell[99665, 2773, 1292, 32, 45, "Input"],
Cell[100960, 2807, 3673, 95, 101, "Text"],
Cell[104636, 2904, 1312, 32, 49, "Input"],
Cell[105951, 2938, 3671, 95, 101, "Text"],
Cell[109625, 3035, 1312, 32, 49, "Input"],
Cell[110940, 3069, 4976, 122, 119, "Text"],
Cell[115919, 3193, 1324, 32, 49, "Input"],
Cell[117246, 3227, 437, 8, 110, "Input"],
Cell[117686, 3237, 235, 9, 33, "Text"],
Cell[117924, 3248, 99, 5, 33, "Text"],
Cell[118026, 3255, 1136, 23, 134, "Input"],
Cell[119165, 3280, 119, 2, 33, "Text"],
Cell[119287, 3284, 2614, 73, 83, "Text"],
Cell[121904, 3359, 1804, 43, 45, "Input"],
Cell[123711, 3404, 3820, 100, 101, "Text"],
Cell[127534, 3506, 1804, 43, 45, "Input"],
Cell[129341, 3551, 5227, 132, 119, "Text"],
Cell[134571, 3685, 1804, 43, 45, "Input"],
Cell[136378, 3730, 3808, 97, 101, "Text"],
Cell[140189, 3829, 1312, 32, 49, "Input"],
Cell[141504, 3863, 4681, 117, 119, "Text"],
Cell[146188, 3982, 1312, 32, 49, "Input"],
Cell[147503, 4016, 5030, 122, 119, "Text"],
Cell[152536, 4140, 1324, 32, 49, "Input"],
Cell[153863, 4174, 437, 8, 110, "Input"],
Cell[154303, 4184, 160, 5, 71, "Text"],
Cell[154466, 4191, 835, 12, 130, "Input"],
Cell[155304, 4205, 309, 7, 71, "Text"]
}, Closed]],
Cell[155628, 4215, 483, 18, 52, "Text"],

Cell[CellGroupData[{
Cell[156136, 4237, 101, 2, 33, "Text"],
Cell[156240, 4241, 71, 0, 33, "Text"],
Cell[156314, 4243, 598, 9, 184, "Input"],
Cell[156915, 4254, 156, 5, 33, "Text"],
Cell[157074, 4261, 2574, 49, 312, "Input"],
Cell[159651, 4312, 1799, 48, 71, "Text"],
Cell[161453, 4362, 1386, 23, 150, "Input"],
Cell[162842, 4387, 1431, 41, 33, "Text"],
Cell[164276, 4430, 1330, 24, 210, "Input"],
Cell[165609, 4456, 155, 5, 33, "Text"],
Cell[165767, 4463, 2551, 48, 312, "Input"],
Cell[168321, 4513, 1798, 48, 71, "Text"],
Cell[170122, 4563, 1385, 23, 150, "Input"],
Cell[171510, 4588, 1430, 41, 33, "Text"],
Cell[172943, 4631, 1262, 23, 190, "Input"],
Cell[174208, 4656, 593, 21, 90, "Text"],
Cell[174804, 4679, 976, 16, 90, "Input"],
Cell[175783, 4697, 652, 23, 90, "Text"],
Cell[176438, 4722, 2843, 53, 370, "Input"]
}, Closed]],
Cell[179296, 4778, 479, 18, 49, "Text"],

Cell[CellGroupData[{
Cell[179800, 4800, 101, 2, 33, "Text"],
Cell[179904, 4804, 71, 0, 33, "Text"],
Cell[179978, 4806, 594, 9, 171, "Input"],
Cell[180575, 4817, 156, 5, 33, "Text"],
Cell[180734, 4824, 2533, 48, 312, "Input"],
Cell[183270, 4874, 1799, 48, 71, "Text"],
Cell[185072, 4924, 1386, 23, 150, "Input"],
Cell[186461, 4949, 1431, 41, 33, "Text"],
Cell[187895, 4992, 1568, 27, 250, "Input"],
Cell[189466, 5021, 155, 5, 33, "Text"],
Cell[189624, 5028, 2530, 48, 312, "Input"],
Cell[192157, 5078, 1798, 48, 71, "Text"],
Cell[193958, 5128, 1385, 23, 150, "Input"],
Cell[195346, 5153, 1430, 41, 33, "Text"],
Cell[196779, 5196, 1502, 26, 230, "Input"],
Cell[198284, 5224, 594, 21, 90, "Text"],
Cell[198881, 5247, 976, 16, 90, "Input"]
}, Closed]],
Cell[199872, 5266, 7142, 201, 296, "Text"],
Cell[207017, 5469, 3685, 103, 55, "Text"],

Cell[CellGroupData[{
Cell[210727, 5576, 101, 2, 33, "Text"],
Cell[210831, 5580, 71, 0, 33, "Text"],
Cell[210905, 5582, 919, 16, 231, "Input"],
Cell[211827, 5600, 156, 5, 33, "Text"],
Cell[211986, 5607, 2574, 49, 312, "Input"],
Cell[214563, 5658, 170, 5, 33, "Text"],
Cell[214736, 5665, 1799, 48, 71, "Text"],
Cell[216538, 5715, 1386, 23, 150, "Input"],
Cell[217927, 5740, 3431, 91, 52, "Text"],
Cell[221361, 5833, 404, 8, 50, "Input",
  Evaluatable->False],
Cell[221768, 5843, 499, 9, 50, "Input",
  Evaluatable->False],
Cell[222270, 5854, 255, 9, 33, "Text"],
Cell[222528, 5865, 1143, 21, 190, "Input"],
Cell[223674, 5888, 155, 5, 33, "Text"],
Cell[223832, 5895, 2551, 48, 312, "Input"],
Cell[226386, 5945, 170, 5, 33, "Text"],
Cell[226559, 5952, 1798, 48, 71, "Text"],
Cell[228360, 6002, 1385, 23, 150, "Input"],
Cell[229748, 6027, 2825, 75, 52, "Text"],
Cell[232576, 6104, 403, 8, 50, "Input",
  Evaluatable->False],
Cell[232982, 6114, 499, 9, 50, "Input",
  Evaluatable->False],
Cell[233484, 6125, 1430, 41, 33, "Text"],
Cell[234917, 6168, 1067, 20, 170, "Input"]
}, Closed]],
Cell[235999, 6191, 309, 7, 68, "Text"],
Cell[236311, 6200, 4752, 124, 221, "Text"],
Cell[241066, 6326, 4748, 124, 221, "Text"],
Cell[245817, 6452, 384, 12, 33, "Text"],
Cell[246204, 6466, 151, 2, 33, "Text"],
Cell[246358, 6470, 1642, 33, 177, "Input"],
Cell[248003, 6505, 150, 2, 33, "Text"],
Cell[248156, 6509, 1641, 33, 177, "Input"],
Cell[249800, 6544, 492, 18, 52, "Text"],

Cell[CellGroupData[{
Cell[250317, 6566, 101, 2, 33, "Text"],
Cell[250421, 6570, 71, 0, 33, "Text"],
Cell[250495, 6572, 533, 8, 150, "Input"],
Cell[251031, 6582, 156, 5, 33, "Text"],
Cell[251190, 6589, 1660, 33, 291, "Input"],
Cell[252853, 6624, 155, 5, 33, "Text"],
Cell[253011, 6631, 1638, 33, 291, "Input"]
}, Closed]],
Cell[254664, 6667, 268, 6, 68, "Text"],
Cell[254935, 6675, 4871, 131, 182, "Text"],
Cell[259809, 6808, 361, 12, 33, "Text"],
Cell[260173, 6822, 151, 2, 33, "Text"],
Cell[260327, 6826, 2216, 42, 152, "Input"],
Cell[262546, 6870, 5427, 147, 182, "Text"],
Cell[267976, 7019, 360, 12, 33, "Text"],
Cell[268339, 7033, 150, 2, 33, "Text"],
Cell[268492, 7037, 2199, 42, 152, "Input"],
Cell[270694, 7081, 506, 18, 52, "Text"],

Cell[CellGroupData[{
Cell[271225, 7103, 101, 2, 33, "Text"],
Cell[271329, 7107, 71, 0, 33, "Text"],
Cell[271403, 7109, 533, 8, 150, "Input"],
Cell[271939, 7119, 156, 5, 33, "Text"],
Cell[272098, 7126, 1272, 24, 230, "Input"],
Cell[273373, 7152, 155, 5, 33, "Text"],
Cell[273531, 7159, 1267, 24, 230, "Input"]
}, Closed]],
Cell[274813, 7186, 158, 3, 32, "Text"],
Cell[274974, 7191, 330, 9, 33, "Text"],
Cell[275307, 7202, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

