(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    200608,       4974]*)
(*NotebookOutlinePosition[    201301,       4998]*)
(*  CellTagsIndexPosition[    201257,       4994]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Legendre Polynomials",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  StyleBox["Numerical Methods Using Mathematica \nComplementary Supplement \n\
for ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Numerical Analysis - Numerical Methods",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" \n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["(c) ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2005",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  TextAlignment->Center]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWe have seen how Newton polynomials and Lagrange polynomials are \
used to approximate ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " on an interval ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  ".  The constructions were based on a discrete set of interpolation points \
in the interval.  We will now consider \"least squares\" approximations where \
the polynomial is \"close\" to the function throughout the interval ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  ".  Our final construction will use Legendre polynomials that were first \
studied by the French mathematician ",
  ButtonBox["Adrien-Marie Legendre",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Legendre.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " (1752-1833). \n\t\n\tGiven a set of interpolation points ",
  Cell[BoxData[
      \({\((x\_i, y\_i)\)}\_\(i = 0\)\%n\  = \ {\((x\_i, f \
\((x\_i)\))\)}\_\(i = 0\)\%n\)]],
  " the Newton polynomial and Lagrange polynomial are algebraically \
equivalent, and they are equivalent to the polynomial constructed with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in subroutine \"",
  StyleBox["InterpolatingPolynomial",
    FontFamily->"Courier New"],
  ".\"  The subroutine \"",
  StyleBox["Fit",
    FontFamily->"Courier New"],
  "\" can be used to construct the discrete least squares fit polynomial. "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Discrete Least Squares Approximation)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given a function  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " on  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["b",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "]"}]]],
  "and ",
  Cell[BoxData[
      \(n + 1\)]],
  " equally spaced nodes ",
  Cell[BoxData[
      \({x\_i = a + \(\(b - a\)\/n\) i}\_\(i = 0\)\%n\)]],
  "  and interpolation points ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          RowBox[{"(", 
            RowBox[{\(x\_i\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(f \((x\_i)\)\)}], ")"}], 
          "}"}], \(i = 0\), "n"]]],
  ".  The ",
  Cell[BoxData[
      \(n\^th\)]],
  " degree polynomial  ",
  Cell[BoxData[
      \(\(q\_n\) \((x)\)\  = \ \[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) 
            x\^\(k - 1\)\)]],
  "  is the discrete least squares interpolation fit provided that the \
coefficients  ",
  Cell[BoxData[
      \({c\_k}\_\(k = 1\)\%\(n + 1\)\)]],
  "  of  ",
  Cell[BoxData[
      \(\(q\_n\) \((x)\)\)]],
  "  minimize the sum \n\n\t\t\t",
  Cell[BoxData[
      \(\[Sum]\+\(i = 0\)\%n\((f \((x\_i)\) - \(q\_n\) \((x\_i)\))\)\^2\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Discrete Least Squares Approximation)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The polynomial  ",
  Cell[BoxData[
      \(\(q\_n\) \((x)\)\  = \ \[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) 
            x\^\(k - 1\)\)]],
  "  satisfies the ",
  Cell[BoxData[
      \(n + 1\)]],
  " equations  \n\t\n\t\t\t",
  Cell[BoxData[
      \(\(\[PartialD]\/\[PartialD]c\_j\) \(\[Sum]\+\(i = 0\)\%n\((\(q\_n\) \
\((x\_i)\) - f \((x\_i)\))\)\^2\)\ \  = \ \ 0\)]],
  "    for   ",
  Cell[BoxData[
      RowBox[{\(j = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(n + 1\)}]]],
  ".  \n\nThese equations can be simplified to obtain the normal equations \
for finding the coefficients ",
  Cell[BoxData[
      \({c\_k}\_\(k = 1\)\%\(n + 1\)\)]],
  "  \n\n\t\t\t ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\(n + 1\)\((c\_k\ \(\[Sum]\+\(i = 0\)\%n x\_i\%\(j \
+ k - 2\)\))\)\ \  = \ \ \[Sum]\+\(i = 0\)\%n f \((x\_i)\) 
            x\_i\%\(j - 1\)\)]],
  "    for   ",
  Cell[BoxData[
      RowBox[{\(j = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(n + 1\)}]]],
  ".   "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " This is the degenerate case of a ",
  ButtonBox["least squares fit",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LeastSquaresFitting.html"], None},
    ButtonStyle->"Hyperlink"],
  " (i.e. if there were  ",
  Cell[BoxData[
      \(m + 1\)]],
  " data points we would have used  ",
  Cell[BoxData[
      \(\[Sum]\+\(i = 0\)\%m\)]],
  "  instead of  ",
  Cell[BoxData[
      \(\[Sum]\+\(i = 0\)\%n\)]],
  "). \nInformation on polynomial curve fitting can be found in the module ",
  ButtonBox["Least Squares Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LeastSqPolyMod.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  StyleBox[".",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  "\tThe following example shows that if ",
  StyleBox["n+1",
    FontFamily->"Courier New"],
  " points are used to find the ",
  "discrete least squares approximation",
  " polynomial of degree ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " , then it is the same as the Newton (and Lagrange) interpolation \
polynomial that passes through the ",
  StyleBox["n+1",
    FontFamily->"Courier New"],
  " points.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compare the \"discrete interpolation polynomial\" and \"discrete least \
squares approximation\" using equally spaced nodes on the interval  ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  \n",
  StyleBox["1 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = \[ExponentialE]\^x\)]],
  ".  \n",
  StyleBox["1 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = \(\[ExponentialE]\^x\) Cos[\[Pi]\/2\ x]\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \[ExponentialE]\^x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) i, f[a + \(\(b - a\)\/n\) i]}, {i, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(p[x_] = 
        InterpolatingPolynomial[XY, x];\)\ \), "\[IndentingNewLine]", 
    \(\(p[x_] = Chop[N[Expand[p[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Fit[XY, Table[x\^\(k - 1\), {k, 1, n + 1}], 
          x];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = Chop[q[x]];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[p[x], {x, \(-1\), 1}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[q[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<            y = f[x] = \>", 
        f[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        PlotLabel \[Rule] "\<y = f[x],p[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<\n\>", "\<p[x] = \>", 
        p[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr3, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        PlotLabel \[Rule] "\<y = f[x],q[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<\n\>", "\<q[x] = \>", 
        q[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr2, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        PlotLabel \[Rule] "\<y = p[x],q[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the equallly spaced nodes \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_i\)}\>\""\_\("\<i=0\>"\)\%n, "\<  = \>", \
\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\),\
 "\<  and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\_i\)]}\>\""\_\("\<i=0\>"\)\%n, "\< = \>", \
\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\
;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the function basis set \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\^\(k - 1\)\)}\>\""\_\("\<k=1\>"\)\%\(n + 1\), "\< \
= \>", Table[x\^\(k - 1\), {k, 1, n + 1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete least squares approximation' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Observe that p[x] = q[x].\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<The constructions used the Mathematica subroutines\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<p[x] = InterpolatingPolynomial[XY,x]   and\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<q[x] = Fit[XY,Table[\!\(x\^\(k - 1\)\),{k,1,n+1}],x], \
respectively.\>\""];\)\ \)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(\[ExponentialE]\^x\) 
          Cos[\[Pi]\/2\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) i, f[a + \(\(b - a\)\/n\) i]}, {i, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(p[x_] = 
        InterpolatingPolynomial[XY, x];\)\ \), "\[IndentingNewLine]", 
    \(\(p[x_] = Chop[N[Expand[p[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Fit[XY, Table[x\^\(k - 1\), {k, 1, n + 1}], 
          x];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = Chop[q[x]];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[p[x], {x, \(-1\), 1}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[q[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<            y = f[x] = \>", 
        f[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x],p[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<\n\>", "\<p[x] = \>", 
        p[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr3, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x],q[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<\n\>", "\<q[x] = \>", 
        q[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr2, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = p[x],q[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the equallly spaced nodes \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_i\)}\>\""\_\("\<i=0\>"\)\%n, "\<  = \>", \
\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\),\
 "\<  and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\_i\)]}\>\""\_\("\<i=0\>"\)\%n, "\< = \>", \
\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\
;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the function basis set \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\^\(k - 1\)\)}\>\""\_\("\<k=1\>"\)\%\(n + 1\), "\< \
= \>", Table[x\^\(k - 1\), {k, 1, n + 1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete least squares approximation' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Observe that p[x] = q[x].\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<The constructions used the Mathematica subroutines\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<p[x] = InterpolatingPolynomial[XY,x]   and\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<q[x] = Fit[XY,Table[\!\(x\^\(k - 1\)\),{k,1,n+1}],x], \
respectively.\>\""];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compare the \"discrete interpolation polynomial\" and \"discrete least \
squares approximation\" using equally spaced nodes.  \n",
  StyleBox["2 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = Sin[\[Pi]\ x]\)]],
  "  on the interval  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  \n",
  StyleBox["2 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = ArcTan[x]\)]],
  "  on the interval  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[\[Pi]\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(a\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(n\  = \ 4;\)\), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) i, f[a + \(\(b - a\)\/n\) i]}, {i, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(p[x_] = 
        InterpolatingPolynomial[XY, x];\)\ \), "\[IndentingNewLine]", 
    \(\(p[x_] = Chop[N[Expand[p[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Fit[XY, Table[x\^\(k - 1\), {k, 1, n + 1}], 
          x];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = Chop[q[x]];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[p[x], {x, \(-1\), 1}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[q[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.25], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<            y = f[x] = \>", 
        f[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, Cdot, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.25], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x],p[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<\n\>", "\<p[x] = \>", 
        p[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr3, Cdot, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.25], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x],q[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<\n\>", "\<q[x] = \>", 
        q[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr2, Cdot, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.25], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = p[x],q[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the equallly spaced nodes \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_i\)}\>\""\_\("\<i=0\>"\)\%n, "\<  = \>", \
\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\),\
 "\<  and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\_i\)]}\>\""\_\("\<i=0\>"\)\%n, "\< = \>", \
\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\
;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the function basis set \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\^\(k - 1\)\)}\>\""\_\("\<k=1\>"\)\%\(n + 1\), "\< \
= \>", Table[x\^\(k - 1\), {k, 1, n + 1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete least squares approximation' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Observe that p[x] = q[x].\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<The constructions used the Mathematica subroutines\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<p[x] = InterpolatingPolynomial[XY,x]   and\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<q[x] = Fit[XY,Table[\!\(x\^\(k - 1\)\),{k,1,n+1}],x], \
respectively.\>\""];\)\ \)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = ArcTan[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(a\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 3;\)\ \), "\[IndentingNewLine]", 
    \(\(n\  = \ 4;\)\), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) i, f[a + \(\(b - a\)\/n\) i]}, {i, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(p[x_] = 
        InterpolatingPolynomial[XY, x];\)\ \), "\[IndentingNewLine]", 
    \(\(p[x_] = Chop[N[Expand[p[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Fit[XY, Table[x\^\(k - 1\), {k, 1, n + 1}], 
          x];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = Chop[q[x]];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[f[x], {x, 0, 3}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[p[x], {x, 0, 3}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[q[x], {x, 0, 3}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<            y = f[x] = \>", 
        f[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, Cdot, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x],p[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<\n\>", "\<p[x] = \>", 
        p[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr3, Cdot, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x],q[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x], "\<\n\>", "\<q[x] = \>", 
        q[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr2, Cdot, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        PlotLabel \[Rule] "\<y = p[x],q[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<For the equallly spaced nodes \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  {\!\(x\_i\)}\>\""\_\("\<i=0\>"\)\%n, "\<  = \>", \
\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\),\
 "\<  and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{f[\!\(x\_i\)]}\>\""\_\("\<i=0\>"\)\%n, "\< = \>", \
\(Transpose[XY]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\
;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using the function basis set \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(x\^\(k - 1\)\)}\>\""\_\("\<k=1\>"\)\%\(n + 1\), "\< \
= \>", Table[x\^\(k - 1\), {k, 1, n + 1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete least squares approximation' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Observe that p[x] = q[x].\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<The constructions used the Mathematica subroutines\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<p[x] = InterpolatingPolynomial[XY,x]   and\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<q[x] = Fit[XY,Table[\!\(x\^\(k - 1\)\),{k,1,n+1}],x], \
respectively.\>\""];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Continuous Least Squares Approximation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tAnother method for approximating  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  on an interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  "  is to find a polynomial  ",
  Cell[BoxData[
      \(\(p\_n\) \((x)\)\)]],
  " with a small average error over the entire interval.  This can be \
accomplished by integrating the square of the difference  ",
  Cell[BoxData[
      \(f[x] - p\_n[x]\)]],
  "  over  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  ".  The following derivation is done on an arbitrary interval  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  ", but we will soon see that it is advantageous to use the interval  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}], 
        "=", \([\(-1\), 1]\)}]]],
  ".  \n\n",
  StyleBox["Definition (ContinuousLeast Squares Approximation)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given a function  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " on  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["b",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "]"}]]],
  ".  The nth degree polynomial  ",
  Cell[BoxData[
      \(\(p\_n\) \((x)\)\  = \ \[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) 
            x\^\(k - 1\)\)]],
  "  is the continuous least squares fit for ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " provided that the coefficients ",
  Cell[BoxData[
      \({c\_k}\_\(k = 1\)\%\(n + 1\)\)]],
  " minimize the integral  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\_a\%b\ \(\((f[x] - p\_n[x])\)\^2\) \[DifferentialD]x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Continuous Least Squares Approximation)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The polynomial  ",
  Cell[BoxData[
      \(\(p\_n\) \((x)\)\  = \ \[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) 
            x\^\(k - 1\)\)]],
  "  satisfies the ",
  Cell[BoxData[
      \(n + 1\)]],
  " equations  \n\t\n\t\t\t",
  Cell[BoxData[
      \(\(\[PartialD]\/\[PartialD]c\_j\) \(\[Integral]\_a\%b\ \(\((\(p\_n\) \
\((x)\) - f \((x)\))\)\^2\) \[DifferentialD]x\)\ \  = \ \ 0\)]],
  "    for   ",
  Cell[BoxData[
      RowBox[{\(j = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(n + 1\)}]]],
  ".  \n\nThese equations can be simplified to obtain the normal equations \
for finding the coefficients ",
  Cell[BoxData[
      \({c\_k}\_\(k = 1\)\%\(n + 1\)\)]],
  "  \n\n\t\t\t ",
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) \(\[Integral]\_a\%b\ \(x\^\(j + 
                      k - 2\)\) \[DifferentialD]x\)\ \  = \ \ \
\[Integral]\_a\%b\ f \((x)\) \(x\^\(j - 1\)\) \[DifferentialD]x\)]],
  "    for   ",
  Cell[BoxData[
      RowBox[{\(j = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(n + 1\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Legendre Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LegendrePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Legendre Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LegendrePolyProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compare the \"discrete least squares approximation\" and \"continuous \
least squares approximation,\" on the interval  ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  \n",
  StyleBox["3 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = \[ExponentialE]\^x\)]],
  ".  \n",
  StyleBox["3 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = \(\[ExponentialE]\^x\) Cos[\[Pi]\/2\ x]\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \[ExponentialE]\^x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(eqns\  = \ 
        Table[\ \[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) \(\[Integral]\_a\%b\ \(x\
\^\(j + k - 2\)\) \[DifferentialD]x\)\ \  \[Equal] \ \ \[Integral]\_a\%b\ 
              f[x] \(x\^\(j - 1\)\) \[DifferentialD]x, {j, 1, 
            n + 1}];\)\), "\[IndentingNewLine]", 
    \(\(vars\  = \ \ Table[\ 
          c\_k, {k, 1, n + 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqns, vars];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the normal equations\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For \>", \*"\"\<{\!\(c\_k\)}\>\""\_\("\<k=1\>"\)\%\(n + 1\), \
"\< = \>", vars];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]]\
;\)\), "\[IndentingNewLine]", 
    \(\(nsolset = solset;\)\), "\[IndentingNewLine]", 
    \(\(nsolset\_\(\(\[LeftDoubleBracket]\)\(1, All, 2\)\(\
\[RightDoubleBracket]\)\) = 
        N[solset\_\(\(\[LeftDoubleBracket]\)\(1, All, 2\)\(\
\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[Partition[nsolset, 1]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(p\_n[x_] = 
        ReplaceAll[\[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) x\^\(k - 1\), 
          nsolset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
;\)\), "\[IndentingNewLine]", 
    \(\(p\_n[x_] = Chop[p\_n[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q\_n[x_] = 
        Fit[XY, Table[x\^i, {i, 0, n}], x];\)\), "\[IndentingNewLine]", 
    \(\(q\_n[x_] = Chop[q\_n[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[p\_n[x], {x, \(-1\), 1}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[q\_n[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<            y = f[x] = \>", 
        f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(p\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x], "\<\n\>", \*"\"\<\!\(p\_n\)[x] = \>\"", 
        p\_n[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr3, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(q\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x], "\<\n\>", \*"\"\<\!\(q\_n\)[x] = \>\"", 
        q\_n[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr2, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        PlotLabel \[Rule] \*"\"\<y = \!\(p\_n\)[x],\!\(q\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'continuous least squares approximation' is\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_n\)[x] = \>\"", 
        p\_n[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete least squares approximation' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_n\)[x] = \>\"", q\_n[x]];\)\ \)}], "Input"],

Cell["\<\
We are done. 

Let us investigate the linear system involved in this example. \
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(M = 
        N[LinearEquationsToMatrices[eqns, 
            vars]];\)\ \), "\[IndentingNewLine]", 
    \(\(A = 
        M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\[IndentingNewLine]", 
    \(\(B = 
        M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\[IndentingNewLine]", 
    \(\(X = LinearSolve[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The system we solved was  A X = B\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[X]];\)\ \)}], "Input"],

Cell[TextData[{
  "We are really done.  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can calculate the coefficients  ",
  Cell[BoxData[
      \({c\_i}\_\(i = 1\)\%n\)]],
  "  by directly setting up the matrix",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  " vector ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["B",
        FontWeight->"Bold"]]],
  ".  This is just for fun !  "
}], "Text"],

Cell[BoxData[{
    \(\(A = 
        Table[\ \[Integral]\_a\%b\ \(x\^\(j + k - 
                    2\)\) \[DifferentialD]x, {j, 1, n + 1}, {k, 1, 
            n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(B = 
        Table[\ \[Integral]\_a\%b\ 
            f[x] \(x\^\(j - 1\)\) \[DifferentialD]x, {j, 1, 
            n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(vars = Table[c\_i, {i, 1, n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(X = LinearSolve[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The system to solve is  A X = B\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[B], "\< = \>", 
        MatrixForm[N[B]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[X], "\< = \>", MatrixForm[N[X]]];\)\ \)}], "Input"],

Cell["This is the same as we obtained previously.  ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(\[ExponentialE]\^x\) 
          Cos[\[Pi]\/2\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a\  = \ \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(eqns\  = \ 
        Table[\ \[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) \(\[Integral]\_a\%b\ \(x\
\^\(j + k - 2\)\) \[DifferentialD]x\)\ \  \[Equal] \ \ \[Integral]\_a\%b\ 
              f[x] \(x\^\(j - 1\)\) \[DifferentialD]x, {j, 1, 
            n + 1}];\)\), "\[IndentingNewLine]", 
    \(\(vars\  = \ \ Table[\ 
          c\_k, {k, 1, n + 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqns, vars];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the normal equations\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For \>", \*"\"\<{\!\(c\_k\)}\>\""\_\("\<k=1\>"\)\%\(n + 1\), \
"\< = \>", vars];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(nsolset = solset;\)\), "\[IndentingNewLine]", 
    \(\(nsolset\_\(\(\[LeftDoubleBracket]\)\(1, All, 2\)\(\
\[RightDoubleBracket]\)\) = 
        Chop[N[solset\_\(\(\[LeftDoubleBracket]\)\(1, All, 2\)\(\
\[RightDoubleBracket]\)\)]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[Partition[nsolset, 1]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(p\_n[x_] = 
        ReplaceAll[\[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) x\^\(k - 1\), 
          nsolset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
;\)\), "\[IndentingNewLine]", 
    \(\(p\_n[x_] = Chop[p\_n[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q\_n[x_] = 
        Fit[XY, Table[x\^i, {i, 0, n}], x];\)\), "\[IndentingNewLine]", 
    \(\(q\_n[x_] = Chop[q\_n[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[p\_n[x], {x, \(-1\), 1}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[q\_n[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<            y = f[x] = \>", 
        f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(p\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x], "\<\n\>", \*"\"\<\!\(p\_n\)[x] = \>\"", 
        p\_n[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr3, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(q\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x], "\<\n\>", \*"\"\<\!\(q\_n\)[x] = \>\"", 
        q\_n[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr2, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(q\_n\)[x]\>\"", 
        PlotLabel \[Rule] \*"\"\<y = \!\(p\_n\)[x],\!\(q\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'continuous least squares approximation' is\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_n\)[x] = \>\"", 
        p\_n[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete least squares approximation' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_n\)[x] = \>\"", q\_n[x]];\)\ \)}], "Input"],

Cell["\<\
We are done. 

Let us investigate the linear system involved in this example. \
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(M = 
        N[LinearEquationsToMatrices[eqns, 
            vars]];\)\ \), "\[IndentingNewLine]", 
    \(\(A = 
        M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\[IndentingNewLine]", 
    \(\(B = 
        Chop[M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(X = Chop[LinearSolve[A, B]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The system we solved was  A X = B\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[X]];\)\ \)}], "Input"],

Cell[TextData[{
  "We are really done.  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can calculate the coefficients  ",
  Cell[BoxData[
      \({c\_i}\_\(i = 1\)\%n\)]],
  "  by directly setting up the matrix",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  " vector ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["B",
        FontWeight->"Bold"]]],
  ".  This is just for fun !  "
}], "Text"],

Cell[BoxData[{
    \(\(A = 
        Table[\ \[Integral]\_a\%b\ \(x\^\(j + k - 
                    2\)\) \[DifferentialD]x, {j, 1, n + 1}, {k, 1, 
            n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(B = 
        Table[\ Chop[
            N[\[Integral]\_a\%b\ 
                f[x] \(x\^\(j - 1\)\) \[DifferentialD]x]], {j, 1, 
            n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(vars = Table[c\_i, {i, 1, n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(X = LinearSolve[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The system to solve is  A X = B\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[X]\ ];\)\ \)}], "Input"],

Cell["This is the same as we obtained previously.  ", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compare the \"discrete least squares approximation\" and \"continuous \
least squares approximation.\"  \n",
  StyleBox["4 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = Sin[\[Pi]\ x]\)]],
  ",  on the interval  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  \n",
  StyleBox["4 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = ArcTan[x]\)]],
  ",  on the interval  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[\[Pi]\ x];\)\ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(eqns\  = \ 
        Table[\ \[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) \(\[Integral]\_a\%b\ \(x\
\^\(j + k - 2\)\) \[DifferentialD]x\)\ \  \[Equal] \ \ \[Integral]\_a\%b\ 
              f[x] \(x\^\(j - 1\)\) \[DifferentialD]x, {j, 1, 
            n + 1}];\)\), "\[IndentingNewLine]", 
    \(\(vars\  = \ \ Table[\ 
          c\_k, {k, 1, n + 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqns, vars];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the normal equations\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For \>", \*"\"\<{\!\(c\_k\)}\>\""\_\("\<k=1\>"\)\%\(n + 1\), \
"\< = \>", vars];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]]\
;\)\), "\[IndentingNewLine]", 
    \(\(nsolset = solset;\)\), "\[IndentingNewLine]", 
    \(\(nsolset\_\(\(\[LeftDoubleBracket]\)\(1, All, 2\)\(\
\[RightDoubleBracket]\)\) = 
        N[solset\_\(\(\[LeftDoubleBracket]\)\(1, All, 2\)\(\
\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[Partition[nsolset, 1]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(p\_n[x_] = 
        ReplaceAll[\[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) x\^\(k - 1\), 
          nsolset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
;\)\), "\[IndentingNewLine]", 
    \(\(p\_n[x_] = Chop[p\_n[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q\_n[x_] = 
        Fit[XY, Table[x\^i, {i, 0, n}], x];\)\), "\[IndentingNewLine]", 
    \(\(q\_n[x_] = Chop[q\_n[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[p\_n[x], {x, \(-1\), 1}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[q\_n[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.25], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<            y = f[x] = \>", 
        f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.25], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(p\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x], "\<\n\>", \*"\"\<\!\(p\_n\)[x] = \>\"", 
        p\_n[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr3, Cdot, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.25], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(q\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x], "\<\n\>", \*"\"\<\!\(q\_n\)[x] = \>\"", 
        q\_n[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr2, Cdot, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.25], Range[0, 1, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = \!\(p\_n\)[x],\!\(q\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'continuous least squares approximation' is\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_n\)[x] = \>\"", 
        p\_n[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete least squares approximation' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_n\)[x] = \>\"", q\_n[x]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We must proceed with caution when using a least squares method because \
the linear system might be ill conditioned, i.e. the solution is highly \
sensitive to round off errors in the matrix and vector.  Let us investigate \
the situation for this example. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(M = 
        N[LinearEquationsToMatrices[eqns, 
            vars]];\)\ \), "\[IndentingNewLine]", 
    \(\(A = 
        M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\[IndentingNewLine]", 
    \(\(B = 
        M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\[IndentingNewLine]", 
    \(\(X = LinearSolve[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The system we solved was  A X = B\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[X]];\)\ \)}], "Input"],

Cell[TextData[{
  "\tThe ",
  ButtonBox["condition number",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ConditionNumber.html"], None},
    ButtonStyle->"Hyperlink"],
  " of the above system can be determined by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<The condition number of the matrix A is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Cond[A] = \>", \ 
        MatrixConditionNumber[N[A]]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Given the linear system  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["A",
            FontWeight->"Bold"], " ", 
          StyleBox["X",
            FontWeight->"Bold"]}], "=", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox[".  If   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox["  are input with machine precision then a bound for the error in \
the computed solution  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(X\&^\),
        FontWeight->"Bold"]]],
  "  ",
  StyleBox["is given by\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftDoubleBracketingBar]", 
            RowBox[{
              StyleBox["X",
                FontWeight->"Bold"], "-", 
              StyleBox[\(X\&^\),
                FontWeight->"Bold"]}], "\[RightDoubleBracketingBar]"}], "  ", 
          "\[LessEqual]", "  ", 
          RowBox[{
            RowBox[{"\[LeftDoubleBracketingBar]", 
              StyleBox[\(X\&^\),
                FontWeight->"Bold"], "\[RightDoubleBracketingBar]"}], 
            RowBox[{"Cond", "[", 
              StyleBox["A",
                FontWeight->"Bold"], "]"}]}]}], "\[Element]"}]]],
  " ",
  StyleBox["\n\nwhere ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \( \[Element] \)]],
  " ",
  StyleBox["is machine epsilon for the computer.  The computed solution  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(X\&^\),
        FontWeight->"Bold"]]],
  StyleBox["  loses about  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(log\_10\), 
        RowBox[{"Cond", "[", 
          StyleBox["A",
            FontWeight->"Bold"], "]"}]}]]],
  StyleBox["  decimal digits of accuracy relative to precision of input. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The condition number of the matrix A is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Cond[A]  =  \>", \ 
        MatrixConditionNumber[N[A]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    \[LeftDoubleBracketingBar]X\[RightDoubleBracketingBar]  \
=  \>", VectorNorm[X, 2]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      \[Epsilon]  =  \>", \ $MachineEpsilon\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \[LeftDoubleBracketingBar]X - \!\(X\&^\)\
\[RightDoubleBracketingBar] \[LessEqual]  \[LeftDoubleBracketingBar]X\
\[RightDoubleBracketingBar]*Cond[A]*\[Epsilon]\>\""\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \[LeftDoubleBracketingBar]X - \!\(X\&^\)\
\[RightDoubleBracketingBar] \[LessEqual] (\>\"", VectorNorm[X, 2], "\<)(\>", 
        MatrixConditionNumber[
          N[A]], "\<)(\>", $MachineEpsilon, "\<)\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \[LeftDoubleBracketingBar]X - \!\(X\&^\)\
\[RightDoubleBracketingBar] \[LessEqual]  \>\"", 
        VectorNorm[X, 2]*
          MatrixConditionNumber[N[A]]*$MachineEpsilon];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses extended precision sixteen digit numbers, there is a possibility \
that the solution",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(X\&^\),
        FontWeight->"Bold"]]],
  StyleBox["  might not have this much accuracy.  ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  When solving the continuous least squares approximation on the interval \
",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ", the matrix of coefficients",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "is known to be a ",
  ButtonBox["Hilbert matrix",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/HilbertMatrix.html"], None},
    ButtonStyle->"Hyperlink"],
  " which is the classic example of an ",
  ButtonBox["ill-conditioned matrix",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Ill-ConditionedMatrix.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  "We are really done.  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can calculate the coefficients  ",
  Cell[BoxData[
      \({c\_i}\_\(i = 1\)\%n\)]],
  "  by directly setting up the matrix",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  " vector ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["B",
        FontWeight->"Bold"]]],
  ".  This is just for fun !  "
}], "Text"],

Cell[BoxData[{
    \(\(A = 
        Table[\ \[Integral]\_a\%b\ \(x\^\(j + k - 
                    2\)\) \[DifferentialD]x, {j, 1, n + 1}, {k, 1, 
            n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(B = 
        Table[\ \[Integral]\_a\%b\ 
            f[x] \(x\^\(j - 1\)\) \[DifferentialD]x, {j, 1, 
            n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(vars = Table[c\_i, {i, 1, n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(X = LinearSolve[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The system to solve is  A X = B\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[B], "\< = \>", 
        MatrixForm[N[B]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[X], "\< = \>", MatrixForm[N[X]]];\)\ \)}], "Input"],

Cell["This is the same as we obtained previously.  ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = ArcTan[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 3;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(eqns\  = \ 
        Table[\ \[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) \(\[Integral]\_a\%b\ \(x\
\^\(j + k - 2\)\) \[DifferentialD]x\)\ \  \[Equal] \ \ \[Integral]\_a\%b\ 
              f[x] \(x\^\(j - 1\)\) \[DifferentialD]x, {j, 1, 
            n + 1}];\)\), "\[IndentingNewLine]", 
    \(\(eqns = MapAll[ComplexExpand, eqns];\)\ \), "\[IndentingNewLine]", 
    \(\(vars\  = \ \ Table[\ 
          c\_k, {k, 1, n + 1}];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqns, vars];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the normal equations\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For \>", \*"\"\<{\!\(c\_k\)}\>\""\_\("\<k=1\>"\)\%\(n + 1\), \
"\< = \>", vars];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]]\
;\)\), "\[IndentingNewLine]", 
    \(\(nsolset = solset;\)\), "\[IndentingNewLine]", 
    \(\(nsolset\_\(\(\[LeftDoubleBracket]\)\(1, All, 2\)\(\
\[RightDoubleBracket]\)\) = 
        N[solset\_\(\(\[LeftDoubleBracket]\)\(1, All, 2\)\(\
\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ TableForm[Partition[nsolset, 1]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(p\_n[x_] = 
        ReplaceAll[\[Sum]\+\(k = 1\)\%\(n + 1\)\(c\_k\) x\^\(k - 1\), 
          nsolset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\
;\)\), "\[IndentingNewLine]", 
    \(\(p\_n[x_] = Chop[p\_n[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q\_n[x_] = 
        Fit[XY, Table[x\^i, {i, 0, n}], x];\)\), "\[IndentingNewLine]", 
    \(\(q\_n[x_] = Chop[q\_n[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[f[x], {x, 0, 3}, PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[p\_n[x], {x, 0, 3}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[q\_n[x], {x, 0, 3}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        PlotLabel \[Rule] "\<y = f[x]\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<            y = f[x] = \>", 
        f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(p\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x], "\<\n\>", \*"\"\<\!\(p\_n\)[x] = \>\"", 
        p\_n[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr3, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = f[x],\!\(q\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x], "\<\n\>", \*"\"\<\!\(q\_n\)[x] = \>\"", 
        q\_n[x], "\<\n\>"\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr2, gr3, Cdot, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        PlotLabel \[Rule] \*"\"\<y = \!\(p\_n\)[x],\!\(q\_n\)[x]\>\"", 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'continuous least squares approximation' is\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_n\)[x] = \>\"", 
        p\_n[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete least squares approximation' is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_n\)[x] = \>\"", q\_n[x]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  We must proceed with caution when using a least squares method because \
the linear system might be ill conditioned, i.e. the solution is highly \
sensitive to round off errors in the matrix and vector.  Let us investigate \
the situation for this example. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(M = 
        N[LinearEquationsToMatrices[eqns, 
            vars]];\)\ \), "\[IndentingNewLine]", 
    \(\(A = 
        M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\[IndentingNewLine]", 
    \(\(B = 
        M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\ \), \
"\[IndentingNewLine]", 
    \(\(X = LinearSolve[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The system we solved was  A X = B\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[X]];\)\ \)}], "Input"],

Cell[TextData[{
  "\tThe ",
  ButtonBox["condition number",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/ConditionNumber.html"], None},
    ButtonStyle->"Hyperlink"],
  " of the above system can be determined by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<The condition number of the matrix A is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Cond[A] = \>", \ 
        MatrixConditionNumber[N[A]]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Given the linear system  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["A",
            FontWeight->"Bold"], " ", 
          StyleBox["X",
            FontWeight->"Bold"]}], "=", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox[".  If   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        StyleBox["B",
          FontWeight->"Bold"]}]]],
  StyleBox["  are input with machine precision then a bound for the error in \
the computed solution  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(X\&^\),
        FontWeight->"Bold"]]],
  "  ",
  StyleBox["is given by\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftDoubleBracketingBar]", 
            RowBox[{
              StyleBox["X",
                FontWeight->"Bold"], "-", 
              StyleBox[\(X\&^\),
                FontWeight->"Bold"]}], "\[RightDoubleBracketingBar]"}], "  ", 
          "\[LessEqual]", "  ", 
          RowBox[{
            RowBox[{"\[LeftDoubleBracketingBar]", 
              StyleBox[\(X\&^\),
                FontWeight->"Bold"], "\[RightDoubleBracketingBar]"}], 
            RowBox[{"Cond", "[", 
              StyleBox["A",
                FontWeight->"Bold"], "]"}]}]}], "\[Element]"}]]],
  " ",
  StyleBox["\n\nwhere ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \( \[Element] \)]],
  " ",
  StyleBox["is machine epsilon for the computer.  The computed solution  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(X\&^\),
        FontWeight->"Bold"]]],
  StyleBox["  loses about  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(log\_10\), 
        RowBox[{"Cond", "[", 
          StyleBox["A",
            FontWeight->"Bold"], "]"}]}]]],
  StyleBox["  decimal digits of accuracy relative to precision of input. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The condition number of the matrix A is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Cond[A]  =  \>", \ 
        MatrixConditionNumber[N[A]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    \[LeftDoubleBracketingBar]X\[RightDoubleBracketingBar]  \
=  \>", VectorNorm[X, 2]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      \[Epsilon]  =  \>", \ $MachineEpsilon\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \[LeftDoubleBracketingBar]X - \!\(X\&^\)\
\[RightDoubleBracketingBar] \[LessEqual]  \[LeftDoubleBracketingBar]X\
\[RightDoubleBracketingBar]*Cond[A]*\[Epsilon]\>\""\ ];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \[LeftDoubleBracketingBar]X - \!\(X\&^\)\
\[RightDoubleBracketingBar] \[LessEqual] (\>\"", VectorNorm[X, 2], "\<)(\>", 
        MatrixConditionNumber[
          N[A]], "\<)(\>", $MachineEpsilon, "\<)\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \[LeftDoubleBracketingBar]X - \!\(X\&^\)\
\[RightDoubleBracketingBar] \[LessEqual]  \>\"", 
        VectorNorm[X, 2]*
          MatrixConditionNumber[N[A]]*$MachineEpsilon];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses extended precision sixteen digit numbers, there is a possibility \
that the solution",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(X\&^\),
        FontWeight->"Bold"]]],
  StyleBox["  might not have this much accuracy.  ",
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell[TextData[{
  "We are really done.  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can calculate the coefficients  ",
  Cell[BoxData[
      \({c\_i}\_\(i = 1\)\%n\)]],
  "  by directly setting up the matrix",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold"]]],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  " vector ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox["B",
        FontWeight->"Bold"]]],
  ".  This is just for fun !  "
}], "Text"],

Cell[BoxData[{
    \(\(A = 
        Table[\ \[Integral]\_a\%b\ \(x\^\(j + k - 
                    2\)\) \[DifferentialD]x, {j, 1, n + 1}, {k, 1, 
            n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(B = 
        Table[\ Chop[
            N[\[Integral]\_a\%b\ 
                f[x] \(x\^\(j - 1\)\) \[DifferentialD]x]], {j, 1, 
            n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(vars = Table[c\_i, {i, 1, n + 1}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(X = LinearSolve[A, B];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The system to solve is  A X = B\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A], MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[B]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X = \>", MatrixForm[Partition[vars, 1]], "\< = \>", 
        MatrixForm[X]\ ];\)\ \)}], "Input"],

Cell["This is the same as we obtained previously.  ", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Orthogonal Polynomials",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tTo start we need some background regarding an the inner product.  \n\
\n",
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Inner Product",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/InnerProduct.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Consider the ",
  ButtonBox["vector space",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/VectorSpace.html"], None},
    ButtonStyle->"Hyperlink"],
  " of functions whose domain is the interval ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  ".  We define the ",
  ButtonBox["inner product of two functions",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/InnerProduct.html"], None},
    ButtonStyle->"Hyperlink"],
  " ",
  Cell[BoxData[
      RowBox[{"f", \((x)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "g", \((x)\)}]]],
  " as follows  \n\n\t\t",
  Cell[BoxData[
      \(\[LeftAngleBracket]f, g\[RightAngleBracket]\  = \ \[Integral]\_a\%b\ 
          f \((x)\) g \((x)\) \[DifferentialD]x\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Function (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Inner Product",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " To compute the inner product of two real functions over ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(\t\)\(\[LeftAngleBracket]f_, 
        g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
          g[x] \(\(\[DifferentialD]x\)\(\ \ \)\)\)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The inner product is a continuous analog to the ordinary ",
  ButtonBox["dot product",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/DotProduct.html"], None},
    ButtonStyle->"Hyperlink"],
  " that is studied in linear algebra.  If the integral is zero then ",
  Cell[BoxData[
      RowBox[{"f", \((x)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "g", \((x)\)}]]],
  " are said to be orthogonal to each other on ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  ".  All the functions we use are assumed to be square-integrable, i. e. ",
  Cell[BoxData[
      \(\[LeftAngleBracket]f, g\[RightAngleBracket]\  < \ \[Infinity]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 5 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the inner product of   ",
  Cell[BoxData[
      \(f[x] = x\^2 - 3  x + 3\)]],
  "  and  ",
  Cell[BoxData[
      \(g[x] = 2  x\^3 + x\^2 + 5  x - 5\)]],
  "  over ",
  Cell[BoxData[
      \(\([0, 2]\)\)]],
  ".  \n",
  StyleBox["5 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the inner product of   ",
  Cell[BoxData[
      \(f[x] = x\^2 - 3  x + 3\)]],
  "  and  ",
  Cell[BoxData[
      \(g[x] = 2  x\^3 + x\^2 + 5  x - 5\)]],
  "  over ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".   \n",
  StyleBox["5 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the inner product of   ",
  Cell[BoxData[
      \(f[x] = \ \(-\(1\/2\)\) + \(3\ x\^2\)\/2\)]],
  "  and  ",
  Cell[BoxData[
      \(g[x] = \(-\(\(3\ x\)\/2\)\) + \(5\ x\^3\)\/2\)]],
  "  over ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = x\^2 - 3  x + 3;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g[x_] = 2  x\^3 + x\^2 + 5  x - 5;\)\ \ \), "\[IndentingNewLine]", 
    \(\[LeftAngleBracket]f_, 
        g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
          g[x] \(\(\[DifferentialD]x\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< g[x] = \>", g[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \
\[LeftAngleBracket]\>", f[x], "\<,\>", 
        g[x], "\<\[RightAngleBracket] = \>", \[LeftAngleBracket]f, 
          g\[RightAngleBracket]\ ];\)\ \)}], "Input"],

Cell["The details of this computation.", "Text"],

Cell[BoxData[{
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = x\^2 - 3  x + 3;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g[x_] = 2  x\^3 + x\^2 + 5  x - 5;\)\ \ \), "\[IndentingNewLine]", 
    \(\(\[LeftAngleBracket]f_, 
          g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[
          x_] = \[Integral]f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[
          x_]\  = \ \[Integral]f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[LeftAngleBracket]\>", f[x], "\< , \>", 
        g[x], "\<\[RightAngleBracket]\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", f[x], "\<)(\>", 
        g[x], "\<)\[DifferentialD]x\>"];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] 
            g[x]], "\<)\[DifferentialD]x\>"];\)\ \ \ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<Find the anti-derivative\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       P[x] = \>", "\<\[Integral]\>", "\<(\>", 
        Expand[f[x] 
            g[x]], "\<)\[DifferentialD]x\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       P[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compute the definite integral\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = P[\>", b, "\<] - P[\>", 
        a, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = (\>", P[b], "\<) - (\>", 
        P[a], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]f, 
          g\[RightAngleBracket]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", \
\[LeftAngleBracket]f, g\[RightAngleBracket]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = \ 
        5\ x\^3 - 3\ x\^2 - 3\ x + 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g[x_] = 
        35\ x\^4 - 30\ x\^2 + 7\ x + 3;\)\ \ \), "\[IndentingNewLine]", 
    \(\[LeftAngleBracket]f_, 
        g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
          g[x] \(\(\[DifferentialD]x\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< g[x] = \>", g[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \
\[LeftAngleBracket]\>", f[x], "\<,\>", 
        g[x], "\<\[RightAngleBracket] = \>", \[LeftAngleBracket]f, 
          g\[RightAngleBracket]\ ];\)\ \)}], "Input"],

Cell["The details of this computation.", "Text"],

Cell[BoxData[{
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = \ 
        5\ x\^3 - 3\ x\^2 - 3\ x + 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g[x_] = 
        35\ x\^4 - 30\ x\^2 + 7\ x + 3;\)\ \ \), "\[IndentingNewLine]", 
    \(\(\[LeftAngleBracket]f_, 
          g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[
          x_] = \[Integral]f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[
          x_]\  = \ \[Integral]f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[LeftAngleBracket]\>", f[x], "\< , \>", 
        g[x], "\<\[RightAngleBracket]\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", f[x], "\<)(\>", 
        g[x], "\<)\[DifferentialD]x\>"];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] 
            g[x]], "\<)\[DifferentialD]x\>"];\)\ \ \ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<Find the anti-derivative\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       P[x] = \>", "\<\[Integral]\>", "\<(\>", 
        Expand[f[x] 
            g[x]], "\<)\[DifferentialD]x\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       P[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compute the definite integral\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = P[\>", b, "\<] - P[\>", 
        a, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = (\>", P[b], "\<) - (\>", 
        P[a], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]f, 
          g\[RightAngleBracket]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", \
\[LeftAngleBracket]f, g\[RightAngleBracket]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(f[
          x_] = \ \(-\(1\/2\)\) + \(3\ x\^2\)\/2;\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(g[
          x_] = \(-\(\(3\ x\)\/2\)\) + \(5\ x\^3\)\/2;\)\ \ \), "\
\[IndentingNewLine]", 
    \(\[LeftAngleBracket]f_, 
        g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
          g[x] \(\(\[DifferentialD]\)\(x\)\(\ \ \)\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< g[x] = \>", g[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \
\[LeftAngleBracket]\>", f[x], "\<,\>", 
        g[x], "\<\[RightAngleBracket] = \>", \[LeftAngleBracket]f, 
          g\[RightAngleBracket]\ ];\)\ \)}], "Input"],

Cell["The details of this computation.", "Text"],

Cell[BoxData[{
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(f[
          x_] = \ \(-\(1\/2\)\) + \(3\ x\^2\)\/2;\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(g[
          x_] = \(-\(\(3\ x\)\/2\)\) + \(5\ x\^3\)\/2;\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(\[LeftAngleBracket]f_, 
          g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[
          x_] = \[Integral]f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[
          x_]\  = \ \[Integral]f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[LeftAngleBracket]\>", f[x], "\< , \>", 
        g[x], "\<\[RightAngleBracket]\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", f[x], "\<)(\>", 
        g[x], "\<)\[DifferentialD]x\>"];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] 
            g[x]], "\<)\[DifferentialD]x\>"];\)\ \ \ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<Find the anti-derivative\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       P[x] = \>", "\<\[Integral]\>", "\<(\>", 
        Expand[f[x] 
            g[x]], "\<)\[DifferentialD]x\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<       P[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compute the definite integral\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = P[\>", b, "\<] - P[\>", 
        a, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = (\>", P[b], "\<) - (\>", 
        P[a], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[f[x] g[x]], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]f, 
          g\[RightAngleBracket]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[LeftAngleBracket]f[x],g[x]\[RightAngleBracket] = \>", \
\[LeftAngleBracket]f, g\[RightAngleBracket]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The endpoints of the interval are important,  if we change  ",
  Cell[BoxData[
      \(\([0, 2]\)\)]],
  "  to  ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  "  we will get a different answer which will be discussed in the next \
example."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the ",
  ButtonBox["Legendre polynomials",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LegendrePolynomial.html"], None},
    ButtonStyle->"Hyperlink"],
  "  ",
  Cell[BoxData[
      \(p\_0[x]\  = \ 1\)]],
  ",  ",
  Cell[BoxData[
      \(p\_1[x]\  = \ x\)]],
  ",  ",
  Cell[BoxData[
      \(p\_2[x]\  = \ \(-\(1\/2\)\) + \(3\ x\^2\)\/2\)]],
  ",  ",
  Cell[BoxData[
      \(p\_3[x]\  = \ \(-\(\(3\ x\)\/2\)\) + \(5\ x\^3\)\/2\)]],
  ",  ",
  Cell[BoxData[
      \(p\_4[x]\  = \ 3\/8 - \(15\ x\^2\)\/4 + \(35\ x\^4\)\/8\)]],
  "  and  ",
  Cell[BoxData[
      \(p\_5[x]\  = \ \(15\ x\)\/8 - \(35\ x\^3\)\/4 + \(63\ x\^5\)\/8\)]],
  "  are ",
  ButtonBox["orthogonal",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/OrthogonalPolynomials.html"], None},
    ButtonStyle->"Hyperlink"],
  " on ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(For[i = 0, 
        i \[LessEqual] 5, \(i++\), \[IndentingNewLine]p\_i[x_] = 
          LegendreP[i, 
            x]; \ \ \ \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = \>", 
          p\_i[x]\ ];\ \ ];\)\)}], "Input"],

Cell[TextData[{
  "For  ",
  Cell[BoxData[
      RowBox[{\(p\_0[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(p\_1[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(p\_2[x]\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(p\_3[x]\)}]}]]],
  " we have.  "
}], "Text"],

Cell[BoxData[{
    \(\(n = 3;\)\), "\[IndentingNewLine]", 
    \(\(\[LeftAngleBracket]f_, 
          g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\n", 
    \(\(For[i = 0, 
        i \[LessEqual] 
          n - 1, \(i++\), \[IndentingNewLine]Print["\<\>"]; \ \
\[IndentingNewLine]For[j = i + 1, 
          j \[LessEqual] 
            n, \(j++\), \[IndentingNewLine]\(Print["\<\[LeftAngleBracket]\>", \
"\<p\>"\_i, "\<[x],\>", "\<p\>"\_j, "\<[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", p\_i[x], "\<)(\>", 
              p\_j[x], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]p\_i, 
                p\_j\[RightAngleBracket]\ ];\)\ \ \ ];\ ];\)\)}], "Input"],

Cell[TextData[{
  "The details for showing that ",
  Cell[BoxData[
      RowBox[{\(p\_2[x]\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(p\_3[x]\)}]]],
  " are orthogonal are given below.  "
}], "Text"],

Cell[BoxData[{
    \(\(\[LeftAngleBracket]f_, 
          g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(p\_2[x_] = LegendreP[2, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(p\_3[x_] = LegendreP[3, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[
          x_] = \[Integral]p\_2[x] 
            p\_3[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(P[
          x_]\  = \ \[Integral]p\_2[x] 
            p\_3[x] \[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(p\_2\)[x],\!\(p\_3\)[x]\
\[RightAngleBracket] = \>\"", "\<\[LeftAngleBracket]\>", p\_2[x], "\< , \>", 
        p\_3[x], "\<\[RightAngleBracket]\>"];\)\ \ \), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(p\_2\)[x],\!\(p\_3\)[x]\
\[RightAngleBracket] = \>\"", "\<\[Integral]\>"\+a\%b, "\<(\>", 
        p\_2[x], "\<)(\>", 
        p\_3[x], "\<)\[DifferentialD]x\>"];\)\ \ \ \), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(p\_2\)[x],\!\(p\_3\)[x]\
\[RightAngleBracket] = \>\"", "\<\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[p\_2[x] 
            p\_3[x]], "\<)\[DifferentialD]x\>"];\)\ \ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Find the anti-derivative\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<         P[x] = \>", "\<\[Integral]\>", "\<(\>", 
        Expand[p\_2[x] 
            p\_3[x]], "\<)\[DifferentialD]x\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<         P[x] = \>", P[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compute the definite integral\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(p\_2\)[x],\!\(p\_3\)[x]\
\[RightAngleBracket] = \>\"", "\<\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[p\_2[x] p\_3[x]], "\<)\[DifferentialD]x = P[\>", 
        b, "\<] - P[\>", a, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(p\_2\)[x],\!\(p\_3\)[x]\
\[RightAngleBracket] = \>\"", "\<\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[p\_2[x] p\_3[x]], "\<)\[DifferentialD]x = (\>", 
        P[b], "\<) - (\>", P[a], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(p\_2\)[x],\!\(p\_3\)[x]\
\[RightAngleBracket] = \>\"", "\<\[Integral]\>"\+a\%b, "\<(\>", 
        Expand[p\_2[x] 
            p\_3[x]], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]p\_2, 
          p\_3\[RightAngleBracket]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[LeftAngleBracket]\!\(p\_2\)[x],\!\(p\_3\)[x]\
\[RightAngleBracket] = \>\"", \[LeftAngleBracket]p\_2, 
          p\_3\[RightAngleBracket]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "For  ",
  Cell[BoxData[
      RowBox[{\(p\_0[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(p\_1[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(p\_2[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(p\_3[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(p\_4[x]\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(p\_5[x]\)}]}]]],
  " we have.  "
}], "Text"],

Cell[BoxData[{
    \(\(n = 5;\)\), "\[IndentingNewLine]", 
    \(\(\[LeftAngleBracket]f_, 
          g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\n", 
    \(\(For[i = 0, 
        i \[LessEqual] 
          n - 1, \(i++\), \[IndentingNewLine]Print["\<\>"]; \
\[IndentingNewLine]For[j = i + 1, 
          j \[LessEqual] 
            n, \(j++\), \[IndentingNewLine]\(Print["\<\[LeftAngleBracket]\>", \
"\<p\>"\_i, "\<[x],\>", "\<p\>"\_j, "\<[x]\[RightAngleBracket] = \>", "\<\
\[Integral]\>"\+a\%b, "\<(\>", p\_i[x], "\<)(\>", 
              p\_j[x], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]p\_i, 
                p\_j\[RightAngleBracket]\ ];\)\ \ \ ];\ ];\)\)}], "Input"],

Cell[TextData[{
  "Therefore, the Legendre polynomials  ",
  Cell[BoxData[
      \({p\_i[x]}\)]],
  "  are orthogonal on ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".   "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Basis Functions",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tA ",
  ButtonBox["basis",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/VectorSpaceBasis.html"], None},
    ButtonStyle->"Hyperlink"],
  " for a ",
  ButtonBox["vector space",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/VectorSpace.html"], None},
    ButtonStyle->"Hyperlink"],
  " ",
  StyleBox["V",
    FontFamily->"Courier New"],
  " of functions is a set of ",
  ButtonBox["linear independent",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LinearlyIndependent.html"], None},
    ButtonStyle->"Hyperlink"],
  " functions ",
  Cell[BoxData[
      \(S = {\(\[Phi]\_i\) \((x)\)}\_\(i = 0\)\%\[Infinity]\)]],
  "  which has the property that any ",
  Cell[BoxData[
      \(f \((x)\) \[Element] V\)]],
  " can be written uniquely as a linear combination  \n\t\n\t\t",
  Cell[BoxData[
      \(f \((x)\)\  = \ \[Sum]\+\(j = 0\)\%\[Infinity]\ \(c\_j\) \
\(\[Phi]\_j\) \((x)\)\)]],
  ".  \n\n",
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The set  ",
  Cell[BoxData[
      \(S = {x\^i}\_\(i = 0\)\%\[Infinity]\)]],
  "  is a basis for the set ",
  Cell[BoxData[
      \(V\)]],
  " of all polynomials and power series. \n\n",
  StyleBox["Definition (Orthogonal Basis)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The set  ",
  Cell[BoxData[
      \(S = {\(\[Phi]\_i\) \((x)\)}\_\(i = 0\)\%\[Infinity]\)]],
  "   is said to be an orthogonal basis on ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  " provided that  \n\n\t\t",
  Cell[BoxData[
      \(\[LeftAngleBracket]\[Phi]\_i, \[Phi]\_j\[RightAngleBracket]\  = \ \(\
\[Integral]\_a\%b\ \(\[Phi]\_i\) \((x)\) \(\[Phi]\_j\) \((x)\) \
\[DifferentialD]x\  = \ 0\)\)]],
  "   when  ",
  Cell[BoxData[
      \(i \[NotEqual] j\)]],
  ", \n\tand  \n\t\t",
  Cell[BoxData[
      \(\[LeftAngleBracket]\[Phi]\_i, \[Phi]\_i\[RightAngleBracket]\  = \ \(\
\[Integral]\_a\%b\ \(\[Phi]\_i\) \((x)\) \(\[Phi]\_i\) \((x)\) \
\[DifferentialD]x\  = \ \[Alpha]\_i\  > \ 0\)\)]],
  "  when  ",
  Cell[BoxData[
      \(i = j\)]],
  ". \n\nIn the special case when ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Alpha]\_i = 1\)\)\)]],
  "  for ",
  Cell[BoxData[
      RowBox[{\(i = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "..."}]]],
  " we say that ",
  Cell[BoxData[
      \(S\)]],
  " is an ",
  ButtonBox["orthonormal basis",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/OrthonormalBasis.html"], None},
    ButtonStyle->"Hyperlink"],
  ".    "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Gram-Schmidt Orthogonalization",
    ButtonData:>{
      URL[ 
      "http://mathworld.wolfram.com/Gram-SchmidtOrthonormalization.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Given  ",
  Cell[BoxData[
      \(S = {x\^k}\_\(k = 0\)\%\[Infinity]\)]],
  "  we can construct a set of ",
  ButtonBox["orthogonal polynomials",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/OrthogonalPolynomials.html"], None},
    ButtonStyle->"Hyperlink"],
  "  ",
  Cell[BoxData[
      \({\(p\_k\) \((x)\)}\_\(k = 0\)\%\[Infinity]\)]],
  "  over the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  as follows: \n\n\t\tUse the inner product  ",
  Cell[BoxData[
      \(\[LeftAngleBracket]f, g\[RightAngleBracket]\  = \ \[Integral]\_a\%b\ 
          f \((x)\) g \((x)\) \[DifferentialD]x\)]],
  ",  and define  \n\n\t\t",
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001100004B000`400?l0
0000o`00003o@@3oool00440oooo00020?ooo`<000001P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool07P3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
7@3oool000<0oooo100000030?ooo`030000003oool0000000L0oooo00@0
00000?ooo`3oool0oooo0P0000020?ooo`800000103oool00`000000oooo
0?ooo`0C0?ooo`D00000103oool000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00H0
oooo1@00000:0?ooo`030000003oool0oooo00@0oooo00030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0103oool000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool2000000H0oooo00<000000?ooo`3oool01P3oool5000000X0
oooo00<000000?ooo`3oool0103oool000<0oooo0P0000020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0103oool00080oooo0P0000000`3oool000000000000=0?ooo`040000
003oool0oooo0?ooo`8000000P3oool2000000@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`040?ooo`005@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
103oool001H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0F0?ooo`8000001P3oool00440oooo00110?ooo`00@@3oool00440oooo
00110?ooo`00\
\>"], "Input",
    Evaluatable->False,
    ImageSize->{65, 17},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "  \n\t\t",
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003@000082000`400?l0
0000o`00003od03oool00=00oooo001T0?ooo`030000003oool0oooo00<0
00001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo0`0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0@03oool003l0oooo00<000000?ooo`3oool08P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`000000103oool2000000P0
oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0;P3oool003h0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`@00000
0`3oool00`000000oooo000000050?ooo`030000003oool0oooo00H0oooo
100000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0]0?ooo`00?P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0000000D0oooo0P0000070?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool003h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0000000>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000050?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;@3oool003d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0=0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;03oool0
03d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`8000000P3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0;03oool003d0oooo00<000000?ooo`3oool08`3oool010000000
oooo0?ooo`3oool2000000030?ooo`000000000001<0oooo0P0000000`3o
ool000000000000:0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0;03oool003d0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0;03oool003d0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
;03oool00080oooo0`0000040?ooo`D00000203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`040?ooo`<000001P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo000000090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool000<0oooo100000040?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`800000103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00@0oooo0P0000020?ooo`800000E`3oool00`000000oooo0?ooo`05
0?ooo`@000000`3oool00`000000oooo000000080?ooo`040000003oool0
oooo0?ooo`8000000P3oool2000000@0oooo00<000000?ooo`3oool0103o
ool000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo00T0oooo1@00000:0?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool00000F03oool00`000000
oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo000000080?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`040?ooo`000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`D000001P3ooolo
000000P0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`000000203oool00`000000oooo0?oo
o`030?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`000`3oool0
1@000000oooo0?ooo`3oool000000080oooo0P0000080?ooo`030000003o
ool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo00T0oooo1@00
000:0?ooo`030000003oool0oooo00H0oooo0P00001I0?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool2000000H0oooo
00<000000?ooo`3oool0103oool000<0oooo0P0000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`00001H0?ooo`030000003oool0oooo00D0
oooo0P0000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
00@0oooo00020?ooo`80000000<0oooo0000000000003@3oool010000000
oooo0?ooo`3oool200000080oooo0P0000040?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0103oool200000080oooo0P00001G0?oo
o`030000003oool0oooo00@0oooo0P0000000`3oool000000000000>0?oo
o`040000003oool0oooo0?ooo`8000000P3oool2000000@0oooo00<00000
0?ooo`3oool0103oool001D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo000F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0
oooo0`0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool3000000H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`00?@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000040?ooo`800000203oool00`000000oooo
0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0/0?ooo`00?@3oool00`000000oooo0?oo
o`0N0?ooo`040000003oool0oooo0?ooo`8000000P3oool2000000D0oooo
100000030?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
1P3oool4000000<0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02`0oooo000m0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo000000050?ooo`8000001`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02`0oooo000m0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0103oool2000000L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0000000h0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0/0?ooo`00?@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo0P0000070?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0=
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;03o
ool003h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000H0oooo0P0000020?ooo`030000003o
ool0oooo0140oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`00?P3oool0
0`000000oooo0?ooo`0M0?ooo`040000003oool0oooo0?ooo`8000000P3o
ool2000000@0oooo0P0000000`3oool000000000000C0?ooo`80000000<0
oooo0000000000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02d0oooo000n0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02d0oooo000o0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
02h0oooo003@0?ooo`00\
\>"], "Input",
    Evaluatable->False,
    ImageSize->{208, 32},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  " \n\t\t",
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000690000=2000`400?l0
0000o`00003oo`3ooon:0?ooo`00o`3ooon:0?ooo`00NP3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0?X0oooo001j0?ooo`800000
403oool200000?/0oooo000o0?ooo`D000000`3oool3000000<0oooo1@00
000:0?ooo`80000000@0oooo0000000000000000403oool5000000@0oooo
00<000000?ooo`3oool01`3oool3000000D0oooo00<000000?ooo`3oool0
2P3oool2000000D0oooo0P0000050?ooo`800000g`3oool00400oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000060?ooo`D0
00001P3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000070?oo
o`050000003oool0oooo0?ooo`000000103oool2000000/0oooo0P000005
0?ooo`8000001@3oool200000=l0oooo00100?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0?h0oooo00100?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00`0oooo0`0000070?ooo`D00000203oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0?h0oooo00100?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000003@3oool0
10000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00h0oooo0P00
003o0?ooo`80oooo000o0?ooo`D000000`3oool3000000<0oooo0P000000
0`3oool000000000000;0?ooo`030000003oool0000000800000503oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?h0oooo00100?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool04P3oool01@00
0000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000
003o0?ooo`40oooo00110?ooo`<00000603oool2000001D0oooo0`00000?
0?ooo`<00000o`3oool20?ooo`00o`3ooon:0?ooo`00o`3ooon:0?ooo`00
o`3ooon:0?ooo`00o`3ooon:0?ooo`00o`3ooon:0?ooo`00o`3ooon:0?oo
o`00o`3ooon:0?ooo`00o`3ooon:0?ooo`00o`3ooon:0?ooo`00o`3ooon:
0?ooo`00I@3oool00`000000oooo0?ooo`03000000@0oooo0P0000000`3o
ool00000000000060?ooo`D000000`3oool00`000000oooo0?ooo`060?oo
o`<00000103oool2000000030?ooo`000000000000H0oooo1@0000020?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool00`0000040?oo
o`80000000<0oooo0000000000001`3oool3000000<0oooo00<000000?oo
o`3oool01`3oool3000000@0oooo0P0000000`3oool00000000000070?oo
o`<000000`3oool00`000000oooo0?ooo`0k0?ooo`00@03oool00`000000
oooo0?ooo`0R0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo000000030?ooo`@000000P3oool00`000000oooo0?ooo`030?oo
o`800000203oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00<0oooo100000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1C0?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo000000030?ooo`@0000000<0oooo
0000003oool0103oool2000000T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000030?ooo`@0000000<0oooo0000003oool0103oool0
0`000000oooo0?ooo`0k0?ooo`00?`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0080oooo100000030?ooo`<000002@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo100000030?oo
o`<000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`020?oo
o`@000000`3oool3000000T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`@000000`3oool3000000T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`00?`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool00000000000P0oooo00<00000
0?ooo`3oool0103oool2000000L0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`030?oo
o`800000203oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`0000000000203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03X0oooo000o0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`00
00003P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0203oool00`000000oooo000000050?ooo`030000003oool0oooo
03T0oooo000n0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool00`3oool01P000000oooo0?ooo`3oool000000?ooo`8000002P3oool2
000000l0oooo00H000000?ooo`3oool0oooo0000003oool2000000X0oooo
0P0000060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0?ooo`00
0000oooo0P00000;0?ooo`030000003oool0oooo00d0oooo00H000000?oo
o`3oool0oooo0000003oool2000000/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0i0?ooo`00?P3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0
oooo01`0oooo0P0000020?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0080oooo0P0000020?ooo`030000003oool0oooo01`0oooo0P000002
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>P3oool0
03h0oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`3oool2
000000030?ooo`000000000001h0oooo0P0000000`3oool000000000000E
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0D03oool0
10000000oooo0?ooo`3oool2000000030?ooo`000000000001h0oooo0P00
00000`3oool000000000000E0?ooo`030000003oool0oooo03X0oooo000n
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0k0?ooo`00?P3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0>`3oool00080oooo0`0000040?ooo`80
000000<0oooo0000000000002@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`040?ooo`<00000103oool2000000030?ooo`000000000000H0
oooo1@0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0J`3oool3000000@0oooo0P0000000`3oool00000000000070?ooo`<0
00002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000000`3oool400000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000030?ooo`@0000000<0oooo0000003oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00030?ooo`@000000`3o
ool3000000P0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`800000
103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo
0P0000020?ooo`800000K@3oool00`000000oooo0?ooo`050?ooo`@00000
0`3oool3000000T0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`3oool200000080oooo0P0000040?ooo`030000003oool0oooo06X0
oooo100000030?ooo`<000002@3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo0?ooo`8000000P3oool2000000@0oooo00<000000?oo
o`3oool0103oool000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool00000000000L0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo00T0oooo1@00
000:0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
KP3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0000000000080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0103oool000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool2000000H0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`060?ooo`8000001`3oool5000000H0ooooE@0000080?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`070?oo
o`D00000303ooom;000000L0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`04
0?ooo`000`3oool01P000000oooo0?ooo`3oool000000?ooo`8000002P3o
ool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?oo
o`090?ooo`D000002P3oool00`000000oooo0?ooo`060?ooo`800000K`3o
ool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0?ooo`000000
oooo0P00000:0?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`80
00001P3oool00`000000oooo0?ooo`1Z0?ooo`060000003oool0oooo0?oo
o`000000oooo0P00000;0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool0103oool0
00<0oooo0P0000020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00
001^0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo06X0oooo0P0000020?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00@0oooo00020?ooo`800000
00<0oooo0000000000003P3oool010000000oooo0?ooo`3oool200000080
oooo0P0000040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0103oool200000080oooo0P00001]0?ooo`030000003oool0oooo00@0
oooo0P0000000`3oool000000000000I0?ooo`040000003oool0oooo0?oo
o`8000000P3oool2000000@0oooo00<000000?ooo`3oool0J@3oool20000
00030?ooo`000000000001P0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`005P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00D0oooo000G0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00X0oooo0`0000040?ooo`80000000<0oooo00000000
00001P3oool5000000<0oooo00<000000?ooo`3oool01P3oool3000000@0
oooo0P0000000`3oool00000000000060?ooo`D000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00<0
0000103oool2000000030?ooo`000000000000H0oooo1@0000020?ooo`03
0000003oool0oooo00L0oooo0`0000040?ooo`80000000<0oooo00000000
00001P3oool500000080oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo000n0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0000000<0oooo100000020?ooo`030000
003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000000`3oool400000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0540oooo
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0000000<0
oooo100000020?ooo`030000003oool0oooo0080oooo0P0000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool400000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`00
?P3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo0?ooo`80
00000P3oool2000000D0oooo100000030?ooo`<000002@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo100000030?ooo`<0
00002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`@0
00000`3oool3000000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`@000000`3oool3000000T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0j0?ooo`00?P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00001P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`0000000000203oool00`000000oooo0?ooo`040?ooo`8000001`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`0000000000
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0000000000080?oo
o`030000003oool0oooo00<0oooo0P0000080?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0000000000080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0>P3oool003h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`040?ooo`8000001`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo000n0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0103oool2000000L0
oooo00H000000?ooo`3oool0oooo0000003oool2000000X0oooo0P00000?
0?ooo`060000003oool0oooo0?ooo`000000oooo0P00000:0?ooo`800000
1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`3oool000000?oo
o`8000002P3oool2000000l0oooo00H000000?ooo`3oool0oooo0000003o
ool2000000X0oooo0P0000060?ooo`030000003oool0oooo03T0oooo000o
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000060?ooo`8000000P3oool00`000000oooo0?oo
o`0L0?ooo`8000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool00`000000oooo0?ooo`0L0?ooo`8000000P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03X0oooo000o
0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`800000103oool2000000030?ooo`000000000001h0oooo0P00
00000`3oool000000000000E0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0D@3oool010000000oooo0?ooo`3oool2000000030?oo
o`000000000001h0oooo0P0000000`3oool000000000000E0?ooo`030000
003oool0oooo03X0oooo000o0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0k0?ooo`00@03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool0
0?l0ooooRP3oool00001\
\>"], "Input",
    Evaluatable->False,
    ImageSize->{393, 52},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  A set of orthonormal polynomials over the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  is  ",
  Cell[BoxData[
      \({\ \(q\_k\) \((x)\)\  = \ \(\(p\_k\) \
\((x)\)\)\/\[LeftAngleBracket]p\_k, p\_k\[RightAngleBracket]\ }\_\(k = 0\)\%\
\[Infinity]\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  When these polynomials are constructed over the interval ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  " and normalized so that ",
  Cell[BoxData[
      \(\(P\_k\) \((x)\) = 1\)]],
  " they are called the Legendre polynomials, and form a basis for the set of \
polynomials and power series over the interval ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The set of orthogonal polynomials ",
  Cell[BoxData[
      \({\(p\_k\) \((x)\)}\_\(k = 0\)\%\[Infinity]\)]],
  " is a basis for the set ",
  StyleBox["V",
    FontFamily->"Courier New"],
  " of all polynomials and power series over the interval ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The set of Legendre polynomials ",
  Cell[BoxData[
      \({\(P\_k\) \((x)\) = \(\(p\_k\) \((x)\)\)\/\(\(p\_k\) \((1)\)\)}\_\(k \
= 0\)\%\[Infinity]\)]],
  " is a basis for the set ",
  StyleBox["V",
    FontFamily->"Courier New"],
  " of all polynomials and power series over the interval ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Legendre Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LegendrePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Start with  ",
  Cell[BoxData[
      \(S = {x\^k}\_\(k = 0\)\%\[Infinity]\)]],
  "  over the interval ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  Use the Gram-Schmidt orthogonalization to construct a few of the \
orthogonal polynomials ",
  Cell[BoxData[
      \({\(p\_k\) \((x)\)}\_\(k = 0\)\%\[Infinity]\)]],
  "  over the interval ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  Construct the corresponding ",
  ButtonBox["Legendre polynomials",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LegendrePolynomial.html"], None},
    ButtonStyle->"Hyperlink"],
  "  ",
  Cell[BoxData[
      \({\(P\_k\) \((x)\) = \(\(p\_k\) \((x)\)\)\/\(\(p\_k\) \((1)\)\)}\_\(k \
= 0\)\%\[Infinity]\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " do it all using recursion as follows.  First define the inner product and \
the recursive formulas. "
}], "Text"],

Cell[BoxData[{
    \(\(a = \(-1\);\)\ \), "\n", 
    \(\(b = \ 1;\)\ \), "\n", 
    \(\[LeftAngleBracket]f_, 
        g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
          g[x] \(\(\[DifferentialD]x\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(\(Remove[p];\)\), "\n", 
    \(\(p\_0[x_]\  = \ 1;\)\ \), "\n", 
    \(\(xp\_0[x]\  = \ x\ p\_0[x];\)\ \), "\n", 
    \(\(p\_1[
          x_]\  = \ \((\ 
            x - \[LeftAngleBracket]xp\_0, p\_0\[RightAngleBracket]\/\
\[LeftAngleBracket]p\_0, p\_0\[RightAngleBracket]\ )\) p\_0[x];\)\ \), "\n", 
    \(\(xp\_1[x_]\  = \ x\ p\_1[x];\)\ \), "\n", 
    \(\(For[k = 2, 
        k \[LessEqual] 9, \(k++\), \[IndentingNewLine]p\_k[x_]\  = \ 
          Expand[\((\ 
                  x - \[LeftAngleBracket]xp\_\(k - 1\), p\_\(k - 1\)\
\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(k - 1\), p\_\(k - 1\)\
\[RightAngleBracket]\ )\) 
                p\_\(k - 1\)[
                  x]\  - \ \ \[LeftAngleBracket]p\_\(k - 1\), p\_\(k - 1\)\
\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(k - 2\), p\_\(k - 2\)\
\[RightAngleBracket]\ p\_\(k - 2\)[x]]\ ; \[IndentingNewLine]xp\_k[x_]\  = \ 
          Expand[x\ p\_k[x]];\ \ ];\)\), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(p\_k_[x_]\  := \ \(p\_k[x] = 
        Expand[\((\ 
                x - \[LeftAngleBracket]xp\_\(k - 1\), p\_\(k - 1\)\
\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(k - 1\), p\_\(k - 1\)\
\[RightAngleBracket]\ )\) 
              p\_\(k - 1\)[
                x]\  - \ \ \[LeftAngleBracket]p\_\(k - 1\), p\_\(k - 1\)\
\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(k - 2\), p\_\(k - 2\)\
\[RightAngleBracket]\ p\_\(k - 2\)[x]]\)\ \), "\n", 
    \(xp\_k_[
        x_]\  := \ \(\(xp\_k[x]\)\(=\)\(Expand[
          x\ p\_k[x]]\)\(\ \ \)\)\)}], "Input"],

Cell["\<\
The polynomials are generated using the above recursive formulas.  \
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<The orthogonal polynomials are\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(For[i = 0, 
        i \[LessEqual] 
          9, \(i++\), \[IndentingNewLine]\(Print["\<p\>"\_i, "\<[x] = \>", 
            p\_i[x]\ ];\)\ \ ];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Details",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Set up the inner product function.  ", "Text"],

Cell[BoxData[{
    \(\(a = \(-1\);\)\ \), "\n", 
    \(\(b = \ 1;\)\ \), "\n", 
    \(\[LeftAngleBracket]f_, 
        g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
          g[x] \(\(\[DifferentialD]x\)\(\ \ \)\)\)}], "Input"],

Cell["Construct the first few orthogonal polynomials.  ", "Text"],

Cell[BoxData[{
    \(\(p\_0[x_]\  = \ 1;\)\ \), "\n", 
    \(\(xp\_0[x]\  = \ x\ p\_0[x];\)\ \), "\n", 
    \(\(p\_1[
          x_]\  = \ \((x - \[LeftAngleBracket]xp\_0, p\_0\[RightAngleBracket]\
\/\[LeftAngleBracket]p\_0, p\_0\[RightAngleBracket])\) p\_0[x];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(p\_0\)[x] = \>\"", 
        p\_0[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\[LeftAngleBracket]x \!\(p\_0\),\!\(p\_0\)\
\[RightAngleBracket] = \>\"", "\<\[Integral]\>"\+a\%b, "\<(\>", 
        x\ p\_0[x], "\<)(\>", 
        p\_0[x], "\<)\[DifferentialD]x = \>", "\<\[Integral]\>"\+a\%b, \
"\<(\>", x\ p\_0[x] 
          p\_0[x], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]xp\_0, 
          p\_0\[RightAngleBracket]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \[LeftAngleBracket]\!\(p\_0\),\!\(p\_0\)\
\[RightAngleBracket] = \>\"", "\<\[Integral]\>"\+a\%b, "\<(\>", 
        p\_0[x], "\<)(\>", 
        p\_0[x], "\<)\[DifferentialD]x = \>", "\<\[Integral]\>"\+a\%b, \
"\<(\>", p\_0[x] 
          p\_0[x], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]p\_0, 
          p\_0\[RightAngleBracket]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\)[x] = (x-\!\(\[LeftAngleBracket]x\\\ p\_0, \
p\_0\[RightAngleBracket]\/\[LeftAngleBracket]p\_0, \
p\_0\[RightAngleBracket]\))\!\(p\_0\)[x]\>\""\ ];\)\), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\!\(p\_1\)[x] = (x - \>\"", \[LeftAngleBracket]xp\_0, 
          p\_0\[RightAngleBracket], "\</\>", \[LeftAngleBracket]p\_0, 
          p\_0\[RightAngleBracket], "\<)\>", 
        p\_0[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\)[x] = (x - \>\"", \[LeftAngleBracket]xp\_0, \
p\_0\[RightAngleBracket]\/\[LeftAngleBracket]p\_0, p\_0\[RightAngleBracket], \
"\<)\>", p\_0[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\)[x] = \>\"", p\_1[x]];\)\)}], "Input"],

Cell[BoxData[
    \(\(\(OrthoPoly[i0_]\  := 
        Mod[{}, \[IndentingNewLine]i = 
            i0; \[IndentingNewLine]xp\_\(i - 1\)[x_]\  = \ 
            x\ p\_\(i - 1\)[x]; \ \ \[IndentingNewLine]p\_i[x_]\  = \ 
            Expand[\((\ 
                    x - \[LeftAngleBracket]xp\_\(i - 1\), p\_\(i - 1\)\
\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(i - 1\), p\_\(i - 1\)\
\[RightAngleBracket]\ )\) 
                  p\_\(i - 1\)[
                    x]\  - \ \ \[LeftAngleBracket]p\_\(i - 1\), p\_\(i - 1\)\
\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(i - 2\), p\_\(i - 2\)\
\[RightAngleBracket]\ p\_\(i - 2\)[
                    x]]; \ \[IndentingNewLine]Print["\<p\>"\_\(i - 2\), \
"\<[x] = \>", 
            p\_\(i - 2\)[
              x]\ ]; \[IndentingNewLine]Print["\<p\>"\_\(i - 1\), "\<[x] = \
\>", p\_\(i - 1\)[
              x]]; \[IndentingNewLine]Print["\<\[LeftAngleBracket]\>", \
"\<xp\>"\_\(i - 1\), "\<,\>", "\<p\>"\_\(i - 1\), "\<\[RightAngleBracket] = \
\>", "\<\[Integral]\>"\+a\%b, "\<(\>", x\ p\_\(i - 1\)[x], "\<)(\>", 
            p\_\(i - 1\)[
              x], "\<)\[DifferentialD]x = \>", "\<\[Integral]\>"\+a\%b, \
"\<(\>", Expand[
              x\ p\_\(i - 1\)[x] 
                p\_\(i - 1\)[
                  x]], "\<)\[DifferentialD]x = \>", \
\[LeftAngleBracket]xp\_\(i - 1\), 
              p\_\(i - 1\)\[RightAngleBracket]\ ]; \[IndentingNewLine]Print["\
\<\[LeftAngleBracket]\>", "\<p\>"\_\(i - 1\), "\<,\>", "\<p\>"\_\(i - 1\), \
"\<\[RightAngleBracket] = \>", "\<\[Integral]\>"\+a\%b, "\<(\>", 
            p\_\(i - 1\)[x], "\<)(\>", 
            p\_\(i - 1\)[
              x], "\<)\[DifferentialD]x = \>", "\<\[Integral]\>"\+a\%b, \
"\<(\>", Expand[
              p\_\(i - 1\)[x] 
                p\_\(i - 1\)[
                  x]], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]p\_\(i \
- 1\), p\_\(i - 1\)\[RightAngleBracket]\ ]; \[IndentingNewLine]Print["\<\
\[LeftAngleBracket]\>", "\<p\>"\_\(i - 2\), "\<,\>", "\<p\>"\_\(i - 2\), "\<\
\[RightAngleBracket] = \>", "\<\[Integral]\>"\+a\%b, "\<(\>", 
            p\_\(i - 2\)[x], "\<)(\>", 
            p\_\(i - 2\)[
              x], "\<)\[DifferentialD]x = \>", "\<\[Integral]\>"\+a\%b, \
"\<(\>", Expand[
              p\_\(i - 2\)[x] 
                p\_\(i - 2\)[
                  x]], "\<)\[DifferentialD]x = \>", \[LeftAngleBracket]p\_\(i \
- 2\), p\_\(i - 2\)\[RightAngleBracket]\ ]; \
\[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = (x-\>", \
"\<\[LeftAngleBracket]xp\>"\_\(i - 1\), "\<,\>", "\<p\>"\_\(i - 1\), "\<\
\[RightAngleBracket]/\[LeftAngleBracket]p\>"\_\(i - 1\), "\<,\>", \
"\<p\>"\_\(i - 1\), "\<\[RightAngleBracket])\>", "\<p\>"\_\(i - 1\), \
\[IndentingNewLine]"\<[x] - (\>", "\<\[LeftAngleBracket]p\>"\_\(i - 1\), "\<,\
\>", "\<p\>"\_\(i - 1\), "\<\[RightAngleBracket]/\[LeftAngleBracket]p\>"\_\(i \
- 2\), "\<,\>", "\<p\>"\_\(i - 2\), "\<\[RightAngleBracket])\>", "\<p\>"\_\(i \
- 2\), "\<[x]\>"\ ]; \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = (x - (\>", \
\[LeftAngleBracket]xp\_\(i - 1\), 
              p\_\(i - 1\)\[RightAngleBracket], "\<)/(\>", \
\[LeftAngleBracket]p\_\(i - 1\), 
              p\_\(i - 1\)\[RightAngleBracket], "\<))\>", "\<p\>"\_\(i - 1\), \
"\<[x] - (\>", \[LeftAngleBracket]p\_\(i - 1\), 
              p\_\(i - 1\)\[RightAngleBracket], "\<)/(\>", \
\[LeftAngleBracket]p\_\(i - 2\), 
              p\_\(i - 2\)\[RightAngleBracket], "\<)\>", "\<p\>"\_\(i - 2\), \
"\<[x]\>"\ ]; \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = (x - (\>", \
\[LeftAngleBracket]xp\_\(i - 1\), 
              p\_\(i - 1\)\[RightAngleBracket], "\<)/(\>", \
\[LeftAngleBracket]p\_\(i - 1\), p\_\(i - 1\)\[RightAngleBracket], "\<))(\>", 
            p\_\(i - 1\)[x], "\<) - (\>", \[LeftAngleBracket]p\_\(i - 1\), 
              p\_\(i - 1\)\[RightAngleBracket], "\<)/(\>", \
\[LeftAngleBracket]p\_\(i - 2\), p\_\(i - 2\)\[RightAngleBracket], "\<)(\>", 
            p\_\(i - 2\)[
              x], "\<)\>"\ ]; \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = \
(x-\>", \[LeftAngleBracket]xp\_\(i - 1\), p\_\(i - 1\)\[RightAngleBracket]\/\
\[LeftAngleBracket]p\_\(i - 1\), p\_\(i - 1\)\[RightAngleBracket], "\<)(\>", 
            p\_\(i - 1\)[
              x], "\<) - \>", \[LeftAngleBracket]p\_\(i - 1\), p\_\(i - 1\)\
\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(i - 2\), p\_\(i - 2\)\
\[RightAngleBracket], "\<(\>", 
            p\_\(i - 2\)[
              x], "\<)\>"\ ]; \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = (\
\>", \((x - \[LeftAngleBracket]xp\_\(i - 1\), p\_\(i - \
1\)\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(i - 1\), p\_\(i - 1\)\
\[RightAngleBracket])\) 
              p\_\(i - 1\)[
                x], "\<) - (\>", \(\[LeftAngleBracket]p\_\(i - 1\), 
                    p\_\(i - \
1\)\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(i - 2\), 
                    p\_\(i - 2\)\[RightAngleBracket]\) 
              p\_\(i - 2\)[
                x], "\<)\>"\ ]; \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = \
(\>", Expand[\((x - \[LeftAngleBracket]xp\_\(i - 1\), p\_\(i - 1\)\
\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(i - 1\), p\_\(i - 1\)\
\[RightAngleBracket])\) p\_\(i - 1\)[x]], "\<) - (\>", 
            Expand[\(\[LeftAngleBracket]p\_\(i - 1\), 
                      p\_\(i - \
1\)\[RightAngleBracket]\/\[LeftAngleBracket]p\_\(i - 2\), 
                      p\_\(i - 2\)\[RightAngleBracket]\) 
                p\_\(i - 2\)[
                  x]], "\<)\>"\ ]; \[IndentingNewLine]Print["\<p\>"\_i, \
"\<[x] = \>", p\_i[x]];\ ];\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(OrthoPoly[2];\)\)], "Input"],

Cell[BoxData[
    \(\(OrthoPoly[3];\)\)], "Input"],

Cell[BoxData[
    \(\(OrthoPoly[4];\)\)], "Input"],

Cell[BoxData[
    \(\(OrthoPoly[5];\)\)], "Input"]
}, Open  ]],

Cell[TextData[{
  "These orthogonal polynomials are related to the Legendre polynomials, all \
we need to do is normalize them so that  ",
  Cell[BoxData[
      \(\(P\_k\) \((1)\) = 1\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<The normalized orthogonal polynomials are\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Clear[k];\)\), "\[IndentingNewLine]", 
    \(\(P\_k_[x_]\  := \ p\_k[x]\/p\_k[1];\)\ \), "\[IndentingNewLine]", 
    \(\(For[i = 0, 
        i \[LessEqual] 
          9, \(i++\), \[IndentingNewLine]Print["\<P\>"\_i, "\<[x] = \>", 
          P\_i[x]\ ]; \[IndentingNewLine]Print["\<      = \>", 
          Expand[P\_i[x]]\ ];\ \ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(n = 5;\)\ \), "\[IndentingNewLine]", 
    \(\(funs = Table[P\_i[x], {i, 0, n}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[Evaluate[funs], {x, \(-1\), 1}, 
        PlotStyle \[Rule] {Cyan, Red, Yellow, Green, Blue, Violet}, 
        Ticks \[Rule] {N[Range[\(-1\), 1, 1\/5]], 
            N[Range[\(-1\), 1, 1\/5]]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Legendre polynomials\>"];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<{\!\(P\_i\)[x]}\>\""\_\("\<i=0\>"\)\%n, "\< = \>", 
      Expand[funs]]\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<The Legendre polynomials defined in Mathematica are\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(For[i = 0, 
        i \[LessEqual] 
          9, \(i++\), \[IndentingNewLine]\(Print["\<p\>"\_i, "\<[x] = \>", 
            LegendreP[i, x]\ ];\)\ \ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["An Alternate Recursive Formula",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tAnother way to recursively define the Legendre polynomials is\n\t\n\t\
\t",
  Cell[BoxData[
      RowBox[{\(\(p\_0\) \((x)\)\  = \ 1\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\n", \(\(p\_1\) \((x)\)\  = \ x\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\n", 
        RowBox[{\(\(p\_k\) \((x)\)\), " ", "=", " ", 
          RowBox[{
            
            RowBox[{\(1\/k\), \((\((2  k - 1)\) 
                    x\ \(p\_\(k - 1\)\) \((x)\) - \((k - 
                        1)\) \(p\_\(k - 2\)\) \((x)\))\), 
              StyleBox[
                RowBox[{"  ", 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]], 
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "k"}], "\[GreaterEqual]", 
            StyleBox[
              RowBox[{"2", 
                StyleBox[".",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]]}]}]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Set up the recursive formulas for the Legendre polynomials and print them \
out. \
\>", "Text"],

Cell[BoxData[{
    \(\(Remove[p];\)\ \), "\[IndentingNewLine]", 
    \(\(p\_0[x_]\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(p\_1[x_]\  = \ x;\)\ \), "\[IndentingNewLine]", 
    \(p\_k_[x_]\  := \ 
      Expand[\(1\/k\) \((\((2  k - 1)\) x\ p\_\(k - 1\)[x] - \((k - 1)\) 
                p\_\(k - 2\)[x])\)]\), "\[IndentingNewLine]", 
    \(\(Print["\<The Legendre polynomials can be \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<generated with the recursive formula\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_k\)[x] = \!\(1\/k\)((2k-1)x \!\(p\_\(k - 1\)\)[x] \
- (k-1)\!\(p\_\(k - 2\)\)[x])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\)[x] = \>\"", 
        p\_0[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\)[x] = \>\"", 
        p\_1[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(For[i = 2, 
        i \[LessEqual] 
          9, \(i++\), \[IndentingNewLine]Print["\<\>"]; \
\[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = \>", 1\/i, "\<(\>", 
          2  i - 1, "\< x (\>", p\_\(i - 1\)[x], "\<) - (\>"\ , 
          i - 1, "\<)(\>", 
          p\_\(i - 2\)[
            x], "\<))\>"]; \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = \>", \
\(1\/i\) \((\((2  i - 1)\) x\ p\_\(i - 1\)[x]\  - \ \((i - 1)\) 
                  p\_\(i - 2\)[
                    x])\)]; \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = \
\>", p\_i[x]\ ];\ \ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(n = 5;\)\ \), "\[IndentingNewLine]", 
    \(\(funs = Table[p\_i[x], {i, 0, n}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[Evaluate[funs], {x, \(-1\), 1}, 
        PlotStyle \[Rule] {Cyan, Red, Yellow, Green, Blue, Violet}, 
        Ticks \[Rule] {N[Range[\(-1\), 1, 1\/5]], 
            N[Range[\(-1\), 1, 1\/5]]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Legendre polynomials\>"];\)\ \), "\[IndentingNewLine]", 
    \(Print[\*"\"\<{\!\(p\_i\)[x]}\>\""\_\("\<i=0\>"\)\%n, "\< = \>", 
      Expand[funs]]\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<The Legendre polynomials defined in Mathematica are\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(For[i = 0, 
        i \[LessEqual] 
          9, \(i++\), \[IndentingNewLine]\(Print["\<p\>"\_i, "\<[x] = \>", 
            LegendreP[i, x]\ ];\)\ \ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Efficient Computations",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWe now present the efficient way to compute the continuous least \
squares approximation.  It has an additional feature that each successive \
term increases the degree of approximation.  Hence, an increasing sequence of \
of approximations can obtained recursively:  \n\t\n\t\t",
  Cell[BoxData[{
      RowBox[{\(\(g\_0\) \((x)\)\  = \ c\_0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        "\[IndentingNewLine]", \(\(g\_1\) \((x)\)\  = \ \(g\_0\) \((x)\) + \ \
\(c\_1\) \(p\_1\) \((x)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", "              ", 
        "\[VerticalEllipsis]"}], 
    "\[IndentingNewLine]", \(\(g\_k\) \((x)\)\  = \ \(g\_\(k - 
                  1\)\) \((x)\)\  + \ \(c\_k\) \(p\_k\) \((x)\)\), 
    "\[IndentingNewLine]", 
      RowBox[{"              ", "\[VerticalEllipsis]"}], 
    "\[IndentingNewLine]", \(\(g\_n\) \((x)\)\  = \ \(g\_\(n - 
                  1\)\) \((x)\)\  + \ \(c\_n\) \(p\_n\) \((x)\)\)}]],
  "  \n\t\n",
  StyleBox["Theorem (Legendre Series Approximation)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The Legendre series approximation of order ",
  Cell[BoxData[
      \(n\)]],
  " for a function ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " over  ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  "  is given by \n\t\n\t\t",
  Cell[BoxData[
      \(\(g\_n\) \((x)\)\  = \ \[Sum]\+\(k = 0\)\%n\ \(c\_k\) \(p\_k\) \
\((x)\)\)]],
  "\n\nwhere  ",
  Cell[BoxData[
      \(\(p\_k\) \((x)\)\)]],
  "  is the ",
  Cell[BoxData[
      \(n\^th\)]],
  " Legendre polynomial and \n\n\t\t",
  Cell[BoxData[
      \(c\_k\ \  = \ \ \(2  k + 1\)\/2\ \(\[Integral]\_\(-1\)\%1\ 
            f \((x)\) \(p\_k\) \((x)\) \[DifferentialD]x\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Legendre Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LegendrePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Legendre Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LegendrePolyProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compare the \"discrete interpolation polynomial\" and \"Legendre series \
approximation,\" on the interval  ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  \n",
  StyleBox["8 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = \[ExponentialE]\^x\)]],
  ".   \n",
  StyleBox["8 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = \(\[ExponentialE]\^x\) Cos[\[Pi]\/2\ x]\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \[ExponentialE]\^x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(c\_k_\ \  := \ \ \(2  k + 1\)\/2\ \(\[Integral]\_\(-1\)\%1 f[x] 
            LegendreP[k, x] \[DifferentialD]x\)\), "\n", 
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n\( c\_k\) 
            LegendreP[k, x];\)\), "\n", 
    \(\(g[x_]\  = Chop[N[Expand[g[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Chop[Expand[
            InterpolatingPolynomial[XY, x]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x], g[x], q[x]}, {x, \(-1\), 1}, 
          PlotStyle \[Rule] {Magenta, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Legendre series approximation is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the 'continuous least squares \
approximation' in example 3(a).\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compare it with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial'\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \)}], "Input"],

Cell["Details for this computation.", "Text"],

Cell["First, construct the coefficients.", "Text"],

Cell[BoxData[
    \(\(For[k = 0, 
        k \[LessEqual] 
          n, \(k++\), \[IndentingNewLine]Print["\<c\>"\_k, "\< = \>", \(2  k \
+ 1\)\/2, "\< \>", "\<\[Integral]\>"\+\(-1\)\%1, "\<(\>", f[x], "\<)(\>", 
          LegendreP[k, 
            x], "\<)\[DifferentialD]x\>"]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< = \>", c\_k, "\< = \>", 
          N[c\_k], "\<\n\>"\ ];\ \ ];\)\)], "Input"],

Cell["Construct the terms.", "Text"],

Cell[BoxData[
    \(\(For[k = 0, 
        k \[LessEqual] 
          n, \(k++\), \[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, "\<,x] = \>", c\_k, "\<(\>", 
          LegendreP[k, 
            x], "\<)\>"\ ]; \[IndentingNewLine]Print["\<c\>"\_k, "\< \
LegendreP[\>", k, "\<,x] = \>", N[c\_k], "\<(\>", 
          LegendreP[k, 
            x], "\<)\>"\ ]; \[IndentingNewLine]Print["\<c\>"\_k, "\< \
LegendreP[\>", k, "\<,x] = \>", 
          N[\(c\_k\) 
              LegendreP[k, 
                x]]\ ]; \[IndentingNewLine]Print["\<c\>"\_k, "\< \
LegendreP[\>", k, "\<,x] = \>", 
          N[Expand[\(c\_k\) 
                LegendreP[k, x]]], "\<\n\>"\ ];\ \ ];\)\)], "Input"],

Cell["Then add up the terms.", "Text"],

Cell[BoxData[{
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n N[c\_k] 
            LegendreP[k, x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", Chop[N[Expand[g[x]]]]\ ];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(\[ExponentialE]\^x\) 
          Cos[\[Pi]\/2\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; Remove[c];\ \), "\[IndentingNewLine]", 
    \(c\_k_\ \  := \ \ \(2  k + 1\)\/2\ \(\[Integral]\_\(-1\)\%1 f[x] 
            LegendreP[k, x] \[DifferentialD]x\)\), "\n", 
    \(\(g[
          x_]\  = \ \ \[Sum]\+\(k = 0\)\%n\( c\_k\) 
            LegendreP[k, x];\)\), "\[IndentingNewLine]", 
    \(\(g[x_]\  = Chop[N[Expand[g[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Chop[Expand[
            InterpolatingPolynomial[XY, x]]];\)\ \), "\[IndentingNewLine]", 
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Expand[InterpolatingPolynomial[XY, 
            x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x], g[x], q[x]}, {x, \(-1\), 1}, 
          PlotStyle \[Rule] {Magenta, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Legendre series approximation is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the 'continuous least squares \
approximation' in example 3(a).\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compare it with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial'\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \)}], "Input"],

Cell["Details for this computation.", "Text"],

Cell["First, construct the coefficients.", "Text"],

Cell[BoxData[
    \(\(For[k = 0, 
        k \[LessEqual] 
          n, \(k++\), \[IndentingNewLine]Print["\<c\>"\_k, "\< = \>", \(2  k \
+ 1\)\/2, "\< \>", "\<\[Integral]\>"\+\(-1\)\%1, "\<(\>", f[x], "\<)(\>", 
          LegendreP[k, 
            x], "\<)\[DifferentialD]x\>"]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< = \>", c\_k, "\< = \>", 
          Chop[N[c\_k]], "\<\n\>"\ ];\ \ ];\)\)], "Input"],

Cell["Construct the terms.", "Text"],

Cell[BoxData[
    \(\(For[k = 0, 
        k \[LessEqual] 
          n, \(k++\), \[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, "\<,x] = \>", c\_k, "\<(\>", 
          LegendreP[k, 
            x], "\<)\>"\ ]; \[IndentingNewLine]Print["\<c\>"\_k, "\< \
LegendreP[\>", k, "\<,x] = \>", Chop[N[c\_k]], "\<(\>", 
          LegendreP[k, 
            x], "\<)\>"\ ]; \[IndentingNewLine]Print["\<c\>"\_k, "\< \
LegendreP[\>", k, "\<,x] = \>", 
          Chop[N[c\_k]] 
            N[LegendreP[k, 
                x]]\ ]; \[IndentingNewLine]Print["\<c\>"\_k, "\< \
LegendreP[\>", k, "\<,x] = \>", 
          Chop[N[Expand[\(c\_k\) 
                  LegendreP[k, x]]]], "\<\n\>"\ ];\ \ ];\)\)], "Input"],

Cell["Then add up the terms.", "Text"],

Cell[BoxData[{
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n Chop[N[c\_k]] 
            LegendreP[k, x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", Chop[N[Expand[g[x]]]]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Shifted Legendre Polynomials",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe \"shifted Legendre polynomials \n\t\n\t\t",
  Cell[BoxData[
      \(\(q\_k\) \((x)\)\  = \ \(p\_k\) \((\(2\ x - a - b\)\/\(b - \
a\))\)\)]],
  "  are ",
  ButtonBox["orthogonal",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/OrthogonalPolynomials.html"], None},
    ButtonStyle->"Hyperlink"],
  " on ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ",  \n\t\n\twhere ",
  Cell[BoxData[
      \(\(\(\ \)\(\(p\_k\) \((x)\)\)\)\)]],
  " are the ",
  ButtonBox["Legendre polynomials",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LegendrePolynomial.html"], None},
    ButtonStyle->"Hyperlink"],
  " on ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print["\<The Legendre polynomials are\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(For[i = 0, 
        i \[LessEqual] 5, \(i++\), \[IndentingNewLine]p\_i[x_] = 
          LegendreP[i, 
            x]; \ \ \ \[IndentingNewLine]Print["\<p\>"\_i, "\<[x] = \>", 
          p\_i[x]\ ];\ \ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[a, b];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The shifted Legendre polynomials are\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_i\)[x] = \!\(p\_i\)[\>\"", \(2\ x - a - b\)\/\(b \
- a\), "\<]\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(For[i = 0, 
        i \[LessEqual] 5, \(i++\), \[IndentingNewLine]q\_i[x_] = 
          ReplaceAll[LegendreP[i, x], 
            x \[Rule] \(2\ x - a - b\)\/\(b - a\)]; \ \ \ \
\[IndentingNewLine]Print["\<q\>"\_i, "\<[x] = \>", 
          q\_i[x]\ ];\ \ ];\)\)}], "Input"],

Cell[TextData[{
  "For  ",
  Cell[BoxData[
      RowBox[{\(q\_0[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(q\_1[x]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(q\_2[x]\), " ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(q\_3[x]\)}]}]]],
  " we have.  "
}], "Text"],

Cell[BoxData[{
    \(\(n = 5;\)\), "\[IndentingNewLine]", 
    \(\(\[LeftAngleBracket]f_, 
          g_\[RightAngleBracket] := \[Integral]\_a\%b f[x] 
            g[x] \[DifferentialD]x;\)\ \ \), "\n", 
    \(\(For[i = 0, 
        i \[LessEqual] 
          n - 1, \(i++\), \[IndentingNewLine]\(For[j = i + 1, 
            j \[LessEqual] 
              n, \(j++\), \[IndentingNewLine]Print["\<\n\>", "\<\
\[LeftAngleBracket]\>", "\<q\>"\_i, "\<[x],\>", "\<q\>"\_j, "\<[x]\
\[RightAngleBracket] = \>"]; \ \ \
\[IndentingNewLine]Print["\<\[Integral]\>"\+a\%b, "\<(\>", q\_i[x], "\<)(\>", 
              q\_j[x], "\<)\[DifferentialD]x\>"\ ]; \ \ \
\[IndentingNewLine]Print["\< = \>", \[LeftAngleBracket]q\_i, 
                q\_j\[RightAngleBracket]\ ];\ \ \ ];\)\ ];\)\)}], "Input"],

Cell[TextData[{
  "Therefore, the shifted Legendre polynomials  ",
  Cell[BoxData[
      \({\ \ q\_i[x] = p\_i[\(2\ x - a - b\)\/\(b - a\)]\ }\)]],
  "  are orthogonal on ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".   "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem (Shifted Legendre Series Interpolation)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The shifted Legendre series approximation of order ",
  Cell[BoxData[
      \(n\)]],
  " for a function ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " over  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  is given by \n\t\n\t\t",
  Cell[BoxData[
      \(\(g\_n\) \((x)\)\  = \ \[Sum]\+\(k = 0\)\%n\ \(c\_k\) \(q\_k\) \
\((x)\)\)]],
  "\n\nwhere  ",
  Cell[BoxData[
      \(\(q\_k\) \((x)\)\  = \ \(p\_k\) \((\(2\ x - a - b\)\/\(b - \
a\))\)\)]],
  "  is the ",
  Cell[BoxData[
      \(n\^th\)]],
  " shifted Legendre polynomial and \n\n\t\t",
  Cell[BoxData[
      \(c\_k\ \  = \ \ \(2  k + 1\)\/\(b - a\)\ \(\[Integral]\_a\%b\ 
            f \((x)\) \(q\_k\) \((x)\) \[DifferentialD]x\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Legendre Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LegendrePolyProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Legendre Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LegendrePolyProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Compare the \"discrete interpolation polynomial\" and \"shifted Legendre \
series approximation\" \n",
  StyleBox["9 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = Sin[\[Pi]\ x]\)]],
  ",  on the interval  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  \n",
  StyleBox["9 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = ArcTan[x]\)]],
  ",  on the interval  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[\[Pi]\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(c\_k_\ \  := \ \ \(2  k + 1\)\/\(b - a\)\ \(\[Integral]\_a\%b f[x] 
            LegendreP[
              k, \(2\ x - a - b\)\/\(b - a\)] \[DifferentialD]x\)\), "\n", 
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n\( c\_k\) 
            LegendreP[k, \(2\ x - a - b\)\/\(b - a\)];\)\), "\n", 
    \(\(g[x_]\  = Chop[N[Expand[g[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Chop[Expand[
            InterpolatingPolynomial[XY, x]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x], g[x], q[x]}, {x, 0, 1}, 
          PlotStyle \[Rule] {Magenta, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The shifted Legendre series approximation is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the 'continuous least squares \
approximation' in example 4(a).\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compare it with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial'\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \)}], "Input"],

Cell["Details for this computation.", "Text"],

Cell["First, construct the coefficients.", "Text"],

Cell[BoxData[
    \(\(For[k = 0, 
        k \[LessEqual] 
          n, \(k++\), \[IndentingNewLine]Print["\<c\>"\_k, "\< = \>", \(2  k \
+ 1\)\/\(b - a\), "\< \>", "\<\[Integral]\>"\+a\%b, "\<(\>", f[x], "\<)(\>", 
          LegendreP[
            k, \(2\ x - a - b\)\/\(b - a\)], "\<)\[DifferentialD]x\>"]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< = \>", c\_k, "\< = \>", 
          N[c\_k], "\<\n\>"\ ];\ \ ];\)\)], "Input"],

Cell["Construct the terms.", "Text"],

Cell[BoxData[
    \(\(For[k = 0, 
        k \[LessEqual] 
          n, \(k++\), \[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, \*"\"\<,\!\(\(2\\\ x - a - b\)\/\(b - a\)\)] = \>\"", 
          c\_k, "\<(\>", 
          LegendreP[
            k, \(2\ x - a - b\)\/\(b - a\)], "\<)\>"\ ]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, \*"\"\<,\!\(\(2\\\ x - a - b\)\/\(b - a\)\)] = \>\"", 
          N[c\_k], "\<(\>", 
          LegendreP[
            k, \(2\ x - a - b\)\/\(b - a\)], "\<)\>"\ ]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, \*"\"\<,\!\(\(2\\\ x - a - b\)\/\(b - a\)\)] = \>\"", 
          N[\(c\_k\) 
              LegendreP[
                k, \(2\ x - a - b\)\/\(b - a\)]]\ ]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, \*"\"\<,\!\(\(2\\\ x - a - b\)\/\(b - a\)\)] = \>\"", 
          N[Expand[\(c\_k\) 
                LegendreP[
                  k, \(2\ x - a - b\)\/\(b - a\)]]], "\<\n\>"\ ];\ \ ];\)\)], \
"Input"],

Cell["Then add up the terms.", "Text"],

Cell[BoxData[{
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n N[c\_k] 
            LegendreP[
              k, \(2\ x - a - b\)\/\(b - a\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", Chop[N[Expand[g[x]]]]\ ];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = ArcTan[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 3;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(c\_k_\ \  := \ \ \(2  k + 1\)\/\(b - a\)\ \(\[Integral]\_a\%b f[x] 
            LegendreP[
              k, \(2\ x - a - b\)\/\(b - a\)] \[DifferentialD]x\)\), "\n", 
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n\( c\_k\) 
            LegendreP[k, \(2\ x - a - b\)\/\(b - a\)];\)\), "\n", 
    \(\(g[x_]\  = Chop[N[Expand[g[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Chop[Expand[
            InterpolatingPolynomial[XY, x]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x], g[x], q[x]}, {x, 0, 3}, 
          PlotStyle \[Rule] {Magenta, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The shifted Legendre series approximation is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the 'continuous least squares \
approximation' in example 3(a).\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compare it with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial'\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \)}], "Input"],

Cell["Details for this computation.", "Text"],

Cell["First, construct the coefficients.", "Text"],

Cell[BoxData[
    \(\(For[k = 0, 
        k \[LessEqual] 
          n, \(k++\), \[IndentingNewLine]Print["\<c\>"\_k, "\< = \>", \(2  k \
+ 1\)\/\(b - a\), "\< \>", "\<\[Integral]\>"\+a\%b, "\<(\>", f[x], "\<)(\>", 
          LegendreP[
            k, \(2\ x - a - b\)\/\(b - a\)], "\<)\[DifferentialD]x\>"]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< = \>", c\_k, "\< = \>", 
          Chop[N[c\_k]], "\<\n\>"\ ];\ \ ];\)\)], "Input"],

Cell["Construct the terms.", "Text"],

Cell[BoxData[
    \(\(For[k = 0, 
        k \[LessEqual] 
          n, \(k++\), \[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, \*"\"\<,\!\(\(2\\\ x - a - b\)\/\(b - a\)\)] = \>\"", 
          c\_k, "\<(\>", 
          LegendreP[
            k, \(2\ x - a - b\)\/\(b - a\)], "\<)\>"\ ]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, \*"\"\<,\!\(\(2\\\ x - a - b\)\/\(b - a\)\)] = \>\"", 
          Chop[N[c\_k]], "\<(\>", 
          LegendreP[
            k, \(2\ x - a - b\)\/\(b - a\)], "\<)\>"\ ]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, \*"\"\<,\!\(\(2\\\ x - a - b\)\/\(b - a\)\)] = \>\"", 
          Chop[N[c\_k]] 
            N[LegendreP[
                k, \(2\ x - a - b\)\/\(b - a\)]]\ ]; \
\[IndentingNewLine]Print["\<c\>"\_k, "\< LegendreP[\>", 
          k, \*"\"\<,\!\(\(2\\\ x - a - b\)\/\(b - a\)\)] = \>\"", 
          Chop[N[Expand[\(c\_k\) 
                  LegendreP[
                    k, \(2\ x - a - b\)\/\(b - a\)]]]], "\<\n\>"\ ];\ \ \
];\)\)], "Input"],

Cell["Then add up the terms.", "Text"],

Cell[BoxData[{
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n Chop[N[c\_k]] 
            LegendreP[
              k, \(2\ x - a - b\)\/\(b - a\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", Chop[N[Expand[g[x]]]]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Error Analysis",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tWe have shown that \"",
  "Legendre series approximation",
  "\" is an efficient way to construct \"the continuous least squares fit.\"  \
We will now compare it's error with that of the \"discrete interpolation \
polynomial.\" "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Investigate the error for",
  " the \"discrete interpolation polynomial\" and \"Legendre series \
approximation,\" on the interval  ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ".  \n",
  StyleBox["10 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = \[ExponentialE]\^x\)]],
  ".   \n",
  StyleBox["10 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = \(\[ExponentialE]\^x\) Cos[\[Pi]\/2\ x]\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \[ExponentialE]\^x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(c\_k_\ \  := \ \ \(2  k + 1\)\/2\ \(\[Integral]\_\(-1\)\%1 f[x] 
            LegendreP[k, x] \[DifferentialD]x\)\), "\n", 
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n\( c\_k\) 
            LegendreP[k, x];\)\), "\n", 
    \(\(g[x_]\  = Chop[N[Expand[g[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Chop[Expand[
            InterpolatingPolynomial[XY, x]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x], g[x], q[x]}, {x, \(-1\), 1}, 
          PlotStyle \[Rule] {Magenta, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 2.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Legendre series approximation is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the 'continuous least squares \
approximation' in example 3(a).\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compare it with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial'\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \)}], "Input"],

Cell["Let us look at the error for the two approximations.", "Text"],

Cell[BoxData[{
    \(\(Plot[f[x] - g[x], {x, \(-1\), 1}, PlotStyle \[Rule] Red, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.001\), 0.00125, 
              0.00025]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the 'Legendre series approximation' where \>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]];\)\ \ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[f[x] - q[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.001\), 0.00125, 
              0.00025]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the 'discrete interpolation polynomial' where \
\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[{f[x] - g[x], f[x] - q[x]}, {x, \(-1\), 1}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.001\), 0.00125, 
              0.00025]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|f[x] - g[x]| \[LessEqual] \>", 
        PaddedForm[
          Abs[f[1] - g[1]], {8, 
            8}], "\<  Red\>"];\)\ \ \ \ \), "\[IndentingNewLine]", 
    \(\(qerrsol = 
        FindRoot[\(f'\)[x] - \(q'\)[x] \[Equal] 0, {x, 
            0.7}];\)\), "\[IndentingNewLine]", 
    \(\(qerr = 
        qerrsol\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|f[x] - q[x]| \[LessEqual] \>", 
        PaddedForm[
          Abs[f[qerr] - q[qerr]], {8, 
            8}], "\<  Blue\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial' is a little \
better.\>"];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(\[ExponentialE]\^x\) 
          Cos[\[Pi]\/2\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; Remove[c];\ \), "\[IndentingNewLine]", 
    \(c\_k_\ \  := \ \ \(2  k + 1\)\/2\ \(\[Integral]\_\(-1\)\%1 f[x] 
            LegendreP[k, x] \[DifferentialD]x\)\), "\n", 
    \(\(g[
          x_]\  = \ \ \[Sum]\+\(k = 0\)\%n\( c\_k\) 
            LegendreP[k, x];\)\), "\[IndentingNewLine]", 
    \(\(g[x_]\  = Chop[N[Expand[g[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Chop[Expand[
            InterpolatingPolynomial[XY, x]]];\)\ \), "\[IndentingNewLine]", 
    \(\(a = \(-1\);\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Expand[InterpolatingPolynomial[XY, 
            x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x], g[x], q[x]}, {x, \(-1\), 1}, 
          PlotStyle \[Rule] {Magenta, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.25}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Legendre series approximation is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the 'continuous least squares \
approximation' in example 3(a).\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compare it with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial'\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \)}], "Input"],

Cell["Let us look at the error for the two approximations.", "Text"],

Cell[BoxData[{
    \(\(Plot[f[x] - g[x], {x, \(-1\), 1}, PlotStyle \[Rule] Red, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.005\), 0.0125, 
              0.0025]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the 'Legendre series approximation' where \>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]];\)\ \ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[f[x] - q[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.0125\), 0.0025, 
              0.005]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the 'discrete interpolation polynomial' where \
\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[{f[x] - g[x], f[x] - q[x]}, {x, \(-1\), 1}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.0125\), 0.0125, 
              0.005]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|f[x] - g[x]| \[LessEqual] \>", 
        PaddedForm[
          Abs[f[1] - g[1]], {8, 
            8}], "\<  Red\>"];\)\ \ \ \ \), "\[IndentingNewLine]", 
    \(\(qerrsol = 
        FindRoot[\(f'\)[x] - \(q'\)[x] \[Equal] 0, {x, 
            0.7}];\)\), "\[IndentingNewLine]", 
    \(\(qerr = 
        qerrsol\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|f[x] - q[x]| \[LessEqual] \>", 
        PaddedForm[
          Abs[f[qerr] - q[qerr]], {8, 
            8}], "\<  Blue\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'Legendre series approximation' is a little better.\>"];\
\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Investigate the error for the \"discrete interpolation polynomial\" and \
\"shifted Legendre series approximation\" \n",
  StyleBox["11 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = Sin[\[Pi]\ x]\)]],
  ",  on the interval  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  \n",
  StyleBox["11 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the function  ",
  Cell[BoxData[
      \(f[x] = ArcTan[x]\)]],
  ",  on the interval  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = Sin[\[Pi]\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(c\_k_\ \  := \ \ \(2  k + 1\)\/\(b - a\)\ \(\[Integral]\_a\%b f[x] 
            LegendreP[
              k, \(2\ x - a - b\)\/\(b - a\)] \[DifferentialD]x\)\), "\n", 
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n\( c\_k\) 
            LegendreP[k, \(2\ x - a - b\)\/\(b - a\)];\)\), "\n", 
    \(\(g[x_]\  = Chop[N[Expand[g[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Chop[Expand[
            InterpolatingPolynomial[XY, x]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x], g[x], q[x]}, {x, 0, 1}, 
          PlotStyle \[Rule] {Magenta, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.8, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The shifted Legendre series approximation is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the 'continuous least squares \
approximation' in example 4(a).\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compare it with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial'\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \)}], "Input"],

Cell["Let us look at the error for the two approximations.", "Text"],

Cell[BoxData[{
    \(\(Plot[f[x] - g[x], {x, 0, 1}, PlotStyle \[Rule] Red, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.00125\), 0.00175, 
              0.0005]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the 'Legendre series approximation' where \>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]];\)\ \ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[f[x] - q[x], {x, 0, 1}, PlotStyle \[Rule] Blue, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.00125\), 0.00175, 
              0.0005]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the 'discrete interpolation polynomial' where \
\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[{f[x] - g[x], f[x] - q[x]}, {x, 0, 1}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[\(-0.00125\), 0.00175, 
              0.0005]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|f[x] - g[x]| \[LessEqual] \>", 
        PaddedForm[
          Abs[f[0] - g[0]], {8, 
            8}], "\<  Red\>"];\)\ \ \ \ \), "\[IndentingNewLine]", 
    \(\(qerrsol = 
        FindRoot[\(f'\)[x] - \(q'\)[x] \[Equal] 0, {x, 
            0.9}];\)\), "\[IndentingNewLine]", 
    \(\(qerr = 
        qerrsol\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|f[x] - q[x]| \[LessEqual] \>", 
        PaddedForm[
          Abs[f[qerr] - q[qerr]], {8, 
            8}], "\<  Blue\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'Legendre series approximation' is better.\>"];\)\)}], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = ArcTan[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a\  = \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 3;\)\ \), "\[IndentingNewLine]", 
    \(Clear[k]; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(c\_k_\ \  := \ \ \(2  k + 1\)\/\(b - a\)\ \(\[Integral]\_a\%b f[x] 
            LegendreP[
              k, \(2\ x - a - b\)\/\(b - a\)] \[DifferentialD]x\)\), "\n", 
    \(\(g[
          x_]\  = \ \[Sum]\+\(k = 0\)\%n\( c\_k\) 
            LegendreP[k, \(2\ x - a - b\)\/\(b - a\)];\)\), "\n", 
    \(\(g[x_]\  = Chop[N[Expand[g[x]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(XY = 
        N[Table[{a + \(\(b - a\)\/n\) k, f[a + \(\(b - a\)\/n\) k]}, {k, 0, 
              n}]];\)\), "\[IndentingNewLine]", 
    \(\(q[x_] = 
        Chop[Expand[
            InterpolatingPolynomial[XY, x]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Cdot = 
        ListPlot[XY, PlotStyle \[Rule] {Red, PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x], g[x], q[x]}, {x, 0, 3}, 
          PlotStyle \[Rule] {Magenta, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, Cdot, PlotRange \[Rule] {{0, 3}, {0, 1.25}}, 
        Ticks \[Rule] {Range[0, 3, 0.5], Range[0, 1.25, 0.25]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The shifted Legendre series approximation is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the 'continuous least squares \
approximation' in example 3(a).\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Compare it with\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The 'discrete interpolation polynomial'\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]\ ];\)\ \)}], "Input"],

Cell["Let us look at the error for the two approximations.", "Text"],

Cell[BoxData[{
    \(\(Plot[f[x] - g[x], {x, 0, 3}, PlotStyle \[Rule] Red, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], 
            Range[\(-0.0125\), 0.0125, 
              0.005]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the 'Legendre series approximation' where \>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = \>", g[x]];\)\ \ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[f[x] - q[x], {x, 0, 3}, PlotStyle \[Rule] Blue, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], 
            Range[\(-0.0125\), 0.0125, 
              0.005]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the 'discrete interpolation polynomial' where \
\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<q[x] = \>", q[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[{f[x] - g[x], f[x] - q[x]}, {x, 0, 3}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[\(-1\), 3, 1], 
            Range[\(-0.0125\), 0.0125, 
              0.005]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|f[x] - g[x]| \[LessEqual] \>", 
        PaddedForm[
          Abs[f[0] - g[0]], {8, 
            8}], "\<  Red\>"];\)\ \ \ \ \), "\[IndentingNewLine]", 
    \(\(qerrsol = 
        FindRoot[\(f'\)[x] - \(q'\)[x] \[Equal] 0, {x, 
            0.2}];\)\), "\[IndentingNewLine]", 
    \(\(qerr = 
        qerrsol\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<|f[x] - q[x]| \[LessEqual] \>", 
        PaddedForm[
          Abs[f[qerr] - q[qerr]], {8, 
            8}], "\<  Blue\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The 'Legendre series approximation' is a little better.\>"];\
\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]],
  "  The maximum error for the \"Legendre series approximation\" seems to \
occurs at an endpoint. The maximum error for the \"discrete interpolation \
polynomial\" occurs near an endpoint. \nThe maximum error for both methods \
are not too much different.   "
}], "Text"],

Cell[TextData[{
  StyleBox["Improvements",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tWhen we study the Fourier-Chebyshev series approximation we will \
see that the error near the endpoints is reduced considerably and hence the \
overall error bounds will be considerably smaller. The details are given in \
the ",
  ButtonBox["Chebyshev Series Module",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/ChebyshevSeriesMod.html"],
       None},
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Legendre Polynomials",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/LegendrePolyBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{972, 652},
WindowMargins->{{6, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 198, 5, 35, "Text"],
Cell[1977, 60, 1133, 38, 140, "Text"]
}, Closed]],
Cell[3125, 101, 2145, 57, 182, "Text"],
Cell[5273, 160, 2059, 65, 116, "Text"],
Cell[7335, 227, 2671, 79, 159, "Text"],
Cell[10009, 308, 836, 26, 52, "Text"],
Cell[10848, 336, 448, 14, 52, "Text"],
Cell[11299, 352, 678, 23, 74, "Text"],

Cell[CellGroupData[{
Cell[12002, 379, 105, 2, 33, "Text"],
Cell[12110, 383, 4327, 80, 810, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16474, 468, 105, 2, 30, "Text"],
Cell[16582, 472, 4359, 81, 821, "Input"]
}, Closed]],
Cell[20956, 556, 704, 26, 68, "Text"],

Cell[CellGroupData[{
Cell[21685, 586, 105, 2, 33, "Text"],
Cell[21793, 590, 4299, 80, 810, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26129, 675, 105, 2, 30, "Text"],
Cell[26237, 679, 4280, 80, 810, "Input"]
}, Closed]],
Cell[30532, 762, 3474, 105, 204, "Text"],
Cell[34009, 869, 2725, 79, 159, "Text"],
Cell[36737, 950, 370, 13, 33, "Text"],
Cell[37110, 965, 357, 12, 33, "Text"],
Cell[37470, 979, 657, 23, 74, "Text"],

Cell[CellGroupData[{
Cell[38152, 1006, 105, 2, 33, "Text"],
Cell[38260, 1010, 1586, 29, 376, "Input"],
Cell[39849, 1041, 3207, 58, 568, "Input"],
Cell[43059, 1101, 102, 4, 71, "Text"],
Cell[43164, 1107, 904, 19, 190, "Input"],
Cell[44071, 1128, 609, 23, 71, "Text"],
Cell[44683, 1153, 965, 18, 197, "Input"],
Cell[45651, 1173, 61, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[45749, 1178, 105, 2, 30, "Text"],
Cell[45857, 1182, 1485, 26, 367, "Input"],
Cell[47345, 1210, 3270, 59, 568, "Input"],
Cell[50618, 1271, 102, 4, 71, "Text"],
Cell[50723, 1277, 916, 19, 190, "Input"],
Cell[51642, 1298, 609, 23, 71, "Text"],
Cell[52254, 1323, 926, 18, 197, "Input"],
Cell[53183, 1343, 61, 0, 33, "Text"]
}, Closed]],
Cell[53259, 1346, 684, 26, 68, "Text"],

Cell[CellGroupData[{
Cell[53968, 1376, 105, 2, 33, "Text"],
Cell[54076, 1380, 1580, 29, 376, "Input"],
Cell[55659, 1411, 3179, 58, 568, "Input"],
Cell[58841, 1471, 373, 8, 52, "Text"],
Cell[59217, 1481, 904, 19, 190, "Input"],
Cell[60124, 1502, 299, 10, 33, "Text"],
Cell[60426, 1514, 198, 4, 50, "Input"],
Cell[60627, 1520, 2481, 78, 109, "Text"],
Cell[63111, 1600, 1237, 23, 173, "Input"],
Cell[64351, 1625, 493, 17, 33, "Text"],
Cell[64847, 1644, 824, 27, 52, "Text"],
Cell[65674, 1673, 609, 23, 71, "Text"],
Cell[66286, 1698, 965, 18, 197, "Input"],
Cell[67254, 1718, 61, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[67352, 1723, 105, 2, 30, "Text"],
Cell[67460, 1727, 1653, 30, 396, "Input"],
Cell[69116, 1759, 3162, 58, 568, "Input"],
Cell[72281, 1819, 373, 8, 52, "Text"],
Cell[72657, 1829, 904, 19, 190, "Input"],
Cell[73564, 1850, 299, 10, 33, "Text"],
Cell[73866, 1862, 198, 4, 50, "Input"],
Cell[74067, 1868, 2481, 78, 109, "Text"],
Cell[76551, 1948, 1237, 23, 173, "Input"],
Cell[77791, 1973, 493, 17, 33, "Text"],
Cell[78287, 1992, 609, 23, 71, "Text"],
Cell[78899, 2017, 926, 18, 197, "Input"],
Cell[79828, 2037, 61, 0, 33, "Text"]
}, Closed]],
Cell[79904, 2040, 1838, 55, 164, "Text"],
Cell[81745, 2097, 790, 24, 33, "Text"],
Cell[82538, 2123, 177, 3, 42, "Input"],
Cell[82718, 2128, 1311, 36, 52, "Text"],
Cell[84032, 2166, 989, 40, 75, "Text"],

Cell[CellGroupData[{
Cell[85046, 2210, 105, 2, 33, "Text"],
Cell[85154, 2214, 784, 13, 184, "Input"],
Cell[85941, 2229, 48, 0, 33, "Text"],
Cell[85992, 2231, 2530, 45, 519, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[88559, 2281, 105, 2, 30, "Text"],
Cell[88667, 2285, 827, 15, 184, "Input"],
Cell[89497, 2302, 48, 0, 33, "Text"],
Cell[89548, 2304, 2573, 47, 519, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[92158, 2356, 105, 2, 30, "Text"],
Cell[92266, 2360, 845, 18, 218, "Input"],
Cell[93114, 2380, 48, 0, 33, "Text"],
Cell[93165, 2382, 2585, 49, 553, "Input"],
Cell[95753, 2433, 357, 12, 33, "Text"]
}, Closed]],
Cell[96125, 2448, 999, 36, 57, "Text"],

Cell[CellGroupData[{
Cell[97149, 2488, 101, 2, 33, "Text"],
Cell[97253, 2492, 339, 7, 110, "Input"],
Cell[97595, 2501, 999, 30, 33, "Text"],
Cell[98597, 2533, 730, 14, 167, "Input"],
Cell[99330, 2549, 441, 13, 33, "Text"],
Cell[99774, 2564, 2808, 51, 518, "Input"],
Cell[102585, 2617, 1569, 46, 33, "Text"],
Cell[104157, 2665, 728, 14, 167, "Input"],
Cell[104888, 2681, 189, 8, 33, "Text"]
}, Closed]],
Cell[105092, 2692, 3692, 116, 317, "Text"],
Cell[108787, 2810, 24549, 432, 207, "Text"],
Cell[133339, 3244, 387, 13, 39, "Text"],
Cell[133729, 3259, 481, 15, 52, "Text"],
Cell[134213, 3276, 419, 14, 33, "Text"],
Cell[134635, 3292, 464, 15, 39, "Text"],
Cell[135102, 3309, 370, 13, 33, "Text"],
Cell[135475, 3324, 831, 26, 58, "Text"],

Cell[CellGroupData[{
Cell[136331, 3354, 101, 2, 33, "Text"],
Cell[136435, 3358, 202, 6, 33, "Text"],
Cell[136640, 3366, 1802, 37, 356, "Input"],
Cell[138445, 3405, 91, 2, 33, "Text"],
Cell[138539, 3409, 268, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[138832, 3419, 97, 2, 33, "Text"],
Cell[138932, 3423, 52, 0, 33, "Text"],
Cell[138987, 3425, 230, 5, 83, "Input"],
Cell[139220, 3432, 65, 0, 33, "Text"],
Cell[139288, 3434, 1885, 33, 302, "Input"],
Cell[141176, 3469, 5515, 101, 585, "Input"],
Cell[146694, 3572, 50, 1, 30, "Input"],
Cell[146747, 3575, 50, 1, 30, "Input"],
Cell[146800, 3578, 50, 1, 30, "Input"],
Cell[146853, 3581, 50, 1, 30, "Input"]
}, Open  ]],
Cell[146918, 3585, 206, 6, 33, "Text"],
Cell[147127, 3593, 466, 9, 146, "Input"],
Cell[147596, 3604, 620, 10, 165, "Input"],
Cell[148219, 3616, 297, 6, 70, "Input"]
}, Closed]],
Cell[148531, 3625, 3050, 82, 147, "Text"],

Cell[CellGroupData[{
Cell[151606, 3711, 137, 3, 33, "Text"],
Cell[151746, 3716, 105, 3, 33, "Text"],
Cell[151854, 3721, 1437, 28, 348, "Input"],
Cell[153294, 3751, 620, 10, 165, "Input"],
Cell[153917, 3763, 297, 6, 70, "Input"]
}, Closed]],
Cell[154229, 3772, 2306, 62, 373, "Text"],
Cell[156538, 3836, 370, 13, 33, "Text"],
Cell[156911, 3851, 357, 12, 33, "Text"],
Cell[157271, 3865, 646, 23, 74, "Text"],

Cell[CellGroupData[{
Cell[157942, 3892, 105, 2, 33, "Text"],
Cell[158050, 3896, 2064, 39, 501, "Input"],
Cell[160117, 3937, 45, 0, 33, "Text"],
Cell[160165, 3939, 50, 0, 33, "Text"],
Cell[160218, 3941, 399, 8, 94, "Input"],
Cell[160620, 3951, 36, 0, 33, "Text"],
Cell[160659, 3953, 701, 16, 110, "Input"],
Cell[161363, 3971, 38, 0, 33, "Text"],
Cell[161404, 3973, 271, 5, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[161712, 3983, 105, 2, 30, "Text"],
Cell[161820, 3987, 2222, 43, 532, "Input"],
Cell[164045, 4032, 45, 0, 33, "Text"],
Cell[164093, 4034, 50, 0, 33, "Text"],
Cell[164146, 4036, 405, 8, 94, "Input"],
Cell[164554, 4046, 36, 0, 33, "Text"],
Cell[164593, 4048, 718, 16, 110, "Input"],
Cell[165314, 4066, 38, 0, 33, "Text"],
Cell[165355, 4068, 277, 5, 91, "Input"]
}, Closed]],
Cell[165647, 4076, 824, 28, 147, "Text"],

Cell[CellGroupData[{
Cell[166496, 4108, 102, 2, 33, "Text"],
Cell[166601, 4112, 324, 7, 90, "Input"],
Cell[166928, 4121, 564, 11, 160, "Input"],
Cell[167495, 4134, 999, 30, 33, "Text"],
Cell[168497, 4166, 780, 15, 191, "Input"],
Cell[169280, 4183, 234, 8, 36, "Text"]
}, Closed]],
Cell[169529, 4194, 844, 28, 150, "Text"],
Cell[170376, 4224, 370, 13, 33, "Text"],
Cell[170749, 4239, 357, 12, 33, "Text"],
Cell[171109, 4253, 678, 26, 71, "Text"],

Cell[CellGroupData[{
Cell[171812, 4283, 105, 2, 33, "Text"],
Cell[171920, 4287, 2118, 40, 501, "Input"],
Cell[174041, 4329, 45, 0, 33, "Text"],
Cell[174089, 4331, 50, 0, 33, "Text"],
Cell[174142, 4333, 428, 8, 94, "Input"],
Cell[174573, 4343, 36, 0, 33, "Text"],
Cell[174612, 4345, 1041, 23, 166, "Input"],
Cell[175656, 4370, 38, 0, 33, "Text"],
Cell[175697, 4372, 312, 6, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[176046, 4383, 105, 2, 30, "Text"],
Cell[176154, 4387, 2122, 40, 501, "Input"],
Cell[178279, 4429, 45, 0, 33, "Text"],
Cell[178327, 4431, 50, 0, 33, "Text"],
Cell[178380, 4433, 434, 8, 94, "Input"],
Cell[178817, 4443, 36, 0, 33, "Text"],
Cell[178856, 4445, 1060, 23, 166, "Input"],
Cell[179919, 4470, 38, 0, 33, "Text"],
Cell[179960, 4472, 318, 6, 91, "Input"]
}, Closed]],
Cell[180293, 4481, 356, 9, 87, "Text"],
Cell[180652, 4492, 679, 25, 74, "Text"],

Cell[CellGroupData[{
Cell[181356, 4521, 106, 2, 33, "Text"],
Cell[181465, 4525, 2064, 39, 501, "Input"],
Cell[183532, 4566, 68, 0, 33, "Text"],
Cell[183603, 4568, 463, 8, 90, "Input"],
Cell[184069, 4578, 464, 8, 90, "Input"],
Cell[184536, 4588, 953, 21, 151, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[185526, 4614, 106, 2, 30, "Text"],
Cell[185635, 4618, 2222, 43, 532, "Input"],
Cell[187860, 4663, 68, 0, 33, "Text"],
Cell[187931, 4665, 461, 8, 90, "Input"],
Cell[188395, 4675, 462, 8, 90, "Input"],
Cell[188860, 4685, 947, 21, 131, "Input"]
}, Closed]],
Cell[189822, 4709, 699, 26, 68, "Text"],

Cell[CellGroupData[{
Cell[190546, 4739, 106, 2, 33, "Text"],
Cell[190655, 4743, 2118, 40, 501, "Input"],
Cell[192776, 4785, 68, 0, 33, "Text"],
Cell[192847, 4787, 459, 8, 90, "Input"],
Cell[193309, 4797, 460, 8, 90, "Input"],
Cell[193772, 4807, 936, 21, 151, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[194745, 4833, 106, 2, 30, "Text"],
Cell[194854, 4837, 2122, 40, 501, "Input"],
Cell[196979, 4879, 68, 0, 33, "Text"],
Cell[197050, 4881, 454, 8, 90, "Input"],
Cell[197507, 4891, 455, 8, 90, "Input"],
Cell[197965, 4901, 940, 21, 131, "Input"]
}, Closed]],
Cell[198920, 4925, 369, 8, 68, "Text"],
Cell[199292, 4935, 543, 14, 90, "Text"],
Cell[199838, 4951, 158, 3, 35, "Text"],
Cell[199999, 4956, 309, 8, 33, "Text"],
Cell[200311, 4966, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

