(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     43131,       1198]*)
(*NotebookOutlinePosition[     43988,       1227]*)
(*  CellTagsIndexPosition[     43944,       1223]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Module for the ",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Catenary",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tA ",
  ButtonBox["catenary",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Catenary.html"], None},
    ButtonStyle->"Hyperlink"],
  " is the curve formed by a flexible cable of uniform density hanging from \
two points under its own weigh.  Cables of suspension bridges and attached to \
telephone poles hang in this shape.  If the lowest point of the catenary is \
at ",
  Cell[BoxData[
      \(\((0, 0)\)\)]],
  ", then the equation of the",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["catenary",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Curves/Catenary.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  " is   \n\n\t\t",
  Cell[BoxData[
      RowBox[{"y", "  ", "=", " ", 
        RowBox[{\(f \((x)\)\), " ", "=", "  ", 
          RowBox[{
            RowBox[{\(c\ cosh \((x\/c)\)\), " ", "-", " ", 
              RowBox[{"c", "    ", 
                StyleBox["where",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[
                  RowBox[{
                    StyleBox["  ",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "  "}]], "c"}]}], ">", 
            "0"}]}]}]],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  ".  "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, c];\)\), "\[IndentingNewLine]", 
    \(\(F[x_, c_] = c\ Cosh[x\/c] - c;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a = 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(d = 0.618759;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(dot0 = 
        Graphics[{{Blue, PointSize[0.03], 
              Point[{\(-\(a\/2\)\), F[\(-\(a\/2\)\), d\/2]}]}, {Blue, 
              PointSize[0.03], Point[{a\/2, F[a\/2, d\/2]}]}}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(gr0 = 
        Plot[{F[x, d\/2]}, {x, \(-\(a\/2\)\), a\/2}, PlotStyle \[Rule] Blue, 
          Ticks \[Rule] {Range[\(-\(a\/2\)\), a\/2, 1\/2], 
              Range[0, b\/2, 1\/2]}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr0, dot0, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<y = \>", F[x, d\/2]];\)\ \), "\[IndentingNewLine]", 
    \(\(dot1 = 
        Graphics[{{Orange, PointSize[0.03], 
              Point[{\(-a\), F[\(-a\), d]}]}, {Orange, PointSize[0.03], 
              Point[{a, F[a, d]}]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{F[x, d]}, {x, \(-a\), a}, PlotStyle \[Rule] Orange, 
          Ticks \[Rule] {Range[\(-a\), a, 1], Range[0, b, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, dot1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<y = \>", F[x, d]];\)\ \), "\[IndentingNewLine]", 
    \(\(dot2 = 
        Graphics[{{Green, PointSize[0.03], 
              Point[{\(-2\) a, F[\(-2\) a, 2  d]}]}, {Green, PointSize[0.03], 
              Point[{2  a, F[2  a, 2  d]}]}}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr2 = 
        Plot[{F[x, 2  d]}, {x, \(-2\) a, 2  a}, PlotStyle \[Rule] Green, 
          Ticks \[Rule] {Range[\(-2\) a, 2  a, 1], Range[0, 2  b, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr2, dot2, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<y = \>", F[x, 2  d]];\)\ \), "\[IndentingNewLine]", 
    \(\(dot3 = 
        Graphics[{{Magenta, PointSize[0.03], 
              Point[{\(-3\) a, F[\(-3\) a, 3  d]}]}, {Magenta, 
              PointSize[0.03], Point[{3  a, F[3  a, 3  d]}]}}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(gr3 = 
        Plot[{F[x, 3  d]}, {x, \(-3\) a, 3  a}, PlotStyle \[Rule] Magenta, 
          Ticks \[Rule] {Range[\(-3\) a, 3  a, 1], Range[0, 3  b, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr3, dot3, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<y = \>", F[x, 3  d]];\)\ \)}], "Input"],

Cell["\<\
Do the above four catenaries look similar ?  Are they the same ? 
Plot them on the same graph to see what is happening.  \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[gr0, gr1, gr2, gr3, dot0, dot1, dot2, dot3, 
        PlotRange \[Rule] {{\(-3\), 3}, {0, 3.1}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 3, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y = \>", F[x, d\/2]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", F[x, d]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", F[x, 2  d]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", F[x, 3  d]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "\tHence we see that the \"shape\" of the curve ",
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  " is preserved when it is changed to ",
  Cell[BoxData[
      \(y = c\ f \((x\/c)\)\)]],
  ", indeed the curve is merely magnified by the scale factor ",
  Cell[BoxData[
      \(c\)]],
  " when ",
  Cell[BoxData[
      \(c > 0\)]],
  " or reduced by the scale factor ",
  Cell[BoxData[
      \(c\)]],
  " when  ",
  Cell[BoxData[
      \(c < 0\)]],
  ".  Therefore, in order to \"preserve the shape\",  use the formula  \n\n\t\
",
  Cell[BoxData[
      RowBox[{"y", " ", "=", " ", 
        RowBox[{
          RowBox[{\(c\ cosh \((x\/c)\)\), " ", "-", " ", 
            RowBox[{"c", "  ", 
              StyleBox["where",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "c"}]}], ">", "0"}]}]],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  ",\n\nfor a \"catenary\" which passes through the origin.  "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[TextData[{
  StyleBox["Approximated by a parabola",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tNotice that  ",
  Cell[BoxData[
      \(f \((x)\)\  = \ \ c\ cosh \((x\/c)\)\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  "  is an even function. The following computation shows that the first term \
in the Maclaurin series is ",
  Cell[BoxData[
      \(x\^2\/\(2\ c\)\)]],
  ".  For this reason it is often claimed that the shape of a hanging cable \
is \"approximated by a parabola.\"  \n\n\t",
  Cell[BoxData[
      RowBox[{
        InterpretationBox[\("f[x] = "\[InvisibleSpace]\(\(-c\) + 
              c\ Cosh[x\/c]\)\),
          SequenceForm[ "f[x] = ", 
            Plus[ 
              Times[ -1, c], 
              Times[ c, 
                Cosh[ 
                  Times[ 
                    Power[ c, -1], x]]]]],
          Editable->False], " ", "=", 
        " ", \(\[Sum]\+\(n = 1\)\%\[Infinity]\( 
                1\/\(\(\((2  n)\)!\) c\^\(2  n - 1\)\)\) x\^\(2  n\)\)}]]],
  ".\n\n\t",
  Cell[BoxData[
      \(f[
          x]\  = \ \(\(1\/\(\(2!\)\ c\)\) x\^2 + \(1\/\(\(4!\)\ c\^3\)\) 
                  x\^4 + \(1\/\(\(6!\)\ c\^5\)\) 
                  x\^6 + \(1\/\(\(8!\)\ c\^7\)\) 
                  x\^8 + \(1\/\(\(10!\)\ c\^9\)\) 
                  x\^10 +  ... \) + \(1\/\(\(\((2  n)\)!\) 
                    c\^\(2  n - 1\)\)\) x\^\(2  n\)\  + \  ... \)]],
  ".\n\n\t",
  Cell[BoxData[
      \(f[x]\  \[TildeTilde] \ \(1\/\(\(2!\)\ c\)\) x\^2\)]]
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Find the Maclaurin series for  ",
  Cell[BoxData[
      \(f \((x)\)\  = \ \ c\ cosh \((x\/c)\)\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, f, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[x_] = c\ Cosh[x\/c] - c;\)\ \), "\[IndentingNewLine]", 
    \(\(s[x_] = Series[f[x], {x, 0, 12}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<s[x] = \>", s[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The first term in the series is:\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[x] \[TildeTilde] \>", 
        Take[Normal[s[x]], 1]];\)\)}], "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "The general term in the series is  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 1\)\%\[Infinity]\( 
              1\/\(\(\((2  n)\)!\) c\^\(2  n - 1\)\)\) x\^\(2  n\)\)]],
  ".  Summing the first six terms in the series, we get   "
}], "Text"],

Cell[BoxData[{
    \(\(s12[
          x_]\  = \ \[Sum]\+\(n = 1\)\%6\( 
                1\/\(\(\((2  n)\)!\) c\^\(2  n - 1\)\)\) 
            x\^\(2  n\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< s[x] = \>", s[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(s\_12\)[x] = \>\"", s12[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is able to sum the infinite series.  "
}], "Text"],

Cell[BoxData[{
    \(\(S[
          x_] = \[Sum]\+\(n = 1\)\%\[Infinity]\( 
                1\/\(\(\((2  n)\)!\) c\^\(2  n - 1\)\)\) 
            x\^\(2  n\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< S[x] = \!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(1\/\(\(\((2  n)\)!\) c\^\(2  n - 1\)\)\)\!\(x\^\(2  n\)\
\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< S[x] = \>", S[x]];\)\), "\[IndentingNewLine]", 
    \(\(S[x_] = FullSimplify[S[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< S[x] = \>", S[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< S[x] = \>", Expand[S[x]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Arc Length",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe arc length of the curve  ",
  Cell[BoxData[
      \(y = \(f[x] = c\ Cosh[x\/c] - c\)\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  "  is found by using the integrand  ",
  Cell[BoxData[
      \(g[
          x]\  = \ \(\@\(1 + \((\(f'\)[x])\)\^2\)\  = \@\(1 + Sinh[x\/c]\^2\)\
\)\)]],
  ".  The length of the catenary over the interval  [0,a] is given by the \
calculation  \n\n\t",
  Cell[BoxData[
      \(Arc\ Length\  = \ \(\[Integral]\_0\%a\((\@\(1 + \((\(f'\)[x])\)\^2\))\
\) \[DifferentialD]x\  = \ c\ Sinh[a\/c]\)\)]],
  "."
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[c, f, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[x_] = c\ Cosh[x\/c] - c;\)\ \), "\[IndentingNewLine]", 
    \(\(g[x_] = \@\(1 + \((\(f'\)[x])\)\^2\);\)\ \), "\[IndentingNewLine]", 
    \(\(G[
          x_]\  = \ \[Integral]\(\@\(1 + \((\(f'\)[x])\)\^2\)\) \
\[DifferentialD]x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<         f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\@\(1 + \((\(f'\)[x])\)\^2\)\) = \>\"", \@\(1 + \
\((\(f'\)[x])\)\^2\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<         g[x] = \>", g[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<G[x] = \>", "\<\[Integral] \>", \*"\"\<\!\(\@\(1 + \
\((\(f'\)[x])\)\^2\)\)\>\"", "\< \[DifferentialD]x\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<G[x] = \>", "\<\[Integral] \>", \@\(1 + \
\((\(f'\)[x])\)\^2\), "\< \[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<G[x] = \>", G[x]];\)\), "\[IndentingNewLine]", 
    \(\(G[x_]\  = \ Simplify[G[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<G[x] = \>", G[x]];\)\), "\[IndentingNewLine]", 
    \(\(G[x_]\  = \ 
        PowerExpand[FullSimplify[G[x]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<G[x] = \>", G[x]];\)\)}], "Input"],

Cell["\<\
Or, we could first simplify the integrand, before using integration. \
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(g[
          x_] = \@\(1 + \((\(f'\)[x])\)\^2\);\)\ \ \), "\[IndentingNewLine]", \

    \(\(Print["\<         f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\@\(1 + \((\(f'\)[x])\)\^2\)\) = \>\"", 
        g[x]];\)\), "\[IndentingNewLine]", 
    \(\(g[x_] = 
        PowerExpand[FullSimplify[g[x]]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\@\(1 + \((\(f'\)[x])\)\^2\)\) = \>\"", 
        g[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<G[x] = \>", "\<\[Integral] \>", \*"\"\<\!\(\@\(1 + \
\((\(f'\)[x])\)\^2\)\)\>\"", "\< \[DifferentialD]x\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<G[x] = \>", "\<\[Integral] \>", 
        PowerExpand[
          FullSimplify[\@\(1 + \((\(f'\)[x])\)\^2\)]], "\< \
\[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<G[x] = \>", G[x]];\)\)}], "Input"],

Cell["\<\
The arc length of the catenary over the interval  [0,a] is given by the \
calculation:\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(Print[\*"\"\<Arc Length = \!\(\[Integral]\_0\%a\)(\!\(\@\(1 + \((\(f'\
\)[x])\)\^2\)\))\[DifferentialD]x\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Arc Length = G[a] - G[0]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Arc Length = \>", G[a]\  - \ G[0]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Catenary Fit",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIn order to find a catenary that has width  ",
  Cell[BoxData[
      \(w = 2  a\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  "  and height  ",
  Cell[BoxData[
      \(h = b\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  "  all we need to observe that  ",
  Cell[BoxData[
      \(f[x] = c\ Cosh[x\/c] - c\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  "  is and even function and that ",
  Cell[BoxData[
      \(y = f[x]\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  " goes through ",
  Cell[BoxData[
      \(\((0, 0)\)\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  " and we also want it to go through the point ",
  Cell[BoxData[
      \(\((a, b)\)\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  ".   On first glance, we see that all we need to do is solve the equation  \
",
  Cell[BoxData[
      \(c\ Cosh[a\/c] - c\  = \ b\)]],
  "  for   ",
  Cell[BoxData[
      \(c\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  ".  However, this is not possible to do analytically with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", as we can find out by issuing the following command.   "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(Clear[a, b, c];\)\), "\[IndentingNewLine]", 
    \(Solve[\ c\ Cosh[a\/c] - c \[Equal] b, \ c]\ \ \)}], "Input"],

Cell[TextData[{
  "\tTherefore, we must resort to using a numerical approximation for c \
instead of a \"formula.\"   In our exploration, the graphs we used the \
mysterious constant ",
  Cell[BoxData[
      \(d = 0.618759\)]],
  ", which was found by determining the catenary that passes through the \
origin and the point ",
  Cell[BoxData[
      \(\((1, 1)\)\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  ".  "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(\(solset\)\(=\)\(FindRoot[
        c\ Cosh[1\/c] - c \[Equal] 1, {c, 1}]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(f[x_] = 
        ReplaceAll[c\ Cosh[x\/c] - c, 
          c \[Rule] 0.6187592277630104];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(dot1 = 
        Graphics[{{Orange, PointSize[0.03], 
              Point[{\(-1\), f[\(-1\)]}]}, {Orange, PointSize[0.03], 
              Point[{1, f[1]}]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        Plot[{f[x]}, {x, \(-1\), 1}, PlotStyle \[Rule] Orange, 
          Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1, 1]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, dot1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<The catenary\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["The Catenary",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CatenaryProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Catenary",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CatenaryProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["The Catenary",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CatenaryProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Catenary",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CatenaryProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the catenary that goes through the origin and also passes through \
the two points  with  a = 10  and b = 6."
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(a = 10;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 6;\)\ \ \), "\[IndentingNewLine]", 
    \(\(pts = {{\(-a\), b}, {0, 0}, {a, b}};\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(dots = 
        Graphics[{Red, PointSize[0.02], Map[Point, pts]}];\)\ \ \), "\n", 
    \(\(Show[dots, PlotRange \[Rule] {{\(-a\) - 0.1, a + 0.1}, {0, b + 0.1}}, 
        Axes \[Rule] True];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Enter the formula for the catenary and determine the constant ",
  Cell[BoxData[
      \(c\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  ".  "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(Clear[c, f, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[x_] = c\ Cosh[x\/c] - c;\)\ \ \), "\[IndentingNewLine]", 
    \(\(h[c_] = f[a] - b;\)\), "\[IndentingNewLine]", 
    \(\(g[c_] = c - h[c]\/\(h'\)[c];\)\), "\[IndentingNewLine]", 
    \(\(eqn1 = f[a] \[Equal] b;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(vals = NestList[g, 10.0, 10];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using Newton`s method\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(c\_n\)} = \>\"", 
        vals];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Obtain  c = \>", 
        vals\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\)];\)\
\ \ \), "\n", 
    \(\(Print["\<Using Mathematica's `FindRoot` procedure\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(solset = FindRoot[eqn1, {c, 9}];\)\ \ \), "\n", 
    \(\(c = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Obtain  c = \>", c];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The desired catenary is\>"];\)\ \ \), "\[IndentingNewLine]", \

    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \ \)}], "Input"],

Cell["Plot this solution. ", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(gr1 = 
        Plot[{f[x]}, {x, \(-a\), a}, 
          PlotRange \[Rule] {{\(-a\) - 0.1, a + 0.1}, {0, b + 0.1}}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Is the desired catenary which\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<goes through (\>", \(-a\), "\<,\>", b, "\<) and (\>", 
        a, "\<,\>", b, "\<)\>"];\)\ \ \)}], "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The length of the catenary can be approximated numerically by using Simpson's \
rule.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(\(Simpson[a0_, b0_, 
          m0_] := \[IndentingNewLine]Module[{a = N[a0], b = N[b0], h, k, 
            m = m0, X}, \[IndentingNewLine]h\  = \ \(b - a\)\/\(2  m\); \ \
\[IndentingNewLine]X\_k_\  = \ 
            a\  + \ k\ h; \ \[IndentingNewLine]Return[\ \(h\/3\) \((F[a] + 
                  F[b] + 2 \(\[Sum]\+\(k = 1\)\%\(m - 1\)F[X\_\(2  k\)]\) + 
                  4 \(\[Sum]\+\(k = 1\)\%m F[
                        X\_\(2  k - 1\)]\))\)\ ];\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(F[x_] = \@\(1 + \((\(f'\)[x])\)\^2\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Length = \>", "\<\[Integral]\>"\+\(-a\)\%a, "\< \>", 
        F[x], "\< \[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(clength\ \  = \ 
        Simpson[\(-10\), 10, 10];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Using Simpson's rule\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The length of the catenary is  \>", 
        clength\ ];\)\ \ \ \)}], "Input"],

Cell[TextData[{
  "The length of the catenary is easily computed using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in ",
  Cell[BoxData[
      StyleBox["NIntegrate",
        FontWeight->"Bold"]]],
  " subroutine. "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(clength = 
        NIntegrate[\@\(1 + \((\(f'\)[x])\)\^2\), {x, \(-a\), 
            a}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Length = \>", "\<\[Integral]\>"\+\(-a\)\%a, "\< \>", \@\(1 + \
\((\(f'\)[x])\)\^2\), "\< \[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The length of the catenary is  \>", 
        clength\ ];\)\ \ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " This could also be computed analytically.  Recall that \n\n\t",
  Cell[BoxData[
      \(\[Integral]\_\(-a\)\%a\((\@\(1 + Sinh[x\/c]\^2\))\) \[DifferentialD]x\
\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\[Integral]\_\(-a\)\%a\((Cosh[
                x\/c])\) \[DifferentialD]x\)\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(c\ Sinh[a\/c] - c\ Sinh[\(-a\)\/c]\)\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(2\ c\ Sinh[a\/c]\)\)\)\)]],
  ". \n\t\n",
  StyleBox["Caution.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  If you use ",
  Cell[BoxData[
      \(\[Integral]\((\@\(1 + \((\(f'\)[x])\)\^2\))\) \(\(\[DifferentialD]x\)\
\(\ \)\)\)]],
  " then ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will go into it's \"special function\" mode of operation and you will get \
Elliptic functions. \n\nThe formula ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " produces for ",
  Cell[BoxData[
      \(\[Integral]\((\@\(1 + Sinh[x\/c]\^2\))\) \[DifferentialD]x\)]],
  " will involve functions studied in first year calculus. \n\nThe following \
definite integral works."
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(len2 = \[Integral]\_\(-a\)\%a\((\@\(1 + Sinh[x\/c]\^2\))\) \(\(\
\[DifferentialD]x\)\(\ \ \)\)\)], "Input"],

Cell["Or you could use the formula ", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(len3 = \(\(2\)  \(c\)\(\ \)\(Sinh[a\/c]\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the equation of the parabola that goes through the origin and the \
point ",
  Cell[BoxData[
      \(\((10, 6)\)\)],
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}}],
  ".  Compare the parabola solution with the catenary solution. "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[d, p, x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(p[x_] = d\ x\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = p[x] = \>", p[x]\ ];\)\ \ \), "\n", 
    \(\(eqn2 = p[a] \[Equal] b;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[eqn2];\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqn2, d];\)\ \ \), "\n", 
    \(\(d = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Obtain  d = \>", d];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The desired parabola is\>"];\)\ \ \), "\[IndentingNewLine]", \

    \(\(Print["\<y = p[x] = \>", p[x]\ ];\)\ \ \)}], "Input"],

Cell["Plot the parabola solution.", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(gr2 = 
        Plot[{p[x]}, {x, \(-a\), a}, 
          PlotRange \[Rule] {{\(-a\) - 0.1, a + 0.1}, {0, b + 0.1}}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr2, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Is the desired parabola which\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<goes through (\>", \(-a\), "\<,\>", b, "\<) and (\>", 
        a, "\<,\>", b, "\<)\>"];\)\ \ \)}], "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The length of the parabola can be approximated numerically by using Simpson's \
rule.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(\(Simpson[a0_, b0_, 
          m0_] := \[IndentingNewLine]Module[{a = N[a0], b = N[b0], h, k, 
            m = m0, X}, \[IndentingNewLine]h\  = \ \(b - a\)\/\(2  m\); \ \
\[IndentingNewLine]X\_k_\  = \ 
            a\  + \ k\ h; \ \[IndentingNewLine]Return[\ \(h\/3\) \((F[a] + 
                  F[b] + 2 \(\[Sum]\+\(k = 1\)\%\(m - 1\)F[X\_\(2  k\)]\) + 
                  4 \(\[Sum]\+\(k = 1\)\%m F[
                        X\_\(2  k - 1\)]\))\)\ ];\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(F[x_] = \@\(1 + \((\(p'\)[x])\)\^2\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Length = \>", "\<\[Integral]\>"\+\(-a\)\%a, "\< \>", 
        F[x], "\< \[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(clength\ \  = \ 
        Simpson[\(-10\), 10, 10];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Using Simpson's rule\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The length of the parabola is  \>", 
        clength\ ];\)\ \ \ \)}], "Input"],

Cell[TextData[{
  "The length of the parabola is easily computed using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in ",
  Cell[BoxData[
      StyleBox["NIntegrate",
        FontWeight->"Bold"]]],
  " subroutine. "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(plength = 
        NIntegrate[\@\(1 + \((\(p'\)[x])\)\^2\), {x, \(-a\), 
            a}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Length = \>", "\<\[Integral]\>"\+\(-a\)\%a, "\< \>", \@\(1 + \
\((\(p'\)[x])\)\^2\), "\< \[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The length of the parabola is  \>", 
        plength];\)\ \ \ \)}], "Input"],

Cell["The length of the parabola could be computed analytically.", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(P[
          x_] = \[Integral]\((\@\(1 + \((\(p'\)[x])\)\^2\))\) \
\[DifferentialD]x;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", p[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<P[x] = \[Integral](\!\(\@\(1 + \((\(p'\)[x])\)\^2\)\))\
\[DifferentialD]x\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[x] = \[Integral] \>", \@\(1 + \((\(p'\)[x])\)\^2\), "\< \
\[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[x] = \>", P[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Length = \>", "\<\[Integral]\>"\+\(-a\)\%a, "\< \>", \@\(1 + \
\((\(p'\)[x])\)\^2\), "\< \[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Length = P[10] - P[-10]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Length = (\>", P[10], "\<) - (\>", 
        P[\(-10\)], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Length = \>", 
        P[10]\  - \ P[\(-10\)]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Length = \>", N[P[10]\  - \ P[\(-10\)]]];\)\)}], "Input"],

Cell["\<\
Notice that there is a difference between the length of the catenary and the \
length of the parabola. \
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(Print["\<The length of the catenary is  \>", 
        clength\ ];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The length of the parabola is  \>", 
        plength];\)\ \ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[gr1, gr2, dots, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = p[x] = \>", p[x]\ ];\)\ \ \)}], "Input"],

Cell["We could plot the difference.  This is just for fun! ", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(Plot[{f[x] - p[x]}, {x, \(-a\), a}, PlotStyle \[Rule] Brown, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y = f[x]- p[x] = \>", f[x] - p[x]\ ];\)\ \ \)}], "Input"],

Cell["\<\
What is the maximum difference in the height of the catenary and parabola?\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(solset = 
        FindMinimum[f[x] - p[x], {x, 5}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The maximum difference is  \>", \(-\ 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)\
];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It occurs when   \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, \
1\)\(\[RightDoubleBracket]\)\)];\)\)}], "Input"],

Cell["\<\
If the unit of length was feet, what is the maximum difference in the height \
of the catenary and parabola in inches?\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(0.142418*12\)], "Input"],

Cell[TextData[{
  "In your home if the error made in construction was  ",
  StyleBox["1.7",
    FontFamily->"Courier New"],
  " inches  off in  6 feet  of height, would you have a concern ?"
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[TextData[{
  StyleBox["Conclusion",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tEither a hanging cable is in the shape of a parabola or a catenary, \
let's look at the history of this controversy.  The following paragraph is \
from the \"Concise Encyclopedia of Mathematics\" by Eric W. Weisstein. \n\n\t\
\"The curve a hanging flexible wire or chain assumes when supported at its \
ends and acted upon by a uniform gravitational force.  The word catenary is \
derived from the Latin word for \"chain''.   In 1669, ",
  StyleBox[ButtonBox["Jungius",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jungius.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  " disproved ",
  StyleBox[ButtonBox["Galileo's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Galileo.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  "  claim that the curve of a chain hanging under gravity would be a \
Parabola (",
  StyleBox[ButtonBox["MacTutor Archive",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jungius.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  ").  The curve is also called the Alysoid and Chainette.  The equation was \
obtained by ",
  StyleBox[ButtonBox["Leibniz",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Leibniz.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  ",  ",
  StyleBox[ButtonBox["Huygens",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Huygens.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  ",  and ",
  StyleBox[ButtonBox["Johann Bernoulli",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Bernoulli_\
Johann.html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  "  in 1691 in response to a challenge by",
  StyleBox[ButtonBox[" Jakob Bernoulli",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Bernoulli_\
Jacob.html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  ".\"  Other mathematicians involved with the study of the catenary have \
been ",
  StyleBox[ButtonBox["Robert Adrain",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Adrain.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  ",  ",
  StyleBox[ButtonBox["James Stirling",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Stirling.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  ", and ",
  StyleBox[ButtonBox["Leonhard Euler",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Euler.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  ".  \n\n\tAn article suitable for undergraduates to read is \"",
  ButtonBox["The Catenary and the Tractrix (in Classroom Notes)",
    ButtonData:>{
      URL[ 
      "http://links.jstor.org/sici?sici=0002-9890%28195906%2F195907%2966%3A6%\
3C500%3ATCATT%3E2.0.CO%3B2-G"], None},
    ButtonStyle->"Hyperlink"],
  "\", Robert C. Yates, American Mathematical Monthly, Vol. 66, No. 6. (Jun. \
- Jul., 1959), pp. 500-505. \n          \n\tThe St. Louis Arch at the \
Jefferson National Expansion Memorial was constructed in the shape of a \
catenary. Visit the National Park Service web site ",
  StyleBox[ButtonBox["arch history and architecture",
    ButtonData:>{
      URL[ "http://www.nps.gov/jeff/arch-ov.htm#Top"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  ".   Or, go directly to the web page for the precise mathematical formula \
for the St. Louis arch (",
  StyleBox[ButtonBox["catenary curve equation",
    ButtonData:>{
      URL[ "http://www.nps.gov/jeff/equation.htm#Top"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  "). \n          \n\tThe University of British Columbia Mathematics \
Department has an ",
  StyleBox[ButtonBox["amusing property of the catenary",
    ButtonData:>{
      URL[ 
      "http://www.sunsite.ubc.ca/LivingMathematics/V001N01/UBCExamples/\
Animation/catenary.html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  " (Java animation). Which is part of their \"",
  StyleBox[ButtonBox["Living Mathematics Project",
    ButtonData:>{
      URL[ "http://SunSITE.UBC.CA/LivingMathematics/V001N01/UBCExamples/"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  "\" for \"Constructing a new medium for the communication of Mathematics''. \
 "
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The Catenary",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/CatenaryBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Catenary",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CatenaryBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 309, 11, 35, "Text"],
Cell[2088, 66, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3567, 118, 2013, 56, 128, "Text"],

Cell[CellGroupData[{
Cell[5605, 178, 104, 2, 33, "Text"],
Cell[5712, 182, 3057, 59, 524, "Input"],
Cell[8772, 243, 145, 3, 52, "Text"],
Cell[8920, 248, 552, 9, 144, "Input"],
Cell[9475, 259, 1250, 39, 134, "Text"]
}, Closed]],
Cell[10740, 301, 1599, 43, 220, "Text"],

Cell[CellGroupData[{
Cell[12364, 348, 104, 2, 33, "Text"],
Cell[12471, 352, 201, 7, 36, "Text"],
Cell[12675, 361, 578, 11, 162, "Input"],
Cell[13256, 374, 258, 6, 38, "Text"],
Cell[13517, 382, 385, 7, 113, "Input"],
Cell[13905, 391, 122, 4, 33, "Text"],
Cell[14030, 397, 678, 12, 194, "Input"]
}, Closed]],
Cell[14723, 412, 740, 22, 146, "Text"],

Cell[CellGroupData[{
Cell[15488, 438, 104, 2, 33, "Text"],
Cell[15595, 442, 1306, 22, 350, "Input"],
Cell[16904, 466, 153, 4, 33, "Text"],
Cell[17060, 472, 936, 19, 209, "Input"],
Cell[17999, 493, 170, 5, 33, "Text"],
Cell[18172, 500, 308, 4, 82, "Input"]
}, Closed]],
Cell[18495, 507, 1447, 49, 112, "Text"],
Cell[19945, 558, 134, 2, 61, "Input"],
Cell[20082, 562, 510, 15, 52, "Text"],
Cell[20595, 579, 119, 2, 42, "Input"],
Cell[20717, 583, 900, 18, 181, "Input"],
Cell[21620, 603, 597, 20, 33, "Text"],
Cell[22220, 625, 589, 20, 33, "Text"],
Cell[22812, 647, 291, 8, 33, "Text"],

Cell[CellGroupData[{
Cell[23128, 659, 101, 2, 33, "Text"],
Cell[23232, 663, 445, 8, 130, "Input"],
Cell[23680, 673, 258, 9, 33, "Text"],
Cell[23941, 684, 1379, 25, 398, "Input"],
Cell[25323, 711, 96, 2, 33, "Text"],
Cell[25422, 715, 711, 15, 110, "Input"],
Cell[26136, 732, 169, 5, 33, "Text"],
Cell[26308, 739, 527, 9, 149, "Input"],
Cell[26838, 750, 486, 8, 132, "Input"],
Cell[27327, 760, 309, 11, 33, "Text"],
Cell[27639, 773, 399, 7, 93, "Input"],
Cell[28041, 782, 1309, 37, 229, "Text"],
Cell[29353, 821, 127, 2, 53, "Input"],
Cell[29483, 825, 105, 2, 33, "Text"],
Cell[29591, 829, 84, 1, 40, "Input"]
}, Closed]],
Cell[29690, 833, 429, 13, 30, "Text"],

Cell[CellGroupData[{
Cell[30144, 850, 101, 2, 33, "Text"],
Cell[30248, 854, 775, 14, 230, "Input"],
Cell[31026, 870, 103, 2, 33, "Text"],
Cell[31132, 874, 708, 15, 110, "Input"],
Cell[31843, 891, 169, 5, 33, "Text"],
Cell[32015, 898, 527, 9, 149, "Input"],
Cell[32545, 909, 486, 8, 132, "Input"],
Cell[33034, 919, 309, 11, 33, "Text"],
Cell[33346, 932, 397, 7, 93, "Input"],
Cell[33746, 941, 134, 2, 33, "Text"],
Cell[33883, 945, 1041, 17, 249, "Input"],
Cell[34927, 964, 187, 5, 33, "Text"],
Cell[35117, 971, 217, 4, 50, "Input"],
Cell[35337, 977, 267, 5, 70, "Input"],
Cell[35607, 984, 129, 2, 33, "Text"],
Cell[35739, 988, 245, 4, 50, "Input"],
Cell[35987, 994, 158, 4, 33, "Text"],
Cell[36148, 1000, 408, 8, 70, "Input"],
Cell[36559, 1010, 202, 5, 33, "Text"],
Cell[36764, 1017, 44, 1, 30, "Input"],
Cell[36811, 1020, 262, 7, 33, "Text"]
}, Closed]],
Cell[37088, 1030, 5041, 135, 353, "Text"],
Cell[42132, 1167, 158, 3, 35, "Text"],
Cell[42293, 1172, 538, 16, 33, "Text"],
Cell[42834, 1190, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

