(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     91699,       2880]*)
(*NotebookOutlinePosition[     92393,       2904]*)
(*  CellTagsIndexPosition[     92349,       2900]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Module for ",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Determinants and Conic Section Curves",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\tFive points in the plane uniquely determine an equation \
for a conic section. The implicit formula for a conic section is often \
mentioned in textbooks, and the special cases for an ellipse, hyperbola, \
parabola, circle are obtained by either setting some coefficients equal to \
zero or making them the same value. ",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[TextData[{
  StyleBox["Implicit Equation for a Line.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\tThe equation  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      StyleBox[\(\(c\_1\) x + \(c\_2\) y + c\_3 = 0\),
        FontWeight->"Bold"]]],
  StyleBox["  of the line through the two points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((x\_1, y\_1)\), \((x\_2, y\_2)\)\)]],
  "  can be computed with the determinant    \n\n\t\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"|", GridBox[{
                {"x", "y", "1"},
                {\(x\_1\), \(y\_1\), "1"},
                {\(x\_2\), \(y\_2\), "1"}
                }], "|"}], "=", "0"}],
        FontWeight->"Bold"]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Use the determinant method to find ",
    FontFamily->"New Century Schlbk"],
  "the line through the points (1,4) and {5,3)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["The matrix  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox["  for the system of equations is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"x", "y", "1"},
              {"x1", "y1", "1"},
              {"x2", "y2", "1"}
              }], ")"}]}], " ", ";"}]], "Input"],

Cell[TextData[{
  "Enter the points (1,4) and (5,3) and put them into rows 2 and 3 of the \
matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[{
    StyleBox[\(pts\  = \ {{1, 4}, {5, 3}}\ ;\),
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\n", \(A\_\(\(\[LeftDoubleBracket]\)\(2, {1, 2}\)\(\
\[RightDoubleBracket]\)\)\  = 
        pts\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ ;\), \
"\n", \(A\_\(\(\[LeftDoubleBracket]\)\(3, {1, 2}\)\(\[RightDoubleBracket]\)\)\
\  = pts\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\ ;\), "\n\
", \(MatrixForm[A]\)}], "Input"],

Cell[TextData[{
  "Form the equation for the line by setting the determinant of  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  equal to zero."
}], "Text"],

Cell[BoxData[
    \(eq1 = \(\(Det[A]\)\(\[Equal]\)\(0\)\(\ \)\)\)], "Input"],

Cell["Then graph the line.", "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), "  "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], Magenta}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 5.2}, {0, 5.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    RowBox[{
      RowBox[{
        StyleBox["line",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ImplicitPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["eq1",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\({x, 0, 5.2}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\({y, 0, 5.2}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] Red\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    RowBox[{
      RowBox[{
        StyleBox["Show",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["[",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["line",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["dots",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(PlotRange \[Rule] {{0, 5.2}, {0, 5.2}}\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(AspectRatio \[Rule] 1\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          ",", \(DisplayFunction \[Rule] $DisplayFunction\)}], "]"}], 
      ";"}], "\n", 
    RowBox[{\(Print["\<Figure 1. The Line \>", eq1];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Through the points  \>", 
        pts];\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Use the determinant method to find ",
    FontFamily->"New Century Schlbk"],
  "the line through the points  (3,1) and (3,4)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["The matrix  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox["  for the system of equations is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"x", "y", "1"},
              {"x1", "y1", "1"},
              {"x2", "y2", "1"}
              }], ")"}]}], " ", ";"}]], "Input"],

Cell[TextData[{
  "Enter the points (3,1) and (3,4) and put them into rows 2 and 3 of the \
matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[{
    StyleBox[\(pts\  = \ {{3, 1}, {3, 4}}\ ;\),
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\n", \(A\_\(\(\[LeftDoubleBracket]\)\(2, {1, 2}\)\(\
\[RightDoubleBracket]\)\)\  = 
        pts\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ ;\), \
"\n", \(A\_\(\(\[LeftDoubleBracket]\)\(3, {1, 2}\)\(\[RightDoubleBracket]\)\)\
\  = pts\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\ ;\), "\n\
", \(MatrixForm[A]\)}], "Input"],

Cell[TextData[{
  "Form the equation for the line by setting the determinant of  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  equal to zero."
}], "Text"],

Cell[BoxData[
    \(eq2 = \(\(Det[A]\)\(\[Equal]\)\(0\)\(\ \)\)\)], "Input"],

Cell["Then graph the line.", "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    StyleBox[\(dots\  = \ 
          ListPlot[pts, PlotStyle \[Rule] {PointSize[0.02], Blue}, 
            PlotRange \[Rule] {{0, 5.2}, {0, 5.2}}, 
            DisplayFunction \[Rule] Identity];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(line\  = \ 
          ImplicitPlot[eq2, {x, 0, 5.2}, {y, 0, 5.2}, 
            PlotStyle \[Rule] Turquoise, DisplayFunction \[Rule] Identity];\),
      
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    RowBox[{
      RowBox[{
        StyleBox["Show",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["[",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["line",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["dots",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(PlotRange \[Rule] {{0, 5.2}, {0, 5.2}}\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(AspectRatio \[Rule] 1\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          ",", \(DisplayFunction \[Rule] $DisplayFunction\)}], "]"}], 
      ";"}], "\n", 
    RowBox[{\(Print["\<Figure 2. The Line \>", eq2];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Use the determinant method to find the ",
    FontFamily->"New Century Schlbk"],
  "line through the points  (1,4) and (5,4)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["The matrix  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox["  for the system of equations is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"x", "y", "1"},
              {"x1", "y1", "1"},
              {"x2", "y2", "1"}
              }], ")"}]}], " ", ";"}]], "Input"],

Cell[TextData[{
  "Enter the points (1,4) and (5,4) and put them into rows 2 and 3 of the \
matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[{
    StyleBox[\(pts\  = \ {{1, 4}, {5, 4}}\ ;\),
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\n", \(A\_\(\(\[LeftDoubleBracket]\)\(2, {1, 2}\)\(\
\[RightDoubleBracket]\)\)\  = 
        pts\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\ ;\), \
"\n", \(A\_\(\(\[LeftDoubleBracket]\)\(3, {1, 2}\)\(\[RightDoubleBracket]\)\)\
\  = pts\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\ ;\), "\n\
", \(MatrixForm[A]\)}], "Input"],

Cell[TextData[{
  "Form the equation for the line by setting the determinant of  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "  equal to zero."
}], "Text"],

Cell[BoxData[
    \(eq3 = \(\(Det[A]\)\(\[Equal]\)\(0\)\(\ \)\)\)], "Input"],

Cell["Then graph the line.", "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], DarkGreen}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 5.2}, {0, 5.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    RowBox[{
      RowBox[{
        StyleBox["line",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ImplicitPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["eq3",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\({x, 0, 5.2}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\({y, 0, 5.2}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] Green\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    RowBox[{
      RowBox[{
        StyleBox["Show",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["[",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["line",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["dots",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(PlotRange \[Rule] {{0, 5.2}, {0, 5.2}}\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(AspectRatio \[Rule] 1\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          ",", \(DisplayFunction \[Rule] $DisplayFunction\)}], "]"}], 
      ";"}], "\n", 
    RowBox[{\(Print["\<Figure 3. The Line \>", eq3];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Implicit Equation for a Circle.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\tThe equation of the circle  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      StyleBox[\(\(c\_1\) \((x\^2 + y\^2)\) + \(c\_2\) x + \(c\_3\) y + 
            c\_4 = 0\),
        FontWeight->"Bold"]]],
  StyleBox["  through the three points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((x\_1, y\_1)\), \((x\_2, y\_2)\), \((x\_3, y\_3)\)\)]],
  "  can be computed with the determinant    \n\n\t\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"|", GridBox[{
                {\(x\^2 + y\^2\), "x", "y", "1"},
                {\(x\_1\%2 + y\_1\%2\), \(x\_1\), \(y\_1\), "1"},
                {\(x\_2\%2 + y\_2\%2\), \(x\_2\), \(y\_2\), "1"},
                {\(x\_3\%2 + y\_3\%2\), \(x\_3\), \(y\_3\), "1"}
                }], "|"}], "=", "0"}],
        FontWeight->"Bold"]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Use the determinant method to find the circle through the \
points ",
    FontFamily->"New Century Schlbk"],
  " (6,1),  (2,2)  and  (1,4).",
  StyleBox["\n",
    FontFamily->"New Century Schlbk"],
  StyleBox["Remark.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" In Exercises 5 and 6 the same points are used to find the \
standard parabola and alternate parabola.",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{6, 1}, {2, 2}, {1, 4}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"Then a row vector corresponding to equation (3) is defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {x\^2 + y\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[
  " for the linear system in (4) and the determinant is now created.  The \
vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining three rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 3, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given three points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x\^2 + y\^2\), "x", "y", "1"},
                {"37", "6", "1", "1"},
                {"8", "2", "2", "1"},
                {"17", "1", "4", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], 
        RowBox[{"(", GridBox[{
              {\(c\_1\)},
              {\(c\_2\)},
              {\(c\_3\)},
              {\(c\_4\)}
              }], ")"}]}], "=", "0"}]], "Text"],

Cell[TextData[StyleBox[
"The determinant of this matrix is computed by typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[StyleBox["The desired equation is:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(eqn\  = \ d == \ 0\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"The conic is the circle shown in Figure 4.  It is plotted using the \
commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], Magenta}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    RowBox[{
      RowBox[{
        StyleBox["curve",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ImplicitPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["eqn",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\({x, 0, 10.2}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\({y, 0, 10.2}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] Red\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    RowBox[{
      RowBox[{
        StyleBox["Show",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["[",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["curve",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["dots",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(AspectRatio \[Rule] 1\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          ",", \(DisplayFunction \[Rule] $DisplayFunction\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Figure 4. The Circle \>", eqn];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Implicit Equation for a Parabola.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\tThe equation of the parabola  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      StyleBox[\(\(c\_1\) x\^2 + \(c\_2\) x + \(c\_3\) y + c\_4 = 0\),
        FontWeight->"Bold"]]],
  StyleBox["  through the three points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((x\_1, y\_1)\), \((x\_2, y\_2)\), \((x\_3, y\_3)\)\)]],
  "  can be computed with the determinant    \n\n\t\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"|", GridBox[{
                {\(x\^2\), "x", "y", "1"},
                {\(x\_1\%2\), \(x\_1\), \(y\_1\), "1"},
                {\(x\_2\%2\), \(x\_2\), \(y\_2\), "1"},
                {\(x\_3\%2\), \(x\_3\), \(y\_3\), "1"}
                }], "|"}], "=", "0"}],
        FontWeight->"Bold"]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Alternate Equation of a Parabola.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk"],
  "\n\n",
  StyleBox["\tThe equation of the parabola  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      StyleBox[\(\(c\_1\) y\^2 + \(c\_2\) x + \(c\_3\) y + c\_4 = 0\),
        FontWeight->"Bold"]]],
  StyleBox["  through the three points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((x\_1, y\_1)\), \((x\_2, y\_2)\), \((x\_3, y\_3)\)\)]],
  "  can be computed with the determinant    \n\n\t\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"|", GridBox[{
                {\(y\^2\), "x", "y", "1"},
                {\(y\_1\%2\), \(x\_1\), \(y\_1\), "1"},
                {\(y\_2\%2\), \(x\_2\), \(y\_2\), "1"},
                {\(y\_3\%2\), \(x\_3\), \(y\_3\), "1"}
                }], "|"}], "=", "0"}],
        FontWeight->"Bold"]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 5.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Use the determinant method to find the standard equation of a \
parabola through the points ",
    FontFamily->"New Century Schlbk"],
  " (6,1),  (2,2)  and  (1,4).",
  StyleBox["\n",
    FontFamily->"New Century Schlbk"],
  StyleBox["Remark.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" In Exercises 4 and 6 the same points are used to find the circle \
and alternate parabola.",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{6, 1}, {2, 2}, {1, 4}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"Then a row vector corresponding to equation (5) is defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {x\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[
  " for the linear system in (6) and the determinant is now created.  The \
vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining three rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 3, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given three points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        RowBox[{
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(x\^2\), "x", "y", "1"},
                  {"36", "6", "1", "1"},
                  {"4", "2", "2", "1"},
                  {"1", "1", "4", "1"}
                  }], "\[NoBreak]", ")"}],
            (MatrixForm[ #]&)], 
          RowBox[{"(", GridBox[{
                {\(c\_1\)},
                {\(c\_2\)},
                {\(c\_3\)},
                {\(c\_4\)}
                }], ")"}]}], "=", "0"}],
      "Text"]], "Text"],

Cell[TextData[StyleBox[
"The determinant of this matrix is computed by typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[StyleBox["The desired equation is:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"\n", 
      StyleBox[\(eqn\  = \ d == \ 0\),
        FontFamily->"Courier",
        FontWeight->"Bold"]}]], "Input"],

Cell[TextData[StyleBox[
"The conic is the standard parabola shown in Figure 5.  It is plotted using \
the commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], Blue}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    StyleBox[\(curve\  = \ 
          ImplicitPlot[eqn, {x, 0, 10.2}, {y, 0, 10.2}, 
            PlotStyle \[Rule] Turquoise, DisplayFunction \[Rule] Identity];\),
      
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(Show[curve, dots, PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] $DisplayFunction];\),
      
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\[IndentingNewLine]", \(Print["\<Figure 5. The Parabola \
\>", eqn]\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Use the determinant method to find the alternate equation of a \
parabola through the points ",
    FontFamily->"New Century Schlbk"],
  " (6,1),  (2,2)  and  (1,4).",
  StyleBox["\n",
    FontFamily->"New Century Schlbk"],
  StyleBox["Remark.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" In Exercises 4 and 5 the same points are used to find the circle \
and standard parabola.",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{6, 1}, {2, 2}, {1, 4}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"Then a row vector corresponding to equation (7) is defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {y\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[
  " for the linear system in (8) and the determinant is now created.  The \
vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining three rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 3, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given three points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(y\^2\), "x", "y", "1"},
                  {"1", "6", "1", "1"},
                  {"4", "2", "2", "1"},
                  {"16", "1", "4", "1"}
                  }], "\[NoBreak]", ")"}],
            (MatrixForm[ #]&)],
          (MatrixForm[ #]&)], 
        RowBox[{"(", GridBox[{
              {\(c\_1\)},
              {\(c\_2\)},
              {\(c\_3\)},
              {\(c\_4\)}
              }], ")"}]}], "=", "0"}]], "Text"],

Cell[TextData[StyleBox[
"The determinant of this matrix is computed by typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[StyleBox["The desired equation is:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"\n", 
      StyleBox[\(eqn\  = \ d == \ 0\),
        FontFamily->"Courier",
        FontWeight->"Bold"]}]], "Input"],

Cell[TextData[StyleBox[
"The conic is the standard parabola shown in Figure 6.  It is plotted using \
the commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    StyleBox[\(\(dots\  = \ 
            ListPlot[pts, PlotStyle \[Rule] {PointSize[0.02], DarkGreen}, 
              PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
              DisplayFunction \[Rule] Identity];\);\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(curve\  = \ 
          ImplicitPlot[eqn, {x, 0, 10.2}, {y, 0, 10.2}, 
            PlotStyle \[Rule] Green, DisplayFunction \[Rule] Identity];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(Show[curve, dots, PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] $DisplayFunction];\),
      
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\[IndentingNewLine]", \(Print["\<Figure 6. The Parabola \
\>", eqn]\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Implicit Equation for a Standard Ellipse.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\tThe equation of the ellipse  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      StyleBox[\(\(c\_1\) x\^2 + \(c\_2\) y\^2 + \(c\_3\) x + \(c\_4\) y + 
            c\_5 = 0\),
        FontWeight->"Bold"]]],
  StyleBox["  through the four points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((x\_1, y\_1)\), \((x\_2, y\_2)\), \((x\_3, y\_3)\), \((x\_4, 
        y\_4)\)\)]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk"],
  "can be computed with the determinant    \n\n\t\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"|", GridBox[{
                {\(x\^2\), \(y\^2\), "x", "y", "1"},
                {\(x\_1\%2\), \(y\_1\%2\), \(x\_1\), \(y\_1\), "1"},
                {\(x\_2\%2\), \(y\_2\%2\), \(x\_2\), \(y\_2\), "1"},
                {\(x\_3\%2\), \(y\_3\%2\), \(x\_3\), \(y\_3\), "1"},
                {\(x\_4\%2\), \(y\_4\%2\), \(x\_4\), \(y\_4\), "1"}
                }], "|"}], "=", "0"}],
        FontWeight->"Bold"]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 7.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Use the determinant method to find the standard ellipse through \
the points ",
    FontFamily->"New Century Schlbk"],
  " (6,1), (2,2), (1,4), (9,2). "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{6, 1}, {2, 2}, {1, 4}, {9, 2}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox["Then a row vector corresponding to equation (9) is \
defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {x\^2, y\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" for the linear system in (10) and the determinant is now \
created.  The vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining five rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 4, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given three points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x\^2\), \(y\^2\), "x", "y", "1"},
                {"36", "1", "6", "1", "1"},
                {"4", "4", "2", "2", "1"},
                {"1", "16", "1", "4", "1"},
                {"81", "4", "9", "2", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], 
        RowBox[{"(", GridBox[{
              {\(c\_1\)},
              {\(c\_2\)},
              {\(c\_3\)},
              {\(c\_4\)},
              {\(c\_5\)}
              }], ")"}]}], "=", "0"}]], "Text"],

Cell[TextData[StyleBox["The determinant of this matrix is computed by \
typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[{
  StyleBox["This quantity is multiplied by  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\(-\ 1\)\/14\)]],
  " ",
  StyleBox["to get the desired equation:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    StyleBox[\(eqn\  = \ \(-\ d\)\/14 == \ 0\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox["The conic is the circle shown in Figure 7.  It is \
plotted using the commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], Magenta}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    StyleBox[\(curve\  = \ 
          ImplicitPlot[eqn, {x, 0, 10.2}, {y, 0, 10.2}, 
            PlotStyle \[Rule] Turquoise, DisplayFunction \[Rule] Identity];\),
      
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(Show[curve, dots, PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] $DisplayFunction];\),
      
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\[IndentingNewLine]", \(Print["\<Figure 7. The Ellipse \>", 
      eqn]\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Implicit Equation for a 5 Point Conic.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\tThe equation of the conic through the five points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((x\_1, y\_1)\), \((x\_2, y\_2)\), \((x\_3, y\_3)\), \((x\_4, 
        y\_4)\), \((x\_5, y\_5)\)\)]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk"],
  "can be computed with the determinant    \n\n\t\t",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          RowBox[{"|", GridBox[{
                {\(x\^2\), \(x\ y\), \(y\^2\), "x", "y", "1"},
                {\(x\_1\%2\), \(x\_1\ y\_1\), \(y\_1\%2\), \(x\_1\), \(y\_1\),
                   "1"},
                {\(x\_2\%2\), \(x\_2\ y\_2\), \(y\_2\%2\), \(x\_2\), \(y\_2\),
                   "1"},
                {\(x\_3\%2\), \(x\_3\ y\_3\), \(y\_3\%2\), \(x\_3\), \(y\_3\),
                   "1"},
                {\(x\_4\%2\), \(x\_4\ y\_4\), \(y\_4\%2\), \(x\_4\), \(y\_4\),
                   "1"},
                {\(x\_5\%2\), \(x\_5\ y\_5\), \(y\_5\%2\), \(x\_5\), \(y\_5\),
                   "1"}
                }], "|"}], "=", "0"}],
        FontWeight->"Bold"]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" 8.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Determine the conic that passes through the five points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((7\/2, 5\/2)\), \((2, 2)\), \((5\/2, 7\/2)\), \((7, 5)\), \((19\/2, 
        7)\)\)]],
  StyleBox[".  ",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{7\/2, 5\/2}, {2, 2}, {5\/2, 7\/2}, {7, 5}, {19\/2, 
              7}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"Then a row vector corresponding to equation (11) is defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {x\^2, \ x\ y, \ y\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[
  " for the linear system in (12) and the determinant is now created.  The \
vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining five rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 5, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given five points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x\^2\), \(x\ y\), \(y\^2\), "x", "y", "1"},
                {\(49\/4\), \(35\/4\), \(25\/4\), \(7\/2\), \(5\/2\), "1"},
                {"4", "4", "4", "2", "2", "1"},
                {\(25\/4\), \(35\/4\), \(49\/4\), \(5\/2\), \(7\/2\), "1"},
                {"49", "35", "25", "7", "5", "1"},
                {\(361\/4\), \(133\/2\), "49", \(19\/2\), "7", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], 
        RowBox[{"(", GridBox[{
              {\(c\_1\)},
              {\(c\_2\)},
              {\(c\_3\)},
              {\(c\_4\)},
              {\(c\_5\)},
              {\(c\_6\)}
              }], ")"}]}], "=", "0"}]], "Text"],

Cell[TextData[StyleBox[
"The determinant of this matrix is computed by typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[{
  StyleBox["This quantity is multiplied by  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\(-\ 8\)\/315\)]],
  StyleBox["to get the desired equation:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    StyleBox[\(eqn\  = \ \(\(-\ 8\)\ d\)\/315 == \ 0\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"The conic is the parabola shown in Figure 8.  It is plotted using the \
commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], Magenta}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    StyleBox[\(curve\  = \ 
          ImplicitPlot[eqn, {x, 0, 10.2}, {y, 0, 10.2}, 
            PlotStyle \[Rule] Red, DisplayFunction \[Rule] Identity];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(Show[curve, dots, PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] $DisplayFunction];\),
      
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\[IndentingNewLine]", \(Print["\<Figure 8. The Parabola \
\>", eqn];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" 9.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Determine the conic that passes through the five points ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\(\(\ \)\(\((14\/5, 22\/5)\), \((2, 2)\), \((22\/5, 14\/5)\), \((7, 
        5)\), \((10, 10)\)\)\)\)]],
  ".",
  StyleBox["  ",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{14\/5, 22\/5}, {2, 2}, {22\/5, 14\/5}, {7, 
              5}, {10, 10}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"Then a row vector corresponding to equation (11) is defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {x\^2, \ x\ y, \ y\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[
  " for the linear system in (12) and the determinant is now created.  The \
vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining five rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 5, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given five points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x\^2\), \(x\ y\), \(y\^2\), "x", "y", "1"},
                
                {\(196\/25\), \(308\/25\), \(484\/25\), \(14\/5\), \(22\/5\), 
                  "1"},
                {"4", "4", "4", "2", "2", "1"},
                
                {\(484\/25\), \(308\/25\), \(196\/25\), \(22\/5\), \(14\/5\), 
                  "1"},
                {"49", "35", "25", "7", "5", "1"},
                {"100", "100", "100", "10", "10", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], 
        RowBox[{"(", GridBox[{
              {\(c\_1\)},
              {\(c\_2\)},
              {\(c\_3\)},
              {\(c\_4\)},
              {\(c\_5\)},
              {\(c\_6\)}
              }], ")"}]}], "=", "0"}]], "Text"],

Cell[TextData[StyleBox[
"The determinant of this matrix is computed by typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[{
  StyleBox["This quantity is multiplied by ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(625\/49152\)]],
  StyleBox[" to get the desired equation:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    StyleBox[\(eqn\  = \ \(625\ d\)\/49152 == \ 0\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"The conic is the ellipse shown in Figure 9.  It is plotted using the \
commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], Blue}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    StyleBox[\(curve\  = \ 
          ImplicitPlot[eqn, {x, 0, 10.2}, {y, 0, 10.2}, 
            PlotStyle \[Rule] Turquoise, DisplayFunction \[Rule] Identity];\),
      
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(Show[curve, dots, PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] $DisplayFunction];\),
      
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\[IndentingNewLine]", \(Print["\<Figure 9. The Ellipse \>", 
        eqn];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" 10.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Determine the conic that passes through the five points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((7\/4, 13\/4)\), \((2, 2)\), \((31\/12, 7\/4)\), \((13\/4, 
        7\/4)\), \((38\/5, 14\/5)\)\)]],
  StyleBox[" .  ",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{7\/4, 13\/4}, {2, 2}, {31\/12, 7\/4}, {13\/4, 
              7\/4}, {38\/5, 14\/5}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"Then a row vector corresponding to equation (11) is defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {x\^2, \ x\ y, \ y\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[
  " for the linear system in (12) and the determinant is now created.  The \
vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining five rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 5, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given five points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x\^2\), \(x\ y\), \(y\^2\), "x", "y", "1"},
                
                {\(49\/16\), \(91\/16\), \(169\/16\), \(7\/4\), \(13\/4\), 
                  "1"},
                {"4", "4", "4", "2", "2", "1"},
                
                {\(961\/144\), \(217\/48\), \(49\/16\), \(31\/12\), \(7\/4\), 
                  "1"},
                
                {\(169\/16\), \(91\/16\), \(49\/16\), \(13\/4\), \(7\/4\), 
                  "1"},
                
                {\(1444\/25\), \(532\/25\), \(196\/25\), \(38\/5\), 
                  \(14\/5\), "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], 
        RowBox[{"(", GridBox[{
              {\(c\_1\)},
              {\(c\_2\)},
              {\(c\_3\)},
              {\(c\_4\)},
              {\(c\_5\)},
              {\(c\_6\)}
              }], ")"}]}], "=", "0"}]], "Text"],

Cell[TextData[StyleBox[
"The determinant of this matrix is computed by typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[{
  StyleBox["This quantity is multiplied by  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(100\/63\)]],
  StyleBox["  to get the desired equation:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    StyleBox[\(eqn\  = \ \(100  d\)\/63\  == \ 0\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"The conic is the hyperbola shown in Figure 10.  It is plotted using the \
commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], DarkGreen}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    StyleBox[\(curve\  = \ 
          ImplicitPlot[eqn, {x, 0, 10.2}, {y, 0, 10.2}, 
            PlotStyle \[Rule] Green, DisplayFunction \[Rule] Identity];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(Show[curve, dots, PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] $DisplayFunction];\),
      
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\[IndentingNewLine]", \(Print["\<Figure 10. The Hyperbola \
\>", eqn];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" 11.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Determine the conic that passes through the five points  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\((1, 1)\), \((3, 5)\), \((5, 4)\), \((7, 3)\), \((9, 7)\)\)]],
  ".  ",
  StyleBox[" ",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{1, 1}, {3, 5}, {5, 4}, {7, 3}, {9, 7}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"Then a row vector corresponding to equation (11) is defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {x\^2, \ x\ y, \ y\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[
  " for the linear system in (12) and the determinant is now created.  The \
vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining five rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 5, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given five points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x\^2\), \(x\ y\), \(y\^2\), "x", "y", "1"},
                {"1", "1", "1", "1", "1", "1"},
                {"9", "15", "25", "3", "5", "1"},
                {"25", "20", "16", "5", "4", "1"},
                {"49", "21", "9", "7", "3", "1"},
                {"81", "63", "49", "9", "7", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], 
        RowBox[{"(", GridBox[{
              {\(c\_1\)},
              {\(c\_2\)},
              {\(c\_3\)},
              {\(c\_4\)},
              {\(c\_5\)},
              {\(c\_6\)}
              }], ")"}]}], "=", "0"}]], "Text"],

Cell[TextData[StyleBox[
"The determinant of this matrix is computed by typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[{
  StyleBox["This quantity is multiplied by  ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(1\/400\)]],
  StyleBox["  to get the desired equation:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    StyleBox[\(eqn\  = \ d\/400\  == \ 0\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"The conic is the pair of intersecting lines shown in Figure 11.  It is \
plotted using the commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], Magenta}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    StyleBox[\(curve\  = \ 
          ImplicitPlot[eqn, {x, 0, 10.2}, {y, 0, 10.2}, 
            PlotPoints \[Rule] 52, PlotStyle \[Rule] Red, 
            DisplayFunction \[Rule] Identity];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(Show[curve, dots, PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] $DisplayFunction];\),
      
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\[IndentingNewLine]", \(Print["\<Figure 11. The Lines \>", 
        eqn];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" 12.",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Determine the conic that passes through the five points ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(\(\(\ \)\(\((1, 8)\), \((2, 1)\), \((8, 9)\), \((9, 2)\), \((10, 
        5)\)\)\)\)]],
  ".",
  StyleBox["  ",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 12.",
  FontFamily->"New Century Schlbk",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["The points are entered into Mathematica with the \
command:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(pts\  = \ {{1, 8}, {2, 1}, {8, 9}, {9, 2}, {10, 5}};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"Then a row vector corresponding to equation (11) is defined:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    StyleBox[\(R\  = \ {x\^2, \ x\ y, \ y\^2, \ x, \ y, \ 1};\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  StyleBox["The matrix ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[
  " for the linear system in (12) and the determinant is now created.  The \
vector ",
    FontFamily->"New Century Schlbk"],
  StyleBox["R",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is stored in the first row by issuing the command  ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A = {R}.",
    FontWeight->"Bold"],
  StyleBox["  Then the remaining five rows of ",
    FontFamily->"New Century Schlbk"],
  StyleBox["A",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" are generated with the loop command:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[{\(A = {R}\ ;\), "\n", 
    StyleBox[\(For[i = 1, \ 
          i \[LessEqual] 5, \ \(i++\), \[IndentingNewLine]A\  = \ 
            Append[A, 
              ReplaceAll[
                R, {x \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\), 
                  y \[Rule] 
                    pts\_\(\(\[LeftDoubleBracket]\)\(i, 2\)\(\
\[RightDoubleBracket]\)\)}]\ ]\ ];\),
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", \(MatrixForm[\ A\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["For the given five points, the homogeneous system ",
    FontFamily->"New Century Schlbk"],
  StyleBox["AC",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"New Century Schlbk"],
  StyleBox["0",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold"],
  StyleBox[" is:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x\^2\), \(x\ y\), \(y\^2\), "x", "y", "1"},
                {"1", "8", "64", "1", "8", "1"},
                {"4", "2", "1", "2", "1", "1"},
                {"64", "72", "81", "8", "9", "1"},
                {"81", "18", "4", "9", "2", "1"},
                {"100", "50", "25", "10", "5", "1"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], 
        RowBox[{"(", GridBox[{
              {\(c\_1\)},
              {\(c\_2\)},
              {\(c\_3\)},
              {\(c\_4\)},
              {\(c\_5\)},
              {\(c\_6\)}
              }], ")"}]}], "=", "0"}]], "Text"],

Cell[TextData[StyleBox[
"The determinant of this matrix is computed by typing:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[
    RowBox[{"d", "=", 
      RowBox[{"Together", "[", " ", 
        StyleBox[\(Det[\ A\ ]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input"],

Cell[TextData[{
  StyleBox["This quantity is multiplied by ",
    FontFamily->"New Century Schlbk"],
  Cell[BoxData[
      \(1\/30000\)]],
  StyleBox[" to get the desired equation:",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[BoxData[
    StyleBox[\(eqn\  = \ \(\(\ \)\(d\)\)\/30000 == \ 0\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[TextData[StyleBox[
"The conic is the ellipse shown in Figure 12.  It is plotted using the \
commands:",
  FontFamily->"New Century Schlbk"]], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`ImplicitPlot`\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["dots",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["ListPlot",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["pts",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle \[Rule] {PointSize[0.02], Blue}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[\(PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}\),
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            ",", \(DisplayFunction \[Rule] Identity\)}], "]"}]}], ";"}], "\n",
   
    StyleBox[\(curve\  = \ 
          ImplicitPlot[eqn, {x, 0, 10.2}, {y, 0, 10.2}, 
            PlotStyle \[Rule] Turquoise, DisplayFunction \[Rule] Identity];\),
      
      FontFamily->"Courier",
      FontWeight->"Bold"], "\n", 
    StyleBox[\(Show[curve, dots, PlotRange \[Rule] {{0, 10.2}, {0, 10.2}}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] $DisplayFunction];\),
      
      FontFamily->"Courier",
      FontWeight->
        "Bold"], "\[IndentingNewLine]", \(Print["\<Figure 12. The Circle \>", 
        eqn];\), "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Through the points  \>", pts];\), " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tDetails for the",
  StyleBox[" implicit formulas for the line, circle, parabola, ellipse, and \
conic are given below.  ",
    FontFamily->"New Century Schlbk"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Conic Fit",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/ConicFitProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Conic Fit",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/ConicFitProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Conic Fit",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/ConicFitProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Conic Fit",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/ConicFitProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  ButtonBox["(",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/numerical/linear/cfo/cof.html"],
       None},
    ButtonStyle->"Hyperlink"],
  StyleBox[ButtonBox["Conic Section Curves",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/numerical/linear/cfo/cof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Conic Section Curves",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/linear/cfo/cof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Conic Fit",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/ConicFitBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Conic Fit",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/ConicFitBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 296, 10, 35, "Text"],
Cell[2075, 65, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3554, 117, 530, 11, 87, "Text"],
Cell[4087, 130, 835, 25, 133, "Text"],
Cell[4925, 157, 289, 8, 33, "Text"],

Cell[CellGroupData[{
Cell[5239, 169, 137, 3, 33, "Text"],
Cell[5379, 174, 258, 8, 33, "Text"],
Cell[5640, 184, 227, 7, 57, "Input"],
Cell[5870, 193, 160, 6, 33, "Text"],
Cell[6033, 201, 484, 9, 92, "Input"],
Cell[6520, 212, 157, 5, 33, "Text"],
Cell[6680, 219, 76, 1, 30, "Input"],
Cell[6759, 222, 36, 0, 33, "Text"],
Cell[6798, 224, 4067, 122, 150, "Input"]
}, Closed]],
Cell[10880, 349, 290, 8, 30, "Text"],

Cell[CellGroupData[{
Cell[11195, 361, 137, 3, 33, "Text"],
Cell[11335, 366, 258, 8, 33, "Text"],
Cell[11596, 376, 227, 7, 57, "Input"],
Cell[11826, 385, 160, 6, 33, "Text"],
Cell[11989, 393, 484, 9, 92, "Input"],
Cell[12476, 404, 157, 5, 33, "Text"],
Cell[12636, 411, 76, 1, 30, "Input"],
Cell[12715, 414, 36, 0, 33, "Text"],
Cell[12754, 416, 1860, 50, 150, "Input"]
}, Closed]],
Cell[14629, 469, 290, 8, 30, "Text"],

Cell[CellGroupData[{
Cell[14944, 481, 137, 3, 33, "Text"],
Cell[15084, 486, 258, 8, 33, "Text"],
Cell[15345, 496, 227, 7, 57, "Input"],
Cell[15575, 505, 160, 6, 33, "Text"],
Cell[15738, 513, 484, 9, 92, "Input"],
Cell[16225, 524, 157, 5, 33, "Text"],
Cell[16385, 531, 76, 1, 30, "Input"],
Cell[16464, 534, 36, 0, 33, "Text"],
Cell[16503, 536, 4080, 122, 150, "Input"]
}, Closed]],
Cell[20598, 661, 1030, 27, 160, "Text"],
Cell[21631, 690, 635, 18, 52, "Text"],

Cell[CellGroupData[{
Cell[22291, 712, 137, 3, 33, "Text"],
Cell[22431, 717, 131, 2, 33, "Text"],
Cell[22565, 721, 133, 3, 30, "Input"],
Cell[22701, 726, 132, 2, 33, "Text"],
Cell[22836, 730, 135, 3, 31, "Input"],
Cell[22974, 735, 799, 24, 33, "Text"],
Cell[23776, 761, 529, 12, 91, "Input"],
Cell[24308, 775, 405, 13, 33, "Text"],
Cell[24716, 790, 523, 16, 77, "Text"],
Cell[25242, 808, 126, 2, 33, "Text"],
Cell[25371, 812, 358, 11, 30, "Input"],
Cell[25732, 825, 96, 1, 33, "Text"],
Cell[25831, 828, 116, 3, 30, "Input"],
Cell[25950, 833, 152, 3, 33, "Text"],
Cell[26105, 838, 4103, 122, 150, "Input"]
}, Closed]],
Cell[30223, 963, 971, 26, 160, "Text"],
Cell[31197, 991, 1031, 29, 163, "Text"],
Cell[32231, 1022, 649, 18, 52, "Text"],

Cell[CellGroupData[{
Cell[32905, 1044, 137, 3, 33, "Text"],
Cell[33045, 1049, 131, 2, 33, "Text"],
Cell[33179, 1053, 133, 3, 30, "Input"],
Cell[33315, 1058, 132, 2, 33, "Text"],
Cell[33450, 1062, 128, 3, 31, "Input"],
Cell[33581, 1067, 799, 24, 33, "Text"],
Cell[34383, 1093, 529, 12, 91, "Input"],
Cell[34915, 1107, 405, 13, 33, "Text"],
Cell[35323, 1122, 576, 18, 77, "Text"],
Cell[35902, 1142, 126, 2, 33, "Text"],
Cell[36031, 1146, 358, 11, 30, "Input"],
Cell[36392, 1159, 96, 1, 33, "Text"],
Cell[36491, 1162, 143, 4, 50, "Input"],
Cell[36637, 1168, 163, 3, 33, "Text"],
Cell[36803, 1173, 2071, 56, 150, "Input"]
}, Closed]],
Cell[38889, 1232, 649, 18, 49, "Text"],

Cell[CellGroupData[{
Cell[39563, 1254, 137, 3, 33, "Text"],
Cell[39703, 1259, 131, 2, 33, "Text"],
Cell[39837, 1263, 133, 3, 30, "Input"],
Cell[39973, 1268, 132, 2, 33, "Text"],
Cell[40108, 1272, 128, 3, 31, "Input"],
Cell[40239, 1277, 799, 24, 33, "Text"],
Cell[41041, 1303, 529, 12, 91, "Input"],
Cell[41573, 1317, 405, 13, 33, "Text"],
Cell[41981, 1332, 577, 18, 77, "Text"],
Cell[42561, 1352, 126, 2, 33, "Text"],
Cell[42690, 1356, 358, 11, 30, "Input"],
Cell[43051, 1369, 96, 1, 33, "Text"],
Cell[43150, 1372, 143, 4, 50, "Input"],
Cell[43296, 1378, 163, 3, 33, "Text"],
Cell[43462, 1383, 1068, 22, 150, "Input"]
}, Closed]],
Cell[44545, 1408, 1205, 31, 180, "Text"],
Cell[45753, 1441, 316, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[46094, 1454, 137, 3, 33, "Text"],
Cell[46234, 1459, 131, 2, 33, "Text"],
Cell[46368, 1463, 141, 3, 30, "Input"],
Cell[46512, 1468, 133, 2, 33, "Text"],
Cell[46648, 1472, 134, 3, 31, "Input"],
Cell[46785, 1477, 796, 23, 33, "Text"],
Cell[47584, 1502, 529, 12, 91, "Input"],
Cell[48116, 1516, 405, 13, 33, "Text"],
Cell[48524, 1531, 611, 18, 93, "Text"],
Cell[49138, 1551, 127, 2, 33, "Text"],
Cell[49268, 1555, 358, 11, 30, "Input"],
Cell[49629, 1568, 243, 8, 36, "Text"],
Cell[49875, 1578, 127, 3, 42, "Input"],
Cell[50005, 1583, 151, 2, 33, "Text"],
Cell[50159, 1587, 2078, 56, 150, "Input"]
}, Closed]],
Cell[52252, 1646, 1272, 31, 200, "Text"],
Cell[53527, 1679, 543, 16, 36, "Text"],

Cell[CellGroupData[{
Cell[54095, 1699, 137, 3, 33, "Text"],
Cell[54235, 1704, 131, 2, 33, "Text"],
Cell[54369, 1708, 180, 4, 42, "Input"],
Cell[54552, 1714, 133, 2, 33, "Text"],
Cell[54688, 1718, 144, 3, 31, "Input"],
Cell[54835, 1723, 799, 24, 33, "Text"],
Cell[55637, 1749, 529, 12, 91, "Input"],
Cell[56169, 1763, 404, 13, 33, "Text"],
Cell[56576, 1778, 792, 20, 137, "Text"],
Cell[57371, 1800, 126, 2, 33, "Text"],
Cell[57500, 1804, 358, 11, 30, "Input"],
Cell[57861, 1817, 237, 7, 36, "Text"],
Cell[58101, 1826, 135, 3, 42, "Input"],
Cell[58239, 1831, 154, 3, 33, "Text"],
Cell[58396, 1836, 2062, 55, 150, "Input"]
}, Closed]],
Cell[60473, 1894, 564, 17, 33, "Text"],

Cell[CellGroupData[{
Cell[61062, 1915, 137, 3, 33, "Text"],
Cell[61202, 1920, 131, 2, 33, "Text"],
Cell[61336, 1924, 182, 4, 42, "Input"],
Cell[61521, 1930, 133, 2, 33, "Text"],
Cell[61657, 1934, 144, 3, 31, "Input"],
Cell[61804, 1939, 799, 24, 33, "Text"],
Cell[62606, 1965, 529, 12, 91, "Input"],
Cell[63138, 1979, 404, 13, 33, "Text"],
Cell[63545, 1994, 867, 24, 127, "Text"],
Cell[64415, 2020, 126, 2, 33, "Text"],
Cell[64544, 2024, 358, 11, 30, "Input"],
Cell[64905, 2037, 234, 7, 36, "Text"],
Cell[65142, 2046, 132, 3, 42, "Input"],
Cell[65277, 2051, 153, 3, 33, "Text"],
Cell[65433, 2056, 2078, 56, 150, "Input"]
}, Closed]],
Cell[67526, 2115, 559, 16, 33, "Text"],

Cell[CellGroupData[{
Cell[68110, 2135, 138, 3, 33, "Text"],
Cell[68251, 2140, 131, 2, 33, "Text"],
Cell[68385, 2144, 194, 4, 42, "Input"],
Cell[68582, 2150, 133, 2, 33, "Text"],
Cell[68718, 2154, 144, 3, 31, "Input"],
Cell[68865, 2159, 799, 24, 33, "Text"],
Cell[69667, 2185, 529, 12, 91, "Input"],
Cell[70199, 2199, 404, 13, 33, "Text"],
Cell[70606, 2214, 995, 28, 145, "Text"],
Cell[71604, 2244, 126, 2, 33, "Text"],
Cell[71733, 2248, 358, 11, 30, "Input"],
Cell[72094, 2261, 233, 7, 36, "Text"],
Cell[72330, 2270, 131, 3, 42, "Input"],
Cell[72464, 2275, 156, 3, 33, "Text"],
Cell[72623, 2280, 2068, 55, 150, "Input"]
}, Closed]],
Cell[74706, 2338, 526, 16, 30, "Text"],

Cell[CellGroupData[{
Cell[75257, 2358, 138, 3, 33, "Text"],
Cell[75398, 2363, 131, 2, 33, "Text"],
Cell[75532, 2367, 149, 3, 30, "Input"],
Cell[75684, 2372, 133, 2, 33, "Text"],
Cell[75820, 2376, 144, 3, 31, "Input"],
Cell[75967, 2381, 799, 24, 33, "Text"],
Cell[76769, 2407, 529, 12, 91, "Input"],
Cell[77301, 2421, 404, 13, 33, "Text"],
Cell[77708, 2436, 722, 20, 109, "Text"],
Cell[78433, 2458, 126, 2, 33, "Text"],
Cell[78562, 2462, 358, 11, 30, "Input"],
Cell[78923, 2475, 232, 7, 36, "Text"],
Cell[79158, 2484, 123, 3, 42, "Input"],
Cell[79284, 2489, 173, 3, 33, "Text"],
Cell[79460, 2494, 2103, 56, 150, "Input"]
}, Closed]],
Cell[81578, 2553, 548, 17, 30, "Text"],

Cell[CellGroupData[{
Cell[82151, 2574, 138, 3, 33, "Text"],
Cell[82292, 2579, 131, 2, 33, "Text"],
Cell[82426, 2583, 150, 3, 30, "Input"],
Cell[82579, 2588, 133, 2, 33, "Text"],
Cell[82715, 2592, 144, 3, 31, "Input"],
Cell[82862, 2597, 799, 24, 33, "Text"],
Cell[83664, 2623, 529, 12, 91, "Input"],
Cell[84196, 2637, 404, 13, 33, "Text"],
Cell[84603, 2652, 723, 20, 109, "Text"],
Cell[85329, 2674, 126, 2, 33, "Text"],
Cell[85458, 2678, 358, 11, 30, "Input"],
Cell[85819, 2691, 232, 7, 36, "Text"],
Cell[86054, 2700, 137, 3, 42, "Input"],
Cell[86194, 2705, 154, 3, 33, "Text"],
Cell[86351, 2710, 2078, 56, 150, "Input"]
}, Closed]],
Cell[88444, 2769, 193, 5, 30, "Text"],
Cell[88640, 2776, 587, 20, 33, "Text"],
Cell[89230, 2798, 579, 20, 33, "Text"],
Cell[89812, 2820, 897, 27, 33, "Text"],
Cell[90712, 2849, 158, 3, 35, "Text"],
Cell[90873, 2854, 526, 16, 33, "Text"],
Cell[91402, 2872, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

