(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     91023,       2406]*)
(*NotebookOutlinePosition[     91689,       2429]*)
(*  CellTagsIndexPosition[     91645,       2425]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Curvature",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Circle of Curvature: It\[CloseCurlyQuote]s a Limit!",
    TextAlignment->Center,
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}},
    FontFamily->"New York",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\nby\nJohn H. Mathews",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["\n",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/articles/2001TangentParabola.pdf"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1]],
  ButtonBox["The AMATYC Review, Vol. 25, No. 1, Fall 2003, pp. 57-63.",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/articles/2003CircleOfCurvature.pdf"],
       None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  TextAlignment->Center,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tGiven the function  ",
  Cell[BoxData[
      \(y\  = \ f[x]\)]],
  ", the formula for the curvature (and radius of curvature) is stated in all \
calculus textbooks  \n\n",
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Curvature",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Curvature.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\[Kappa][
          x]\  = \ \(f''\)[x]\/\((1 + \((\(f'\)[x])\)\^2)\)\^\(3/2\)\)]],
  ",  \n\t      \n",
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Radius of Curvature",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RadiusofCurvature.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\[Rho][
          x]\  = \ \((1 + \((\(f'\)[x])\)\^2)\)\^\(3/2\)\/\(f''\)[x]\)]],
  ".  \n\n",
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Osculating Circle",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/OsculatingCircle.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  At the point {",
  StyleBox["x,f[x]}",
    FontFamily->"Courier New"],
  " on the curve  ",
  StyleBox["y = f[x]",
    FontFamily->"Courier New"],
  ",  the osculating circle is tangent to the curve and has radius  ",
  StyleBox["r[x]",
    FontFamily->"Courier New"],
  ".   "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the parabola  ",
  Cell[BoxData[
      \(y = \(f[x] = x\^2\)\)]],
  " and the point ",
  StyleBox["{0,f[0]} = (0,0)",
    FontFamily->"Courier New"],
  " on the curve.  Find the radius of curvature and the circle of curvature."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(\[Rho][
          x_] = \((1 + \((\(f'\)[x])\)\^2)\)\^\(3/2\)\/\(f''\)[x];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<  f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f'[x] = \>", \(f'\)[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f''[x] = \>", \(f''\)[
          x], "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \[Rho][x] = (1 + \
(f'[x]\!\(\()\^2\)\)\!\(\()\^\(3/2\)\)\)/(f''[x])\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  \[Rho][x] = (1 + (\>", \(f'\)[
          x], \*"\"\<\!\(\()\^2\)\)\!\(\()\^\(3/2\)\)\)/(\>\"", \(f''\)[
          x], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \[Rho][x] = (1 + \>", \((\(f'\)[x])\)\^2, \*"\"\<\!\(\()\^\
\(3/2\)\)\)/(\>\"", \(f''\)[x], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \[Rho][x] = \>", \[Rho][
          x], "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<For f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The radius of curvature at the point {x,f[x]} is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  \[Rho][x] = \>", \[Rho][x]];\)\)}], "Input"],

Cell[TextData[{
  "At  ",
  StyleBox["x=0",
    FontFamily->"Courier New"],
  ",  we have  ",
  Cell[BoxData[
      \(\[Rho][
          0]\  = \ \(\((1 + \((\(f'\)[0])\)\^2)\)\^\(3/2\)\/\(f''\)[0] = \
\(1\/2\ \((1 + 4\ *0\^2)\)\^\(3/2\) = 1\/2\)\)\)]],
  " \n\nWe know the shape of this parabola and from symmetry we can conclude \
that the circle of curvature will have center ",
  Cell[BoxData[
      \(\((0, 1\/2)\)\)]],
  "  and radius  ",
  Cell[BoxData[
      \(\[Rho] = 1\/2\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(circle1 = 
        Graphics[{Magenta, 
            Circle[{0, 1\/2}, 1\/2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph, circle1, AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    \[Rho][x] = \>", \[Rho][
          x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<At the point\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<{0,f[0]} = \>", {0, f[0]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    \[Rho][0] = \>", \[Rho][0]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Discussion.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " What do other kinds of \"tangent circles\" look like?"
}], "Text"],

Cell[BoxData[{
    \(\(circle2 = 
        Graphics[{Red, 
            Circle[{0, 1\/4}, 1\/4]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph, circle2, 
        PlotRange \[Rule] {{\(-\(1\/\@2\)\), 1\/\@2}, {0, 1\/2}}, 
        AspectRatio \[Rule] 1\/\(2 \@ 2\), 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.25]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[graph, circle1, PlotRange \[Rule] {{\(-1\), 1}, {0, 1}}, 
        AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(circle3 = Graphics[{Green, Circle[{0, 1}, 1]}];\)\ \), "\n", 
    \(\(Show[graph, circle3, PlotRange \[Rule] {{\(-1\), 1}, {0, 2}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell["\<\
It looks like the \"circle of curvature\" is the \"best fitting\" circle.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Finding Curvature at Any Point",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tFor the above example the circle of curvature was easy to locate \
because it's center lies on the y-axis.  How do you locate the center if the \
point of tangency is not the origin?  To begin, we need the concepts of \
tangent and normal vectors. "
}], "Text"],

Cell[TextData[{
  StyleBox["Tangent and Normal Vectors",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \n\n\tGiven the graph  ",
  Cell[BoxData[
      \(y = f[x]\)]],
  ",  a ",
  StyleBox["vector tangent",
    FontColor->RGBColor[0, 0, 1]],
  " to the curve at the point  (",
  StyleBox["x,f(x))",
    FontFamily->"Courier New"],
  "  is   ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(v\&\[RightVector]\),
          FontWeight->"Bold"], "=", \({1, f' \((x)\)}\)}]]],
  ".  The ",
  StyleBox["unit tangent",
    FontColor->RGBColor[0, 0, 1]],
  " vector is  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(u\&\[RightVector]\),
          FontWeight->"Bold"], " ", "=", 
        FractionBox[
          StyleBox[\(v\&\[RightVector]\),
            FontWeight->"Bold"], 
          RowBox[{"\[LeftDoubleBracketingBar]", 
            StyleBox[\(v\&\[RightVector]\),
              FontWeight->"Bold"], "\[RightDoubleBracketingBar]"}]]}]]],
  ",  which can be written as \n\n",
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Unit Tangent",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/TangentVector.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(u\&\[RightVector]\),
          FontWeight->"Bold"], 
        "=", \(\(1\/\@\(1 + \((\(f'\)[x])\)\^2\)\) \({1, \(f'\)[
              x]}\)\(\ \)\)}]]],
  "\n\t\nFor vectors in  ",
  Cell[BoxData[
      StyleBox[\(\[DoubleStruckCapitalR]\^2\),
        FontWeight->"Bold"]]],
  ",  a corresponding perpendicular vector called the ",
  StyleBox["unit normal",
    FontColor->RGBColor[0, 0, 1]],
  " vector is given by \n\n",
  StyleBox["Lemma (Unit Normal) ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\&\[RightVector]\),
          FontWeight->"Bold"], 
        "=", \(\(1\/\@\(1 + \((\(f'\)[x])\)\^2\)\) {\(-\(f'\)[x]\), 1}\)}]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Verification.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Recall.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Two vectors are perpendicular if and only if their dot product is zero.\n\
\n\tIt is easy to verify that  ",
  Cell[BoxData[
      StyleBox[\(n\&\[RightVector]\),
        FontWeight->"Bold"]]],
  "  is perpendicular to  ",
  Cell[BoxData[
      StyleBox[\(t\&\[RightVector]\),
        FontWeight->"Bold"]]],
  "  with the calculation  \n\n",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(u\&\[RightVector]\),
            FontWeight->"Bold"], ".", 
          StyleBox[\(n\&\[RightVector]\),
            FontWeight->"Bold"]}], " ", "=", 
        " ", \(\(1\/\(1 + \((\(f'\)[x])\)\^2\)\) {1, \(f'\)[
                  x]} . {\(-\(f'\)[x]\), 
                1} = \ \(\(1\/\(1 + \((\(f'\)[x])\)\^2\)\) \((\(-\(f'\)[
                      x]\) + \(f'\)[
                    x])\) = \(\(1\/\(1 + \((\(f'\)[x])\)\^2\)\) \((0)\) = \ 
              0\)\)\)}]]],
  ".  \n\nIt is also possible to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " verify this computation."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear[f, x];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox[\(U\&\[RightVector]\),
            FontWeight->"Bold"], 
          "=", \(\(1\/\@\(1 + \((\(f'\)[x])\)\^2\)\) {1, \(f'\)[x]}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox[\(N\&\[RightVector]\),
            FontWeight->"Bold"], 
          "=", \(\(1\/\@\(1 + \((\(f'\)[x])\)\^2\)\) {\(-\(f'\)[x]\), 1}\)}], 
        ";"}], "  "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<For the curve y = f[x], at the point {x,f[x]}\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<  \!\(\*
StyleBox[\(U\&\[RightVector]\),\nFontWeight->\"Bold\"]\) = \>\"", ",", 
            StyleBox[\(U\&\[RightVector]\),
              FontWeight->"Bold"]}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<  \!\(\*
StyleBox[\(N\&\[RightVector]\),\nFontWeight->\"Bold\"]\) = \>\"", ",", 
            StyleBox[\(N\&\[RightVector]\),
              FontWeight->"Bold"]}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\*
StyleBox[\(U\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\".\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\(N\&\[RightVector]\),\nFontWeight->\"Bold\"]\) = \>\"", ",", 
            StyleBox[\(U\&\[RightVector]\),
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox["\"\<.\>\"",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox[\(N\&\[RightVector]\),
              FontWeight->"Bold"]}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\(U\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\".\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\(N\&\[RightVector]\),\nFontWeight->\"Bold\"]\) = \!\(\*
StyleBox[\(U\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\),\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\(N\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\),\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"+\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\(U\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\),\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\(N\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\),\nFontWeight->\"Bold\"]\)\>\"", "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\*
StyleBox[\(U\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\".\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\(N\&\[RightVector]\),\nFontWeight->\"Bold\"]\) = (\>\"", ",", 
            
            StyleBox[\(U\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\),
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox["\"\<)(\>\"",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            
            StyleBox[\(N\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\),
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox["\"\<) + (\>\"",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            
            StyleBox[\(U\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\),
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox["\"\<)(\>\"",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            
            StyleBox[\(N\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\),
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox["\"\<)\>\"",
              FontWeight->"Bold"]}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\*
StyleBox[\(U\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\".\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\(N\&\[RightVector]\),\nFontWeight->\"Bold\"]\) = (\>\"", ",", 
            
            StyleBox[\(\(U\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\) 
                N\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\),
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox["\"\<) + (\>\"",
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            
            StyleBox[\(\(U\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\) 
                N\&\[RightVector]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\),
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox["\"\<)\>\"",
              FontWeight->"Bold"]}], "]"}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{"\"\<\!\(\*
StyleBox[\(U\&\[RightVector]\),\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\".\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\(N\&\[RightVector]\),\nFontWeight->\"Bold\"]\) = \>\"", ",", 
            StyleBox[\(U\&\[RightVector] . N\&\[RightVector]\),
              FontWeight->"Bold"]}], "]"}], ";"}], " "}]}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the parabola  ",
  Cell[BoxData[
      \(y = \(f[x] = x\^2\)\)]],
  " and the point  ",
  StyleBox["(1,f(1)) = (1,1)",
    FontFamily->"Courier New"],
  "  on the curve.  \nFind the unit tangent and unit normal at point ",
  StyleBox["(1,1)",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^2;\)\), "\[IndentingNewLine]", 
    \(\(p\&\[RightVector][x_] = {x, f[x]};\)\), "\[IndentingNewLine]", 
    \(\(u\&\[RightVector][
          x_] = \(1\/\@\(1 + \(f'\)[x]\^2\)\) {1, \(f'\)[x]};\)\), "\n", 
    \(\(n\&\[RightVector][
          x_] = \(1\/\@\(1 + \(f'\)[x]\^2\)\) {\(-\(f'\)[x]\), 
            1};\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[x] = \>\"", 
        p\&\[RightVector][x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\&\[RightVector]\)[x] = \>\"", 
        u\&\[RightVector][x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(n\&\[RightVector]\)[x] = \>\"", 
        n\&\[RightVector][x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(x0 = 1\/2;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(pdot = 
        Graphics[{Blue, PointSize[0.02], 
            Point[p\&\[RightVector][x0]]}];\)\), "\[IndentingNewLine]", 
    \(\(tline = 
        Graphics[{Red, 
            Line[{p\&\[RightVector][x0], 
                p\&\[RightVector][x0] + 
                  u\&\[RightVector][x0]}]}];\)\), "\[IndentingNewLine]", 
    \(\(nline = 
        Graphics[{Red, 
            Line[{p\&\[RightVector][x0], 
                p\&\[RightVector][x0] + 
                  n\&\[RightVector][x0]}]}];\)\), "\[IndentingNewLine]", 
    \(\(graph = 
        Plot[f[x], {x, \(-3\), 3}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph, pdot, tline, nline, 
        PlotRange \[Rule] {{\(-1\), 1.5}, {0, 2.5}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2.5, 0.5]}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        p\&\[RightVector][x0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        u\&\[RightVector][x0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(n\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        n\&\[RightVector][x0]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the parabola  ",
  Cell[BoxData[
      \(y = \(f[x] = x\^2\)\)]],
  " and the point  ",
  StyleBox["(1,f(1)) = (1,1)",
    FontFamily->"Courier New"],
  "  on the curve.  \nFind the radius of curvature and the circle of \
curvature."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(c\&\[RightVector][x_] = 
        p\&\[RightVector][x] + \[Rho][x] 
            n\&\[RightVector][x];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        p\&\[RightVector][x0]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Rho][\>", 
        x0, "\<] = \>", \[Rho][x0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The center of the circle of convergence is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[x] = \!\(p\&\[RightVector]\)[x] \
+ \[Rho][x]\!\(n\&\[RightVector]\)[x]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        p\&\[RightVector][x0], "\< + \>", \[Rho][x0], 
        n\&\[RightVector][x0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        p\&\[RightVector][x0], "\< + \>", \[Rho][x0] 
          n\&\[RightVector][x0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        c\&\[RightVector][x0]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(cdot = 
        Graphics[{Green, PointSize[0.02], 
            Point[c\&\[RightVector][x0]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(circle = 
        Graphics[{Green, 
            Circle[c\&\[RightVector][x0], \[Rho][
                x0]]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[graph, pdot, tline, nline, cdot, circle, 
        PlotRange \[Rule] {{\(-2.0\), 1.7}, {\(-0.4\), 3.3}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 0.5], Range[0, 3.5, 0.5]}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        p\&\[RightVector][x0]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The circle of convergence\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<\[Rho][\>", 
        x0, "\<] = \>", \[Rho][x0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        c\&\[RightVector][x0]];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[graph, pdot, tline, nline, cdot, circle, 
        PlotRange \[Rule] {{0, 1}, {0, 1}}, 
        Ticks \[Rule] {Range[0, 1, 0.25], Range[0, 1, 0.25]}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        p\&\[RightVector][x0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The circle of convergence\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<\[Rho][\>", 
        x0, "\<] = \>", \[Rho][x0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", x0, "\<] = \>", 
        c\&\[RightVector][x0]];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["A new construction of the Circle of Curvature",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\t\tWhat determines a circle?  A center and a radius.  The formula for \
the radius of curvature is well established.  What idea could we use to help \
understand the situation.  We could use the fact that three points determine \
a circle and see where this leads.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the parabola  ",
  Cell[BoxData[
      \(y = \(f[x] = x\^2\)\)]],
  " and the point  ",
  StyleBox["(0,f(0)) = (0,0)",
    FontFamily->"Courier New"],
  "  on the curve.  \nFind collocation circle to go through the three points  \
",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(-h\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((\(-h\))\)\)}], ")"}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((0)\)\)}], ")"}]]],
  ",  and  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"h", 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((h)\)\)}], ")"}]]],
  ", and explore the situation for h = 1,.1,.01."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Three points on the curve\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<{-h,f[-h]} = \>", {\(-h\), 
          f[\(-h\)]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<( 0, f[0]} = \>", {0, f[0]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<{ h, f[h]} = \>", {h, f[h]}];\)\ \)}], "Input"],

Cell[TextData[{
  "Start with the equation of a circle  \n\n\t",
  Cell[BoxData[
      \(\((x - a)\)\^2 + \((y - b)\)\^2 = r\^2\)]],
  ".  \n\nThen write down three equations that force the collocation circle \
to go through the three points  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(-h\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((\(-h\))\)\)}], ")"}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((0)\)\)}], ")"}]]],
  ",  and  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"h", 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((h)\)\)}], ")"}]]],
  ".  \nEnter the equations into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, h, r];\)\), "\[IndentingNewLine]", 
    \(eqn1\  = \ \ \((\(-h\) - a)\)\^2 + \((f[\(-h\)] - b)\)\^2 \[Equal] 
        r\^\(\(2\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(eqn2\  = \ \ \ \ \ \ \((0 - a)\)\^2\ \  + \ \ \ \ \((f[0] - b)\)\^2\ \ \
\  \[Equal] r\^\(\(2\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(eqn3\  = \ \ \(\(\((h - a)\)\^2 + \((f[h] - b)\)\^2\)\(\[Equal]\)\(r\^2\
\)\(\ \ \)\)\)}], "Input"],

Cell["Expand the equations and get", "Text"],

Cell[BoxData[{
    \(ExpandAll[eqn1]\ \), "\[IndentingNewLine]", 
    \(ExpandAll[eqn2]\ \), "\[IndentingNewLine]", 
    \(ExpandAll[eqn3]\ \)}], "Input"],

Cell[TextData[{
  "Solve the equations for ",
  Cell[BoxData[
      RowBox[{"a", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{"b", " ", 
          StyleBox["and",
            FontFamily->"Times New Roman"], " ", "r"}]}]]],
  " and extract the formula for the radius of the collocation circle.  \n\
Since it depends on ",
  Cell[BoxData[
      RowBox[{"x", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], " ", "r"}]]],
  " we will store it as the function ",
  Cell[BoxData[
      \(Rcc[h]\)]],
  ".    "
}], "Text"],

Cell[BoxData[{
    \(\(solset = 
        Solve[{eqn1, eqn2, eqn3}, {a, b, r}];\)\), "\[IndentingNewLine]", 
    \(\(Print[{eqn1, eqn2, eqn3}];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Rcc[h_] = 
        PowerExpand[
          MapAll[FullSimplify, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\)]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", 
        f[x], "\<  at the point {0,0}\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Radius of the collocation circle\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Rcc[h] = \>", Rcc[h]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\nDraw the circle of curvature for various values\n\n",
  Cell[BoxData[
      \(h\  = 1.0, 0.9, 0.8, 0.7, 0.5, 0.4, 0.3, 0.2, 0.1, 0.08, 0.06, 0.04, 
      0.03, 0.02, 0.01\)]]
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(p\&\[RightVector][x_] = {x, f[x]};\)\), "\[IndentingNewLine]", 
    \(\(H = {1.0, 0.9, 0.8, 0.7, 0.5, 0.4, 0.3, 0.2, 0.1, 0.08, 0.06, 0.04, 
          0.03, 0.02, 0.01};\)\), "\[IndentingNewLine]", 
    \(For[i = 1, 
      i \[LessEqual] Length[H], \(i++\), \[IndentingNewLine]h0 = 
        H\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\); 
      ccdots = Graphics[{{Green, PointSize[0.03], 
              Point[p\&\[RightVector][\(-h0\)]]}, {Green, PointSize[0.03], 
              Point[p\&\[RightVector][0]]}, {Green, PointSize[0.03], 
              Point[p\&\[RightVector][h0]]}}]; \[IndentingNewLine]graph = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]circle1 = 
        Graphics[{Red, 
            Circle[{0, Rcc[h0]}, Rcc[h0]]}]; \ \[IndentingNewLine]Show[graph, 
        circle1, ccdots, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.5}}, 
        AspectRatio \[Rule] 0.75, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1.5, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\ ]\)}], "Input",
  AnimationDisplayTime->0.482681],

Cell[BoxData[{
    \(\(Print["\<y = f[x] = \>", 
        f[x], "\<  at the point {0,0}\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Radius of the collocation circle\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[H], \(i++\), \[IndentingNewLine]\(Print["\<h = \>", 
            H\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), \
"\<  The radius  = \>", 
            Rcc[H\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\
];\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Take the limit and get the circle of curvature\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<           The radius = \>", \[Rho][0.0]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(lim = Limit[Rcc[h], h \[Rule] 0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", 
        f[x], "\<  at the point {0,0}\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The radius of the collocation circle is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Rcc[h] = \>", Rcc[h]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Take the limit as h\[Rule]0\>"];\)\), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< Rcc[h] = \>", \*"\"\
\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", 
        Rcc[h]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< Rcc[h] = \>", 
        lim];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<It is the same as the radius of curvature at x = 0\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<      \[Rho][x] = \>", \[Rho][
          x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<      \[Rho][0] = \>", \[Rho][0]];\)\ \)}], "Input"],

Cell["\<\
We can conjecture that the limit of the collocation polynomial is the circle \
of curvature. \
\>", "Text"]
}, Closed]],

Cell[TextData[StyleBox["Derivation of the Radius of Curvature",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text",
  TextAlignment->Left],

Cell[TextData[{
  "\tThe standard derivation of the formula for radius curvature involves the \
rate of change of the unit tangent vector.  This new derivation starts with \
the collocation the collocation circle to go through the three points  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x - h\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((x - h)\)\)}], ")"}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"x", 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((x)\)\)}], ")"}]]],
  ",  and  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x + h\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((x + h)\)\)}], ")"}]]],
  "  on the curve  ",
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  ".  The limit as ",
  Cell[BoxData[
      \(h \[Rule] 0\)]],
  " is the osculating circle to the curve  ",
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  " at the point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"x", 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((x)\)\)}], ")"}]]],
  ".  The radius of curvature and formulas for the location of its center are \
simultaneously derived.  The computer algebra software ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is used to assist in finding the limits.   "
}], "Text"],

Cell[TextData[{
  "\tStart with the equation ",
  Cell[BoxData[
      \(\((x - a)\)\^2 + \((y - b)\)\^2 = r\^2\)]],
  ",  of a circle.  Then write down three equations that force the \
collocation circle to go through the three points  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x - h\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((x - h)\)\)}], ")"}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"x", 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((x)\)\)}], ")"}]]],
  ",  and  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(x + h\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(f \((x + h)\)\)}], ")"}]]],
  "  on the curve  ",
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  ".  Enter the equations into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, f, h, r, x];\)\), "\[IndentingNewLine]", 
    \(eqn1\  = \ \ \((x - h - a)\)\^2 + \((f[x - h] - b)\)\^2 \[Equal] 
        r\^\(\(2\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(eqn2\  = \ \ \ \ \ \ \((x - a)\)\^2\ \  + \ \ \ \ \((f[x] - b)\)\^2\ \ \
\  \[Equal] r\^\(\(2\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(eqn3\  = \ \ \(\(\((x + h - a)\)\^2 + \((f[x + h] - b)\)\^2\)\(\[Equal]\
\)\(r\^2\)\(\ \ \)\)\)}], "Input"],

Cell[TextData[{
  "Solve the equations for ",
  Cell[BoxData[
      RowBox[{"a", 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{"b", " ", 
          StyleBox["and",
            FontFamily->"Times New Roman"], " ", "r"}]}]]],
  " and extract the formula for the radius of the collocation circle.  Since \
it depends on ",
  Cell[BoxData[
      RowBox[{"x", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], " ", "r"}]]],
  " we will store it as the function ",
  Cell[BoxData[
      \(r[x, h]\)]],
  ".    "
}], "Text"],

Cell[BoxData[{
    \(\(eqns = {eqn1, eqn2, eqn3};\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[eqns, {a, b, r}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(r[x_, h_] = 
        PowerExpand[
          MapAll[FullSimplify, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\)]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equations\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[x,h] = \>", r[x, h]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "The formula looks bewildering and one may wonder if it is of any value.  \n\
However, we can demonstrate the power of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and see if it can take the limit.  "
}], "Text"],

Cell[BoxData[{
    \(\(r[x_] = 
        Limit[r[x, h], h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[x] = \>", \*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \
r[x,h]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<r[x] = \>", \*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", 
        r[x, h]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<r[x] = \>", \ r[x]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "The computer gets the correct formula, but leaves out all the human \
understanding.  The formula for  ",
  Cell[BoxData[
      \(r[x, h]\)]],
  " can be rewritten so that human insight and inspiration is involved, but \
the computer cannot think of the formulas we desire to see.  So human \
intervention must be called upon and the simplifications must be typed in by \
hand.   "
}], "Text"],

Cell[BoxData[
    \(\(r[x, 
          h] \[Equal] \ \(\@\(h\^2 + \((F[x] - F[x - h])\)\^2\)\ \@\(h\^2 + \
\((F[x + h] - F[x])\)\^2\)\ \@\(4\ h\^2 + \((F[x + h] - F[x - \
h])\)\^2\)\)\/\(2\ h\ \((F[x + h] - 2\ F[x] + F[x - h])\)\);\)\)], "Input"],

Cell[BoxData[
    \(\(r[x, 
          h]\  \[Equal] \(\@\(\(h\^2\) \((1 + \((F[x] - F[x - h])\)\^2\/h\^2)\
\)\)\ \@\(\(h\^2\) \((1 + \((F[h + x] - F[x])\)\^2\/h\^2)\)\)\ \@\(4\ \
\(h\^2\) \((1 + \((F[x + h] - F[x - h])\)\^2\/\((2  h)\)\^2)\)\)\)\/\(2\ h\^3\
\ \((\(F[x + h] - 2\ F[x] + F[x - h]\)\/h\^2)\)\)\ \ ;\)\)], "Input"],

Cell[BoxData[
    \(\(r[x, 
          h]\  \[Equal] \(\@\(1 + \((\(F[x] - F[x - h]\)\/h)\)\^2\)\ \@\(1 + \
\((\(F[h + x] - F[x]\)\/h)\)\^2\)\ \@\(1 + \((\(F[x + h] - F[x - h]\)\/\(2  h\
\))\)\^2\)\)\/\(\(\ \)\(\(F[x + h] - 2\ F[x] + F[x - h]\)\/h\^2\)\)\ \ \
;\)\)], "Input"],

Cell[TextData[{
  "Notice that when we take the limit as ",
  Cell[BoxData[
      \(h \[Rule] 0\)]],
  ", the limiting value for each of the radicals in the numerator is  ",
  Cell[BoxData[
      \(\@\(1 + \(F'\)[x]\^2\)\)]],
  ".  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is capable of finding them, we illustrate this with the third one."
}], "Text"],

Cell[BoxData[{
    \(\(lim1 = 
        Limit[\@\(1 + \((\(F[x + h] - F[x - h]\)\/\(2  h\))\)\^2\)\ , 
          h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", \
\*"\"\<\!\(\@\(1 + \((\(F[x + h] - F[x - h]\)\/\(2  h\))\)\^2\)\) = \>\"", 
        lim1\ ];\)\)}], "Input"],

Cell[TextData[{
  "Therefore, the limit in the numerator is ",
  Cell[BoxData[
      \(\((1 + \(F'\)[x]\^2)\)\^\(3/2\)\)]],
  ".  The difference quotient in the denominator is recognized as the \
numerical approximation formula for the second derivative, hence the is  ",
  Cell[BoxData[
      \(\(F''\)[x]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(lim2 = 
        Limit[\ \(F[x + h] - 2\ F[x] + F[x - h]\)\/h\^2\ , h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", \
\*"\"\<\!\(\(F[x + h] - 2\\\ F[x] + F[x - h]\)\/h\^2\) = \>\"", 
        lim2\ ];\)\)}], "Input"],

Cell[TextData[{
  "We already knew that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows the rules for taking limits of functions when the formula is given. \
 Now we know that it has the \"artificial intelligence\" to rearrange \
quantities involving an arbitrary function and can identify difference \
quotients for approximating derivatives and find their appropriate limits.  \
It takes quite a bit of trust to let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " do our thinking.  From the steps we filled in, we can gain trust for the \
computer's way of doing it.  "
}], "Text"],

Cell[TextData[{
  StyleBox["The Osculating Circle",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nWe now show that the limit of the collocation circle as ",
  Cell[BoxData[
      \(h \[Rule] 0\)]],
  " is the osculating circle.\nNow we want to find the center  (a, b)  of the \
osculating circle. \n\nThe abscissa for the center of the collocation circle \
is"
}], "Text"],

Cell[BoxData[{
    \(\(a[x_, h_] = 
        MapAll[FullSimplify, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 3, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Print["\<The abscisssa of the center of the collocation circle\>"];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<a[x,h] = \>", \ a[x, h]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Take the limit as  ",
  Cell[BoxData[
      \(h \[Rule] 0\)]],
  ",  to obtain the abscissa for the center of the circle of curvature.  "
}], "Text"],

Cell[BoxData[{
    \(\(a[x_] = 
        Limit[a[x, h], h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The abscisssa of the center of the circle of \
curvature\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<a[x] = \>", \*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", \
"\<a[x,h]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<a[x] = \>", \*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", 
        a[x, h]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<a[x] = \>", \ a[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(a[x_] = Expand[\ a[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<a[x] = \>", \ a[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "If we want to see \"what's happening\" in this limit, then we must \
rearrange the formula for  ",
  Cell[BoxData[
      \(a[x, h]\)]],
  ".  A little finesse permits us to write it as follows "
}], "Text"],

Cell[BoxData[{
    \(\(A[x_, h_] = 
        x - \(\(F[x + h] - F[x - h]\)\/\(2  h\)\)\/\(\(\(\ \)\(F[h + x] - 2  \
F[x] + F[x - h]\)\)\/h\^2\) - \(\((\(F[x] - F[\(-h\) + x]\)\/h)\)\ \
\((\(\(-F[x]\) + F[h + x]\)\/h)\)\ \((\(\(-F[\(-h\) + x]\) + F[h + x]\)\/\(2  \
h\))\)\)\/\(\(\(\ \)\(F[h + x] - 2  F[x] + F[x - h]\)\)\/h\^2\);\)\), "\n", 
    \(\(lim3 = 
        Limit[\ A[x, h]\ , h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", "\<A[x,h] = \
\>", \*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", \*"\"\<(x-\!\(\(\(F[x + \
h] - F[x - h]\)\/\(2  h\)\)\/\(\(\(\\\ \)\(F[h + x] - 2  F[x] + F[x - \
h]\)\)\/h\^2\)\)-\!\(\(\((\(F[x] - F[\(-h\) + x]\)\/h)\)\\\ \((\(\(-F[x]\) + \
F[h + x]\)\/h)\)\\\ \((\(\(-F[\(-h\) + x]\) + F[h + x]\)\/\(2  h\))\)\)\/\(\(\
\(\\\ \)\(F[h + x] - 2  F[x] + F[x - h]\)\)\/h\^2\)\))\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", "\<A[x,h] = \
\>", Expand[lim3]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The numerators involve three difference quotients, all of which tend to ",
  Cell[BoxData[
      \(\(F'\)[x]\)]],
  " when  ",
  Cell[BoxData[
      \(h \[Rule] 0\)]],
  " , and the difference quotient in the denominators tends to ",
  Cell[BoxData[
      \(\(F''\)[x]\)]],
  "when  ",
  Cell[BoxData[
      \(h \[Rule] 0\)]],
  ".  \n\nThus we have established the formula  ",
  Cell[BoxData[
      RowBox[{\(a[x]\), "=", 
        RowBox[{"x", "-", 
          FractionBox[\(\(F'\)[x]\), 
            RowBox[{
              SuperscriptBox["F", "''",
                MultilineFunction->None], "[", "x", "]"}]], 
          "-", \(\(F'\)[x]\^3\/\(F''\)[x]\)}]}]]],
  " for the abscissa of center of the circle of curvature."
}], "Text"],

Cell[TextData[{
  StyleBox["The Abscissa the Easy Way",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nSubtract from  ",
  Cell[BoxData[
      \(x\)]],
  " the radius of curvature times ",
  Cell[BoxData[
      \(\(f'\)[x]\/\@\(1 + \(f'\)[x]\^2\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<r[x] = \>", r[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The abscisssa of the center of the circle of \
curvature\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a[x] = x - \!\(\(f'\)[x]\/\@\(1 + \(f'\)[x]\^2\)\)r[x]\>\
\""\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<a[x] = x - \>", \(f'\)[x]\/\@\(1 + \(f'\)[x]\^2\), 
        r[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<a[x] = \>", 
        x - \(\(f'\)[x]\/\@\(1 + \(f'\)[x]\^2\)\) 
            r[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<a[x] = \>", 
        Expand[x - \(\(f'\)[x]\/\@\(1 + \(f'\)[x]\^2\)\) 
              r[x]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["The Ordinate for the Center of the Circle of Curvature",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nThe ordinate for the center of the collocation circle is"
}], "Text"],

Cell[BoxData[{
    \(\(b[x_, h_] = 
        MapAll[FullSimplify, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 2, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Print["\<The ordinate of the center of the collocation circle\>"];\)\ \
\), "\n", 
    \(\(Print["\<b[x,h] = \>", \ b[x, h]\ ];\)\ \), "\n", 
    \(\(b[x_] = 
        Expand[\ Limit[b[x, h], h \[Rule] 0, 
            Analytic \[Rule] True]\ ];\)\ \), "\n", 
    \(\(Print["\<The ordinate of the center of the circle of curvature\>"];\)\
\ \), "\n", 
    \(\(Print["\<b[x] = \>", \*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", \
"\<b[x,h]\>"];\)\), "\n", 
    \(\(Print["\<b[x] = \>", \*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< \>", 
        b[x, h]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<b[x] = \>", \ b[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "If we want to see \"what's happening\" in this limit, then we must \
rearrange the formula for  ",
  Cell[BoxData[
      \(b[x, h]\)]],
  ".  A little finesse permits us to write it as follows "
}], "Text"],

Cell[BoxData[
    \(\(\(B[x_, h_] = \(F[x - h] + F[x + h]\)\/2 + 
          1\/\(\(F[x + h] - 2\ F[x] + F[x - h]\)\/h\^2\) + \(\(\ \)\(\(\(F[x \
+ h] - F[x]\)\/h\) \(F[x] - F[x - h]\)\/h\)\)\/\(\(\ \)\(\(F[x + h] - 2\ F[x] \
+ F[x - h]\)\/h\^2\)\);\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "The limit of  ",
  Cell[BoxData[
      \(\(F[x - h] + F[x + h]\)\/2\)]],
  " as  ",
  Cell[BoxData[
      \(h \[Rule] 0\)]],
  " is merely ",
  Cell[BoxData[
      \(F[x]\)]],
  ",  and we have already observed that the limit in the denominator is ",
  Cell[BoxData[
      \(\(F''\)[x]\)]],
  "and both quotients in the numerator tend to  ",
  Cell[BoxData[
      \(\(F'\)[x]\)]],
  " as  ",
  Cell[BoxData[
      \(h \[Rule] 0\)]],
  " .  \n\nThus we have established the formula  ",
  Cell[BoxData[
      \(b[x] = \[InvisibleSpace]F[x] + 
          1\/\(F''\)[x] + \(F'\)[x]\^2\/\(F''\)[x]\)]],
  " for the ordinate of center of the circle of curvature."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Details",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(lim1\  = \ 
        Limit[\(F[x - h] + F[x + h]\)\/2, h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< \!\(\(F[x - h] \
+ F[x + h]\)\/2\) = \>\"", lim1\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(lim2\  = \ 
        Limit[\(F[x + h] - 2\ F[x] + F[x - h]\)\/h\^2, h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< \!\(\(F[x + h] \
- 2\\\ F[x] + F[x - h]\)\/h\^2\) = \>\"", 
        lim2\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<and it follows that\>"];\)\), "\[IndentingNewLine]", 
    \(\(lim2\  = \ 
        Limit[1\/\(\(F[x + h] - 2\ F[x] + F[x - h]\)\/h\^2\), h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< \!\(1\/\(\(F[x \
+ h] - 2\\\ F[x] + F[x - h]\)\/h\^2\)\) = \>\"", lim2\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(lim3\  = \ 
        Limit[\ \(F[x + h] - F[x]\)\/h, h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< \!\(\(F[x + h] \
- F[x]\)\/h\) = \>\"", lim3\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(lim3\  = \ 
        Limit[\ \(F[x] - F[x - h]\)\/h, h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< \!\(\(F[x] - \
F[x - h]\)\/h\) = \>\"", lim3\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(lim3\  = \ 
        Limit[\ \(F[x + h] - 2\ F[x] + F[x - h]\)\/h\^2, h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< \!\(\(F[x + h] \
- 2\\\ F[x] + F[x - h]\)\/h\^2\) = \>\"", lim3\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<and it follows that\>"];\)\), "\[IndentingNewLine]", 
    \(\(lim3\  = \ 
        Limit[\(\(\ \)\(\(\(F[x + h] - F[x]\)\/h\) \(F[x] - F[x - h]\)\/h\)\)\
\/\(\(\ \)\(\(F[x + h] - 2\ F[x] + F[x - h]\)\/h\^2\)\), h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< \!\(\(\(\\\ \
\)\(\(\(F[x + h] - F[x]\)\/h\) \(F[x] - F[x - h]\)\/h\)\)\/\(\(\\\ \)\(\(F[x \
+ h] - 2\\\ F[x] + F[x - h]\)\/h\^2\)\)\) = \>\"", lim3\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(lim4\  = \ 
        Limit[B[x, h], h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< B[x,h] = \>", \*"\"\
\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< (\>", 
        B[x, h], "\<)\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< B[x,h] = \>", 
        lim4\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", "\< B[x,h] = \>", 
        Expand[lim4]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Ordinate of the Circle the Easy Way",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nAdd to  ",
  Cell[BoxData[
      \(f[x]\)]],
  "  the radius of curvature times",
  Cell[BoxData[
      \(1\/\@\(1 + \(f'\)[x]\^2\)\)]]
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<r[x] = \>", r[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The abscisssa of the center of the circle of \
curvature\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<b[x] = f[x] - \!\(\(f'\)[x]\/\@\(1 + \
\(f'\)[x]\^2\)\)r[x]\>\""\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<b[x] = f[x] - \>", \(f'\)[x]\/\@\(1 + \(f'\)[x]\^2\), 
        r[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<b[x] = \>", 
        f[x] - \(\(f'\)[x]\/\@\(1 + \(f'\)[x]\^2\)\) 
            r[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<b[x] = \>", 
        Expand[f[x] - \(\(f'\)[x]\/\@\(1 + \(f'\)[x]\^2\)\) 
              r[x]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["The Osculating Circle",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nAt the point  ",
  Cell[BoxData[
      \(p\&\[RightVector][x]\  = \ {x, f[x]}\)]],
  " on the curve  ",
  Cell[BoxData[
      \(y = f[x]\)]],
  ", the center and radius of the osculating circle are given by the limits \
calculated in the preceding discussion."
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<Given the curve\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   y = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<At the point\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[x] = \>\"", {x, 
          f[x]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The center and radius of the osculating circle are\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[x] = \>\"", {a[x], 
          b[x]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[x] = \>", r[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the parabola  ",
  Cell[BoxData[
      \(y\  = \ \(\(f \((x)\)\)\(=\)\(x\^2\)\(\ \)\)\)]],
  " at the point  ",
  Cell[BoxData[
      \(\((1\/2, f \((1\/2)\))\)\  = \ \((1\/2, 1\/4)\)\)]],
  ".  Draw the circle of curvature for various values  \n",
  Cell[BoxData[
      RowBox[{\(h\  = 1.0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.9", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.8", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.7", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.5", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.4", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.08", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.06", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.04", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.03", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.02", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.01", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.0075", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.005", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.0025", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "0.001"}]]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(p\&\[RightVector][x_] = {x, f[x]};\)\ \), "\[IndentingNewLine]", 
    \(\(r[x_, 
          h_] = \(\@\(h\^2 + \((f[x] - f[x - h])\)\^2\)\ \@\(h\^2 + \((f[x + \
h] - f[x])\)\^2\)\ \@\(4\ h\^2 + \((f[x + h] - f[x - h])\)\^2\)\)\/\(2\ h\ \
\((f[x + h] - 2\ f[x] + f[x - h])\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(a[x_, 
          h_]\  = \(f[x]\^2\ \((f[\(-h\) + x] - f[h + x])\) + h\ \((h - 2\ x)\
\)\ f[h + x] + f[\(-h\) + x]\^2\ f[h + x] - f[\(-h\) + x]\ \((h\^2 + 2\ h\ x \
+ f[h + x]\^2)\) + f[x]\ \((4\ h\ x - f[\(-h\) + x]\^2 + f[h + \
x]\^2)\)\)\/\(h\ \((4\ f[x] - 2\ \((f[\(-h\) + x] + f[h + x])\))\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(b[x_, 
          h_]\  = \ \(2\ h\^2 - 2\ f[x]\^2 + f[\(-h\) + x]\^2 + f[h + x]\^2\)\
\/\(2\ \((\(-2\)\ f[x] + f[\(-h\) + x] + f[h + x])\)\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Alim\  = \ 
        Limit[a[1\/2, h], h \[Rule] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Blim\  = \ 
        Limit[b[1\/2, h], h \[Rule] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Rlim\  = \ 
        Limit[r[1\/2, h], h \[Rule] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Information for the animation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<   \>", "\<f[x] = \>", 
        f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   \>", \*"\"\<\!\(p\&\[RightVector]\)[x] = \>\"", 
        p\&\[RightVector][x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The center and radius for the collocation circles at\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", \*"\"\<\!\(p\&\[RightVector]\)[\!\(1\/2\)] = \>\"", 
        p\&\[RightVector][1\/2]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a[\!\(1\/2\),h] = \>\"", 
        a[1\/2, h]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<b[\!\(1\/2\),h] = \>\"", 
        b[1\/2, h]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<r[\!\(1\/2\),h] = \>\"", 
        r[1\/2, h]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<At the point\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<      \>", \*"\"\<\!\(p\&\[RightVector]\)[\!\(1\/2\)] = \
\>\"", p\&\[RightVector][1\/2]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Take the limit as h\[Rule]0 and get the circle of \
curvature\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< a[\!\(1\/2\),h] \
= \>\"", Alim];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< b[\!\(1\/2\),h] \
= \>\"", Blim];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(h \[Rule] 0\)\)\>\"", \*"\"\< r[\!\(1\/2\),h] \
= \>\"", Rlim];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<      \>", \*"\"\<\!\(c\&\[RightVector]\)[\!\(1\/2\)] = \
\>\"", {Alim, Blim}\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<      \>", \*"\"\<r[\!\(1\/2\)] = \>\"", 
        Rlim];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_] = x\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(p\&\[RightVector][x_] = {x, f[x]};\)\), "\[IndentingNewLine]", 
    \(\(r[x_, 
          h_] = \(\@\(h\^2 + \((f[x] - f[x - h])\)\^2\)\ \@\(h\^2 + \((f[x + \
h] - f[x])\)\^2\)\ \@\(4\ h\^2 + \((f[x + h] - f[x - h])\)\^2\)\)\/\(2\ h\ \
\((f[x + h] - 2\ f[x] + f[x - h])\)\);\)\), "\[IndentingNewLine]", 
    \(\(a[x_, 
          h_]\  = \(f[x]\^2\ \((f[\(-h\) + x] - f[h + x])\) + h\ \((h - 2\ x)\
\)\ f[h + x] + f[\(-h\) + x]\^2\ f[h + x] - f[\(-h\) + x]\ \((h\^2 + 2\ h\ x \
+ f[h + x]\^2)\) + f[x]\ \((4\ h\ x - f[\(-h\) + x]\^2 + f[h + \
x]\^2)\)\)\/\(h\ \((4\ f[x] - 2\ \((f[\(-h\) + x] + f[h + x])\))\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(b[x_, 
          h_]\  = \ \(2\ h\^2 - 2\ f[x]\^2 + f[\(-h\) + x]\^2 + f[h + x]\^2\)\
\/\(2\ \((\(-2\)\ f[x] + f[\(-h\) + x] + f[h + x])\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(H = {1.0, 0.9, 0.8, 0.7, 0.5, 0.4, 0.3, 0.2, 0.1, 0.08, 0.06, 0.04, 
          0.03, 0.02, 0.01, 0.0075, 0.005, 0.0025, 
          0.001};\)\), "\[IndentingNewLine]", 
    \(For[i = 1, 
      i \[LessEqual] Length[H], \(i++\), \[IndentingNewLine]h0 = 
        H\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\); 
      ccdots = Graphics[{{Green, PointSize[0.03], 
              Point[p\&\[RightVector][1\/2 - h0]]}, {Green, PointSize[0.03], 
              Point[p\&\[RightVector][1\/2]]}, {Green, PointSize[0.03], 
              Point[p\&\[RightVector][
                  1\/2 + h0]]}}]; \[IndentingNewLine]graph = 
        Plot[f[x], {x, \(-1\), 1}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity]; \[IndentingNewLine]circle1 = 
        Graphics[{Red, 
            Circle[{a[1\/2, h0], b[1\/2, h0]}, 
              r[1\/2, h0]]}\ ]; \ \[IndentingNewLine]Show[graph, circle1, 
        ccdots, PlotRange \[Rule] {{\(-1\), 1}, {\(-0.5\), 1.5}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1.5, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\ ]\)}], "Input",
  AnimationDisplayTime->0.482681]
}, Closed]],

Cell[TextData[{
  StyleBox["Generalizations for 2D",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIn two dimensions, a curve can be expressed with the parametric \
equations  ",
  Cell[BoxData[
      \(x = f[t]\)]],
  " and  ",
  Cell[BoxData[
      \(y = g[t]\)]],
  ".   Similarly, the formulas for the radius of curvature and center of \
curvature can be derived using limits.  At the point  ",
  Cell[BoxData[
      \(p\&\[RightVector][t]\  = {f[t], g[t]}\)]],
  "  the center and radius of the circle of convergence is \n\t\n\t\t",
  Cell[BoxData[
      \(c\&\[RightVector][
          t]\  = \ {f[
              t] + \(\(g'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(g'\)[t]\ \(f''\)[t] - \(f'\)[t]\ \(g''\)[t]\), \ 
          g[t] + \(\(f'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\)}\)]],
  "  \n\t\t\n\t\t",
  Cell[BoxData[
      \(r[
          t]\  = \ \ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\^\(3/2\)\/\(\(|\)\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \
\(f''\)[t]\)\(|\)\)\)]],
  "  \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The absolute value is necessary, otherwise the formula would only work \
for a curve that is ",
  ButtonBox["positively oriented",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CurveOrientation.html"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Details",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, f, g, h, t, r];\)\ \), "\[IndentingNewLine]", 
    \(\(eqn1\  = \ \ \ \ \ \ \((f[t] - a)\)\^2\ \  + \ \ \ \ \((g[t] - \
b)\)\^2\ \ \ \  \[Equal] \ r\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqn2\  = \ \ \((f[t - h] - a)\)\^2 + \((g[t - h] - b)\)\^2\  \[Equal] \
\ r\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqn3\  = \ \ \((f[t + h] - a)\)\^2 + \((g[t + h] - b)\)\^2\  \[Equal] \
\ r\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns = {eqn1, eqn2, eqn3};\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Find the collocation circle (x-a\!\(\()\^2\)\) + \
(y-b\!\(\()\^2\)\) = \!\(r\^2\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<That goes through the three points\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<{f[t-h],g[t-h]}, {f[t],g[t]}, {f[t+h],g[t+h]}\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Solve the equations\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(solset = 
        Solve[{eqn1, eqn2, eqn3}, {a, b, 
            r}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\ 
        PowerExpand[
          MapAll[FullSimplify, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2, 1\)\(\[RightDoubleBracket]\
\)\)]], "\<\n\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ 
        PowerExpand[
          MapAll[FullSimplify, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2, 2\)\(\[RightDoubleBracket]\
\)\)]], "\<\n\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\ 
        PowerExpand[
          MapAll[FullSimplify, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2, 3\)\(\[RightDoubleBracket]\
\)\)]]];\)\ \)}], "Input"],

Cell[TextData[{
  "Now let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the limit of the collocation circles and get the osculating circle."
}], "Text"],

Cell[BoxData[{
    \(\(r[t_, h_] = 
        PowerExpand[
          MapAll[FullSimplify, 
            solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\
\[RightDoubleBracket]\)\)]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(r[t_] = 
        Limit[r[t, h], h \[Rule] 0, 
          Analytic \[Rule] True];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The radius of the collocation circle is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<r[t,h] = \>", \ r[t, h]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Take the limit as h\[Rule]0 and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<the radius of the circle of curvature\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<  r[t] = \>", \ r[t]\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{
    \(\(a[t_, h_] = 
        MapAll[FullSimplify, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 2, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(a[t_] = 
        Expand[Limit[\ a[t, h], h \[Rule] 0, 
            Analytic \[Rule] True]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The abscissa of the collocation circle is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<a[t,h] = \>", \ a[t, h]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Take the limit as h\[Rule]0 and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<the abscissa of the circle of curvature\>", "\<\n\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<  a[t] = \>", 
        f[t] + Simplify[a[t] - f[t]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(b[t_, h_] = 
        MapAll[FullSimplify, 
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 3, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(b[t_] = 
        Expand[Limit[b[t, h], h \[Rule] 0, 
            Analytic \[Rule] True]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The ordinate of the collocation circle is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<b[t,h] = \>", \ b[t, h]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Take the limit as h\[Rule]0 and get\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<the ordinate of the circle of curvature\>", "\<\n\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<  b[t] = \>", 
        g[t] + Simplify[b[t] - g[t]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(c\&\[RightVector][x_]\  = \ {f[t] + Simplify[a[t] - f[t]], 
          g[t] + Simplify[b[t] - g[t]]};\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   x = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   y = \>", g[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[t] = \>\"", {f[t], 
          g[t]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[t] = \>\"", 
        c\&\[RightVector][t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[t] = \>", r[t]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Abscissa the Easy Way",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nSubtract from  ",
  Cell[BoxData[
      \(f[x]\)]],
  " the radius of curvature times ",
  Cell[BoxData[
      \(\(g'\)[x]\/\@\(\(f'\)[x]\^2 + \(g'\)[x]\^2\)\)]],
  ".  The abscissa of the circle of curvature is \n\n\t",
  Cell[BoxData[{
      \(a[t]\  = \ 
        f[t]\  - \ \(\(g'\)[t]\/\@\(\(f'\)[t]\^2 + \(g'\)[t]\^2\)\) 
            r[t]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(a[t]\  = \ 
        f[t]\  - \ \(\(g'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\)\)}]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Details",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(r[
          t_]\  = \ \((\(f'\)[t]\^2 + \(g'\)[t]\^2)\)\^\(3/2\)\/\(\(f'\)[t]\ \
\(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<r[t] = \>", r[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The abscisssa of the center of the circle of \
curvature\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a[t] = f[t] - \!\(\(g'\)[t]\/\@\(\(f'\)[t]\^2 + \
\(g'\)[t]\^2\)\)r[t]\>\""\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<a[t] = f[t] - \>", \(g'\)[t]\/\@\(\(f'\)[t]\^2 + \
\(g'\)[t]\^2\), r[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<a[t] = \>", 
        f[t] - \(\(g'\)[t]\/\@\(\(f'\)[t]\^2 + \(g'\)[t]\^2\)\) 
            r[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<And\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<a[t] = \>", 
        f[t] - Simplify[\(\(g'\)[t]\/\@\(\(f'\)[t]\^2 + \(g'\)[t]\^2\)\) 
              r[t]]\ ];\)\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["The Ordinate the Easy Way",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nAdd to  ",
  Cell[BoxData[
      \(g[x]\)]],
  " the radius of curvature times ",
  Cell[BoxData[
      \(\(f'\)[x]\/\@\(\(f'\)[x]\^2 + \(g'\)[x]\^2\)\)]],
  ".  The ordinate of the circle of curvature is \n\n\t",
  Cell[BoxData[{
      \(b[t]\  = \ 
        g[t]\  + \ \(\(f'\)[t]\/\@\(\(f'\)[t]\^2 + \(g'\)[t]\^2\)\) 
            r[t]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(b[t]\  = \ 
        g[t]\  + \ \(\(f'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\)\)}]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Details",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(r[
          t_]\  = \ \((\(f'\)[t]\^2 + \(g'\)[t]\^2)\)\^\(3/2\)\/\(\(f'\)[t]\ \
\(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[t] = \>", r[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The ordinate of the center of the circle of curvature\>"];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<b[t] = g[t] + \!\(\(f'\)[t]\/\@\(\(f'\)[t]\^2 + \
\(g'\)[t]\^2\)\)r[t]\>\""\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<b[t] = g[t] + \>", \(f'\)[t]\/\@\(\(f'\)[t]\^2 + \
\(g'\)[t]\^2\), r[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<b[t] = \>", 
        g[t] + \(\(f'\)[t]\/\@\(\(f'\)[t]\^2 + \(g'\)[t]\^2\)\) 
            r[t]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the ",
  ButtonBox["cardioid",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Curves/Cardioid.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  "  ",
  Cell[BoxData[
      \(x = 2  cos \((t)\) - cos \((2  t)\)\)]],
  ",  ",
  Cell[BoxData[
      \(y = 2  sin \((t)\) - sin \((2  t)\)\)]],
  ".  Draw the circle of curvature at   ",
  Cell[BoxData[
      \(\(\(t = \[Pi]\/3\)\(,\)\(\(2  \[Pi]\)\/3\)\(,\)\(\ \)\(\[Pi]\)\(\ \
\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[t_] = \ 2  Cos[t] - Cos[2  t];\)\ \), "\[IndentingNewLine]", 
    \(\(g[t_] = \ 2  Sin[t] - Sin[2  t];\)\ \), "\[IndentingNewLine]", 
    \(\(p\&\[RightVector][t_] = {f[t], g[t]};\)\ \), "\[IndentingNewLine]", 
    \(\(c\&\[RightVector][
          t_]\  = {f[
              t] - \(\(g'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\), \ 
          g[t] + \(\(f'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\)};\)\ \), \
"\[IndentingNewLine]", 
    \(\(r[
          t_]\  = \ \((\(f'\)[t]\^2 + \(g'\)[t]\^2)\)\^\(3/2\)\/\(\(f'\)[t]\ \
\(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   x = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   y = \>", g[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[t] = \>\"", {f[t], 
          g[t]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[t] = \>\"", 
        MapAll[Simplify, 
          c\&\[RightVector][t]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[t] = \>", MapAll[Simplify, r[t]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(T = \[Pi]\/3;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ccdots = 
        Graphics[{{Blue, PointSize[0.03], Point[p\&\[RightVector][T]]}, {Red, 
              PointSize[0.03], 
              Point[c\&\[RightVector][T]]}}];\)\), "\[IndentingNewLine]", 
    \(\(graph = 
        ParametricPlot[{f[t], g[t]}, {t, 0, 2  \[Pi]}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(circle1 = 
        Graphics[{Red, 
            Circle[c\&\[RightVector][T], 
              r[T]]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph, circle1, ccdots, 
        PlotRange \[Rule] {{\(-3\), 2.5}, {\(-2.75\), 2.75}}, 
        AspectRatio \[Rule] \ 1, 
        Ticks \[Rule] {Range[\(-3\), 2, 1], Range[\(-2\), 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", 
        T, "\<] = \>", {f[T], g[T]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", T, "\<] = \>", 
        MapAll[Simplify, 
          c\&\[RightVector][T]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[\>", T, "\<] = \>", 
        MapAll[Simplify, r[T]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(T = \(2  \[Pi]\)\/3;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ccdots = 
        Graphics[{{Blue, PointSize[0.03], Point[p\&\[RightVector][T]]}, {Red, 
              PointSize[0.03], 
              Point[c\&\[RightVector][T]]}}];\)\), "\[IndentingNewLine]", 
    \(\(graph = 
        ParametricPlot[{f[t], g[t]}, {t, 0, 2  \[Pi]}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(circle1 = 
        Graphics[{Red, 
            Circle[c\&\[RightVector][T], 
              r[T]]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph, circle1, ccdots, 
        PlotRange \[Rule] {{\(-3\), 2.5}, {\(-2.75\), 2.75}}, 
        AspectRatio \[Rule] \ 1, 
        Ticks \[Rule] {Range[\(-3\), 2, 1], Range[\(-2\), 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", 
        T, "\<] = \>", {f[T], g[T]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", T, "\<] = \>", 
        MapAll[Simplify, 
          c\&\[RightVector][T]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[\>", T, "\<] = \>", 
        MapAll[Simplify, r[T]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(T = \[Pi];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ccdots = 
        Graphics[{{Blue, PointSize[0.03], Point[p\&\[RightVector][T]]}, {Red, 
              PointSize[0.03], 
              Point[c\&\[RightVector][T]]}}];\)\), "\[IndentingNewLine]", 
    \(\(graph = 
        ParametricPlot[{f[t], g[t]}, {t, 0, 2  \[Pi]}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(circle1 = 
        Graphics[{Red, 
            Circle[c\&\[RightVector][T], 
              r[T]]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph, circle1, ccdots, 
        PlotRange \[Rule] {{\(-3\), 2.5}, {\(-2.75\), 2.75}}, 
        AspectRatio \[Rule] \ 1, 
        Ticks \[Rule] {Range[\(-3\), 2, 1], Range[\(-2\), 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", 
        T, "\<] = \>", {f[T], g[T]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", T, "\<] = \>", 
        MapAll[Simplify, 
          c\&\[RightVector][T]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[\>", T, "\<] = \>", 
        MapAll[Simplify, r[T]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the ",
  ButtonBox["cardioid",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Curves/Cardioid.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  "  ",
  Cell[BoxData[
      \(x = 2  cos \((\(-t\))\) - cos \((\(-2\) t)\)\)]],
  ",  ",
  Cell[BoxData[
      \(y = 2  sin \((\(-t\))\) - sin \((\(-2\) t)\)\)]],
  ".  Draw the circle of curvature at   ",
  Cell[BoxData[
      \(t = \[Pi]\/3\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The radius of curvature formula  ",
  Cell[BoxData[
      \(r[
          t]\  = \ \((\(f'\)[t]\^2 + \(g'\)[t]\^2)\)\^\(3/2\)\/\(\(f'\)[t]\ \
\(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\)\)]],
  "  can be used provided that the curve is ",
  ButtonBox["positively oriented",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CurveOrientation.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  Loosely speaking the curve must be oriented in the \"counterclockwise \
direction\".  Let's investigate the situation at hand.  "
}], "Text"],

Cell[BoxData[{
    \(\(f[t_] = \ 
        2  Cos[\(-t\)] - Cos[\(-2\) t];\)\ \), "\[IndentingNewLine]", 
    \(\(g[t_] = \ 
        2  Sin[\(-t\)] - Sin[\(-2\) t];\)\ \), "\[IndentingNewLine]", 
    \(\(p\&\[RightVector][t_] = {f[t], g[t]};\)\ \), "\[IndentingNewLine]", 
    \(\(c\&\[RightVector][
          t_]\  = {f[
              t] - \(\(g'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\), \ 
          g[t] + \(\(f'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\)};\)\ \), \
"\[IndentingNewLine]", 
    \(\(r[
          t_]\  = \ \((\(f'\)[t]\^2 + \(g'\)[t]\^2)\)\^\(3/2\)\/\(\(f'\)[t]\ \
\(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   x = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   y = \>", g[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[t] = \>\"", {f[t], 
          g[t]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[t] = \>\"", 
        MapAll[Simplify, 
          c\&\[RightVector][t]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[t] = \>", MapAll[Simplify, r[t]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(T = \[Pi]\/3;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ccdots = 
        Graphics[{{Blue, PointSize[0.03], Point[p\&\[RightVector][T]]}, {Red, 
              PointSize[0.03], 
              Point[c\&\[RightVector][T]]}}];\)\), "\[IndentingNewLine]", 
    \(\(graph = 
        ParametricPlot[{f[t], g[t]}, {t, 0, 2  \[Pi]}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(circle1 = 
        Graphics[{Red, 
            Circle[c\&\[RightVector][T], 
              r[T]]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph, circle1, ccdots, 
        PlotRange \[Rule] {{\(-3\), 2.5}, {\(-2.75\), 2.75}}, 
        AspectRatio \[Rule] \ 1, 
        Ticks \[Rule] {Range[\(-3\), 2, 1], Range[\(-2\), 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", 
        T, "\<] = \>", {f[T], g[T]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", T, "\<] = \>", 
        MapAll[Simplify, 
          c\&\[RightVector][T]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[\>", T, "\<] = \>", 
        MapAll[Simplify, r[T]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The formulas failed because the curve is 'negatively \
oriented'\>"];\)\)}], "Input"],

Cell[TextData[{
  "The formula for the radius of curvature computes a negative value.  The \
correct the situation, change the sign and use ",
  Cell[BoxData[
      \(r[
          t]\  = \ \(-\ \(\((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\^\(3/2\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[
                    t]\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(f[t_] = \ 
        2  Cos[\(-t\)] - Cos[\(-2\) t];\)\ \), "\[IndentingNewLine]", 
    \(\(g[t_] = \ 
        2  Sin[\(-t\)] - Sin[\(-2\) t];\)\ \), "\[IndentingNewLine]", 
    \(\(p\&\[RightVector][t_] = {f[t], g[t]};\)\ \), "\[IndentingNewLine]", 
    \(\(c\&\[RightVector][
          t_]\  = {f[
              t] - \(\(g'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\), \ 
          g[t] + \(\(f'\)[t]\ \((\(f'\)[t]\^2 + \
\(g'\)[t]\^2)\)\)\/\(\(f'\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\)};\)\ \), \
"\[IndentingNewLine]", 
    \(\(r[
          t_]\  = \ \(-\ \(\((\(f'\)[t]\^2 + \(g'\)[t]\^2)\)\^\(3/2\)\/\(\(f'\
\)[t]\ \(g''\)[t] - \(g'\)[t]\ \(f''\)[
                    t]\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   x = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   y = \>", g[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[t] = \>\"", {f[t], 
          g[t]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[t] = \>\"", 
        MapAll[Simplify, 
          c\&\[RightVector][t]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[t] = \>", MapAll[Simplify, r[t]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(T = \[Pi]\/3;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ccdots = 
        Graphics[{{Blue, PointSize[0.03], Point[p\&\[RightVector][T]]}, {Red, 
              PointSize[0.03], 
              Point[c\&\[RightVector][T]]}}];\)\), "\[IndentingNewLine]", 
    \(\(graph = 
        ParametricPlot[{f[t], g[t]}, {t, 0, 2  \[Pi]}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(circle1 = 
        Graphics[{Red, 
            Circle[c\&\[RightVector][T], 
              r[T]]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph, circle1, ccdots, 
        PlotRange \[Rule] {{\(-3\), 2.5}, {\(-2.75\), 2.75}}, 
        AspectRatio \[Rule] \ 1, 
        Ticks \[Rule] {Range[\(-3\), 2, 1], Range[\(-2\), 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\&\[RightVector]\)[\>\"", 
        T, "\<] = \>", {f[T], g[T]}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\&\[RightVector]\)[\>\"", T, "\<] = \>", 
        MapAll[Simplify, 
          c\&\[RightVector][T]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r[\>", T, "\<] = \>", 
        MapAll[Simplify, r[T]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The formula for the radius of curvature should include an absolute \
value.  Be careful!  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " it could be written as\n\n\t\t",
  Cell[BoxData[
      \(r[t]\  = \ 
        Abs[\ \((\(f'\)[t]\^2 + \(g'\)[t]\^2)\)\^\(3/2\)\/\(\(f'\)[t]\ \
\(g''\)[t] - \(g'\)[t]\ \(f''\)[t]\)]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Reference",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox[" John Mathews,",
    FontFamily->"New Century Schlbk"],
  StyleBox[" ",
    FontFamily->"New York"],
  ButtonBox["The Circle of Curvature: It\[CloseCurlyQuote]s a Limit!",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/articles/2003CircleOfCurvature.pdf"],
       None},
    ButtonStyle->"Hyperlink"],
  StyleBox[", The AMATYC Review, Vol. 25, No. 1, Fall 2003",
    FontFamily->"New York"],
  StyleBox[", pp. 57-63.  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Curvature",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/CurvatureBib.html"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Curvature",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CurvatureBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1014, 646},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 162, 4, 35, "Text"],
Cell[1941, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3420, 111, 888, 27, 89, "Text"],
Cell[4311, 140, 1897, 62, 163, "Text"],
Cell[6211, 204, 353, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[6589, 219, 101, 2, 33, "Text"],
Cell[6693, 223, 1205, 22, 274, "Input"],
Cell[7901, 247, 504, 17, 83, "Text"],
Cell[8408, 266, 919, 17, 218, "Input"],
Cell[9330, 285, 171, 5, 33, "Text"],
Cell[9504, 292, 977, 19, 221, "Input"],
Cell[10484, 313, 97, 2, 33, "Text"]
}, Closed]],
Cell[10596, 318, 390, 8, 87, "Text"],
Cell[10989, 328, 2158, 70, 210, "Text"],

Cell[CellGroupData[{
Cell[13172, 402, 103, 2, 33, "Text"],
Cell[13278, 406, 1112, 31, 152, "Text"],
Cell[14393, 439, 6250, 156, 334, "Input"]
}, Closed]],
Cell[20658, 598, 407, 14, 49, "Text"],

Cell[CellGroupData[{
Cell[21090, 616, 101, 2, 33, "Text"],
Cell[21194, 620, 790, 14, 219, "Input"],
Cell[21987, 636, 1541, 31, 269, "Input"]
}, Closed]],
Cell[23543, 670, 359, 12, 49, "Text"],

Cell[CellGroupData[{
Cell[23927, 686, 101, 2, 33, "Text"],
Cell[24031, 690, 1256, 21, 215, "Input"],
Cell[25290, 713, 1160, 23, 214, "Input"],
Cell[26453, 738, 850, 16, 172, "Input"]
}, Closed]],
Cell[27318, 757, 422, 8, 87, "Text"],
Cell[27743, 767, 896, 30, 52, "Text"],

Cell[CellGroupData[{
Cell[28664, 801, 101, 2, 33, "Text"],
Cell[28768, 805, 461, 8, 130, "Input"],
Cell[29232, 815, 838, 27, 128, "Text"],
Cell[30073, 844, 445, 7, 90, "Input"],
Cell[30521, 853, 44, 0, 33, "Text"],
Cell[30568, 855, 154, 3, 70, "Input"],
Cell[30725, 860, 576, 19, 52, "Text"],
Cell[31304, 881, 221, 4, 70, "Input"],
Cell[31528, 887, 469, 10, 90, "Input"],
Cell[32000, 899, 291, 8, 86, "Text"],
Cell[32294, 909, 1231, 20, 234, "Input"],
Cell[33528, 931, 722, 14, 130, "Input"],
Cell[34253, 947, 990, 18, 226, "Input"],
Cell[35246, 967, 117, 3, 33, "Text"]
}, Closed]],
Cell[35378, 973, 150, 3, 30, "Text"],
Cell[35531, 978, 1386, 41, 90, "Text"],
Cell[36920, 1021, 906, 30, 52, "Text"],
Cell[37829, 1053, 457, 7, 90, "Input"],
Cell[38289, 1062, 575, 19, 33, "Text"],
Cell[38867, 1083, 611, 11, 150, "Input"],
Cell[39481, 1096, 244, 6, 52, "Text"],
Cell[39728, 1104, 437, 8, 106, "Input"],
Cell[40168, 1114, 412, 9, 52, "Text"],
Cell[40583, 1125, 245, 4, 50, "Input"],
Cell[40831, 1131, 327, 5, 78, "Input"],
Cell[41161, 1138, 275, 5, 78, "Input"],
Cell[41439, 1145, 370, 11, 52, "Text"],
Cell[41812, 1158, 366, 7, 96, "Input"],
Cell[42181, 1167, 331, 9, 52, "Text"],
Cell[42515, 1178, 333, 6, 76, "Input"],
Cell[42851, 1186, 611, 13, 71, "Text"],
Cell[43465, 1201, 392, 10, 128, "Text"],
Cell[43860, 1213, 338, 7, 70, "Input"],
Cell[44201, 1222, 168, 5, 33, "Text"],
Cell[44372, 1229, 741, 13, 186, "Input"],
Cell[45116, 1244, 225, 6, 33, "Text"],
Cell[45344, 1252, 1044, 17, 171, "Input"],
Cell[46391, 1271, 752, 23, 78, "Text"],
Cell[47146, 1296, 288, 11, 81, "Text"],
Cell[47437, 1309, 745, 14, 240, "Input"],
Cell[48185, 1325, 220, 5, 71, "Text"],
Cell[48408, 1332, 815, 17, 186, "Input"],
Cell[49226, 1351, 225, 6, 33, "Text"],
Cell[49454, 1359, 271, 4, 61, "Input"],
Cell[49728, 1365, 687, 24, 100, "Text"],

Cell[CellGroupData[{
Cell[50440, 1393, 97, 2, 33, "Text"],
Cell[50540, 1397, 288, 5, 76, "Input"],
Cell[50831, 1404, 725, 12, 187, "Input"],
Cell[51559, 1418, 282, 5, 76, "Input"],
Cell[51844, 1425, 282, 5, 76, "Input"],
Cell[52129, 1432, 318, 5, 76, "Input"],
Cell[52450, 1439, 553, 8, 141, "Input"],
Cell[53006, 1449, 554, 10, 114, "Input"]
}, Closed]],
Cell[53575, 1462, 283, 10, 78, "Text"],
Cell[53861, 1474, 755, 14, 240, "Input"],
Cell[54619, 1490, 390, 12, 71, "Text"],
Cell[55012, 1504, 603, 10, 152, "Input"],
Cell[55618, 1516, 5377, 158, 55, "Text"],

Cell[CellGroupData[{
Cell[61020, 1678, 101, 2, 33, "Text"],
Cell[61124, 1682, 2950, 53, 755, "Input"],
Cell[64077, 1737, 2154, 38, 438, "Input"]
}, Closed]],
Cell[66246, 1778, 1430, 40, 218, "Text"],

Cell[CellGroupData[{
Cell[67701, 1822, 97, 2, 33, "Text"],
Cell[67801, 1826, 1746, 36, 311, "Input"],
Cell[69550, 1864, 171, 5, 33, "Text"],
Cell[69724, 1871, 767, 16, 150, "Input"],
Cell[70494, 1889, 765, 16, 150, "Input"],
Cell[71262, 1907, 763, 16, 150, "Input"],
Cell[72028, 1925, 584, 9, 132, "Input"]
}, Closed]],
Cell[72627, 1937, 676, 19, 177, "Text"],

Cell[CellGroupData[{
Cell[73328, 1960, 97, 2, 33, "Text"],
Cell[73428, 1964, 1011, 18, 300, "Input"]
}, Closed]],
Cell[74454, 1985, 670, 19, 177, "Text"],

Cell[CellGroupData[{
Cell[75149, 2008, 97, 2, 33, "Text"],
Cell[75249, 2012, 798, 14, 237, "Input"]
}, Closed]],
Cell[76062, 2029, 606, 22, 33, "Text"],

Cell[CellGroupData[{
Cell[76693, 2055, 101, 2, 33, "Text"],
Cell[76797, 2059, 1201, 21, 253, "Input"],
Cell[78001, 2082, 1328, 27, 225, "Input"],
Cell[79332, 2111, 1335, 27, 227, "Input"],
Cell[80670, 2140, 1325, 27, 214, "Input"]
}, Closed]],
Cell[82010, 2170, 564, 21, 33, "Text"],

Cell[CellGroupData[{
Cell[82599, 2195, 101, 2, 33, "Text"],
Cell[82703, 2199, 553, 13, 61, "Text"],
Cell[83259, 2214, 1237, 23, 253, "Input"],
Cell[84499, 2239, 1496, 30, 265, "Input"],
Cell[85998, 2271, 341, 9, 42, "Text"],
Cell[86342, 2282, 1269, 24, 253, "Input"],
Cell[87614, 2308, 1328, 27, 225, "Input"],
Cell[88945, 2337, 458, 14, 80, "Text"]
}, Closed]],
Cell[89418, 2354, 612, 19, 68, "Text"],
Cell[90033, 2375, 158, 3, 35, "Text"],
Cell[90194, 2380, 529, 16, 33, "Text"],
Cell[90726, 2398, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

