(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     35277,       1182]*)
(*NotebookOutlinePosition[     36103,       1209]*)
(*  CellTagsIndexPosition[     36059,       1205]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Midpoint Rule for Numerical \
Integration",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem  (Midpoint Rule)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Consider ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  " over",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\([x\_0, x\_1]\)\)]],
  StyleBox[", where ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_1 = x\_0 + h\)]],
  ". ",
  StyleBox["The midpoint rule is  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(MP \((f, h)\)\  = \ \(\(h\)\(\ \)\(f\) \((x\_0 + h\/2)\)\(\ \)\)\)]],
  ".  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["This is an numerical approximation to the integral of ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox[" over ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\([x\_0, x\_1]\)\)]],
  StyleBox[" and we have the expression  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(x\_0\)\%\(x\_1\)\ 
          f \((x)\) \[DifferentialD]x\), "  ", 
        StyleBox["\[TildeTilde]",
          FontSize->14], "  ", \(MP \((f, h)\)\)}]]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "The remainder term for the midpoint rule is  ",
  Cell[BoxData[
      RowBox[{
        InterpretationBox[
          RowBox[{\(\(R\_MP\) \((f, h)\)\), " ", "=", " ", 
            RowBox[{\(1\/24\), 
              SuperscriptBox["f", "''",
                MultilineFunction->None], \((c)\)}]}],
          SeriesData[ h, 0, {
            Times[ 
              Rational[ 1, 24], 
              Derivative[ 2][ f][ x]]}, 3, 4, 1]], \(h\^3\)}]]],
  ",  where ",
  Cell[BoxData[
      \(c\)]],
  " lies somewhere between ",
  Cell[BoxData[
      RowBox[{\(x\_0\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(x\_1\)}]]],
  ", and have the equality  \n\n\t",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(x\_0\)\%\(x\_1\)\ 
          f \((x)\) \[DifferentialD]x\), " ", "=", " ", 
        RowBox[{\(h\ f \((x\_0 + h\/2)\)\), " ", "+", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(1\/24\), 
                SuperscriptBox["f", "''",
                  MultilineFunction->None], \((c)\)}],
              SeriesData[ h, 0, {
                Times[ 
                  Rational[ 1, 24], 
                  Derivative[ 2][ f][ x]]}, 3, 4, 1]], \(h\^3\)}]}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["The Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/MidpointRuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Midpoint Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/MidpointRuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Composite Midpoint Rule",
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["\tAn intuitive method of finding the area under a curve y = f(x)  \
is by approximating that area with a series of rectangles that lie above the \
intervals  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\([x\_\(k - 1\), x\_k]\)}\_\(k = 1\)\%m\)]],
  StyleBox[".  When several rectangles are used, we call it the ",
    FontFamily->"Times New Roman"],
  StyleBox["composite midpoint rule",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem  (Composite Midpoint Rule)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Consider ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  " over",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[".  Suppose that the interval ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[" is subdivided into  m  subintervals  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\([x\_\(k - 1\), x\_k]\)}\_\(k = 1\)\%m\)]],
  StyleBox["  of equal width  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(h = \(b\  - \ a\)\/m\)]],
  StyleBox["  by using the equally spaced nodes  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(c\_k = a + \((k - 1\/2)\)\ h\)]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(k = 1, 2,  ... , m\)]],
  StyleBox[".   The ",
    FontFamily->"Times New Roman"],
  StyleBox["composite midpoint rule for m subintervals",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" is  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(M \((f, h)\)\  = \ \ h \(\[Sum]\+\(k = 1\)\%m f \((c\_k)\)\)\)]],
  ".  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["This is an numerical approximation to the integral of ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox[" over ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[" and we write  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Integral]\_a\%b\ f \((x)\) \[DifferentialD]x\), "  ", 
        StyleBox["\[TildeTilde]",
          FontSize->14], "  ", \(M \((f, h)\)\)}]]],
  ".  "
}], "Text"],

Cell[TextData[StyleBox["Remainder term for the Composite Midpoit Rule",
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Corollary  (Midpoint Rule: Remainder term)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Suppose that ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[" is subdivided into  m  subintervals  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\([x\_\(k - 1\), x\_k]\)}\_\(k = 1\)\%m\)]],
  StyleBox["  of width  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(h = \(b\  - \ a\)\/m\)]],
  StyleBox[".   The ",
    FontFamily->"Times New Roman"],
  StyleBox["composite midpoint rule",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(M \((f, h)\)\  = \ 
        h \(\[Sum]\+\(k = 1\)\%m f \((a + \((k - 1\/2)\)\ h)\)\)\)]],
  "  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["is an numerical approximation to the integral, and  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\[Integral]\_a\%b\ 
          f \((x)\) \[DifferentialD]x\ \  = \ \ M \((f, 
              h)\)\  + \ \(E\_M\) \((f, h)\)\)]],
  ".  \n\nFurthermore, if ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(f \((x)\)\), "\[Element]", 
        RowBox[{
          SuperscriptBox[
            StyleBox["C",
              FontWeight->"Bold"], "2"], "[", \(a, b\), "]"}]}]]],
  ",  then there exists a value  c  with  a < c < b  so that the error term  \
",
  Cell[BoxData[
      \(\(E\_M\) \((f, h)\)\)]],
  "  has the form\n\n\t",
  Cell[BoxData[
      \(\(E\_M\) \((f, 
            h)\)\  = \ \(\(\((b\  - \ a)\) \(f\^2\) \((c)\)\)\/24\) h\^2\)]],
  ".  \n\nThis is expressed using the \"big ",
  Cell[BoxData[
      StyleBox["O",
        FontWeight->"Bold",
        FontSlant->"Italic"]]],
  "\" notation  ",
  Cell[BoxData[
      RowBox[{\(\(E\_M\) \((f, h)\)\), " ", "=", " ", 
        RowBox[{
          StyleBox["O",
            FontWeight->"Bold",
            FontSlant->"Italic"], \((h\^2)\)}]}]]],
  ".  \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  When the step size is reduced by a factor of ",
  Cell[BoxData[
      \(1\/2\)]],
  " the error term  ",
  Cell[BoxData[
      \(\(E\_M\) \((f, h)\)\)]],
  " should be reduced by approximately ",
  Cell[BoxData[
      \(\((1\/2)\)\^2\  = \ 0.25\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["The Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/MidpointRuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Midpoint Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/MidpointRuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Midpoint/Midpoint.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Midpoint/Midpoint.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["The Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/MidpointRuleProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Midpoint Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/MidpointRuleProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm Composite Midpoint Rule.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  To approximate the integral  \n\n\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubsuperscriptBox["\[Integral]", 
            StyleBox["a",
              FontSize->10], 
            StyleBox["b",
              FontSize->10]],
          FontSize->18], \(f \((x)\) \[DifferentialD]x\)}]]],
  Cell[BoxData[
      RowBox[{
        StyleBox["\[TildeTilde]",
          FontSize->14], " "}]]],
  Cell[BoxData[
      \(h \(\[Sum]\+\(k = 1\)\%m f \((c\_k)\)\)\)]],
  ",  \n\nby sampling ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  " at the ",
  Cell[BoxData[
      \(m\)]],
  " equally spaced points  ",
  Cell[BoxData[
      \(c\_k = a + \((k - 1\/2)\)\ h\)]],
  "  for  ",
  Cell[BoxData[
      \(k = 1, 2, \[CenterEllipsis], m\)]],
  ",  where  ",
  Cell[BoxData[
      \(h = \(b\  - \ a\)\/m\)],
    AspectRatioFixed->False],
  ".  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Midpoint Rule).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(MidpointRule[a0_, b0_, 
          m0_] := \[IndentingNewLine]Module[{a = N[a0], b = N[b0], c, k, 
            m = m0}, \[IndentingNewLine]h\  = \ \(b - a\)\/m; \
\[IndentingNewLine]c\_k_ = 
            a + \((k - 1\/2)\)\ h; \ \[IndentingNewLine]Return[\ 
            h \(\[Sum]\+\(k = 1\)\%m f[c\_k]\)\ ];\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell["Or you can use the traditional program.", "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Midpoint Rule).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(MidpointRule[a0_, b0_, 
          m0_] := \[IndentingNewLine]Module[{a = N[a0], b = N[b0], m = m0, 
            k}, \[IndentingNewLine]h\  = \ \(b - a\)\/m; \ \ \
\[IndentingNewLine]sum = 0; \ \[IndentingNewLine]For[\ k = 1, \ 
            k \[LessEqual] 
              m, \ \(k++\), \ \[IndentingNewLine]\(sum = 
                sum + f[
                    a + \((k - 
                            1/2)\)\ h];\)\ ]; \ \[IndentingNewLine]Return[\ 
            h\ sum];\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Numerically approximate the integral  ",
  Cell[BoxData[
      \(\[Integral]\_0\%2\((2 + Cos[2 \@ x])\) \[DifferentialD]x\)]],
  "  by using the midpoint rule with  m = 1, 2, 4, 8, and 16  subintervals."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_]\ \  = \ 2 + Cos[2 \@ x];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(FilledPlot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2}, {0, 3}}, 
        PlotStyle \[Rule] {{Thickness[0.01], Magenta}}, Fills \[Rule] Cyan, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["We will use simulated hand computations for the solution.", "Text"],

Cell[BoxData[
    \(\(\(f[x_] = 2 + Cos[2 \@ x];\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(m1 = \(\(\(2 - 0\)\/1\) \((f[1])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m1]\ \ \)}], "Input"],

Cell[BoxData[{
    \(m2 = \(\(\(2 - 0\)\/2\) \((f[1\/2] + 
            f[3\/2])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m2]\ \ \)}], "Input"],

Cell[BoxData[{
    \(m4 = \(\(\(2 - 0\)\/4\) \((f[1\/4] + f[3\/4] + f[5\/4] + 
            f[7\/4])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m4]\ \ \)}], "Input"],

Cell[BoxData[{
    \(m8 = \(\(\(2 - 0\)\/8\) \((f[1\/8] + f[3\/8] + f[5\/8] + f[7\/8] + 
            f[9\/8] + f[11\/8] + f[13\/8] + 
            f[15\/8])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m8]\ \ \)}], "Input"],

Cell[BoxData[{
    \(m16 = \(\(\(2 - 0\)\/16\) \((f[1\/16] + f[3\/16] + f[5\/16] + 
            f[7\/16] + f[9\/16] + f[11\/16] + f[13\/16] + f[15\/16] + 
            f[17\/16] + f[19\/16] + f[21\/16] + f[23\/16] + f[25\/16] + 
            f[27\/16] + f[29\/16] + 
            f[31\/16])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m16]\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Numerically approximate the integral  ",
  Cell[BoxData[
      \(\[Integral]\_0\%2\((2 + Cos[2 \@ x])\) \[DifferentialD]x\)]],
  "  by using the midpoint rule with  m = 50, 100, 200, 400  and 800  \
subintervals."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["We will use the subroutine for the solution.", "Text"],

Cell[BoxData[
    \(\(\(f[x_] = 2 + Cos[2 \@ x];\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(t50 = MidpointRule[0, 2, 50]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[t50, 12]\ \ \)}], "Input"],

Cell[BoxData[{
    \(t100 = MidpointRule[0, 2, 100]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[t100, 12]\ \ \)}], "Input"],

Cell[BoxData[{
    \(t200 = MidpointRule[0, 2, 200]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[t200, 12]\ \ \)}], "Input"],

Cell[BoxData[{
    \(t400 = MidpointRule[0, 2, 400]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[t400, 12]\ \ \)}], "Input"],

Cell[BoxData[{
    \(t800 = MidpointRule[0, 2, 800]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[t800, 12]\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the analytic value of the integral  ",
  Cell[BoxData[
      \(\[Integral]\_0\%2\((2 + Cos[2 \@ x])\) \[DifferentialD]x\)]],
  "  (i.e. find the \"true value\").   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(val = \[Integral]\_0\%2\((2 + 
              Cos[2 \@ x])\) \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(\(\(N[val]\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(NumberForm[N[val]\ \ , 12]\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the \"true value\" in example 3 and find the error for the ",
  "midpoint",
  " rule approximations in example 2.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(t50\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(t100\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(t200\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(t400\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(t800\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  When the step size is reduced by a factor of ",
  Cell[BoxData[
      \(1\/2\)]],
  " the error term  ",
  Cell[BoxData[
      \(\(E\_M\) \((f, h)\)\)]],
  " should be reduced by approximately  ",
  Cell[BoxData[
      \(\((1\/2)\)\^2\  = \ 0.25\)]],
  ".  Explore this phenomenon. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(val - t100\)\/\(val - t50\)\)], "Input"],

Cell[BoxData[
    \(\(val - t200\)\/\(val - t100\)\)], "Input"],

Cell[BoxData[
    \(\(val - t400\)\/\(val - t200\)\)], "Input"],

Cell[BoxData[
    \(\(val - t800\)\/\(val - t400\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Numerically approximate the integral ",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_0\%3\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", 
                StyleBox[\(\[ExponentialE]\^\(-x\)\),
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox[\(Sin[x\^2]\),
                  FontSize->12]}], 
              StyleBox["+",
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox["1",
                FontSize->12]}], ")"}], \(\[DifferentialD]x\)}]}]]],
  " by using the midpoint rule with  m = 1, 2, 4, 8, and 16  subintervals."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(f[x_]\), "  ", "=", " ", 
          RowBox[{
            RowBox[{"3", 
              StyleBox[\(\[ExponentialE]\^\(-x\)\),
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox[\(Sin[x\^2]\),
                FontSize->12]}], 
            StyleBox["+",
              FontSize->12], 
            StyleBox[" ",
              FontSize->12], 
            StyleBox["1",
              FontSize->12]}]}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`FilledPlot`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(FilledPlot[f[x], {x, 0, 3}, PlotRange \[Rule] {{0, 3}, {0, 2}}, 
          PlotStyle \[Rule] {{Thickness[0.01], Magenta}}, Fills \[Rule] Cyan, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<f[x] = \>", f[x]\ ];\), " "}]}], "Input"],

Cell["We will use simulated hand computations for the solution.", "Text"],

Cell[BoxData[{
    \(m1 = \(\(\(2 - 0\)\/1\) \((f[1])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m1]\ \ \)}], "Input"],

Cell[BoxData[{
    \(m2 = \(\(\(2 - 0\)\/2\) \((f[1\/2] + 
            f[3\/2])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m2]\ \ \)}], "Input"],

Cell[BoxData[{
    \(m4 = \(\(\(2 - 0\)\/4\) \((f[1\/4] + f[3\/4] + f[5\/4] + 
            f[7\/4])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m4]\ \ \)}], "Input"],

Cell[BoxData[{
    \(m8 = \(\(\(2 - 0\)\/8\) \((f[1\/8] + f[3\/8] + f[5\/8] + f[7\/8] + 
            f[9\/8] + f[11\/8] + f[13\/8] + 
            f[15\/8])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m8]\ \ \)}], "Input"],

Cell[BoxData[{
    \(m16 = \(\(\(2 - 0\)\/16\) \((f[1\/16] + f[3\/16] + f[5\/16] + 
            f[7\/16] + f[9\/16] + f[11\/16] + f[13\/16] + f[15\/16] + 
            f[17\/16] + f[19\/16] + f[21\/16] + f[23\/16] + f[25\/16] + 
            f[27\/16] + f[29\/16] + 
            f[31\/16])\)\(\ \ \)\)\), "\[IndentingNewLine]", 
    \(N[m16]\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Numerically approximate the integral ",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_0\%3\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", 
                StyleBox[\(\[ExponentialE]\^\(-x\)\),
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox[\(Sin[x\^2]\),
                  FontSize->12]}], 
              StyleBox["+",
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox["1",
                FontSize->12]}], ")"}], \(\[DifferentialD]x\)}]}]]],
  " by using the midpoint rule with  m = 50, 100, 200, 400  and 800  \
subintervals."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["We will use the subroutine for the solution.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(f[x_]\), "=", 
          RowBox[{
            RowBox[{"3", 
              StyleBox[\(\[ExponentialE]\^\(-x\)\),
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox[\(Sin[x\^2]\),
                FontSize->12]}], 
            StyleBox["+",
              FontSize->12], 
            StyleBox[" ",
              FontSize->12], 
            StyleBox["1",
              FontSize->12]}]}], ";"}], " "}]], "Input"],

Cell[BoxData[{
    \(t50 = MidpointRule[0, 3, 50]\ \), "\[IndentingNewLine]", 
    \(NumberForm[t50, 12]\ \)}], "Input"],

Cell[BoxData[{
    \(t100 = MidpointRule[0, 3, 100]\ \), "\[IndentingNewLine]", 
    \(NumberForm[t100, 12]\ \)}], "Input"],

Cell[BoxData[{
    \(t200 = MidpointRule[0, 3, 200]\ \), "\[IndentingNewLine]", 
    \(NumberForm[t200, 12]\ \)}], "Input"],

Cell[BoxData[{
    \(t400 = MidpointRule[0, 3, 400]\ \), "\[IndentingNewLine]", 
    \(NumberForm[t400, 12]\ \)}], "Input"],

Cell[BoxData[{
    \(t800 = MidpointRule[0, 3, 800]\ \), "\[IndentingNewLine]", 
    \(NumberForm[t800, 12]\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the analytic value of the integral  ",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_0\%3\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", 
                StyleBox[\(\[ExponentialE]\^\(-x\)\),
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox[\(Sin[x\^2]\),
                  FontSize->12]}], 
              StyleBox["+",
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox["1",
                FontSize->12]}], ")"}], \(\[DifferentialD]x\)}]}]]],
  "  (i.e. find the \"true value\").  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    RowBox[{"val", "=", 
      RowBox[{\(\[Integral]\_0\%3\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", 
                StyleBox[\(\[ExponentialE]\^\(-x\)\),
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox[\(Sin[x\^2]\),
                  FontSize->12]}], 
              StyleBox["+",
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox["1",
                FontSize->12]}], ")"}], \(\[DifferentialD]x\)}]}]}]], "Input"],

Cell[BoxData[
    \(val = N[Re[val]]\)], "Input"],

Cell[BoxData[
    \(NumberForm[val, 12]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the \"true value\" in example 8 and find the error for the ",
  "midpoint",
  " rule approximations in exercise 7.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(val - t50\)], "Input"],

Cell[BoxData[
    \(val - t100\)], "Input"],

Cell[BoxData[
    \(val - t200\)], "Input"],

Cell[BoxData[
    \(val - t400\)], "Input"],

Cell[BoxData[
    \(val - t800\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  When the step size is reduced by a factor of ",
  Cell[BoxData[
      \(1\/2\)]],
  " the error term  ",
  Cell[BoxData[
      \(\(E\_M\) \((f, h)\)\)]],
  " should be reduced by approximately  ",
  Cell[BoxData[
      \(\((1\/2)\)\^2\  = \ 0.25\)]],
  ".  Explore this phenomenon. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(val - t100\)\/\(val - t50\)\)], "Input"],

Cell[BoxData[
    \(\(val - t200\)\/\(val - t100\)\)], "Input"],

Cell[BoxData[
    \(\(val - t400\)\/\(val - t200\)\)], "Input"],

Cell[BoxData[
    \(\(val - t800\)\/\(val - t400\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Various Scenarios",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" and Animations for the Midpoint Rule.",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Let  ",
  Cell[BoxData[
      \(f[x] = 1 + \[ExponentialE]\^\(-x\)\ Sin[8\ x\^\(2/3\)]\)]],
  "  over  ",
  Cell[BoxData[
      \(\([0, 2]\)\)]],
  ".  Use the Midpoint Rule to approximate the value of the integral. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        1 + \[ExponentialE]\^\(-x\)\ Sin[
              8\ x\^\(2/3\)];\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 2.0;\)\ \), "\[IndentingNewLine]", 
    \(\(M = {1, 2, 4, 6, 8, 10, 12, 14, 16, 20, 24, 28, 32, 40, 50, 60, 70, 
          80, 100, 120};\)\), "\[IndentingNewLine]", 
    \(\(tbl = Table[j, {j, 1, 20}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(For[j = 1, 
        j \[LessEqual] 
          20, \(j++\), \ \[IndentingNewLine]\(tbl\_\(\(\[LeftDoubleBracket]\)\
\(j\)\(\[RightDoubleBracket]\)\) = {M\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\), 
              NumberForm[
                MidpointRule[a, b, 
                  M\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\)], {8, 6}]};\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[tbl, 
          TableHeadings \[Rule] {None, {"\<m sample points\>", \
"\<MidpointRule[a,b,m]\>"}}, 
          TableSpacing \[Rule] {2, 1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2.01}, {0, 2.01}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
        Axes \[Rule] True, PlotStyle \[Rule] Magenta];\)\ \)}], "Input",
  AnimationDisplayTime->0.371293],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Midpoint/Midpointaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Quadrature/Midpoint/\
Midpointaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Midpoint/Midpoint.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Midpoint/Midpoint.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Midpoint Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/MidpointRuleBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Midpoint Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/MidpointRuleBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 198, 5, 35, "Text"],
Cell[1977, 60, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3456, 112, 1336, 45, 161, "Text"],
Cell[4795, 159, 1451, 42, 78, "Text"],
Cell[6249, 203, 628, 22, 33, "Text"],
Cell[6880, 227, 162, 4, 35, "Text"],
Cell[7045, 233, 570, 14, 52, "Text"],
Cell[7618, 249, 2001, 65, 161, "Text"],
Cell[9622, 316, 184, 4, 35, "Text"],
Cell[9809, 322, 2554, 82, 305, "Text"],
Cell[12366, 406, 628, 22, 33, "Text"],
Cell[12997, 430, 730, 24, 33, "Text"],
Cell[13730, 456, 614, 21, 33, "Text"],
Cell[14347, 479, 1000, 37, 119, "Text"],
Cell[15350, 518, 143, 2, 33, "Text"],
Cell[15496, 522, 384, 7, 160, "Input"],
Cell[15883, 531, 55, 0, 33, "Text"],
Cell[15941, 533, 143, 2, 33, "Text"],
Cell[16087, 537, 546, 11, 166, "Input"],
Cell[16636, 550, 320, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[16981, 562, 101, 2, 33, "Text"],
Cell[17085, 566, 478, 7, 113, "Input"],
Cell[17566, 575, 73, 0, 33, "Text"],
Cell[17642, 577, 71, 1, 33, "Input"],
Cell[17716, 580, 122, 2, 63, "Input"],
Cell[17841, 584, 148, 3, 63, "Input"],
Cell[17992, 589, 168, 3, 63, "Input"],
Cell[18163, 594, 224, 4, 63, "Input"],
Cell[18390, 600, 357, 6, 63, "Input"]
}, Closed]],
Cell[18762, 609, 330, 9, 31, "Text"],

Cell[CellGroupData[{
Cell[19117, 622, 101, 2, 33, "Text"],
Cell[19221, 626, 60, 0, 33, "Text"],
Cell[19284, 628, 71, 1, 33, "Input"],
Cell[19358, 631, 124, 2, 50, "Input"],
Cell[19485, 635, 127, 2, 50, "Input"],
Cell[19615, 639, 127, 2, 50, "Input"],
Cell[19745, 643, 127, 2, 50, "Input"],
Cell[19875, 647, 127, 2, 50, "Input"]
}, Closed]],
Cell[20017, 652, 287, 8, 31, "Text"],

Cell[CellGroupData[{
Cell[20329, 664, 101, 2, 33, "Text"],
Cell[20433, 668, 110, 2, 42, "Input"],
Cell[20546, 672, 55, 1, 30, "Input"],
Cell[20604, 675, 75, 1, 30, "Input"]
}, Closed]],
Cell[20694, 679, 237, 7, 30, "Text"],

Cell[CellGroupData[{
Cell[20956, 690, 101, 2, 33, "Text"],
Cell[21060, 694, 64, 1, 30, "Input"],
Cell[21127, 697, 65, 1, 30, "Input"],
Cell[21195, 700, 65, 1, 30, "Input"],
Cell[21263, 703, 65, 1, 30, "Input"],
Cell[21331, 706, 65, 1, 30, "Input"]
}, Closed]],
Cell[21411, 710, 400, 14, 33, "Text"],

Cell[CellGroupData[{
Cell[21836, 728, 101, 2, 33, "Text"],
Cell[21940, 732, 62, 1, 42, "Input"],
Cell[22005, 735, 63, 1, 42, "Input"],
Cell[22071, 738, 63, 1, 42, "Input"],
Cell[22137, 741, 63, 1, 42, "Input"]
}, Closed]],
Cell[22215, 745, 821, 24, 31, "Text"],

Cell[CellGroupData[{
Cell[23061, 773, 101, 2, 33, "Text"],
Cell[23165, 777, 997, 24, 111, "Input"],
Cell[24165, 803, 73, 0, 33, "Text"],
Cell[24241, 805, 122, 2, 63, "Input"],
Cell[24366, 809, 148, 3, 63, "Input"],
Cell[24517, 814, 168, 3, 63, "Input"],
Cell[24688, 819, 224, 4, 63, "Input"],
Cell[24915, 825, 357, 6, 63, "Input"]
}, Closed]],
Cell[25287, 834, 831, 25, 31, "Text"],

Cell[CellGroupData[{
Cell[26143, 863, 101, 2, 33, "Text"],
Cell[26247, 867, 60, 0, 33, "Text"],
Cell[26310, 869, 530, 17, 31, "Input"],
Cell[26843, 888, 120, 2, 50, "Input"],
Cell[26966, 892, 123, 2, 50, "Input"],
Cell[27092, 896, 123, 2, 50, "Input"],
Cell[27218, 900, 123, 2, 50, "Input"],
Cell[27344, 904, 123, 2, 50, "Input"]
}, Closed]],
Cell[27482, 909, 789, 24, 31, "Text"],

Cell[CellGroupData[{
Cell[28296, 937, 101, 2, 33, "Text"],
Cell[28400, 941, 621, 18, 42, "Input"],
Cell[29024, 961, 49, 1, 30, "Input"],
Cell[29076, 964, 52, 1, 30, "Input"]
}, Closed]],
Cell[29143, 968, 238, 7, 30, "Text"],

Cell[CellGroupData[{
Cell[29406, 979, 101, 2, 33, "Text"],
Cell[29510, 983, 42, 1, 30, "Input"],
Cell[29555, 986, 43, 1, 30, "Input"],
Cell[29601, 989, 43, 1, 30, "Input"],
Cell[29647, 992, 43, 1, 30, "Input"],
Cell[29693, 995, 43, 1, 30, "Input"]
}, Closed]],
Cell[29751, 999, 401, 14, 33, "Text"],

Cell[CellGroupData[{
Cell[30177, 1017, 102, 2, 33, "Text"],
Cell[30282, 1021, 62, 1, 42, "Input"],
Cell[30347, 1024, 63, 1, 42, "Input"],
Cell[30413, 1027, 63, 1, 42, "Input"],
Cell[30479, 1030, 63, 1, 42, "Input"]
}, Closed]],
Cell[30557, 1034, 303, 10, 32, "Text"],
Cell[30863, 1046, 335, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[31223, 1061, 102, 2, 33, "Text"],
Cell[31328, 1065, 1413, 28, 231, "Input"],
Cell[32744, 1095, 767, 26, 33, "Text"]
}, Closed]],
Cell[33526, 1124, 730, 24, 30, "Text"],
Cell[34259, 1150, 158, 3, 35, "Text"],
Cell[34420, 1155, 557, 17, 33, "Text"],
Cell[34980, 1174, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

