(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    267374,       5678]*)
(*NotebookOutlinePosition[    268040,       5701]*)
(*  CellTagsIndexPosition[    267996,       5697]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Newton-Cotes Integration",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Introduction to Quadrature",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["We now approach the subject of numerical integration. The goal is \
to approximate the definite integral of  ",
    FontFamily->"Times-Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox["  over the interval  ",
    FontFamily->"Times-Roman"],
  StyleBox["[a,b]",
    FontFamily->"Courier New"],
  StyleBox["  by evaluating  ",
    FontFamily->"Times-Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox["  at a finite number\nof sample points.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Quadrature Formula)",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["Suppose that  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(a = \(\(x\_0 < x\_1 <  ... \) < x\_m = b\)\)]],
  StyleBox[".   A formula of the form \n\n(1)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(Q[f]\  = \ \[Sum]\+\(k = 0\)\%m\( w\_k\) f \((x\_k)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(\(w\_0\) f \((x\_0)\)\  + \ \(w\_1\) 
                f \((x\_1)\)\  + \(w\_2\) 
                f \((x\_2)\)\  +  ... \) + \ \(w\_m\) f \((x\_m)\)\)\)\)\)]],
  " \n",
  StyleBox["\n",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["with the property that\n\n(2)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_a\%b\ f \((x)\) \[DifferentialD]x\  = \ 
        Q[f]\  + \ E[f]\)]],
  StyleBox[" \n",
    FontFamily->"Times-Roman"],
  StyleBox["\n",
    FontFamily->"MTSYN"],
  StyleBox["is called a numerical integration or ",
    FontFamily->"Times-Roman"],
  StyleBox["quadrature formula",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  The term  ",
    FontFamily->"Times-Roman"],
  StyleBox["E[f]",
    FontFamily->"Courier New"],
  StyleBox["  is called the ",
    FontFamily->"Times-Roman"],
  StyleBox["truncation error",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" for integration.  The values ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \({x\_k}\_\(k = 0\)\%m\)]],
  StyleBox[" are called the ",
    FontFamily->"Times-Roman"],
  StyleBox["quadrature nodes",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \({w\_k}\_\(k = 0\)\%m\)]],
  " are called the ",
  StyleBox["weights",
    FontColor->RGBColor[0, 0, 1]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["\tDepending on the application, the nodes  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \({x\_k}\_\(k = 0\)\%m\)]],
  StyleBox["  are chosen in various ways.  For the Trapezoidal Rule, Simpson\
\[CloseCurlyQuote]s Rule, and Boole\[CloseCurlyQuote]s Rule, the nodes are \
chosen to be equally spaced.  For Gauss-Legendre quadrature, the nodes are \
chosen to be zeros of certain Legendre polynomials.  When the integration \
formula is used to develop a predictor formula for differential equations, \
all the nodes are chosen less than ",
    FontFamily->"Times-Roman"],
  StyleBox["b",
    FontFamily->"Courier New"],
  StyleBox[".  For all applications, it is necessary to know something about \
the accuracy of the numerical solution.  This leads us to the next \
definition. ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Degree of Precision)",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  The ",
    FontFamily->"Times-Roman"],
  StyleBox["degree of precision",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" of a quadrature formula is the positive integer  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  such that  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(E[P\_i] = 0\)]],
  "  ",
  StyleBox["for all polynomials  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(P\_i\) \((x)\)\)]],
  " ",
  StyleBox[" of degree  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(i \[LessEqual] n\)]],
  StyleBox[",  but for which  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(E[P\_\(i + 1\)] \[NotEqual] 0\)]],
  "  ",
  StyleBox["for some polynomial",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\(P\_\(i + 1\)\) \((x)\)\)]],
  "  ",
  StyleBox["of degree  ",
    FontFamily->"Times-Roman"],
  StyleBox["n+1",
    FontFamily->"Courier New"],
  StyleBox[".  That is \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_a\%b\ \(P\_i\) \((x)\) \[DifferentialD]x\  = \ 
        Q[P\_i]\)]],
  StyleBox["   when degree  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(i \[LessEqual] n\)]],
  StyleBox[",  \nand\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_a\%b\ \(P\_\(i + 
                  1\)\) \((x)\) \[DifferentialD]x\  \[NotEqual] \ 
        Q[P\_\(i + 1\)]\)]],
  StyleBox["   when degree  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(i = n + 1\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["\tThe form of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(E[P\_i]\)]],
  " ",
  StyleBox["can be anticipated by studying what happens when  ",
    FontFamily->"Times-Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox["  is a polynomial.  Consider the arbitrary polynomial \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(P\_i\) \((x)\)\  = \ \(\(a\_i\) x\^i + \(a\_\(i - 1\)\) 
                x\^\(i - 1\) +  ... \) + \(a\_2\) x\^2 + \(a\_1\) x + 
          a\_0\)]],
  StyleBox["\n\t\nof degree ",
    FontFamily->"Times-Roman"],
  StyleBox["i",
    FontFamily->"Courier New"],
  StyleBox[".  If  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(i \[LessEqual] n\)]],
  StyleBox[",  then  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(P\_i\%\((n + 1)\)\) \((x)\) \[Congruent] 0\)]],
  "  ",
  StyleBox["for all  ",
    FontFamily->"Times-Roman"],
  StyleBox["x",
    FontFamily->"Courier New"],
  StyleBox[",  and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(P\_\(n + 1\)\%\((n + 1)\)\) \((x)\) \[Congruent] \(\((n + 1)\)!\) 
          a\_\(n + 1\)\)]],
  "  ",
  StyleBox["for all  ",
    FontFamily->"Times-Roman"],
  StyleBox["x",
    FontFamily->"Courier New"],
  StyleBox[".  Thus it is not surprising that the general form for the \
truncation error term is\n\n(3)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(E \((f)\)\), " ", "=", " ", 
        RowBox[{"K", " ", 
          SuperscriptBox["f", 
            TagBox[\((n + 1)\),
              Derivative],
            MultilineFunction->None], \((c)\)}]}]]],
  ",",
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  StyleBox["\n\n",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["where  ",
    FontFamily->"Times-Roman"],
  StyleBox["K",
    FontFamily->"Courier New"],
  StyleBox["  is a suitably chosen constant and  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  is the degree of precision.  The proof of this general result \
can be found in advanced books on numerical integration.  The derivation of \
quadrature formulas is sometimes based on polynomial interpolation.  Recall \
that there exists a unique polynomial  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(P\_m\) \((x)\)\)]],
  "  ",
  StyleBox["of degree  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(\(\[LessEqual]\)\(m\)\)\)]],
  StyleBox[",  passing through the  ",
    FontFamily->"Times-Roman"],
  StyleBox["m+1",
    FontFamily->"Courier New"],
  StyleBox["  equally spaced points  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \({\((x\_k, f \((x\_k)\))\)}\_\(k = 0\)\%m\)]],
  StyleBox[".   When this polynomial is used to approximate  ",
    FontFamily->"Times-Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox["  over  ",
    FontFamily->"Times-Roman"],
  StyleBox["[a,b]",
    FontFamily->"Courier New"],
  StyleBox[",  and then the integral of  ",
    FontFamily->"Times-Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox[" is approximated by the integral of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(P\_m\) \((x)\)\)]],
  StyleBox[",  the resulting formula is called a ",
    FontFamily->"Times-Roman"],
  StyleBox["Newton-Cotes quadrature formula",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  When the sample points  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x\_0 = a\)]],
  "  ",
  StyleBox["and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x\_m = b\)]],
  "  ",
  StyleBox["are used, it is called a ",
    FontFamily->"Times-Roman"],
  StyleBox["closed",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" Newton-Cotes formula.  The next result gives the formulas when \
approximating polynomials of degree  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(m = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "4"}]]],
  StyleBox["  are used.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Closed Newton-Cotes Quadrature Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Newton-CotesFormulas.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[")",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x\_k\  = \ x\_0\  + \ k\ h\)]],
  "  ",
  StyleBox["are equally spaced nodes and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f\_k = f \((x\_k)\)\)]],
  StyleBox[".  The first four closed Newton-Cotes quadrature formulas:\n\n(4) \
",
    FontFamily->"Times-Roman"],
  ButtonBox["Trapezoidal Rule",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/TrapezoidalRule.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_\(x\_0\)\%\(x\_1\)\ 
          f \((x)\) \[DifferentialD]x\  \[TildeTilde] \ \(h\/2\) \((f \
\((x\_0)\)\  + \ f \((x\_1)\))\)\)]],
  StyleBox["  \n\n(5) ",
    FontFamily->"Times-Roman"],
  ButtonBox["Simpson\[CloseCurlyQuote]s Rule",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SimpsonsRule.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_\(x\_0\)\%\(x\_2\)\ 
          f \((x)\) \[DifferentialD]x\  \[TildeTilde] \ \(h\/3\) \((f \
\((x\_0)\)\  + \ 4  f \((x\_1)\)\  + \ f \((x\_2)\))\)\)]],
  "  ",
  StyleBox["\n\n(6) ",
    FontFamily->"Times-Roman"],
  ButtonBox["Simpson 3/8 Rule",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Simpsons38Rule.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_\(x\_0\)\%\(x\_3\)\ 
          f \((x)\) \[DifferentialD]x\  \[TildeTilde] \ \(\(3  
                h\)\/8\) \((f \((x\_0)\)\  + \ 3  f \((x\_1)\)\  + \ 
              3  f \((x\_2)\) + \ f \((x\_3)\))\)\)]],
  "  ",
  StyleBox["\n\n(7) ",
    FontFamily->"Times-Roman"],
  ButtonBox["Boole\[CloseCurlyQuote]s Rule",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BoolesRule.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_\(x\_0\)\%\(x\_4\)\ 
          f \((x)\) \[DifferentialD]x\  \[TildeTilde] \ \(\(2  h\)\/45\) \((7 
                 f \((x\_0)\) + 32  f \((x\_1)\) + 12  f \((x\_2)\) + 
              32  f \((x\_3)\) + 7  f \((x\_4)\))\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  StyleBox[ButtonBox["Newton-Cotes Quadrature",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/NewtonCotesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  StyleBox[ButtonBox["Newton-CotesQuadrature",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonCotesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary (Newton-Cotes Precision)",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times-Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox["  is sufficiently differentiable; then  ",
    FontFamily->"Times-Roman"],
  StyleBox["E[f]",
    FontFamily->"Courier New"],
  StyleBox["  for Newton-Cotes quadrature involves an appropriate higher \
derivative.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["(8) The trapezoidal rule has degree of precision  ",
    FontFamily->"Times-Roman"],
  StyleBox["n=1",
    FontFamily->"Courier New"],
  StyleBox[".  If  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \[Element] \(C\^2\)[a, b]\)]],
  StyleBox[", then \n\n\t",
    FontFamily->"Times-Roman"],
  "\t",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(x\_0\)\%\(x\_1\)\ 
          f \((x)\) \[DifferentialD]x\), " ", "=", " ", 
        RowBox[{\(\(h\/2\) \((f\_0\  + \ f\_1)\)\), " ", "-", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(1\/12\), 
                SuperscriptBox["f", 
                  TagBox[\((2)\),
                    Derivative],
                  MultilineFunction->None], \((c)\)}],
              SeriesData[ h, 0, {
                Times[ 
                  Rational[ 1, 24], 
                  Derivative[ 2][ f][ x]]}, 3, 4, 1]], \(h\^3\)}]}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(9) Simpson\[CloseCurlyQuote]s rule has degree of precision  ",
    FontFamily->"Times-Roman"],
  StyleBox["n=3",
    FontFamily->"Courier New"],
  StyleBox[".  If  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \[Element] \(C\^4\)[a, b]\)]],
  StyleBox[", then \n\n\t",
    FontFamily->"Times-Roman"],
  "\t",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(x\_0\)\%\(x\_2\)\ 
          f \((x)\) \[DifferentialD]x\), " ", "=", " ", 
        RowBox[{\(\(h\/3\) \((f\_0\  + \ 4  f\_1\  + \ f\_2)\)\), " ", "-", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(1\/90\), " ", 
                SuperscriptBox["f", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], \((c)\)}],
              SeriesData[ h, 0, {
                Times[ 
                  Rational[ 1, 24], 
                  Derivative[ 2][ f][ x]]}, 3, 4, 1]], \(h\^5\)}]}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(10) Simpson\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(3\/8\)]],
  StyleBox["rule has degree of precision  ",
    FontFamily->"Times-Roman"],
  StyleBox["n=3",
    FontFamily->"Courier New"],
  StyleBox[".  If  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \[Element] \(C\^4\)[a, b]\)]],
  StyleBox[", then \n\n\t",
    FontFamily->"Times-Roman"],
  "\t",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(x\_0\)\%\(x\_3\)\ 
          f \((x)\) \[DifferentialD]x\), " ", "=", " ", 
        RowBox[{\(\(\(3  h\)\/8\) \((f\_0\  + \ 3  f\_1\  + \ 3  f\_2 + \ 
                f\_3)\)\), " ", "-", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(3\/80\), " ", 
                SuperscriptBox["f", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], \((c)\)}],
              SeriesData[ h, 0, {
                Times[ 
                  Rational[ 1, 24], 
                  Derivative[ 2][ f][ x]]}, 3, 4, 1]], \(h\^5\)}]}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(11) Boole\[CloseCurlyQuote]s rule has degree of precision  ",
    FontFamily->"Times-Roman"],
  StyleBox["n=5",
    FontFamily->"Courier New"],
  StyleBox[".  If  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \[Element] \(C\^6\)[a, b]\)]],
  StyleBox[", then \n\n\t",
    FontFamily->"Times-Roman"],
  "\t",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(x\_0\)\%\(x\_4\)\ 
          f \((x)\) \[DifferentialD]x\), " ", "=", " ", 
        RowBox[{\(\(\(2  h\)\/45\) \((7  f\_0\  + \ 32  f\_1\  + \ 
                12  f\_2 + \ 32  f\_3 + 7  f\_4)\)\), " ", "-", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(8\/945\), " ", 
                SuperscriptBox["f", 
                  TagBox[\((6)\),
                    Derivative],
                  MultilineFunction->None], \((c)\)}],
              SeriesData[ h, 0, {
                Times[ 
                  Rational[ 1, 24], 
                  Derivative[ 2][ f][ x]]}, 3, 4, 1]], \(h\^7\)}]}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Trapezoidal Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/TrapezoidalRuleProof.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Trapezoidal Rule",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/TrapezoidalRuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Simpson's Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/SimpsonsRuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/SimpsonsRuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Simpson38RuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Simpson38RuleProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Boole's Rule",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/n2003/BooleRuleProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Boole's Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/BooleRuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Consider the function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\) = 1 + \[ExponentialE]\^\(-x\)\ sin \((4\ x)\)\)]],
  StyleBox[",  the equally spaced quadrature nodes  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x\_0 = 0.0\)]],
  ", ",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x\_1 = 0.5\)]],
  StyleBox[",  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x\_2 = 1.0\)]],
  StyleBox[",  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x\_3 = 1.5\)]],
  StyleBox[", and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x\_4 = 2.0\)]],
  StyleBox[",  and the corresponding function values  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f\_0 = 1.00000\)]],
  StyleBox[",  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f\_1 = 1.55152\)]],
  StyleBox[",  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f\_2 = 0.72159\)]],
  StyleBox[",  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f\_3 = 0.93765\)]],
  StyleBox[",  and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f\_4 = 1.13390\)]],
  StyleBox[".  Apply the various quadrature formulas (4) through (7). ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
CP3oool01`2c/k<000000000002c/k<0oooo0000003@d=000P1>CTh00`3@
d=00oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00D000000?oo
o`3oool000000=3@d00204i>CP030=3@d03oool0oooo02/0oooo00@0CTi>
0000000000000000<03oool004h0oooo00@0J6QX0?7al@3alO40J6QX0P3o
ool0101>CTh0oooo0?ooo`1>CTh_0?ooo`030000003oool0oooo02d0oooo
00D000000?ooo`3oool0oooo04i>CP020?ooo`0304i>CP3oool0oooo02/0
oooo00<0d=3@08f=S@3oool0<@3oool004h0oooo00@000000?ooo`3oool0
00001@3oool00`1>CTh0oooo0?ooo`0]0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0103oool00`1>CTh0oooo0?ooo`0]0?ooo`03
0:NWY`3oool0oooo02l0oooo001>0?ooo`040000003oool0oooo00000080
oooo0P1XJ6P00`1>CTh0d=3@0?ooo`0^0?ooo`030000003oool0oooo02d0
oooo00@000000?ooo`3oool0oooo0P1XJ6P00`1>CTh0d=3@0?ooo`0^0?oo
o`030>WYj@2=SHd0oooo02l0oooo001>0?ooo`0406QXJ03alO40jNWY07al
O080oooo00<0/k>c0<O7a`3oool0;`3oool00`2WYjL000000?ooo`0]0?oo
o`030:NWY`000000oooo0080oooo00<0/k>c0<O7a`3oool0;P3oool0101>
CTh0jNWY0>WYj@00000`0?ooo`00CP3oool0102m_Kd000000000002m_Kd2
0?ooo`040>WYj@0000000000000002l0oooo00<0J6QX0?ooo`3oool0;@3o
ool01@1XJ6P0oooo0?ooo`3oool0jNWY00<00000;@3oool0103@d=00CTi>
04i>CP3@d=0`0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3oool;0?ooo`0307alO03@d=00O7al01<0oooo000F0?ooocd0
000000<0003o000000000000[@0000070?ooo`030=3@d0000000d=3@01<0
oooo000P0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0
<@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool06@3oool00`3alO4000000?7al@0C0?ooo`00803o
ool00`0000000?oo003oo`0`003oo`030000o`3oool0oooo0340oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo01T0oooo00<0d=3@0000003@d=004`3oool00200oooo00<00000
003oo`00ool0<000ool00`000?l0oooo0?ooo`2d0?ooo`0307alO03@d=00
O7al01<0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0003o0?oo
o`3oool0bP3oool00200oooo00<00000003oo`00ool0<000ool00`000?l0
oooo0?ooo`3:0?ooo`00803oool00`0000000?oo003oo`0`003oo`030000
o`3oool0oooo0<X0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0
003o0?ooo`3oool0bP3oool00200oooo00<00000003oo`00ool0<000ool0
0`000?l0oooo0?ooo`3:0?ooo`00803oool00`0000000?oo003oo`0`003o
o`030000o`3oool0oooo0<X0oooo000P0?ooo`0300000000ool00?oo0300
0?oo00<0003o0?ooo`3oool0bP3oool00200oooo00<00000003oo`00ool0
<000ool00`000?l0oooo0?ooo`3:0?ooo`00803oool00`0000000?oo003o
o`0`003oo`030000o`3oool0oooo0<X0oooo000P0?ooo`0300000000ool0
0?oo03000?oo00<0003o0?ooo`3oool0bP3oool00200oooo00<00000003o
o`00ool0<000ool00`000?l0oooo0?ooo`3:0?ooo`00803oool00`000000
0?oo003oo`0`003oo`030000o`3oool0oooo0<X0oooo000P0?ooo`030000
0000ool00?oo03000?oo00<0003o0?ooo`3oool0bP3oool00200oooo00<0
0000003oo`00ool0<000ool00`000?l0oooo0?ooo`3:0?ooo`00803oool0
0`0000000?oo003oo`0`003oo`030000o`3oool0oooo0<X0oooo000P0?oo
o`0300000000ool00?oo03000?oo00<0003o0?ooo`3oool0bP3oool00200
oooo00<00000003oo`00ool0<000ool00`000?l0oooo0?ooo`3:0?ooo`00
803oool00`0000000?oo003oo`0`003oo`030000o`3oool0oooo0<X0oooo
000P0?ooo`0300000000ool00?oo03000?oo00<0003o0?ooo`3oool0bP3o
ool00200oooo00<00000003oo`00ool0<000ool00`000?l0oooo0?ooo`3:
0?ooo`00803oool00`0000000?oo003oo`0`003oo`030000o`3oool0oooo
0<X0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0003o0?ooo`3o
ool0bP3oool00200oooo00<00000003oo`00ool0<000ool00`000?l0oooo
0?ooo`3:0?ooo`00803oool00`0000000?oo003oo`0`003oo`030000o`3o
ool0oooo0<X0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0003o
0?ooo`3oool0bP3oool00200oooo00<00000003oo`00ool0<000ool00`00
0?l0oooo0?ooo`3:0?ooo`00803oool00`0000000?oo003oo`0`003oo`03
0000o`3oool0oooo0<X0oooo000P0?ooo`0300000000ool00?oo03000?oo
00<0003o0?ooo`3oool0bP3oool00200oooo00<00000003oo`00ool0<000
ool00`000?l0oooo0?ooo`3:0?ooo`00803oool00`0000000?oo003oo`0`
003oo`030000o`3oool0oooo0<X0oooo000P0?ooo`0300000000ool00?oo
03000?oo00<0003o0?ooo`3oool0bP3oool00200oooo00<00000003oo`00
ool0<000ool00`000?l0oooo0?ooo`3:0?ooo`00803oool00`0000000?oo
003oo`0`003oo`030000o`3oool0oooo0<X0oooo000P0?ooo`0300000000
ool00?oo03000?oo00<0003o0?ooo`3oool0bP3oool00200oooo00<00000
003oo`00ool0<000ool00`000?l0oooo0?ooo`3:0?ooo`00403oool01`2c
/k<000000000002c/k<0oooo0000003@d=000P1>CTh00`3@d=00oooo0?oo
o`040?ooo`0300000000ool00?oo03000?oo00<0003o0?ooo`3oool0bP3o
ool00100oooo00@0J6QX0?7al@3alO40J6QX0P3oool0101>CTh0oooo0?oo
o`1>CTh60?ooo`0300000000ool00?oo03000?oo00<0003o0?ooo`3oool0
bP3oool00100oooo00@000000?ooo`3oool000001@3oool00`1>CTh0oooo
0?ooo`040?ooo`0300000000ool00?oo03000?oo00<0003o0?ooo`3oool0
bP3oool00100oooo00@000000?ooo`3oool000000P3oool206QXJ00304i>
CP3@d=00oooo00D0oooo00<00000003oo`00ool0<000ool00`000?l0oooo
0?ooo`3:0?ooo`00403oool0101XJ6P0lO7a0>WYj@1lO7`20?ooo`030;>c
/`37alL0oooo00L0oooo00<00000003oo`00ool0<000ool00`000?l0oooo
0?ooo`3:0?ooo`00403oool0102m_Kd000000000002m_Kd20?ooo`040>WY
j@0000000000000000H0oooo00<00000003oo`00ool0<000ool00`000?l0
oooo0?ooo`3:0?ooo`00803oool00`0000000?oo003oo`0`003oo`030000
o`3oool0oooo0<X0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0
003o0?ooo`3oool0bP3oool00200oooo00<00000003oo`00ool0<000ool0
0`000?l0oooo0?ooo`3:0?ooo`00803oool00`0000000?oo003oo`0`003o
o`030000o`3oool0oooo0<X0oooo000P0?ooo`0300000000ool00?oo0300
0?oo00<0003o0?ooo`3oool0bP3oool00200oooo00<00000003oo`00ool0
<000ool00`000?l0oooo0?ooo`3:0?ooo`00803oool00`0000000?oo003o
o`0`003oo`030000o`3oool0oooo0<X0oooo000P0?ooo`0300000000ool0
0?oo03000?oo00<0003o0?ooo`3oool0bP3oool00200oooo00<00000003o
o`00ool0<000ool00`000?l0oooo0?ooo`3:0?ooo`00803oool00`000000
0?oo003oo`0`003oo`030000o`3oool0oooo0<X0oooo000P0?ooo`030000
0000ool00?oo03000?oo00<0003o0?ooo`3oool0bP3oool00200oooo00<0
0000003oo`00ool0<000ool00`000?l0oooo0?ooo`0h0?ooo`/0ObXZQ`3o
ool00200oooo00<00000003oo`00ool0<000ool00`000?l0oooo0?ooo`0_
0?ooo`<0ObXZ103oool207lZ:P/0oooo0`1o:RZ40?ooo`00803oool00`00
00000?oo003oo`0`003oo`030000o`3oool0oooo02h0oooo1@1o:RX00`3o
ool0ObXZ07lZ:P0@0?ooo`<0ObXZP@3oool00200oooo00<00000003oo`00
ool0<000ool00`000?l0oooo0?ooo`0^0?ooo`H0ObXZ5@3oool307lZ:Wh0
oooo000P0?ooo`0300000000ool00?oo03000?oo00<0003o0?ooo`3oool0
;P3oool507lZ:QT0oooo0P1o:RYl0?ooo`00803oool00`0000000?oo003o
o`0`003oo`030000o`3oool0oooo02h0oooo101o:RXL0?ooo`0307lZ:P3o
ool0oooo07T0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0003o
0?ooo`3oool0;@3oool00`1o:RX0oooo0?ooo`0O0?ooo`80ObXZN@3oool0
0200oooo00<00000003oo`00ool0<000ool00`000?l0oooo0?ooo`0[0?oo
o`80ObXZ903oool00`1o:RX0oooo0?ooo`1f0?ooo`00803oool00`000000
0?oo003oo`0`003oo`030000o`3oool0oooo02X0oooo00<0ObXZ0?ooo`3o
ool09@3oool207lZ:WH0oooo000P0?ooo`0300000000ool00?oo03000?oo
00<0003o0?ooo`3oool0:@3oool00`1o:RX0oooo0?ooo`0X0?ooo`0307lZ
:P3oool0oooo07<0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0
003o0?ooo`3oool0:03oool00`1o:RX0oooo0?ooo`0Z0?ooo`0307lZ:P3o
ool0oooo0780oooo000P0?ooo`0300000000ool00?oo03000?oo00<0003o
0?ooo`3oool09P3oool207lZ:Rh0oooo0P1o:RYb0?ooo`00803oool00`00
00000?oo003oo`0`003oo`030000o`3oool0oooo02D0oooo00<0ObXZ0?oo
o`3oool0<03oool00`1o:RX0oooo0?ooo`1_0?ooo`00803oool00`000000
0?oo003oo`0`003oo`030000o`3oool0oooo02@0oooo00<0ObXZ0?ooo`3o
ool0<P3oool00`1o:RX0oooo0?ooo`1^0?ooo`00803oool00`0000000?oo
003oo`0`003oo`030000o`3oool0oooo02<0oooo00<0ObXZ0?ooo`3oool0
=03oool207lZ:Vh0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0
003o0?ooo`3oool08`3oool00`1o:RX0oooo0?ooo`0f0?ooo`0307lZ:P3o
ool0oooo06/0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0003o
0?ooo`3oool08P3oool00`1o:RX0oooo0?ooo`0h0?ooo`80ObXZJ`3oool0
0200oooo00<00000003oo`00ool0<000ool00`000?l0oooo0?ooo`0Q0?oo
o`0307lZ:P3oool0oooo03/0oooo00<0ObXZ0?ooo`3oool0J03oool00200
oooo00<00000003oo`00ool0<000ool00`000?l0oooo0?ooo`0Q0?ooo`03
07lZ:P3oool0oooo03`0oooo0P1o:RYX0?ooo`00803oool00`0000000?oo
003oo`0`003oo`030000o`3oool0oooo0200oooo00<0ObXZ0?ooo`3oool0
?`3oool407lZ:V@0oooo000P0?ooo`0300000000ool00?oo03000?oo00<0
003o0?ooo`3oool07`3oool00`1o:RX0oooo0?ooo`100?ooo`D0ObXZH`3o
ool00200oooo00<00000003oo`00ool0<000ool00`000?l0oooo0?ooo`0O
0?ooo`0307lZ:P3oool0oooo0400oooo1@1o:RYS0?ooo`00803oool00`00
00000?oo003oo`0`003oo`030000o`3oool0oooo01h0oooo00<0ObXZ0?oo
o`3oool0@@3oool507lZ:V<0oooo000P0?ooo`0300000000ool00?oo0300
0?oo00<0003o0?ooo`3oool07@3oool00`1o:RX0oooo0?ooo`130?ooo`<0
ObXZ00<0oooo07lZ:P1o:RX0H@3oool001T0oooo00<000000?ooo`3oool0
0`3oool307lZ:S400?oo00<0003o0?ooo`3oool0703oool00`1o:RX0oooo
0?ooo`1:0?ooo`0307lZ:P3oool0oooo05h0oooo000I0?ooo`030000003o
ool0oooo0080oooo1@1o:RX`003oo`030000o`3oool0oooo01`0oooo00<0
ObXZ0?ooo`3oool0B`3oool00`1o:RX0oooo0?ooo`1M0?ooo`006@3oool0
0`000000oooo0?ooo`020?ooo`D0ObXZ<000ool00`000?l0oooo0?ooo`0K
0?ooo`0307lZ:P3oool0oooo04d0oooo0P1o:RYM0?ooo`006@3oool00`00
0000oooo0?ooo`020?ooo`D0ObXZ<000ool00`000?l0oooo0?ooo`0J0?oo
o`0307lZ:P3oool0oooo0500oooo00<0ObXZ0?ooo`3oool0FP3oool001P0
oooo00<0YjNW0000003oool0103oool307lZ:P030?ooo`000?l00?oo02h0
0?oo00<0003o0?ooo`3oool06@3oool00`1o:RX0oooo0?ooo`1B0?ooo`80
ObXZFP3oool001T0oooo00<0J6QX0?ooo`3oool0103oool01@000000ObXZ
0?ooo`3oool0003o02h00?oo00<0003o0?ooo`3oool06@3oool00`1o:RX0
oooo0?ooo`1D0?ooo`80ObXZF03oool00200oooo00<0000007lZ:P3oool0
0P3oool20000ob`00?oo00<0003o0?ooo`3oool0603oool00`1o:RX0oooo
0?ooo`1G0?ooo`80ObXZEP3oool00200oooo00<000000?ooo`1o:RX00`3o
ool00`00ool0003o003oo`0Z003oo`030000o`3oool0oooo01L0oooo00<0
ObXZ0?ooo`3oool0FP3oool207lZ:U@0oooo000P0?ooo`030000003oool0
ObXZ00@0oooo00<00?oo0000o`00ool0:@00ool00`000?l0oooo0?ooo`0G
0?ooo`0307lZ:P3oool0oooo05`0oooo00<0ObXZ0?ooo`3oool0D@3oool0
0200oooo00<000000?ooo`1o:RX01P3oool00`000?l00?oo003oo`0W003o
o`030000o`3oool0oooo01H0oooo00<0ObXZ0?ooo`3oool0GP3oool207lZ
:U40oooo000P0?ooo`040000003oool0oooo07lZ:PH0oooo00<0003o003o
o`00ool09P00ool00`000?l0oooo0?ooo`0E0?ooo`0307lZ:P3oool0oooo
0640oooo0`1o:RY>0?ooo`00803oool010000000oooo0?ooo`1o:RX70?oo
o`030000o`00ool00?oo02D00?oo00<0003o0?ooo`3oool05@3oool00`1o
:RX0oooo0?ooo`1T0?ooo`@0ObXZ5P3oool307lZ:S40oooo000P0?ooo`04
0000003oool0oooo07lZ:PP0oooo00<0003o003oo`00ool09000ool00`00
0?l0oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo06T0oooo101o:RXA0?oo
o`D0ObXZ<03oool00200oooo00D000000?ooo`3oool0oooo07lZ:P080?oo
o`030000o`00ool00?oo02<00?oo00<0003o0?ooo`3oool04`3oool00`1o
:RX0oooo0?ooo`1^0?oooaH0ObXZ<03oool00200oooo00D000000?ooo`3o
ool0oooo07lZ:P090?ooo`030000o`00ool00?oo02800?oo00<0003o0?oo
o`3oool04`3oool00`1o:RX0oooo0?ooo`1o0?ooo`D0ObXZ<03oool00200
oooo00D000000?ooo`3oool0oooo07lZ:P0:0?ooo`030000o`00ool00?oo
02400?oo00<0003o0?ooo`3oool04P3oool00`1o:RX0oooo0?ooo`210?oo
o`<0ObXZ<@3oool00200oooo00<000000?ooo`3oool00P3oool00`1o:RX0
oooo0?ooo`080?ooo`030000o`00ool00?oo02000?oo00<0003o0?ooo`3o
ool04P3oool00`1o:RX0oooo0?ooo`2e0?ooo`00803oool00`000000oooo
0?ooo`020?ooo`0307lZ:P3oool0oooo00T0oooo00<0003o003oo`00ool0
7`00ool00`000?l0oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo0;H0oooo
000P0?ooo`030000003oool0oooo0080oooo00<0ObXZ0?ooo`3oool02P3o
ool20000oal00?oo00<0003o0?ooo`3oool0403oool00`1o:RX0oooo0?oo
o`2g0?ooo`00803oool00`000000oooo0?ooo`030?ooo`0307lZ:P3oool0
oooo00/0oooo0P000?lM003oo`030000o`3oool0oooo0100oooo00<0ObXZ
0?ooo`3oool0]`3oool00200oooo00<000000?ooo`3oool00`3oool00`1o
:RX0oooo0?ooo`0<0?ooo`03003oo`000?l00?oo01/00?oo00<0003o0?oo
o`3oool03`3oool00`1o:RX0oooo0?ooo`2h0?ooo`00803oool00`000000
oooo0?ooo`030?ooo`0307lZ:P3oool0oooo00d0oooo00<00?oo0000o`00
ool06P00ool00`000?l0oooo0?ooo`0>0?ooo`0307lZ:P3oool0oooo0;T0
oooo000P0?ooo`030000003oool0oooo00@0oooo00<0ObXZ0?ooo`3oool0
3@3oool00`00ool0003o003oo`0I003oo`030000o`3oool0oooo00h0oooo
00<0ObXZ0?ooo`3oool0^@3oool00200oooo00<000000?ooo`3oool0103o
ool00`1o:RX0oooo0?ooo`0>0?ooo`03003oo`000?l00?oo01P00?oo00<0
003o0?ooo`3oool03@3oool00`1o:RX0oooo0?ooo`2j0?ooo`00803oool0
0`000000oooo0?ooo`040?ooo`0307lZ:P3oool0oooo0100oooo00<0003o
003oo`00ool05P00ool00`000?l0oooo0?ooo`0=0?ooo`0307lZ:P3oool0
oooo0;X0oooo000P0?ooo`030000003oool0oooo00D0oooo00<0ObXZ0?oo
o`3oool0403oool00`000?l00?oo003oo`0E003oo`030000o`3oool0oooo
00`0oooo00<0ObXZ0?ooo`3oool0^`3oool00200oooo00<000000?ooo`3o
ool01@3oool00`1o:RX0oooo0?ooo`0A0?ooo`030000o`00ool00?oo01@0
0?oo00<0003o0?ooo`3oool0303oool00`1o:RX0oooo0?ooo`2k0?ooo`00
803oool00`000000oooo0?ooo`050?ooo`0307lZ:P3oool0oooo0180oooo
00<0003o003oo`00ool04`00ool00`000?l0oooo0?ooo`0;0?ooo`0307lZ
:P3oool0oooo0;`0oooo000P0?ooo`030000003oool0oooo00H0oooo00<0
ObXZ0?ooo`3oool04P3oool00`000?l00?oo003oo`0B003oo`030000o`3o
ool0oooo00X0oooo00<0ObXZ0?ooo`3oool0_@3oool00200oooo00<00000
0?ooo`3oool01P3oool00`1o:RX0oooo0?ooo`0C0?ooo`030000o`00ool0
0?oo01400?oo00<0003o0?ooo`3oool02P3oool00`1o:RX0oooo0?ooo`2m
0?ooo`00803oool00`000000oooo0?ooo`070?ooo`0307lZ:P3oool0oooo
01<0oooo00<0003o003oo`00ool04000ool00`000?l0oooo0?ooo`090?oo
o`0307lZ:P3oool0oooo0;h0oooo000P0?ooo`030000003oool0oooo00L0
oooo00<0ObXZ0?ooo`3oool0503oool00`000?l00?oo003oo`0?003oo`03
0000o`3oool0oooo00T0oooo00<0ObXZ0?ooo`3oool0_P3oool00200oooo
00<000000?ooo`3oool0203oool00`1o:RX0oooo0?ooo`0D0?ooo`030000
o`00ool00?oo00h00?oo00<0003o0?ooo`3oool0203oool00`1o:RX0oooo
0?ooo`2o0?ooo`00803oool00`000000oooo0?ooo`080?ooo`0307lZ:P3o
ool0oooo01D0oooo0P000?l>003oo`030000o`3oool0oooo00P0oooo00<0
ObXZ0?ooo`3oool0_`3oool00200oooo00<000000?ooo`3oool02@3oool0
0`1o:RX0oooo0?ooo`0F0?ooo`80003o3000ool00`000?l0oooo0?ooo`07
0?ooo`0307lZ:P3oool0oooo0<00oooo000P0?ooo`030000003oool0oooo
00T0oooo00<0ObXZ0?ooo`3oool0603oool00`000?l00?oo003oo`09003o
o`030000o`3oool0oooo00H0oooo00<0ObXZ0?ooo`3oool0`@3oool00200
oooo00<000000?ooo`3oool02P3oool00`1o:RX0oooo0?ooo`0H0?ooo`03
0000o`00ool00?oo00P00?oo00<0003o0?ooo`3oool01@3oool00`1o:RX0
oooo0?ooo`320?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`0307lZ
:P3oool0oooo01T0oooo00<0003o003oo`00ool01`00ool00`000?l0oooo
0?ooo`050?ooo`0307lZ:P3oool0oooo0<80oooo000P0?ooo`030000003o
ool0oooo00/0oooo00<0ObXZ0?ooo`3oool06@3oool00`000?l00?oo003o
o`06003oo`030000o`3oool0oooo00@0oooo00<0ObXZ0?ooo`3oool0``3o
ool00200oooo00<000000?ooo`3oool02`3oool00`1o:RX0oooo0?ooo`0J
0?ooo`030000o`00ool00?oo00D00?oo00<0003o0?ooo`3oool00`3oool0
0`1o:RX0oooo0?ooo`340?ooo`00803oool00`000000oooo0?ooo`0<0?oo
o`0307lZ:P3oool0oooo01X0oooo00<0003o003oo`00ool01000ool00`00
0?l0oooo0?ooo`020?ooo`0307lZ:P3oool0oooo0<D0oooo000B0?ooo`05
0000003oool0oooo0000003@d=000P1>CTh00`3@d=00oooo0?ooo`040?oo
o`030000003oool0oooo00`0oooo00<0ObXZ0?ooo`3oool06`3oool00`00
0?l00?oo003oo`03003oo`030000o`3oool0oooo0080oooo00<0ObXZ0?oo
o`3oool0a@3oool00180oooo00D000000?ooo`3oool0oooo04i>CP020?oo
o`0304i>CP3oool0oooo00@0oooo0`00000=0?ooo`0307lZ:P3oool0oooo
01/0oooo00<0003o003oo`00ool00P00ool01@000?l0oooo0?ooo`3oool0
ObXZ0<P0oooo000B0?ooo`030000003oool0oooo00@0oooo00<0CTi>0?oo
o`3oool0103oool00`000000oooo0?ooo`0=0?ooo`0307lZ:P3oool0oooo
01`0oooo00D0003o003oo`00ool00?oo0000o`020?ooo`0307lZ:P3oool0
oooo0<L0oooo000B0?ooo`040000003oool0oooo0?ooo`80J6QX00<0CTi>
0=3@d03oool01@3oool00`000000oooo0?ooo`0>0?ooo`0307lZ:P3oool0
oooo01`0oooo00H0003o003oo`00ool0003o0?ooo`1o:R[:0?ooo`004@3o
ool00`2WYjL000000?ooo`020?ooo`030;>c/`37alL0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`1o:RX0oooo0?ooo`0M0?ooo`030000o`1o
:RX0003o0080ObXZbP3oool00180oooo00D0J6QX0?ooo`3oool0oooo0>WY
j@03000000H0oooo00<000000?ooo`3oool03`3oool00`1o:RX0oooo0?oo
o`0L0?ooo`80ObXZ00<0003o07lZ:P1o:RX0bP3oool00200oooo00<00000
0?ooo`3oool0403oool00`1o:RX0oooo0?ooo`0K0?ooo`D0ObXZbP3oool0
0200oooo00<000000?ooo`3oool04@3oool00`1o:RX0oooo0?ooo`0J0?oo
o`D0ObXZbP3oool00200oooo00<000000?ooo`3oool04P3oool00`1o:RX0
oooo0?ooo`0I0?ooo`@0ObXZb`3oool00200oooo00<000000?ooo`3oool0
4P3oool00`1o:RX0oooo0?ooo`0H0?ooo`0307lZ:P3oool0oooo0<d0oooo
000P0?ooo`030000003oool0oooo01<0oooo00<0ObXZ0?ooo`3oool05P3o
ool00`1o:RX0oooo0?ooo`3>0?ooo`00803oool00`000000oooo0?ooo`0D
0?ooo`0307lZ:P3oool0oooo01@0oooo00<0ObXZ0?ooo`3oool0c`3oool0
0200oooo00<000000?ooo`3oool05@3oool00`1o:RX0oooo0?ooo`0B0?oo
o`0307lZ:P3oool0oooo0=00oooo000P0?ooo`030000003oool0oooo01H0
oooo00<0ObXZ0?ooo`3oool0403oool00`1o:RX0oooo0?ooo`3A0?ooo`00
803oool00`000000oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo00h0oooo
00<0ObXZ0?ooo`3oool0dP3oool00200oooo00<000000?ooo`3oool0603o
ool00`1o:RX0oooo0?ooo`0;0?ooo`80ObXZe@3oool00200oooo00<00000
0?ooo`3oool06@3oool207lZ:PT0oooo0P1o:R[G0?ooo`00803oool00`00
0000oooo0?ooo`0K0?ooo`T0ObXZf@3oool00200oooo00<000000?ooo`3o
ool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool00200oooo00<0
00000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool0
0200oooo00<000000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3o
ool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool00200oooo00<0
00000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool001l0oooo00<0Vi^K0?ooo`3o
ool0oP3oool001l0oooo00<0CTi>0?ooo`3oool0oP3oool001h0oooo00<0
lO7a0000003YjNT0o`3oool001h0oooo00<0/k>c08f=S@2WYjL0o`3oool0
01h0oooo00<0CTi>0?7al@1XJ6P0o`3oool001d0oooo00D0d=3@0:NWY`3o
ool0YjNW0=3@d03n0?ooo`007@3oool01@1lO7`0jNWY0?ooo`3YjNT0O7al
0?h0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000
\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
CP3oool01`2c/k<000000000002c/k<0oooo0000003@d=000P1>CTh00`3@
d=00oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00D000000?oo
o`3oool000000=3@d00204i>CP030=3@d03oool0oooo02/0oooo00@0CTi>
0000000000000000<03oool004h0oooo00@0J6QX0?7al@3alO40J6QX0P3o
ool0101>CTh0oooo0?ooo`1>CTh_0?ooo`030000003oool0oooo02d0oooo
00D000000?ooo`3oool0oooo04i>CP020?ooo`0304i>CP3oool0oooo02/0
oooo00<0d=3@08f=S@3oool0<@3oool004h0oooo00@000000?ooo`3oool0
00001@3oool00`1>CTh0oooo0?ooo`0]0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0103oool00`1>CTh0oooo0?ooo`0]0?ooo`03
0:NWY`3oool0oooo02l0oooo001>0?ooo`040000003oool0oooo00000080
oooo0P1XJ6P00`1>CTh0d=3@0?ooo`0^0?ooo`030000003oool0oooo02d0
oooo00@000000?ooo`3oool0oooo0P1XJ6P00`1>CTh0d=3@0?ooo`0^0?oo
o`030>WYj@2=SHd0oooo02l0oooo001>0?ooo`0406QXJ03alO40jNWY07al
O080oooo00<0/k>c0<O7a`3oool0;`3oool00`2WYjL000000?ooo`0]0?oo
o`030:NWY`000000oooo0080oooo00<0/k>c0<O7a`3oool0;P3oool0101>
CTh0jNWY0>WYj@00000`0?ooo`00CP3oool0102m_Kd000000000002m_Kd2
0?ooo`040>WYj@0000000000000002l0oooo00<0J6QX0?ooo`3oool0;@3o
ool01@1XJ6P0oooo0?ooo`3oool0jNWY00<00000;@3oool0103@d=00CTi>
04i>CP3@d=0`0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3oool;0?ooo`0307alO03@d=00O7al01<0oooo000F0?ooog40
000000<006@0000000000000N@0000070?ooo`030=3@d0000000d=3@01<0
oooo000P0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
<@3oool00`00I000oooo0?ooo`0`0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool06@3oool00`3alO4000000?7al@0C0?ooo`00803o
ool00`000000O?`007cl001T07cl0003001T003oool0oooo0300oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0I0?ooo`030=3@d000
0000d=3@01<0oooo000P0?ooo`030000001lo000O?`006@0O?`000<006@0
0?ooo`3oool0P03oool00`1lO7`0d=3@07alO00C0?ooo`00803oool00`00
0000O?`007cl001T07cl0003001T003oool0oooo09H0oooo000P0?ooo`03
0000001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3oool00200oooo
00<0000007cl001lo000I01lo0000`00I000oooo0?ooo`2F0?ooo`00803o
ool00`000000O?`007cl001T07cl0003001T003oool0oooo09H0oooo000P
0?ooo`030000001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3oool0
0200oooo00<0000007cl001lo000I01lo0000`00I000oooo0?ooo`2F0?oo
o`00803oool00`000000O?`007cl001T07cl0003001T003oool0oooo09H0
oooo000P0?ooo`030000001lo000O?`006@0O?`000<006@00?ooo`3oool0
UP3oool00200oooo00<0000007cl001lo000I01lo0000`00I000oooo0?oo
o`2F0?ooo`00803oool00`000000O?`007cl001T07cl0003001T003oool0
oooo09H0oooo000P0?ooo`030000001lo000O?`006@0O?`000<006@00?oo
o`3oool0UP3oool00200oooo00<0000007cl001lo000I01lo0000`00I000
oooo0?ooo`2F0?ooo`00803oool00`000000O?`007cl001T07cl0003001T
003oool0oooo09H0oooo000P0?ooo`030000001lo000O?`006@0O?`000<0
06@00?ooo`3oool0UP3oool00200oooo00<0000007cl001lo000I01lo000
0`00I000oooo0?ooo`2F0?ooo`00803oool00`000000O?`007cl001T07cl
0003001T003oool0oooo09H0oooo000P0?ooo`030000001lo000O?`006@0
O?`000<006@00?ooo`3oool0UP3oool00200oooo00<0000007cl001lo000
I01lo0000`00I000oooo0?ooo`2F0?ooo`00803oool00`000000O?`007cl
001T07cl0003001T003oool0oooo09H0oooo000P0?ooo`030000001lo000
O?`006@0O?`000<006@00?ooo`3oool0UP3oool00200oooo00<0000007cl
001lo000I01lo0000`00I000oooo0?ooo`2F0?ooo`00803oool00`000000
O?`007cl001T07cl0003001T003oool0oooo09H0oooo000P0?ooo`030000
001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3oool00200oooo00<0
000007cl001lo000I01lo0000`00I000oooo0?ooo`2F0?ooo`00803oool0
0`000000O?`007cl001T07cl0003001T003oool0oooo09H0oooo000P0?oo
o`030000001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3oool00200
oooo00<0000007cl001lo000I01lo0000`00I000oooo0?ooo`2F0?ooo`00
803oool00`000000O?`007cl001T07cl0003001T003oool0oooo09H0oooo
000P0?ooo`030000001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3o
ool00200oooo00<0000007cl001lo000I01lo0000`00I000oooo0?ooo`2F
0?ooo`00803oool00`000000O?`007cl001T07cl0003001T003oool0oooo
09H0oooo000P0?ooo`030000001lo000O?`006@0O?`000<006@00?ooo`3o
ool0UP3oool00200oooo00<0000007cl001lo000I01lo0000`00I000oooo
0?ooo`2F0?ooo`00803oool00`000000O?`007cl001T07cl0003001T003o
ool0oooo09H0oooo000P0?ooo`030000001lo000O?`006@0O?`000<006@0
0?ooo`3oool0UP3oool00100oooo00L0/k>c000000000000/k>c0?ooo`00
0000d=3@0080CTi>00<0d=3@0?ooo`3oool0103oool00`000000O?`007cl
001T07cl0003001T003oool0oooo09H0oooo000@0?ooo`0406QXJ03alO40
lO7a06QXJ080oooo00@0CTi>0?ooo`3oool0CTi>1P3oool00`000000O?`0
07cl001T07cl0003001T003oool0oooo09H0oooo000@0?ooo`040000003o
ool0oooo000000D0oooo00<0CTi>0?ooo`3oool0103oool00`000000O?`0
07cl001T07cl0003001T003oool0oooo09H0oooo000@0?ooo`040000003o
ool0oooo00000080oooo0P1XJ6P00`1>CTh0d=3@0?ooo`050?ooo`030000
001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3oool00100oooo00@0
J6QX0?7al@3YjNT0O7al0P3oool00`2c/k<0alO70?ooo`070?ooo`030000
001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3oool00100oooo00@0
_Kfm000000000000_Kfm0P3oool0103YjNT000000000000000060?ooo`03
0000001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3oool00200oooo
00<0000007cl001lo000I01lo0000`00I000oooo0?ooo`2F0?ooo`00803o
ool00`000000O?`007cl001T07cl0003001T003oool0oooo09H0oooo000P
0?ooo`030000001lo000O?`006@0O?`000<006@00?ooo`3oool0UP3oool0
0200oooo00<0000007cl001lo000I01lo0000`00I000oooo0?ooo`2F0?oo
o`00803oool00`000000O?`007cl001T07cl0003001T003oool0oooo09H0
oooo000P0?ooo`030000001lo000O?`006@0O?`000<006@00?ooo`3oool0
UP3oool00200oooo00<0000007cl001lo000I01lo0000`00I000oooo0?oo
o`2F0?ooo`00803oool00`000000O?`007cl001T07cl0003001T003oool0
oooo09H0oooo000P0?ooo`030000001lo000O?`006@0O?`000<006@00?oo
o`3oool0UP3oool00200oooo00<0000007cl001lo000I01lo0000`00I000
oooo0?ooo`2F0?ooo`00803oool00`000000O?`007cl001T07cl0003001T
003oool0oooo09H0oooo000P0?ooo`030000001lo000O?`006@0O?`000<0
06@00?ooo`3oool0103oool;07lZ:XL0oooo000P0?ooo`030000001lo000
O?`00680O?`00P1o:RX00`00I000oooo0?ooo`020?ooo`80ObXZ2`3oool3
07lZ:X@0oooo000P0?ooo`030000001lo000O?`00640O?`00`1o:RX00`00
I000ObXZ0?ooo`0207lZ:Q00oooo0`1o:RZ10?ooo`00803oool00`000000
O?`007cl001Q07cl00<0ObXZ00<006@007lZ:P1o:RX05@3oool307lZ:Wh0
oooo000P0?ooo`030000001lo000O?`00640O?`01@1o:RXI0?ooo`80ObXZ
O03oool00200oooo00<0000007cl001lo000H@1lo00407lZ:Q`0oooo00<0
ObXZ0?ooo`3oool0N@3oool00200oooo00<0000007cl001lo000H01lo000
101o:RX0O?`007cl0000I00N0?ooo`80ObXZN@3oool00200oooo00<00000
07cl001lo000GP1lo00207lZ:P80O?`000<006@00?ooo`3oool07`3oool0
0`1o:RX0oooo0?ooo`1f0?ooo`00803oool00`000000O?`007cl001M07cl
000307lZ:P1lo000O?`00080O?`000<006@00?ooo`3oool0803oool207lZ
:WH0oooo000P0?ooo`030000001lo000O?`005`0O?`000<0ObXZ07cl001l
o0000`1lo0000`00I000oooo0?ooo`0R0?ooo`0307lZ:P3oool0oooo07<0
oooo000P0?ooo`030000001lo000O?`005/0O?`000<0ObXZ07cl001lo000
0`1lo0000`00I000oooo0?ooo`0T0?ooo`0307lZ:P3oool0oooo0780oooo
000P0?ooo`030000001lo000O?`005T0O?`00P1o:RX607cl0003001T003o
ool0oooo02D0oooo0P1o:RYb0?ooo`00803oool00`000000O?`007cl001H
07cl000307lZ:P1lo000O?`000D0O?`000<006@00?ooo`3oool0:03oool0
0`1o:RX0oooo0?ooo`1_0?ooo`00803oool00`000000O?`007cl001G07cl
000307lZ:P1lo000O?`000H0O?`000<006@00?ooo`3oool0:@3oool00`1o
:RX0oooo0?ooo`1^0?ooo`00803oool00`000000O?`007cl001F07cl0003
07lZ:P1lo000O?`000L0O?`000<006@00?ooo`3oool0:P3oool207lZ:Vh0
oooo000P0?ooo`030000001lo000O?`005H0O?`000<0ObXZ07cl001lo000
1P1lo0000`00I000oooo0?ooo`0]0?ooo`0307lZ:P3oool0oooo06/0oooo
000P0?ooo`030000001lo000O?`005D0O?`000<0ObXZ07cl001lo0001`1l
o0000`00I000oooo0?ooo`0^0?ooo`80ObXZJ`3oool00200oooo00<00000
07cl001lo000E01lo0000`1o:RX0O?`007cl000707cl0003001T003oool0
oooo0340oooo00<0ObXZ0?ooo`3oool0J03oool00200oooo00<0000007cl
001lo000E01lo0000`1o:RX0O?`007cl000707cl0003001T003oool0oooo
0380oooo0P1o:RYX0?ooo`00803oool00`000000O?`007cl001C07cl0003
07lZ:P1lo000O?`000L0O?`000<006@00?ooo`3oool0=@3oool407lZ:V@0
oooo000P0?ooo`030000001lo000O?`00580O?`000<0ObXZ07cl001lo000
201lo0000`00I000oooo0?ooo`0e0?ooo`D0ObXZH`3oool00200oooo00<0
000007cl001lo000DP1lo0000`1o:RX0O?`007cl000707cl0003001T003o
ool0oooo03H0oooo1@1o:RYS0?ooo`00803oool00`000000O?`007cl001A
07cl000307lZ:P1lo000O?`000P0O?`000<006@00?ooo`3oool0=P3oool5
07lZ:V<0oooo000P0?ooo`030000001lo000O?`00500O?`000<0ObXZ07cl
001lo000201lo0000`00I000oooo0?ooo`0h0?ooo`<0ObXZ00<0oooo07lZ
:P1o:RX0H@3oool001T0oooo00<000000?ooo`3oool00`3oool307lZ:U00
O?`000<0ObXZ07cl001lo0002@1lo0000`00I000oooo0?ooo`0n0?ooo`03
07lZ:P3oool0oooo05h0oooo000I0?ooo`030000003oool0oooo0080oooo
1@1o:RY?07cl000307lZ:P1lo000O?`000P0O?`000<006@00?ooo`3oool0
@03oool00`1o:RX0oooo0?ooo`1M0?ooo`006@3oool00`000000oooo0?oo
o`020?ooo`D0ObXZCP1lo0000`1o:RX0O?`007cl000807cl0003001T003o
ool0oooo0480oooo0P1o:RYM0?ooo`006@3oool00`000000oooo0?ooo`02
0?ooo`D0ObXZC@1lo0000`1o:RX0O?`007cl000907cl0003001T003oool0
oooo04@0oooo00<0ObXZ0?ooo`3oool0FP3oool001P0oooo00<0YjNW0000
003oool0103oool307lZ:Td0O?`000<0ObXZ07cl001lo0002@1lo0000`00
I000oooo0?ooo`160?ooo`80ObXZFP3oool001T0oooo00<0J6QX0?ooo`3o
ool0103oool00`000000ObXZ001T001<07cl000307lZ:P1lo000O?`000T0
O?`000<006@00?ooo`3oool0B03oool207lZ:UP0oooo000P0?ooo`030000
001o:RX006@004/0O?`000<0ObXZ07cl001lo0002@1lo0000`00I000oooo
0?ooo`1;0?ooo`80ObXZEP3oool00200oooo00@000000?ooo`1o:RX006@0
B@1lo0000`1o:RX0O?`007cl000907cl0003001T003oool0oooo04h0oooo
0P1o:RYD0?ooo`00803oool010000000oooo07lZ:P00I01907cl000307lZ
:P1lo000O?`000T0O?`000<006@00?ooo`3oool0D03oool00`1o:RX0oooo
0?ooo`1A0?ooo`00803oool01@000000oooo07lZ:P3oool006@004L0O?`0
00<0ObXZ07cl001lo0002@1lo0000`00I000oooo0?ooo`1B0?ooo`80ObXZ
D@3oool00200oooo00H000000?ooo`3oool0ObXZ0?ooo`00I01507cl0003
07lZ:P1lo000O?`000X0O?`000<006@00?ooo`3oool0E03oool307lZ:Th0
oooo000P0?ooo`060000003oool0oooo07lZ:P3oool006@0A@1lo0000`1o
:RX0O?`007cl000907cl0003001T003oool0oooo05P0oooo101o:RXF0?oo
o`<0ObXZ<@3oool00200oooo00@000000?ooo`3oool0ObXZ0P3oool00`00
I000O?`007cl001107cl000307lZ:P1lo000O?`000X0O?`000<006@00?oo
o`3oool0G03oool407lZ:Q40oooo1@1o:RX`0?ooo`00803oool01`000000
oooo0?ooo`3oool0ObXZ0?ooo`00I000@P1lo0000`1o:RX0O?`007cl000:
07cl0003001T003oool0oooo0640oooo5P1o:RX`0?ooo`00803oool01@00
0000oooo0?ooo`3oool0ObXZ0080oooo00<006@007cl001lo000?`1lo000
0`1o:RX0O?`007cl000:07cl0003001T003oool0oooo0780oooo1@1o:RX`
0?ooo`00803oool01@000000oooo0?ooo`3oool0ObXZ00<0oooo00<006@0
07cl001lo000?@1lo0000`1o:RX0O?`007cl000:07cl0003001T003oool0
oooo07@0oooo0`1o:RXa0?ooo`00803oool00`000000oooo0?ooo`020?oo
o`0407lZ:P3oool0oooo001T03l0O?`000<0ObXZ07cl001lo0002P1lo000
0`00I000oooo0?ooo`2X0?ooo`00803oool00`000000oooo0?ooo`020?oo
o`0507lZ:P3oool0oooo0?ooo`00I000?@1lo0000`1o:RX0O?`007cl000:
07cl0003001T003oool0oooo0:T0oooo000P0?ooo`030000003oool0oooo
0080oooo00H0ObXZ0?ooo`3oool0oooo07cl0000I00k07cl000307lZ:P1l
o000O?`000X0O?`000<006@00?ooo`3oool0ZP3oool00200oooo00<00000
0?ooo`3oool00`3oool01@1o:RX0oooo0?ooo`3oool006@003/0O?`000<0
ObXZ07cl001lo0002P1lo0000`00I000oooo0?ooo`2Z0?ooo`00803oool0
0`000000oooo0?ooo`030?ooo`0307lZ:P3oool0oooo0080oooo00<006@0
07cl001lo000=`1lo0000`1o:RX0O?`007cl000:07cl0003001T003oool0
oooo0:/0oooo000P0?ooo`030000003oool0oooo00<0oooo00<0ObXZ0?oo
o`3oool00P3oool00`00I000O?`007cl000f07cl000307lZ:P1lo000O?`0
00X0O?`000<006@00?ooo`3oool0[03oool00200oooo00<000000?ooo`3o
ool0103oool00`1o:RX0oooo0?ooo`020?ooo`03001T001lo000O?`003D0
O?`000<0ObXZ07cl001lo0002P1lo0000`00I000oooo0?ooo`2/0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`0307lZ:P3oool0oooo0080oooo
00<006@007cl001lo000=01lo0000`1o:RX0O?`007cl000:07cl0003001T
003oool0oooo0:d0oooo000P0?ooo`030000003oool0oooo00@0oooo00<0
ObXZ0?ooo`3oool00`3oool00`00I000O?`007cl000c07cl000307lZ:P1l
o000O?`000T0O?`000<006@00?ooo`3oool0[P3oool00200oooo00<00000
0?ooo`3oool01@3oool00`1o:RX0oooo0?ooo`030?ooo`03001T001lo000
O?`00340O?`000<0ObXZ07cl001lo0002@1lo0000`00I000oooo0?ooo`2_
0?ooo`00803oool00`000000oooo0?ooo`050?ooo`0307lZ:P3oool0oooo
00@0oooo00<006@007cl001lo000<01lo0000`1o:RX0O?`007cl000807cl
00030?ooo`00I000oooo0;00oooo000P0?ooo`030000003oool0oooo00D0
oooo00<0ObXZ0?ooo`3oool0103oool00`00I000O?`007cl000_07cl0003
07lZ:P1lo000O?`000T0O?`000<006@00?ooo`3oool0/03oool00200oooo
00<000000?ooo`3oool01P3oool00`1o:RX0oooo0?ooo`040?ooo`03001T
001lo000O?`002d0O?`000<0ObXZ07cl001lo0002@1lo0000`00I000oooo
0?ooo`2a0?ooo`00803oool00`000000oooo0?ooo`060?ooo`0307lZ:P3o
ool0oooo00D0oooo00<006@007cl001lo000;01lo0000`1o:RX0O?`007cl
000807cl0003001T003oool0oooo0;80oooo000P0?ooo`030000003oool0
oooo00L0oooo00<0ObXZ0?ooo`3oool01@3oool00`00I000O?`007cl000Z
07cl000307lZ:P1lo000O?`000T0O?`000<006@00?ooo`3oool0/P3oool0
0200oooo00<000000?ooo`3oool01`3oool00`1o:RX0oooo0?ooo`060?oo
o`03001T001lo000O?`002T0O?`000<0ObXZ07cl001lo000201lo0000`00
I000oooo0?ooo`2c0?ooo`00803oool00`000000oooo0?ooo`080?ooo`03
07lZ:P3oool0oooo00H0oooo00<006@007cl001lo0009`1lo0000`1o:RX0
O?`007cl000807cl0003001T003oool0oooo0;@0oooo000P0?ooo`030000
003oool0oooo00P0oooo00<0ObXZ0?ooo`3oool01`3oool00`00I000O?`0
07cl000V07cl000307lZ:P1lo000O?`000L0O?`000<006@00?ooo`3oool0
]@3oool00200oooo00<000000?ooo`3oool02@3oool00`1o:RX0oooo0?oo
o`070?ooo`03001T001lo000O?`002@0O?`000<0ObXZ07cl001lo0001`1l
o0000`00I000oooo0?ooo`2f0?ooo`00803oool00`000000oooo0?ooo`09
0?ooo`0307lZ:P3oool0oooo00P0oooo00<006@007cl001lo0008P1lo000
0`1o:RX0O?`007cl000707cl0003001T003oool0oooo0;L0oooo000P0?oo
o`030000003oool0oooo00X0oooo00<0ObXZ0?ooo`3oool0203oool00`00
I000O?`007cl000P07cl000307lZ:P1lo000O?`000L0O?`000<006@00?oo
o`3oool0^03oool00200oooo00<000000?ooo`3oool02P3oool00`1o:RX0
oooo0?ooo`090?ooo`03001T001lo000O?`001l0O?`000<0ObXZ07cl001l
o0001P1lo0000`00I000oooo0?ooo`2i0?ooo`00803oool00`000000oooo
0?ooo`0;0?ooo`0307lZ:P3oool0oooo00T0oooo00<006@007cl001lo000
7@1lo0000`1o:RX0O?`007cl000607cl0003001T003oool0oooo0;X0oooo
000P0?ooo`030000003oool0oooo00/0oooo00<0ObXZ0?ooo`3oool02P3o
ool00`00I000O?`007cl000K07cl000307lZ:P1lo000O?`000H0O?`000<0
06@00?ooo`3oool0^`3oool00200oooo00<000000?ooo`3oool0303oool0
0`1o:RX0oooo0?ooo`0:0?ooo`03001T001lo000O?`001T0O?`000<0ObXZ
07cl001lo0001P1lo0000`00I000oooo0?ooo`2l0?ooo`004P3oool01@00
0000oooo0?ooo`000000d=3@0080CTi>00<0d=3@0?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`0307lZ:P3oool0oooo00/0oooo00<006@0
07cl001lo000601lo0000`1o:RX0O?`007cl000407cl008006@0_`3oool0
0180oooo00D000000?ooo`3oool0oooo04i>CP020?ooo`0304i>CP3oool0
oooo00@0oooo0`00000=0?ooo`0307lZ:P3oool0oooo00/0oooo00<006@0
07cl001lo0005P1lo0000`1o:RX0O?`007cl000307cl008006@0`@3oool0
0180oooo00<000000?ooo`3oool0103oool00`1>CTh0oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo00<0ObXZ0?ooo`3oool0303oool3001T
01@0O?`000<0ObXZ07cl001lo0000`1lo0000`00I000oooo0?ooo`310?oo
o`004P3oool010000000oooo0?ooo`3oool206QXJ00304i>CP3@d=00oooo
00D0oooo00<000000?ooo`3oool03P3oool00`1o:RX0oooo0?ooo`0>0?oo
o`8006@04@1lo0000`1o:RX0O?`007cl000207cl008006@0a03oool00140
oooo00<0YjNW0000003oool00P3oool00`2c/k<0alO70?ooo`070?ooo`03
0000003oool0oooo00h0oooo00<0ObXZ0?ooo`3oool0403oool2001T00`0
O?`0101o:RX207cl008006@0aP3oool00180oooo00D0J6QX0?ooo`3oool0
oooo0>WYj@03000000H0oooo00<000000?ooo`3oool03`3oool00`1o:RX0
oooo0?ooo`0A0?ooo`@006@01`1lo00507lZ:P8006@0b03oool00200oooo
00<000000?ooo`3oool0403oool00`1o:RX0oooo0?ooo`0D0?ooo`L006@0
1@1o:R[:0?ooo`00803oool00`000000oooo0?ooo`0A0?ooo`0307lZ:P3o
ool0oooo01X0oooo1@1o:R[:0?ooo`00803oool00`000000oooo0?ooo`0B
0?ooo`0307lZ:P3oool0oooo01T0oooo101o:R[;0?ooo`00803oool00`00
0000oooo0?ooo`0B0?ooo`0307lZ:P3oool0oooo01P0oooo00<0ObXZ0?oo
o`3oool0c@3oool00200oooo00<000000?ooo`3oool04`3oool00`1o:RX0
oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo0<h0oooo000P0?ooo`030000
003oool0oooo01@0oooo00<0ObXZ0?ooo`3oool0503oool00`1o:RX0oooo
0?ooo`3?0?ooo`00803oool00`000000oooo0?ooo`0E0?ooo`0307lZ:P3o
ool0oooo0180oooo00<0ObXZ0?ooo`3oool0d03oool00200oooo00<00000
0?ooo`3oool05P3oool00`1o:RX0oooo0?ooo`0@0?ooo`0307lZ:P3oool0
oooo0=40oooo000P0?ooo`030000003oool0oooo01L0oooo00<0ObXZ0?oo
o`3oool03P3oool00`1o:RX0oooo0?ooo`3B0?ooo`00803oool00`000000
oooo0?ooo`0H0?ooo`0307lZ:P3oool0oooo00/0oooo0P1o:R[E0?ooo`00
803oool00`000000oooo0?ooo`0I0?ooo`80ObXZ2@3oool207lZ:]L0oooo
000P0?ooo`030000003oool0oooo01/0oooo2@1o:R[I0?ooo`00803oool0
0`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?oo
o`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo
0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool0
0`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?oo
o`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo
0?ooo`3m0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`007`3oool0
0`2KVi/0oooo0?ooo`3n0?ooo`007`3oool00`1>CTh0oooo0?ooo`3n0?oo
o`007P3oool00`3alO4000000>WYj@3o0?ooo`007P3oool00`2c/k<0SHf=
0:NWY`3o0?ooo`007P3oool00`1>CTh0lO7a06QXJ03o0?ooo`007@3oool0
1@3@d=00YjNW0?ooo`2WYjL0d=3@0?h0oooo000M0?ooo`0507alO03YjNT0
oooo0>WYj@1lO7`0oP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "\n\t\tT",
  StyleBox["rapezoidal Rule\t\t\t\t\t\tSimpson\[CloseCurlyQuote]s Rule",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
CP3oool01`2c/k<000000000002c/k<0oooo0000003@d=000P1>CTh00`3@
d=00oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00D000000?oo
o`3oool000000=3@d00204i>CP030=3@d03oool0oooo02/0oooo00@0CTi>
0000000000000000<03oool004h0oooo00@0J6QX0?7al@3alO40J6QX0P3o
ool0101>CTh0oooo0?ooo`1>CTh_0?ooo`030000003oool0oooo02d0oooo
00D000000?ooo`3oool0oooo04i>CP020?ooo`0304i>CP3oool0oooo02/0
oooo00<0d=3@08f=S@3oool0<@3oool004h0oooo00@000000?ooo`3oool0
00001@3oool00`1>CTh0oooo0?ooo`0]0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0103oool00`1>CTh0oooo0?ooo`0]0?ooo`03
0:NWY`3oool0oooo02l0oooo001>0?ooo`040000003oool0oooo00000080
oooo0P1XJ6P00`1>CTh0d=3@0?ooo`0^0?ooo`030000003oool0oooo02d0
oooo00@000000?ooo`3oool0oooo0P1XJ6P00`1>CTh0d=3@0?ooo`0^0?oo
o`030>WYj@2=SHd0oooo02l0oooo001>0?ooo`0406QXJ03alO40jNWY07al
O080oooo00<0/k>c0<O7a`3oool0;`3oool00`2WYjL000000?ooo`0]0?oo
o`030:NWY`000000oooo0080oooo00<0/k>c0<O7a`3oool0;P3oool0101>
CTh0jNWY0>WYj@00000`0?ooo`00CP3oool0102m_Kd000000000002m_Kd2
0?ooo`040>WYj@0000000000000002l0oooo00<0J6QX0?ooo`3oool0;@3o
ool01@1XJ6P0oooo0?ooo`3oool0jNWY00<00000;@3oool0103@d=00CTi>
04i>CP3@d=0`0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3oool;0?ooo`0307alO03@d=00O7al01<0oooo000F0?oooj@0
000000<0ogl0000000000000AP0000070?ooo`030=3@d0000000d=3@01<0
oooo000P0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0`0?ooo`030?mo003oool0oooo0340oooo
00<000000?ooo`3oool06@3oool00`3alO4000000?7al@0C0?ooo`00803o
ool00`000000ool00?oo002G0?oo00030?mo003oool0oooo0340oooo00<0
00000?ooo`3oool06@3oool00`3@d=0000000=3@d00C0?ooo`00803oool0
0`000000ool00?oo002G0?oo00030?mo003oool0oooo04d0oooo00<0O7al
0=3@d01lO7`04`3oool00200oooo00<000000?oo003oo`00U`3oo`000`3o
O`00oooo0?ooo`1S0?ooo`00803oool00`000000ool00?oo002G0?oo0003
0?mo003oool0oooo06<0oooo000P0?ooo`030000003oo`00ool009L0ool0
00<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003oo`00U`3o
o`000`3oO`00oooo0?ooo`1S0?ooo`00803oool00`000000ool00?oo002G
0?oo00030?mo003oool0oooo06<0oooo000P0?ooo`030000003oo`00ool0
09L0ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003o
o`00U`3oo`000`3oO`00oooo0?ooo`1S0?ooo`00803oool00`000000ool0
0?oo002G0?oo00030?mo003oool0oooo06<0oooo000P0?ooo`030000003o
o`00ool009L0ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<00000
0?oo003oo`00U`3oo`000`3oO`00oooo0?ooo`1S0?ooo`00803oool00`00
0000ool00?oo002G0?oo00030?mo003oool0oooo06<0oooo000P0?ooo`03
0000003oo`00ool009L0ool000<0ogl00?ooo`3oool0H`3oool00200oooo
00<000000?oo003oo`00U`3oo`000`3oO`00oooo0?ooo`1S0?ooo`00803o
ool00`000000ool00?oo002G0?oo00030?mo003oool0oooo06<0oooo000P
0?ooo`030000003oo`00ool009L0ool000<0ogl00?ooo`3oool0H`3oool0
0200oooo00<000000?oo003oo`00U`3oo`000`3oO`00oooo0?ooo`1S0?oo
o`00803oool00`000000ool00?oo002G0?oo00030?mo003oool0oooo06<0
oooo000P0?ooo`030000003oo`00ool009L0ool000<0ogl00?ooo`3oool0
H`3oool00200oooo00<000000?oo003oo`00U`3oo`000`3oO`00oooo0?oo
o`1S0?ooo`00803oool00`000000ool00?oo002G0?oo00030?mo003oool0
oooo06<0oooo000P0?ooo`030000003oo`00ool009L0ool000<0ogl00?oo
o`3oool0H`3oool00200oooo00<000000?oo003oo`00U`3oo`000`3oO`00
oooo0?ooo`1S0?ooo`00803oool00`000000ool00?oo002G0?oo00030?mo
003oool0oooo06<0oooo000P0?ooo`030000003oo`00ool009L0ool000<0
ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003oo`00U`3oo`00
0`3oO`00oooo0?ooo`1S0?ooo`00803oool00`000000ool00?oo002G0?oo
00030?mo003oool0oooo06<0oooo000P0?ooo`030000003oo`00ool009L0
ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003oo`00
U`3oo`000`3oO`00oooo0?ooo`1S0?ooo`00803oool00`000000ool00?oo
002G0?oo00030?mo003oool0oooo06<0oooo000P0?ooo`030000003oo`00
ool009L0ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo
003oo`00U`3oo`000`3oO`00oooo0?ooo`1S0?ooo`00803oool00`000000
ool00?oo002G0?oo00030?mo003oool0oooo06<0oooo000P0?ooo`030000
003oo`00ool009L0ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<0
00000?oo003oo`00U`3oo`000`3oO`00oooo0?ooo`1S0?ooo`00803oool0
0`000000ool00?oo002G0?oo00030?mo003oool0oooo06<0oooo000@0?oo
o`070;>c/`00000000000;>c/`3oool000000=3@d00204i>CP030=3@d03o
ool0oooo00@0oooo00<000000?oo003oo`00U`3oo`000`3oO`00oooo0?oo
o`1S0?ooo`00403oool0101XJ6P0lO7a0?7al@1XJ6P20?ooo`0404i>CP3o
ool0oooo04i>CPH0oooo00<000000?oo003oo`00U`3oo`000`3oO`00oooo
0?ooo`1S0?ooo`00403oool010000000oooo0?ooo`0000050?ooo`0304i>
CP3oool0oooo00@0oooo00<000000?oo003oo`00U`3oo`000`3oO`00oooo
0?ooo`1S0?ooo`00403oool010000000oooo0?ooo`0000020?ooo`80J6QX
00<0CTi>0=3@d03oool01@3oool00`000000ool00?oo002G0?oo00030?mo
003oool0oooo06<0oooo000@0?ooo`0406QXJ03alO40jNWY07alO080oooo
00<0/k>c0<O7a`3oool01`3oool00`000000ool00?oo002G0?oo00030?mo
003oool0oooo06<0oooo000@0?ooo`040;fm_@00000000000;fm_@80oooo
00@0jNWY00000000000000001P3oool00`000000ool00?oo002G0?oo0003
0?mo003oool0oooo06<0oooo000P0?ooo`030000003oo`00ool007L0ool0
2@3oO`0G0?oo00030?mo003oool0oooo06<0oooo000P0?ooo`030000003o
o`00ool007@0ool00`3oO`090?ooo`80ogl05@3oo`000`3oO`00oooo0?oo
o`1S0?ooo`00803oool00`000000ool00?oo001b0?oo0080ogl03P3oool2
0?mo01<0ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo
003oo`00L@3oo`000`3oO`00oooo0?ooo`0@0?ooo`030?mo003oo`00ool0
0100ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003o
o`00K`3oo`020?mo01@0oooo0P3oO`0@0?oo00030?mo003oool0oooo06<0
oooo000P0?ooo`030000003oo`00ool006h0ool000<0ogl00?ooo`3oool0
5P3oool00`3oO`00ool00?oo000=0?oo00030?mo003oool0oooo06<0oooo
000P0?ooo`030000003oo`00ool006d0ool000<0ogl00?ooo`3oool0603o
ool00`3oO`00ool00?oo000<0?oo00030?mo003oool0oooo06<0oooo000P
0?ooo`030000003oo`00ool006/0ool00P3oO`0L0?ooo`030?mo003oo`00
ool000/0ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo
003oo`00JP3oo`000`3oO`00oooo0?ooo`0M0?ooo`030?mo003oo`00ool0
00X0ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003o
o`00J@3oo`000`3oO`00oooo0?ooo`0O0?ooo`030?mo003oo`00ool000T0
ool000<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003oo`00
J03oo`000`3oO`00oooo0?ooo`0P0?ooo`030?mo003oo`00ool000T0ool0
00<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003oo`00I`3o
o`00103oO`00oooo0?ooo`3oool;07lZ:QH0oooo00<0ogl00?oo003oo`00
203oo`000`3oO`00oooo0?ooo`1S0?ooo`00803oool00`000000ool00?oo
001R0?oo00<0ObXZ00@0ool00?mo003oool0oooo0P1o:RX;0?ooo`<0ObXZ
503oool00`3oO`00ool00?oo00070?oo00030?mo003oool0oooo06<0oooo
000P0?ooo`030000003oo`00ool00640ool01@1o:RX00`3oool0ObXZ07lZ
:P0@0?ooo`<0ObXZ4@3oool00`3oO`00ool00?oo00070?oo00030?mo003o
ool0oooo06<0oooo000P0?ooo`030000003oo`00ool00640ool01P1o:RXE
0?ooo`<0ObXZ3`3oool00`3oO`00ool00?oo00060?oo00030?mo003oool0
oooo06<0oooo000P0?ooo`030000003oo`00ool00640ool01@1o:RXI0?oo
o`80ObXZ3P3oool00`3oO`00ool00?oo00050?oo00030?mo003oool0oooo
06<0oooo000P0?ooo`030000003oo`00ool00640ool0101o:RXL0?ooo`03
07lZ:P3oool0oooo00`0oooo00<0ogl00?oo003oo`00103oo`000`3oO`00
oooo0?ooo`1S0?ooo`00803oool00`000000ool00?oo001P0?oo000307lZ
:P3oO`00oooo01l0oooo0P1o:RX<0?ooo`030?mo003oo`00ool000@0ool0
00<0ogl00?ooo`3oool0H`3oool00200oooo00<000000?oo003oo`00GP3o
o`0207lZ:P030?oo003oO`00oooo0240oooo00<0ObXZ0?ooo`3oool02P3o
ool00`3oO`00ool00?oo00030?oo00030?mo003oool0oooo06<0oooo000P
0?ooo`030000003oo`00ool005d0ool000@0ObXZ0?oo003oo`00ogl0903o
ool207lZ:PX0oooo00<0ogl00?oo003oo`000`3oo`000`3oO`00oooo0?oo
o`1S0?ooo`00803oool00`000000ool00?oo001L0?oo000407lZ:P3oo`00
ool00?mo02L0oooo00<0ObXZ0?ooo`3oool0203oool00`3oO`00ool00?oo
00020?oo00030?mo003oool0oooo06<0oooo000P0?ooo`030000003oo`00
ool005/0ool000@0ObXZ0?oo003oo`00ogl0:@3oool00`1o:RX0oooo0?oo
o`070?ooo`030?mo003oo`00ool00080ool000<0ogl00?ooo`3oool0H`3o
ool00200oooo00<000000?oo003oo`00F@3oo`0207lZ:P80ool000<0ogl0
0?ooo`3oool0:@3oool207lZ:PP0oooo00D0ogl00?oo003oo`00ool00?mo
001U0?ooo`00803oool00`000000ool00?oo001H0?oo000607lZ:P3oo`00
ool00?oo003oO`00ool0;@3oool00`1o:RX0oooo0?ooo`050?ooo`050?mo
003oo`00ool00?oo003oO`00I@3oool00200oooo00<000000?oo003oo`00
E`3oo`000`1o:RX0ool00?oo00020?oo00030?mo003oool0oooo02d0oooo
00<0ObXZ0?ooo`3oool01@3oool0103oO`00ool00?oo003oO`1U0?ooo`00
803oool00`000000ool00?oo001F0?oo000307lZ:P3oo`00ool00080ool0
00<0ogl00?ooo`3oool0;`3oool207lZ:PD0oooo00@0ogl00?oo003oo`00
ogl0I@3oool00200oooo00<000000?oo003oo`00EP3oo`001@1o:RX0ool0
0?oo003oo`00ogl003@0oooo00<0ObXZ0?ooo`3oool00`3oool00`3oO`00
ool00?mo001U0?ooo`00803oool00`000000ool00?oo001E0?oo000507lZ
:P3oo`00ool00?oo003oO`00=P3oool207lZ:P<0oooo00<0ogl00?oo003o
O`00I@3oool00200oooo00<000000?oo003oo`00E03oo`000`1o:RX0ool0
0?oo00020?oo00030?mo003oool0oooo03H0oooo00@0ObXZ0?ooo`3oool0
oooo0P3oO`1U0?ooo`00803oool00`000000ool00?oo001D0?oo000507lZ
:P3oo`00ool00?oo003oO`00>P3oool207lZ:P030?ooo`3oO`00ogl006D0
oooo000P0?ooo`030000003oo`00ool005<0ool000D0ObXZ0?oo003oo`00
ool00?mo000m0?ooo`80ObXZ00<0ogl007lZ:P3oool0H`3oool00200oooo
00<000000?oo003oo`00DP3oo`001@1o:RX0ool00?oo003oo`00ogl003h0
oooo1@1o:RYS0?ooo`00803oool00`000000ool00?oo001B0?oo000507lZ
:P3oo`00ool00?oo003oO`00?P3oool207lZ:P030?mo001o:RX0ObXZ06<0
oooo000P0?ooo`030000003oo`00ool00540ool000D0ObXZ0?oo003oo`00
ool00?mo000o0?ooo`D0ObXZH`3oool00200oooo00<000000?oo003oo`00
D03oo`001@1o:RX0ool00?oo003oo`00ogl00440oooo0`1o:RX00`3oool0
ObXZ07lZ:P1Q0?ooo`006@3oool00`000000oooo0?ooo`030?ooo`<0ObXZ
D03oo`000`1o:RX0ool00?oo00020?oo00030?mo003oool0oooo04D0oooo
00<0ObXZ0?ooo`3oool0GP3oool001T0oooo00<000000?ooo`3oool00P3o
ool507lZ:Tl0ool000D0ObXZ0?oo003oo`00ool00?mo00190?ooo`0307lZ
:P3oool0oooo05d0oooo000I0?ooo`030000003oool0oooo0080oooo1@1o
:RY>0?oo000507lZ:P3oo`00ool00?oo003oO`00B`3oool207lZ:Ud0oooo
000I0?ooo`030000003oool0oooo0080oooo1@1o:RY=0?oo000307lZ:P3o
o`00ool00080ool000<0ogl00?ooo`3oool0B`3oool00`1o:RX0oooo0?oo
o`1J0?ooo`00603oool00`2WYjL000000?ooo`040?ooo`<0ObXZC@3oo`00
0`1o:RX0ool00?oo00020?oo00030?mo003oool0oooo04d0oooo0P1o:RYJ
0?ooo`006@3oool00`1XJ6P0oooo0?ooo`040?ooo`030000001o:RX0ool0
04`0ool000D0ObXZ0?oo003oo`00ool00?mo001B0?ooo`80ObXZF03oool0
0200oooo00<0000007lZ:P3oo`00B`3oo`000`1o:RX0ool00?oo00020?oo
00030?mo003oool0oooo0580oooo0P1o:RYF0?ooo`00803oool00`000000
oooo07lZ:P1:0?oo000307lZ:P3oo`00ool00080ool000<0ogl00?ooo`3o
ool0E@3oool207lZ:U@0oooo000P0?ooo`030000003oool0ObXZ04X0ool0
00<0ObXZ0?oo003oo`000P3oo`000`3oO`00oooo0?ooo`1G0?ooo`0307lZ
:P3oool0oooo0540oooo000P0?ooo`030000003oool0ObXZ04T0ool000<0
ObXZ0?oo003oo`000P3oo`000`3oO`00oooo0?ooo`1I0?ooo`80ObXZD@3o
ool00200oooo00@000000?ooo`3oool0ObXZA`3oo`000`1o:RX0ool00?oo
00020?oo00030?mo003oool0oooo05`0oooo0`1o:RY>0?ooo`00803oool0
10000000oooo0?ooo`1o:RY70?oo000307lZ:P3oo`00ool00080ool000<0
ogl00?ooo`3oool0G`3oool407lZ:QH0oooo0`1o:RXa0?ooo`00803oool0
10000000oooo0?ooo`1o:RY60?oo000307lZ:P3oo`00ool00080ool000<0
ogl00?ooo`3oool0I03oool407lZ:Q40oooo1@1o:RX`0?ooo`00803oool0
1@000000oooo0?ooo`3oool0ObXZ04@0ool000<0ObXZ0?oo003oo`000P3o
o`000`3oool0ogl00?ooo`1Y0?oooaH0ObXZ<03oool00200oooo00D00000
0?ooo`3oool0oooo07lZ:P140?oo000607lZ:P3oo`00ool00?oo003oool0
ogl0O03oool507lZ:S00oooo000P0?ooo`050000003oool0oooo0?ooo`1o
:RX0@`3oo`000`1o:RX0ool00?oo00020?oo00030?mo003oool0oooo07`0
oooo0`1o:RXa0?ooo`00803oool00`000000oooo0?ooo`020?ooo`0307lZ
:P3oo`00ool00400ool000H0ObXZ0?oo003oo`00ool00?ooo`3oO`2b0?oo
o`00803oool00`000000oooo0?ooo`020?ooo`0307lZ:P3oo`00ool003l0
ool000H0ObXZ0?oo003oo`00ool00?ooo`3oO`2c0?ooo`00803oool00`00
0000oooo0?ooo`020?ooo`0307lZ:P3oo`00ool003h0ool000<0ObXZ0?oo
003oo`000P3oo`000`3oO`00oooo0?ooo`2b0?ooo`00803oool00`000000
oooo0?ooo`030?ooo`0307lZ:P3oo`00ool003d0ool000D0ObXZ0?oo003o
o`00ool00?mo002e0?ooo`00803oool00`000000oooo0?ooo`030?ooo`03
07lZ:P3oo`00ool003`0ool000H0ObXZ0?oo003oo`00ool00?ooo`3oO`2e
0?ooo`00803oool00`000000oooo0?ooo`030?ooo`0307lZ:P3oO`00ool0
03/0ool000<0ObXZ0?oo003oo`000P3oo`000`3oO`00oooo0?ooo`2d0?oo
o`00803oool00`000000oooo0?ooo`040?ooo`0307lZ:P3oo`00ool003X0
ool000D0ObXZ0?oo003oo`00ool00?mo002g0?ooo`00803oool00`000000
oooo0?ooo`040?ooo`0307lZ:P3oO`00ool003T0ool000H0ObXZ0?oo003o
o`00ool00?ooo`3oO`2g0?ooo`00803oool00`000000oooo0?ooo`040?oo
o`0307lZ:P3oO`00ool003T0ool000D0ObXZ0?oo003oo`00ool00?mo002h
0?ooo`00803oool00`000000oooo0?ooo`050?ooo`0307lZ:P3oO`00ool0
03L0ool000D0ObXZ0?oo003oo`00ool00?mo002i0?ooo`00803oool00`00
0000oooo0?ooo`050?ooo`0307lZ:P3oO`00ool003L0ool000@0ObXZ0?oo
003oo`00ogl0^P3oool00200oooo00<000000?ooo`3oool01@3oool00`1o
:RX0oooo0?mo000f0?oo000407lZ:P3oo`00ool00?mo0;/0oooo000P0?oo
o`030000003oool0oooo00H0oooo00<0ObXZ0?mo003oo`00=03oo`00101o
:RX0ool00?oo003oO`2l0?ooo`00803oool00`000000oooo0?ooo`060?oo
o`0307lZ:P3oool0ogl003@0ool000@0ObXZ0?oo003oo`00ogl0_03oool0
0200oooo00<000000?ooo`3oool01`3oool00`1o:RX0ogl00?oo000b0?oo
000407lZ:P3oo`00ool00?mo0;d0oooo000P0?ooo`030000003oool0oooo
00L0oooo00<0ObXZ0?mo003oo`00<P3oo`000`1o:RX0ool00?mo002n0?oo
o`00803oool00`000000oooo0?ooo`080?ooo`0307lZ:P3oO`00ool00300
ool000<0ObXZ0?oo003oO`00_`3oool00200oooo00<000000?ooo`3oool0
203oool00`1o:RX0ogl00?oo000`0?oo000307lZ:P3oO`00oooo0;l0oooo
000P0?ooo`030000003oool0oooo00T0oooo00<0ObXZ0?mo003oo`00;P3o
o`000`1o:RX0ogl00?ooo`300?ooo`00803oool00`000000oooo0?ooo`09
0?ooo`0307lZ:P3oO`00ool002d0ool000<0ObXZ0?oo003oO`00`@3oool0
0200oooo00<000000?ooo`3oool02P3oool00`1o:RX0ogl00?oo000[0?oo
000307lZ:P3oo`00ogl00<80oooo000P0?ooo`030000003oool0oooo00X0
oooo00<0ObXZ0?ooo`3oO`00:`3oo`000`1o:RX0ogl00?ooo`320?ooo`00
803oool00`000000oooo0?ooo`0;0?ooo`0307lZ:P3oO`00ool002T0ool0
00<0ObXZ0?mo003oool0``3oool00200oooo00<000000?ooo`3oool02`3o
ool00`1o:RX0oooo0?mo000X0?oo000307lZ:P3oo`00ogl00<@0oooo000P
0?ooo`030000003oool0oooo00`0oooo00<0ObXZ0?ooo`3oO`009P3oo`00
0`1o:RX0ool00?mo00350?ooo`004P3oool01@000000oooo0?ooo`000000
d=3@0080CTi>00<0d=3@0?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`0407lZ:P3oool0oooo0?mo02D0ool000<0ObXZ0?mo003oool0a@3o
ool00180oooo00D000000?ooo`3oool0oooo04i>CP020?ooo`0304i>CP3o
ool0oooo00@0oooo0`00000=0?ooo`0307lZ:P3oool0ogl002@0ool000<0
ObXZ0?mo003oool0aP3oool00180oooo00<000000?ooo`3oool0103oool0
0`1>CTh0oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00@0ObXZ
0?ooo`3oool0ogl08P3oo`000`1o:RX0ogl00?ooo`370?ooo`004P3oool0
10000000oooo0?ooo`3oool206QXJ00304i>CP3@d=00oooo00D0oooo00<0
00000?ooo`3oool03P3oool0101o:RX0oooo0?ooo`3oO`0P0?oo000307lZ
:P3oO`00oooo0<P0oooo000A0?ooo`030:NWY`000000oooo0080oooo00<0
/k>c0<O7a`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`0507lZ:P3o
ool0oooo0?oo003oO`00703oo`0407lZ:/X0oooo000B0?ooo`0506QXJ03o
ool0oooo0?ooo`3YjNT00`0000060?ooo`030000003oool0oooo00l0oooo
00@0ObXZ0?ooo`3oool0ogl06`3oo`0507lZ:/X0oooo000P0?ooo`030000
003oool0oooo0100oooo00@0ObXZ0?ooo`3oool0ogl06P3oo`0507lZ:/X0
oooo000P0?ooo`030000003oool0oooo0140oooo00@0ObXZ0?ooo`3oool0
ogl06@3oo`0507lZ:/X0oooo000P0?ooo`030000003oool0oooo0180oooo
00@0ObXZ0?ooo`3oool0ogl05`3oo`000`3oO`00ObXZ07lZ:P0207lZ://0
oooo000P0?ooo`030000003oool0oooo0180oooo00D0ObXZ0?ooo`3oool0
oooo0?mo000D0?oo0080ogl000<0ObXZ0?ooo`3oool0c@3oool00200oooo
00<000000?ooo`3oool04`3oool01@1o:RX0oooo0?ooo`3oool0ogl00140
ool00P3oO`000`3oool0ObXZ0?ooo`3?0?ooo`00803oool00`000000oooo
0?ooo`0D0?ooo`0407lZ:P3oool0oooo0?ooo`80ogl03@3oo`020?mo0080
oooo00<0ObXZ0?ooo`3oool0c`3oool00200oooo00<000000?ooo`3oool0
5@3oool00`1o:RX0oooo0?ooo`020?ooo`@0ogl01P3oo`030?mo00<0oooo
00<0ObXZ0?ooo`3oool0d03oool00200oooo00<000000?ooo`3oool05P3o
ool00`1o:RX0oooo0?ooo`050?ooo`H0ogl01@3oool00`1o:RX0oooo0?oo
o`3A0?ooo`00803oool00`000000oooo0?ooo`0G0?ooo`0307lZ:P3oool0
oooo00h0oooo00<0ObXZ0?ooo`3oool0dP3oool00200oooo00<000000?oo
o`3oool0603oool00`1o:RX0oooo0?ooo`0;0?ooo`80ObXZe@3oool00200
oooo00<000000?ooo`3oool06@3oool207lZ:PT0oooo0P1o:R[G0?ooo`00
803oool00`000000oooo0?ooo`0K0?ooo`T0ObXZf@3oool00200oooo00<0
00000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool0
0200oooo00<000000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3o
ool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool00200oooo00<0
00000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool0
0200oooo00<000000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3o
ool0o@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001l0oooo00<0
Vi^K0?ooo`3oool0oP3oool001l0oooo00<0CTi>0?ooo`3oool0oP3oool0
01h0oooo00<0lO7a0000003YjNT0o`3oool001h0oooo00<0/k>c08f=S@2W
YjL0o`3oool001h0oooo00<0CTi>0?7al@1XJ6P0o`3oool001d0oooo00D0
d=3@0:NWY`3oool0YjNW0=3@d03n0?ooo`007@3oool01@1lO7`0jNWY0?oo
o`3YjNT0O7al0?h0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo0000\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
CP3oool01`2c/k<000000000002c/k<0oooo0000003@d=000P1>CTh00`3@
d=00oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00D000000?oo
o`3oool000000=3@d00204i>CP030=3@d03oool0oooo02/0oooo00@0CTi>
0000000000000000<03oool004h0oooo00@0J6QX0?7al@3alO40J6QX0P3o
ool0101>CTh0oooo0?ooo`1>CTh_0?ooo`030000003oool0oooo02d0oooo
00D000000?ooo`3oool0oooo04i>CP020?ooo`0304i>CP3oool0oooo02/0
oooo00<0d=3@08f=S@3oool0<@3oool004h0oooo00@000000?ooo`3oool0
00001@3oool00`1>CTh0oooo0?ooo`0]0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0103oool00`1>CTh0oooo0?ooo`0]0?ooo`03
0:NWY`3oool0oooo02l0oooo001>0?ooo`040000003oool0oooo00000080
oooo0P1XJ6P00`1>CTh0d=3@0?ooo`0^0?ooo`030000003oool0oooo02d0
oooo00@000000?ooo`3oool0oooo0P1XJ6P00`1>CTh0d=3@0?ooo`0^0?oo
o`030>WYj@2=SHd0oooo02l0oooo001>0?ooo`0406QXJ03alO40jNWY07al
O080oooo00<0/k>c0<O7a`3oool0;`3oool00`2WYjL000000?ooo`0]0?oo
o`030:NWY`000000oooo0080oooo00<0/k>c0<O7a`3oool0;P3oool0101>
CTh0jNWY0>WYj@00000`0?ooo`00CP3oool0102m_Kd000000000002m_Kd2
0?ooo`040>WYj@0000000000000002l0oooo00<0J6QX0?ooo`3oool0;@3o
ool01@1XJ6P0oooo0?ooo`3oool0jNWY00<00000;@3oool0103@d=00CTi>
04i>CP3@d=0`0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3oool;0?ooo`0307alO03@d=00O7al01<0oooo000F0?ooomP0
000000<0o`000000000000004P0000070?ooo`030=3@d0000000d=3@01<0
oooo000P0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0340oooo
00<0o`000?ooo`3oool06@3oool00`3alO4000000?7al@0C0?ooo`00803o
ool00`000000ol3;0?o0b`3;0?o0b`030?l0003oool0oooo01T0oooo00<0
d=3@0000003@d=004`3oool00200oooo00<000000?o0b`3o`</0b`3o`</0
0`3o0000oooo0?ooo`0I0?ooo`0307alO03@d=00O7al01<0oooo000P0?oo
o`030000003o`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3oool00200
oooo00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_0?ooo`00
803oool00`000000ol3;0?o0b`3;0?o0b`030?l0003oool0oooo02l0oooo
000P0?ooo`030000003o`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3o
ool00200oooo00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_
0?ooo`00803oool00`000000ol3;0?o0b`3;0?o0b`030?l0003oool0oooo
02l0oooo000P0?ooo`030000003o`</0ol3;0</0ol3;00<0o`000?ooo`3o
ool0;`3oool00200oooo00<000000?o0b`3o`</0b`3o`</00`3o0000oooo
0?ooo`0_0?ooo`00803oool00`000000ol3;0?o0b`3;0?o0b`030?l0003o
ool0oooo02l0oooo000P0?ooo`030000003o`</0ol3;0</0ol3;00<0o`00
0?ooo`3oool0;`3oool00200oooo00<000000?o0b`3o`</0b`3o`</00`3o
0000oooo0?ooo`0_0?ooo`00803oool00`000000ol3;0?o0b`3;0?o0b`03
0?l0003oool0oooo02l0oooo000P0?ooo`030000003o`</0ol3;0</0ol3;
00<0o`000?ooo`3oool0;`3oool00200oooo00<000000?o0b`3o`</0b`3o
`</00`3o0000oooo0?ooo`0_0?ooo`00803oool00`000000ol3;0?o0b`3;
0?o0b`030?l0003oool0oooo02l0oooo000P0?ooo`030000003o`</0ol3;
0</0ol3;00<0o`000?ooo`3oool0;`3oool00200oooo00<000000?o0b`3o
`</0b`3o`</00`3o0000oooo0?ooo`0_0?ooo`00803oool00`000000ol3;
0?o0b`3;0?o0b`030?l0003oool0oooo02l0oooo000P0?ooo`030000003o
`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3oool00200oooo00<00000
0?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_0?ooo`00803oool00`00
0000ol3;0?o0b`3;0?o0b`030?l0003oool0oooo02l0oooo000P0?ooo`03
0000003o`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3oool00200oooo
00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_0?ooo`00803o
ool00`000000ol3;0?o0b`3;0?o0b`030?l0003oool0oooo02l0oooo000P
0?ooo`030000003o`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3oool0
0200oooo00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_0?oo
o`00803oool00`000000ol3;0?o0b`3;0?o0b`030?l0003oool0oooo02l0
oooo000P0?ooo`030000003o`</0ol3;0</0ol3;00<0o`000?ooo`3oool0
;`3oool00200oooo00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?oo
o`0_0?ooo`00803oool00`000000ol3;0?o0b`3;0?o0b`030?l0003oool0
oooo02l0oooo000P0?ooo`030000003o`</0ol3;0</0ol3;00<0o`000?oo
o`3oool0;`3oool00200oooo00<000000?o0b`3o`</0b`3o`</00`3o0000
oooo0?ooo`0_0?ooo`00803oool00`000000ol3;0?o0b`3;0?o0b`030?l0
003oool0oooo02l0oooo000P0?ooo`030000003o`</0ol3;0</0ol3;00<0
o`000?ooo`3oool0;`3oool00200oooo00<000000?o0b`3o`</0b`3o`</0
0`3o0000oooo0?ooo`0_0?ooo`00403oool01`2c/k<000000000002c/k<0
oooo0000003@d=000P1>CTh00`3@d=00oooo0?ooo`040?ooo`030000003o
`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3oool00100oooo00@0J6QX
0?7al@3alO40J6QX0P3oool0101>CTh0oooo0?ooo`1>CTh60?ooo`030000
003o`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3oool00100oooo00@0
00000?ooo`3oool000001@3oool00`1>CTh0oooo0?ooo`040?ooo`030000
003o`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3oool00100oooo00@0
00000?ooo`3oool000000P3oool206QXJ00304i>CP3@d=00oooo00D0oooo
00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_0?ooo`00403o
ool0101XJ6P0lO7a0>WYj@1lO7`20?ooo`030;>c/`37alL0oooo00L0oooo
00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_0?ooo`00403o
ool0102m_Kd000000000002m_Kd20?ooo`040>WYj@0000000000000000H0
oooo00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_0?ooo`00
803oool00`000000ol3;0?o0b`3;0?o0b`030?l0003oool0oooo02l0oooo
000P0?ooo`030000003o`</0ol3;0</0ol3;00<0o`000?ooo`3oool0;`3o
ool00200oooo00<000000?o0b`3o`</0b`3o`</00`3o0000oooo0?ooo`0_
0?ooo`00803oool00`000000ol3;0?o0b`3;0?o0b`030?l0003oool0oooo
02l0oooo000P0?ooo`030000003o`</0ol3;0</0ol3;00<0o`000?ooo`3o
ool0;`3oool00200oooo00<000000?o0b`3o`</0b`3o`</00`3o0000oooo
0?ooo`0_0?ooo`00803oool00`000000ol3;0?o0b`3;0?o0b`030?l0003o
ool0oooo02l0oooo000P0?ooo`030000003o`</0ol3;0</0ol3;00<0o`00
0?ooo`3oool0;`3oool00200oooo00<000000?o0b`3o`</0b`3o`</00`3o
0000oooo0?ooo`0_0?ooo`00803oool00`000000ol3;0?o0b`1_0?o0b`X0
o`00DP3o`</00`3o0000oooo0?ooo`0_0?ooo`00803oool00`000000ol3;
0?o0b`1/0?o0b`<0o`002P3oool40?l004h0ol3;00<0o`000?ooo`3oool0
;`3oool00200oooo00<000000?o0b`3o`</0J03o`</30?l000/0ObXZ1P3o
ool00`3o`</0o`000?l0001<0?o0b`030?l0003oool0oooo02l0oooo000P
0?ooo`030000003o`</0ol3;0680ol3;0`1o:RX20?o0b`040?l0003oool0
ObXZ07lZ:P/0oooo0`1o:RX60?ooo`80o`00BP3o`</00`3o0000oooo0?oo
o`0_0?ooo`00803oool00`000000ol3;0?o0b`1Q0?o0b`D0ObXZ00<0o`00
07lZ:P1o:RX0403oool307lZ:PD0oooo0P3o00180?o0b`030?l0003oool0
oooo02l0oooo000P0?ooo`030000003o`</0ol3;0640ol3;1P1o:RXE0?oo
o`<0ObXZ103oool00`3o0000ol3;0?o0b`150?o0b`030?l0003oool0oooo
02l0oooo000P0?ooo`030000003o`</0ol3;0640ol3;1@1o:RXI0?ooo`80
ObXZ0`3oool20?l004D0ol3;00<0o`000?ooo`3oool0;`3oool00200oooo
00<000000?o0b`3o`</0H@3o`</407lZ:Q`0oooo00<0ObXZ0?ooo`3oool0
0P3oool00`3o0000ol3;0?o0b`120?o0b`030?l0003oool0oooo02l0oooo
000P0?ooo`030000003o`</0ol3;0600ol3;00<0ObXZ0?ooo`3oool07`3o
ool207lZ:P<0oooo00<0o`000?o0b`3o`</0@@3o`</00`3o0000oooo0?oo
o`0_0?ooo`00803oool00`000000ol3;0?o0b`1N0?o0b`80ObXZ903oool0
101o:RX0oooo0?ooo`3oool20?l00440ol3;00<0o`000?ooo`3oool0;`3o
ool00200oooo00<000000?o0b`3o`</0G@3o`</00`1o:RX0o`000?ooo`0U
0?ooo`80ObXZ0`3oool00`3o0000ol3;0?o0b`0n0?o0b`030?l0003oool0
oooo02l0oooo000P0?ooo`030000003o`</0ol3;05`0ol3;00<0ObXZ0?l0
003oool0:03oool01@1o:RX0oooo0?ooo`3oool0o`0003l0ol3;00<0o`00
0?ooo`3oool0;`3oool00200oooo00<000000?o0b`3o`</0F`3o`</00`1o
:RX0o`000?ooo`0Z0?ooo`0407lZ:P3oool0oooo0?ooo`80o`00?@3o`</0
0`3o0000oooo0?ooo`0_0?ooo`00803oool00`000000ol3;0?o0b`1I0?o0
b`80ObXZ00<0o`000?ooo`3oool0:`3oool207lZ:P<0oooo00<0o`000?o0
b`3o`</0>P3o`</00`3o0000oooo0?ooo`0_0?ooo`00803oool00`000000
ol3;0?o0b`1H0?o0b`0307lZ:P3o`</0o`000300oooo00D0ObXZ0?ooo`3o
ool0oooo0?l0000k0?o0b`030?l0003oool0oooo02l0oooo000P0?ooo`03
0000003o`</0ol3;05L0ol3;00<0ObXZ0?o0b`3o0000<P3oool01@1o:RX0
oooo0?ooo`3oool0o`0003X0ol3;00<0o`000?ooo`3oool0;`3oool00200
oooo00<000000?o0b`3o`</0EP3o`</00`1o:RX0ol3;0?l0000d0?ooo`80
ObXZ0P3oool00`3o0000ol3;0?o0b`0g0?o0b`030?l0003oool0oooo02l0
oooo000P0?ooo`030000003o`</0ol3;05H0ol3;00<0ObXZ0?l0003oool0
=P3oool0101o:RX0oooo0?ooo`3o000h0?o0b`030?l0003oool0oooo02l0
oooo000P0?ooo`030000003o`</0ol3;05D0ol3;00<0ObXZ0?o0b`3o0000
>03oool207lZ:P030?ooo`3o0000ol3;03H0ol3;00<0o`000?ooo`3oool0
;`3oool00200oooo00<000000?o0b`3o`</0E03o`</00`1o:RX0ol3;0?l0
000k0?ooo`0307lZ:P3oool0o`0003H0ol3;00<0o`000?ooo`3oool0;`3o
ool00200oooo00<000000?o0b`3o`</0E03o`</00`1o:RX0o`000?ooo`0l
0?ooo`80ObXZ00<0o`000?o0b`3o`</0<`3o`</00`3o0000oooo0?ooo`0_
0?ooo`00803oool00`000000ol3;0?o0b`1C0?o0b`0307lZ:P3o0000oooo
03l0oooo101o:RXb0?o0b`030?l0003oool0oooo02l0oooo000P0?ooo`03
0000003o`</0ol3;0580ol3;00<0ObXZ0?l0003oool0@03oool507lZ:S40
ol3;00<0o`000?ooo`3oool0;`3oool00200oooo00<000000?o0b`3o`</0
DP3o`</00`1o:RX0oooo0?ooo`100?ooo`D0ObXZ<@3o`</00`3o0000oooo
0?ooo`0_0?ooo`00803oool00`000000ol3;0?o0b`1A0?o0b`0307lZ:P3o
ool0oooo0440oooo1@1o:RXa0?o0b`030?l0003oool0oooo02l0oooo000P
0?ooo`030000003o`</0ol3;0500ol3;00<0ObXZ0?l0003oool0@`3oool3
07lZ:P030?o0b`1o:RX0ObXZ02l0ol3;00<0o`000?ooo`3oool0;`3oool0
01T0oooo00<000000?ooo`3oool00`3oool307lZ:U00ol3;00<0ObXZ0?l0
003oool0B03oool00`3o`</0o`0007lZ:P0^0?o0b`030?l0003oool0oooo
02l0oooo000I0?ooo`030000003oool0oooo0080oooo1@1o:RY?0?o0b`03
07lZ:P3oool0oooo04T0oooo00<0o`000?o0b`1o:RX0;@3o`</00`3o0000
oooo0?ooo`0_0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`D0ObXZ
CP3o`</00`1o:RX0oooo0?ooo`1;0?ooo`040?l0003o`</0ObXZ07lZ:R/0
ol3;00<0o`000?ooo`3oool0;`3oool001T0oooo00<000000?ooo`3oool0
0P3oool507lZ:Td0ol3;00<0ObXZ0?l0003oool0C@3oool0103o0000ol3;
0?o0b`1o:RXZ0?o0b`030?l0003oool0oooo02l0oooo000H0?ooo`030:NW
Y`000000oooo00@0oooo0`1o:RY=0?o0b`0307lZ:P3o0000oooo04l0oooo
00<0o`000?o0b`3o`</00P1o:RXX0?o0b`030?l0003oool0oooo02l0oooo
000I0?ooo`0306QXJ03oool0oooo00@0oooo00<0000007lZ:P3o`</0C03o
`</00`1o:RX0oooo0?ooo`1@0?ooo`040?l0003o`</0ol3;0?o0b`80ObXZ
9P3o`</00`3o0000oooo0?ooo`0_0?ooo`00803oool00`000000ObXZ0?o0
b`1;0?o0b`0307lZ:P3oool0oooo0580oooo00<0o`000?o0b`3o`</00P3o
`</207lZ:R@0ol3;00<0o`000?ooo`3oool0;`3oool00200oooo00<00000
0?l0001o:RX0BP3o`</00`1o:RX0o`000?ooo`1D0?ooo`030?l0003o`</0
ol3;00<0ol3;0P1o:RXR0?o0b`030?l0003oool0oooo02l0oooo000P0?oo
o`030000003o0000ObXZ04X0ol3;00<0ObXZ0?ooo`3oool0E03oool00`3o
`</0o`000?o0b`050?o0b`0307lZ:P3o`</0ol3;01l0ol3;00<0o`000?oo
o`3oool0;`3oool00200oooo00<000000?ooo`1o:RX0B@3o`</00`1o:RX0
oooo0?ooo`1G0?ooo`030?l0003o`</0ol3;00@0ol3;0P1o:RXO0?o0b`03
0?l0003oool0oooo02l0oooo000P0?ooo`040000003oool0o`0007lZ:TL0
ol3;00<0ObXZ0?l0003oool0F@3oool00`3o0000ol3;0?o0b`050?o0b`<0
ObXZ703o`</00`3o0000oooo0?ooo`0_0?ooo`00803oool010000000oooo
0?l0001o:RY70?o0b`0307lZ:P3oool0oooo05X0oooo00<0o`000?o0b`3o
`</01`3o`</407lZ:QH0ol3;0P1o:RX00`3o0000oooo0?ooo`0_0?ooo`00
803oool010000000oooo0?l0001o:RY60?o0b`0307lZ:P3o0000oooo05`0
oooo00<0o`000?o0b`3o`</02P3o`</407lZ:Q40ol3;0`1o:RX00`3o0000
ObXZ0?ooo`0_0?ooo`00803oool01@000000oooo0?ooo`3o0000ObXZ04@0
ol3;00<0ObXZ0?l0003oool0GP3oool00`3o0000ol3;0?o0b`0=0?o0baH0
ObXZ<03oool00200oooo00D000000?ooo`3oool0o`0007lZ:P140?o0b`03
07lZ:P3oool0oooo05l0oooo00<0o`000?o0b`3o`</07@3o`</507lZ:S00
oooo000P0?ooo`050000003oool0oooo0?l0001o:RX0@`3o`</00`1o:RX0
o`000?ooo`1Q0?ooo`030?l0003o`</0ol3;01d0ol3;0`1o:RXa0?ooo`00
803oool01P000000oooo0?ooo`3o0000ol3;07lZ:T80ol3;00<0ObXZ0?oo
o`3oool0HP3oool20?l001`0ol3;00<0o`000?ooo`3oool0<P3oool00200
oooo00H000000?ooo`3oool0oooo0?l0001o:RY10?o0b`0307lZ:P3oool0
oooo06D0oooo00<0o`000?o0b`3o`</06@3o`</00`3o0000oooo0?ooo`0b
0?ooo`00803oool01P000000oooo0?ooo`3oool0o`0007lZ:T00ol3;00<0
ObXZ0?l0003oool0I`3oool00`3o0000ol3;0?o0b`0G0?o0b`030?l0003o
ool0oooo03<0oooo000P0?ooo`070000003oool0oooo0?ooo`3o0000ol3;
07lZ:P0o0?o0b`0307lZ:P3oool0oooo06P0oooo00<0o`000?o0b`3o`</0
5@3o`</00`3o0000oooo0?ooo`0d0?ooo`00803oool01`000000oooo0?oo
o`3oool0o`000?o0b`1o:RX0?P3o`</00`1o:RX0o`000?ooo`1Z0?ooo`80
o`00503o`</00`3o0000oooo0?ooo`0e0?ooo`00803oool00`000000oooo
0?ooo`020?ooo`030?l0001o:RX0ol3;03`0ol3;00<0ObXZ0?l0003oool0
K@3oool00`3o0000ol3;0?o0b`0?0?o0b`030?ooo`3o0000oooo03L0oooo
000P0?ooo`030000003oool0oooo0080oooo00<0o`000?o0b`1o:RX0?03o
`</00`1o:RX0oooo0?ooo`1^0?ooo`80o`003P3o`</20?l003T0oooo000P
0?ooo`030000003oool0oooo0080oooo00<0o`000?o0b`1o:RX0>`3o`</0
0`1o:RX0o`000?ooo`1a0?ooo`80o`002P3o`</20?l003/0oooo000P0?oo
o`030000003oool0oooo0080oooo00<0o`000?o0b`1o:RX0>`3o`</00`1o
:RX0oooo0?ooo`1c0?ooo`X0o`00?@3oool00200oooo00<000000?ooo`3o
ool00`3oool00`3o0000ol3;07lZ:P0i0?o0b`0307lZ:P3oool0oooo0;/0
oooo000P0?ooo`030000003oool0oooo00<0oooo00<0o`000?o0b`1o:RX0
>@3o`</00`1o:RX0oooo0?ooo`2k0?ooo`00803oool00`000000oooo0?oo
o`030?ooo`030?l0003o`</0ObXZ03P0ol3;00<0ObXZ0?ooo`3oool0_03o
ool00200oooo00<000000?ooo`3oool0103oool00`3o0000ol3;07lZ:P0f
0?o0b`0307lZ:P3oool0oooo0;d0oooo000P0?ooo`030000003oool0oooo
00@0oooo00<0o`000?o0b`1o:RX0=@3o`</00`3o0000ObXZ0?ooo`2n0?oo
o`00803oool00`000000oooo0?ooo`040?ooo`040?l0003o`</0ol3;07lZ
:S@0ol3;00<0ObXZ0?ooo`3oool0_P3oool00200oooo00<000000?ooo`3o
ool0103oool0103o0000ol3;0?o0b`1o:RXc0?o0b`030?l0001o:RX0oooo
0;l0oooo000P0?ooo`030000003oool0oooo00D0oooo00@0o`000?o0b`3o
`</0ObXZ<@3o`</00`3o0000ObXZ0?ooo`300?ooo`00803oool00`000000
oooo0?ooo`050?ooo`040?l0003o`</0ol3;07lZ:S40ol3;00<0o`0007lZ
:P3oool0`03oool00200oooo00<000000?ooo`3oool01@3oool01@3o0000
ol3;0?o0b`3o`</0ObXZ02l0ol3;00<0o`0007lZ:P3oool0`@3oool00200
oooo00<000000?ooo`3oool01P3oool0103o0000ol3;0?o0b`1o:RX^0?o0
b`030?l0001o:RX0oooo0<80oooo000P0?ooo`030000003oool0oooo00H0
oooo00D0o`000?o0b`3o`</0ol3;07lZ:P0]0?o0b`0307lZ:P3oool0oooo
0<80oooo000P0?ooo`030000003oool0oooo00L0oooo00@0o`000?o0b`3o
`</0ObXZ;03o`</00`3o0000ObXZ0?ooo`330?ooo`00803oool00`000000
oooo0?ooo`070?ooo`050?l0003o`</0ol3;0?o0b`1o:RX0:P3o`</00`3o
0000ObXZ0?ooo`340?ooo`00803oool00`000000oooo0?ooo`080?ooo`04
0?l0003o`</0ol3;07lZ:RX0ol3;00<0ObXZ0?ooo`3oool0a03oool00200
oooo00<000000?ooo`3oool0203oool01@3o0000ol3;0?o0b`3o`</0ObXZ
02P0ol3;00<0ObXZ0?ooo`3oool0a@3oool00180oooo00D000000?ooo`3o
ool000000=3@d00204i>CP030=3@d03oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool0103o0000ol3;0?o0b`1o:RXW0?o0b`030?l0001o:RX0
oooo0<H0oooo000B0?ooo`050000003oool0oooo0?ooo`1>CTh00P3oool0
0`1>CTh0oooo0?ooo`040?ooo`<000002@3oool01@3o0000ol3;0?o0b`3o
`</0ObXZ02H0ol3;00<0ObXZ0?ooo`3oool0aP3oool00180oooo00<00000
0?ooo`3oool0103oool00`1>CTh0oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo00D0ol3;0?l0003o`</0ol3;07lZ:P0U0?o0b`0307lZ:P3o
ool0oooo0<L0oooo000B0?ooo`040000003oool0oooo0?ooo`80J6QX00<0
CTi>0=3@d03oool01@3oool00`000000oooo0?ooo`0:0?ooo`050?l0003o
`</0ol3;0?o0b`1o:RX08`3o`</00`1o:RX0oooo0?ooo`380?ooo`004@3o
ool00`2WYjL000000?ooo`020?ooo`030;>c/`37alL0oooo00L0oooo00<0
00000?ooo`3oool02P3oool01@3o0000ol3;0?o0b`3o`</0ObXZ0200ol3;
101o:R[:0?ooo`004P3oool01@1XJ6P0oooo0?ooo`3oool0jNWY00<00000
1P3oool00`000000oooo0?ooo`0:0?ooo`030?o0b`3o0000ol3;0080ol3;
00<0ObXZ0?o0b`3o`</0703o`</507lZ:/X0oooo000P0?ooo`030000003o
ool0oooo00/0oooo00<0o`000?o0b`3o`</00P3o`</00`1o:RX0ol3;0?o0
b`0K0?o0b`D0ObXZbP3oool00200oooo00<000000?ooo`3oool02`3oool0
0`3o0000ol3;0?o0b`030?o0b`0307lZ:P3o`</0ol3;01X0ol3;1@1o:R[:
0?ooo`00803oool00`000000oooo0?ooo`0<0?ooo`030?l0003o`</0ol3;
00<0ol3;00<0ObXZ0?o0b`3o`</06@3o`</407lZ://0oooo000P0?ooo`03
0000003oool0oooo00`0oooo00<0o`000?o0b`3o`</00`3o`</00`1o:RX0
ol3;0?o0b`0H0?o0b`0307lZ:P3oool0oooo0<d0oooo000P0?ooo`030000
003oool0oooo00d0oooo00<0o`000?o0b`3o`</00`3o`</00`1o:RX0ol3;
0?o0b`0F0?o0b`0307lZ:P3oool0oooo0<h0oooo000P0?ooo`030000003o
ool0oooo00d0oooo00<0o`000?o0b`3o`</0103o`</00`1o:RX0ol3;0?o0
b`0D0?o0b`0307lZ:P3o0000oooo0<l0oooo000P0?ooo`030000003oool0
oooo00h0oooo00<0o`000?o0b`3o`</0103o`</00`1o:RX0ol3;0?o0b`0B
0?o0b`0307lZ:P3o0000oooo0=00oooo000P0?ooo`030000003oool0oooo
00l0oooo00<0o`000?o0b`3o`</0103o`</00`1o:RX0ol3;0?o0b`0@0?o0
b`0307lZ:P3o0000oooo0=40oooo000P0?ooo`030000003oool0oooo0100
oooo00<0o`000?o0b`3o`</0103o`</00`1o:RX0ol3;0?o0b`0>0?o0b`03
07lZ:P3o0000oooo0=80oooo000P0?ooo`030000003oool0oooo0140oooo
00<0o`000?o0b`3o`</0103o`</00`1o:RX0ol3;0?o0b`0;0?o0b`80ObXZ
00<0o`000?ooo`3oool0dP3oool00200oooo00<000000?ooo`3oool04@3o
ool00`3o`</0o`000?o0b`050?o0b`80ObXZ2@3o`</207lZ:P030?o0b`3o
0000oooo0=@0oooo000P0?ooo`030000003oool0oooo0180oooo00<0o`00
0?o0b`3o`</01P3o`</907lZ:P030?o0b`3o0000o`000=H0oooo000P0?oo
o`030000003oool0oooo01<0oooo00<0o`000?o0b`3o`</03P3o`</00`3o
0000oooo0?ooo`3F0?ooo`00803oool00`000000oooo0?ooo`0D0?ooo`03
0?l0003o`</0ol3;00`0ol3;00<0o`000?ooo`3oool0e`3oool00200oooo
00<000000?ooo`3oool05@3oool20?l000/0ol3;00<0o`000?ooo`3oool0
f03oool00200oooo00<000000?ooo`3oool05`3oool40?l00080ol3;1@3o
003K0?ooo`00803oool00`000000oooo0?ooo`0J0?ooo`@0o`00g`3oool0
0200oooo00<000000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3o
ool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool00200oooo00<0
00000?ooo`3oool0o@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
01l0oooo00<0Vi^K0?ooo`3oool0oP3oool001l0oooo00<0CTi>0?ooo`3o
ool0oP3oool001h0oooo00<0lO7a0000003YjNT0o`3oool001h0oooo00<0
/k>c08f=S@2WYjL0o`3oool001h0oooo00<0CTi>0?7al@1XJ6P0o`3oool0
01d0oooo00D0d=3@0:NWY`3oool0YjNW0=3@d03n0?ooo`007@3oool01@1l
O7`0jNWY0?ooo`3YjNT0O7al0?h0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo0000\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "\n\t\t",
  StyleBox["Simpson\[CloseCurlyQuote]s 3/8 Rule",
    FontFamily->"Times-Roman"],
  "\t\t\t\t\t\t",
  StyleBox["Boole\[CloseCurlyQuote]s Rule",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        1 + \[ExponentialE]\^\(-x\)\ Sin[
              4\ x];\)\ \), "\[IndentingNewLine]", 
    \(\(h = 0.5;\)\ \), "\[IndentingNewLine]", 
    \(x\_0 = 0.0; x\_1 = x\_0 + h; x\_2 = x\_0 + 2  h; x\_3 = x\_0 + 3  h; 
    x\_4 = x\_0 + 4  h;\), "\n", 
    \(f\_0 = f[x\_0]; f\_1 = f[x\_1]; f\_2 = f[x\_2]; f\_3 = f[x\_3]; 
    f\_4 = f[x\_4];\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Using (8) the Trapezoidal Rule: \n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0.0\%0.5\ f[x] \[DifferentialD]x\)]],
  " ",
  Cell[BoxData[
      \(\(\(\[TildeTilde]\)\(\ \)\(\(h\/2\) \((f\_0\  + \ f\_1)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(0.5\/2\) \((1.00000 + 1.55152)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.25 \((2.55152)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.637879\)\)\)\)]],
  "  \n\t\t\t\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<The Trapezoidal Rule with  h = \>", 
        h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%0.5\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(h\/2\)(\!\(f\_0\) + \!\(f\_1\)) = \>\"", \
\(h\/2\) \((f\_0\  + \ f\_1)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Using (9) Simpson\[CloseCurlyQuote]s Rule: \n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0.0\%1.0\ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(\[TildeTilde]\)\(\ \)\(\(h\/3\) \((f\_0\  + \ 
              4  f\_1\  + \ f\_2)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(0.5\/3\) \((1.00000\  + \ 4*1.55152\  + \ 
              0.72159)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.166667 \((1.00000\  + \ 6.20608\  + \ 
              0.72159)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.166667 \((7.92767)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(1.32128\)\)\)\)]],
  "  \n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<Simpson's Rule with  h = \>", 
        h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1.0\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(h\/3\)(\!\(f\_0\) + 4\!\(f\_1\) + \!\(f\_2\)) \
= \>\"", \(h\/3\) \((f\_0\  + \ 4  f\_1\  + \ f\_2)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Using (10) Simpson\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(3\/8\)]],
  "R",
  StyleBox["ule:\n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0.0\%1.5\ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(\[TildeTilde]\)\(\ \)\(\(\(3  h\)\/8\) \((f\_0\  + \ 
              3  f\_1\  + \ 3  f\_2 + \ f\_3)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(\(3*0.5\)\/8\) \((1.00000\  + \ 
              3*1.55152\  + \ 3*0.72159 + \ 0.93765)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.1875 \((1.00000\  + \ 4.65456\  + \ 
              2.16477 + \ 0.93765)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.1875 \((8.75698)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(1.64193\)\)\)\)]],
  "  \n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<Simpson's \!\(3\/8\) Rule with  h = \>\"", 
        h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1.5\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(\(3  h\)\/8\)(\!\(f\_0\) + 3\!\(f\_1\) + \
3\!\(f\_2\)+ \!\(f\_3\)) = \>\"", \(\(3  h\)\/8\) \((f\_0\  + \ 3  f\_1\  + \ 
              3  f\_2 + \ f\_3)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Using (11) Boole\[CloseCurlyQuote]s Rule:\n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0.0\%2.0\ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(\[TildeTilde]\)\(\ \)\(\(\(2  h\)\/45\) \((7  f\_0\  + \ 
              32  f\_1\  + \ 12  f\_2 + \ 32  f\_3 + 7  f\_4)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(\(2*0.5\)\/45\) \((7*1.00000\  + \ 
              32*1.55152\  + \ 12*0.72159 + \ 32*\ 0.93765 + 
              7*1.13390)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.0222222 \((7.00000\  + \ 49.64864\  + \ 
              8.65908 + \ 30.0048 + 7.9373)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.0222222 \((103.24982)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(2.29444\)\)\)\)]],
  "  \n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<Boole's Rule with  h = \>", h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%2.0\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(\(2  \
h\)\/45\)(7\!\(f\_0\)+32\!\(f\_1\)+12\!\(f\_2\)+32\!\(f\_3\)+7\!\(f\_4\)) = \
\>\"", \(\(2  h\)\/45\) \((7  f\_0 + 32  f\_1 + 12  f\_2 + 32  f\_3 + 
              7  f\_4)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"MSAM6"],
  StyleBox["It is important to realize that the quadrature formulas (4) \
through (7) applied in the example above give approximations for definite \
integrals over different intervals.",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times-Bold"],
  StyleBox["The graph of the curve  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  "  ",
  StyleBox["and the areas under the Lagrange polynomials  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = \(P\_1\) \((x)\)\)]],
  StyleBox[", ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = \(P\_2\) \((x)\)\)]],
  StyleBox[", ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = \(P\_3\) \((x)\)\)]],
  StyleBox[", and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = \(P\_4\) \((x)\)\)]],
  StyleBox["  are shown in the figures for this example.",
    FontFamily->"Times-Roman"]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["\tIn Example 1 we applied the quadrature rules with  ",
    FontFamily->"Times-Roman"],
  StyleBox["h = 0.5",
    FontFamily->"Courier New"],
  StyleBox[".  If the endpoints of the interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["[",
          FontFamily->"Courier New"], 
        RowBox[{
          StyleBox["a",
            FontFamily->"Courier New"], 
          StyleBox[",",
            FontFamily->"Times New Roman"], 
          StyleBox["b",
            FontFamily->"Courier New"]}], 
        StyleBox["]",
          FontFamily->"Courier New"]}]]],
  StyleBox["  are held fixed, the step size must be adjusted for each rule.  \
The step sizes are  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h = b - a\)]],
  StyleBox[",  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h = \(b - a\)\/2\)]],
  StyleBox[",  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h = \(b - a\)\/3\)]],
  StyleBox[",  and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h = \(b - a\)\/4\)]],
  StyleBox["  for the trapezoidal rule, Simpson\[CloseCurlyQuote]s rule, \
Simpson\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(3\/8\)]],
  StyleBox["rule, and Boole\[CloseCurlyQuote]s rule, respectively.  The next \
example illustrates this point.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Consider the integration of the function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\) = 1 + \[ExponentialE]\^\(-x\)\ sin \((4\ x)\)\)]],
  StyleBox["  over the fixed interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["[",
            FontFamily->"Courier New"], 
          RowBox[{
            StyleBox["a",
              FontFamily->"Courier New"], 
            StyleBox[",",
              FontFamily->"Times New Roman"], 
            StyleBox["b",
              FontFamily->"Courier New"]}], 
          StyleBox["]",
            FontFamily->"Courier New"]}], 
        StyleBox[" ",
          FontFamily->"Courier New"], 
        StyleBox["=",
          FontFamily->"Courier New"], 
        StyleBox[" ",
          FontFamily->"Courier New"], 
        RowBox[{
          StyleBox["[",
            FontFamily->"Courier New"], 
          RowBox[{
            StyleBox["0",
              FontFamily->"Courier New"], 
            StyleBox[",",
              FontFamily->"Times New Roman"], 
            StyleBox["1",
              FontFamily->"Courier New"]}], 
          StyleBox["]",
            FontFamily->"Courier New"]}]}]]],
  StyleBox[".  Apply the various formulas (4) through (7).",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
AP3oool01`2c/k<000000000002c/k<0oooo0000001>CTh00`00000Q0?oo
o`060;>c/`00000000000;>c/`3oool000000P3oool00`000000oooo0?oo
o`0P0?ooo`070;>c/`00000000000;>c/`3oool000000>7Qh@0204i>CP03
0=3@d03oool0oooo01l0oooo00L0/k>c000000000000/k>c0?ooo`000000
d=3@0080CTi>00<0d=3@0?ooo`3oool0903oool00`000000oooo0?ooo`0V
0?ooo`00AP3oool0101XJ6P0lO7a0?7al@1XJ6P20?ooo`030=3@d02=SHd0
oooo0280oooo00@0J6QX0?7al@3alO40J6QX0`3oool300000240oooo00@0
J6QX0?7al@3alO40J6QX0P3oool0101lO7`0lO7a0?ooo`1>CThQ0?ooo`04
06QXJ03alO40lO7a06QXJ080oooo00@0J6QX0?ooo`3oool0CTi>9P3oool0
0`000000oooo0?ooo`0V0?ooo`00AP3oool010000000oooo0?ooo`000004
0?ooo`030:NWY`3oool0oooo0200oooo00@000000?ooo`3oool000000`3o
ool00`1XJ6P000000?ooo`0Q0?ooo`040000003oool0oooo00000080oooo
00@000000>WYj@3oool0CTi>8@3oool010000000oooo0?ooo`0000020?oo
o`0404i>CP3oool0oooo06QXJ2H0oooo00<000000?ooo`3oool09P3oool0
04H0oooo00@000000?ooo`3oool00000103oool00`3YjNT0SHf=0?ooo`0P
0?ooo`040000003oool0oooo000000<0oooo00<0YjNW0000003oool08@3o
ool010000000oooo0?ooo`0000020?ooo`040000002=SHd000000=3@d240
oooo00@000000?ooo`3oool000000P3oool0103@d=0000000000003@d=0V
0?ooo`030000003oool0oooo02H0oooo00160?ooo`0406QXJ03alO40jNWY
07alO080oooo00@0CTi>0>WYj@3YjNT000008@3oool0101XJ6P0lO7a0>WY
j@1lO7`30?ooo`030=3@d0000000oooo0240oooo00@0J6QX0?7al@3YjNT0
O7al0P3oool00`2=SHd0jNWY0?ooo`0R0?ooo`0406QXJ03alO40jNWY07al
O080oooo00@0CTi>0?ooo`3oool0CTi>9@3oool00`2WYjL000000?ooo`0W
0?ooo`00AP3oool0102m_Kd000000000002m_Kd20?ooo`040=3@d01>CTh0
CTi>0=3@d240oooo00@0_Kfm000000000000_Kfm0`3oool00`3alO400000
0?ooo`0Q0?ooo`040;fm_@00000000000;fm_@80oooo00@0jNWY06QXJ000
0000/k>c8@3oool0102m_Kd000000000002m_Kd20?ooo`040;>c/`000000
00000;fm_BH0oooo00<0J6QX0?ooo`3oool09P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo2`3oool00`1lO7`0d=3@
07alO00C0?ooo`005P3ooooQ000000030000o`000000000000T000001`3o
ool00`3@d=0000000=3@d00C0?ooo`00803oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<0003o
0?ooo`3oool0403oool00`3alO4000000?7al@0C0?ooo`00803oool00`00
00000?oo003oo`3D003oo`030000o`3oool0oooo0100oooo00<0d=3@0000
003@d=004`3oool00200oooo00<00000003oo`00ool0e000ool00`000?l0
oooo0?ooo`0@0?ooo`0307alO03@d=00O7al01<0oooo000P0?ooo`030000
0000ool00?oo0=@00?oo00<0003o0?ooo`3oool09P3oool00200oooo00<0
0000003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00803oool0
0`0000000?oo003oo`3D003oo`030000o`3oool0oooo02H0oooo000P0?oo
o`0300000000ool00?oo0=@00?oo00<0003o0?ooo`3oool09P3oool00200
oooo00<00000003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00
803oool00`0000000?oo003oo`3D003oo`030000o`3oool0oooo02H0oooo
000P0?ooo`0300000000ool00?oo0=@00?oo00<0003o0?ooo`3oool09P3o
ool00200oooo00<00000003oo`00ool0e000ool00`000?l0oooo0?ooo`0V
0?ooo`00803oool00`0000000?oo003oo`3D003oo`030000o`3oool0oooo
02H0oooo000P0?ooo`0300000000ool00?oo0=@00?oo00<0003o0?ooo`3o
ool09P3oool00200oooo00<00000003oo`00ool0e000ool00`000?l0oooo
0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`3D003oo`030000o`3o
ool0oooo02H0oooo000P0?ooo`0300000000ool00?oo0=@00?oo00<0003o
0?ooo`3oool09P3oool00200oooo00<00000003oo`00ool0e000ool00`00
0?l0oooo0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`3D003oo`03
0000o`3oool0oooo02H0oooo000P0?ooo`0300000000ool00?oo0=@00?oo
00<0003o0?ooo`3oool09P3oool00200oooo00<00000003oo`00ool0e000
ool00`000?l0oooo0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`3D
003oo`030000o`3oool0oooo02H0oooo000P0?ooo`0300000000ool00?oo
0=@00?oo00<0003o0?ooo`3oool09P3oool00200oooo00<00000003oo`00
ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00803oool00`0000000?oo
003oo`3D003oo`030000o`3oool0oooo02H0oooo000P0?ooo`0300000000
ool00?oo0=@00?oo00<0003o0?ooo`3oool09P3oool00200oooo00<00000
003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00803oool00`00
00000?oo003oo`3D003oo`030000o`3oool0oooo02H0oooo000P0?ooo`03
00000000ool00?oo0=@00?oo00<0003o0?ooo`3oool09P3oool00200oooo
00<00000003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00803o
ool00`0000000?oo003oo`3D003oo`030000o`3oool0oooo02H0oooo000P
0?ooo`0300000000ool00?oo0=@00?oo00<0003o0?ooo`3oool09P3oool0
0200oooo00<00000003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?oo
o`00803oool00`0000000?oo003oo`3D003oo`030000o`3oool0oooo02H0
oooo000P0?ooo`0300000000ool00?oo0=@00?oo00<0003o0?ooo`3oool0
9P3oool00200oooo00<00000003oo`00ool0e000ool00`000?l0oooo0?oo
o`0V0?ooo`00803oool00`0000000?oo003oo`3D003oo`030000o`3oool0
oooo02H0oooo000P0?ooo`0300000000ool00?oo0=@00?oo00<0003o0?oo
o`3oool09P3oool00200oooo00<00000003oo`00ool0e000ool00`000?l0
oooo0?ooo`0V0?ooo`00403oool01`2c/k<000000000002c/k<0oooo0000
003@d=000P1>CTh00`3@d=00oooo0?ooo`040?ooo`0300000000ool00?oo
0=@00?oo00<0003o0?ooo`3oool09P3oool00100oooo00@0J6QX0?7al@3a
lO40J6QX0P3oool0101>CTh0oooo0?ooo`1>CTh60?ooo`0300000000ool0
0?oo0=@00?oo00<0003o0?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000001@3oool00`1>CTh0oooo0?ooo`040?ooo`0300000000ool0
0?oo0=@00?oo00<0003o0?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000000P3oool206QXJ00304i>CP3@d=00oooo00D0oooo00<00000
003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00403oool0101X
J6P0lO7a0>WYj@1lO7`20?ooo`030;>c/`37alL0oooo00L0oooo00<00000
003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00403oool0102m
_Kd000000000002m_Kd20?ooo`040>WYj@0000000000000000H0oooo00<0
0000003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00803oool0
0`0000000?oo003oo`3D003oo`030000o`3oool0oooo02H0oooo000P0?oo
o`0300000000ool00?oo0=@00?oo00<0003o0?ooo`3oool09P3oool00200
oooo00<00000003oo`00ool0e000ool00`000?l0oooo0?ooo`0V0?ooo`00
803oool00`0000000?oo003oo`3D003oo`030000o`3oool0oooo02H0oooo
000P0?ooo`0300000000ool00?oo0=@00?oo00<0003o0?ooo`3oool09P3o
ool00200oooo00<00000003oo`00ool0e000ool00`000?l0oooo0?ooo`0V
0?ooo`00803oool00`0000000?oo003oo`3D003oo`030000o`3oool0oooo
02H0oooo000P0?ooo`0300000000ool00?oo0=@00?oo00<0003o0?ooo`3o
ool09P3oool00200oooo00<00000003oo`00ool0e000ool00`000?l0oooo
0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`3D003oo`030000o`3o
ool0oooo02H0oooo000P0?ooo`0300000000ool00?oo0=@00?oo00<0003o
0?ooo`3oool09P3oool00200oooo00<00000003oo`00ool0e000ool00`00
0?l0oooo0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`3D003oo`03
0000o`3oool0oooo00H0oooo0`1o:RXM0?ooo`00803oool00`0000000?oo
003oo`3D003oo`030000o`1o:RX0oooo0080oooo101o:RXP0?ooo`00803o
ool00`0000000?oo003oo`3A003oo`80003o00<0ObXZ0000o`1o:RX00`1o
:RXT0?ooo`00803oool00`0000000?oo003oo`38003oo`T0003o1P1o:RXV
0?ooo`00803oool00`0000000?oo003oo`2o003oo`T0003o103oool407lZ
:P@0oooo0P1o:RXW0?ooo`00803oool00`0000000?oo003oo`2f003oo`T0
003o2`3oool207lZ:S40oooo000P0?ooo`0300000000ool00?oo0:d00?oo
2@000?lB0?ooo`80ObXZ<`3oool00200oooo00<00000003oo`00ool0Y000
ool90000oaT0oooo0P1o:RXe0?ooo`00803oool00`0000000?oo003oo`2K
003oo`T0003o7`3oool307lZ:SL0oooo000P0?ooo`0300000000ool00?oo
09800?oo2@000?lV0?ooo`80ObXZ>P3oool00200oooo00<00000003oo`00
ool0R@00ool90000ob`0oooo0`1o:RXl0?ooo`00803oool00`0000000?oo
003oo`1k003oo`D0oooo2@000?lc0?ooo`80ObXZ?`3oool00200oooo00<0
0000003oo`00ool0KP00oolB0000ocX0oooo0P1o:RY10?ooo`00803oool0
0`0000000?oo003oo`1U003oo`T0003oBP3oool207lZ:T<0oooo000P0?oo
o`0300000000ool00?oo05`00?oo2@000?mB0?ooo`0307lZ:P3oool0oooo
04<0oooo000P0?ooo`0300000000ool00?oo05<00?oo2@000?mI0?ooo`80
ObXZAP3oool00200oooo00<00000003oo`00ool0BP00ool90000of40oooo
00<0ObXZ0?ooo`3oool0AP3oool00200oooo00<00000003oo`00ool0@@00
ool90000ofP0oooo0P1o:RY90?ooo`00803oool00`0000000?oo003oo`0h
003oo`T0003oL03oool00`1o:RX0oooo0?ooo`190?ooo`00803oool00`00
00000?oo003oo`0_003oo`T0003oM`3oool207lZ:T`0oooo000P0?ooo`03
00000000ool00?oo02H00?oo2@000?mn0?ooo`80ObXZCP3oool00200oooo
00<00000003oo`00ool07@00ool90000ohH0oooo00<0ObXZ0?ooo`3oool0
CP3oool00200oooo00<00000003oo`00ool05@00ool80000ohd0oooo0P1o
:RYA0?ooo`006@3oool00`000000oooo0?ooo`030?ooo`80ObXZ3P00ool9
0000oi@0oooo00<0ObXZ0?ooo`3oool0D@3oool001T0oooo00<000000?oo
o`3oool00P3oool407lZ:P<00?oo2P000?nK0?ooo`80ObXZE03oool001T0
oooo00<000000?ooo`3oool00P3oool407lZ:P<0003oX`3oool207lZ:UH0
oooo000I0?ooo`030000003oool0oooo00<0oooo0`1o:RZU0?ooo`0307lZ
:P3oool0oooo05H0oooo000H0?ooo`030:NWY`000000oooo00D0oooo00<0
000007lZ:P3oool0XP3oool207lZ:UT0oooo000I0?ooo`0306QXJ03oool0
oooo00@0oooo00<000000?ooo`1o:RX0X03oool207lZ:U/0oooo000P0?oo
o`040000003oool0oooo07lZ:Yh0oooo00<0ObXZ0?ooo`3oool0F`3oool0
0200oooo00D000000?ooo`3oool0oooo07lZ:P2L0?ooo`0307lZ:P3oool0
oooo05`0oooo000P0?ooo`050000003oool0oooo0?ooo`1o:RX0VP3oool2
07lZ:Ul0oooo000P0?ooo`030000003oool0oooo0080oooo00<0ObXZ0?oo
o`3oool0UP3oool00`1o:RX0oooo0?ooo`1O0?ooo`00803oool00`000000
oooo0?ooo`030?ooo`0307lZ:P3oool0oooo09@0oooo00<0ObXZ0?ooo`3o
ool0H03oool00200oooo00<000000?ooo`3oool0103oool00`1o:RX0oooo
0?ooo`2A0?ooo`80ObXZH`3oool00200oooo00<000000?ooo`3oool0103o
ool00`1o:RX0oooo0?ooo`2@0?ooo`0307lZ:P3oool0oooo06<0oooo000P
0?ooo`030000003oool0oooo00D0oooo00<0ObXZ0?ooo`3oool0SP3oool0
0`1o:RX0oooo0?ooo`1T0?ooo`00803oool00`000000oooo0?ooo`060?oo
o`0307lZ:P3oool0oooo08`0oooo00<0ObXZ0?ooo`3oool0I@3oool00200
oooo00<000000?ooo`3oool01`3oool00`1o:RX0oooo0?ooo`290?ooo`80
ObXZJ03oool00200oooo00<000000?ooo`3oool01`3oool00`1o:RX0oooo
0?ooo`280?ooo`0307lZ:P3oool0oooo06P0oooo000P0?ooo`030000003o
ool0oooo00P0oooo00<0ObXZ0?ooo`3oool0QP3oool00`1o:RX0oooo0?oo
o`1Y0?ooo`00803oool00`000000oooo0?ooo`090?ooo`0307lZ:P3oool0
oooo08<0oooo0P1o:RY/0?ooo`00803oool00`000000oooo0?ooo`0:0?oo
o`0307lZ:P3oool0oooo0840oooo00<0ObXZ0?ooo`3oool0K03oool00200
oooo00<000000?ooo`3oool02P3oool00`1o:RX0oooo0?ooo`200?ooo`03
07lZ:P3oool0oooo06d0oooo000P0?ooo`030000003oool0oooo00/0oooo
00<0ObXZ0?ooo`3oool0OP3oool00`1o:RX0oooo0?ooo`1^0?ooo`00803o
ool00`000000oooo0?ooo`0<0?ooo`0307lZ:P3oool0oooo07/0oooo0P1o
:RYa0?ooo`00803oool00`000000oooo0?ooo`0=0?ooo`0307lZ:P3oool0
oooo07T0oooo00<0ObXZ0?ooo`3oool0L@3oool00200oooo00<000000?oo
o`3oool03@3oool00`1o:RX0oooo0?ooo`1h0?ooo`0307lZ:P3oool0oooo
0780oooo000P0?ooo`030000003oool0oooo00h0oooo00<0ObXZ0?ooo`3o
ool0MP3oool00`1o:RX0oooo0?ooo`1c0?ooo`00803oool00`000000oooo
0?ooo`0?0?ooo`0307lZ:P3oool0oooo07@0oooo00<0ObXZ0?ooo`3oool0
M03oool00200oooo00<000000?ooo`3oool0403oool00`1o:RX0oooo0?oo
o`1a0?ooo`80ObXZM`3oool00200oooo00<000000?ooo`3oool04@3oool0
0`1o:RX0oooo0?ooo`1_0?ooo`0307lZ:P3oool0oooo07L0oooo000P0?oo
o`030000003oool0oooo0180oooo00<0ObXZ0?ooo`3oool0K@3oool00`1o
:RX0oooo0?ooo`1h0?ooo`00803oool00`000000oooo0?ooo`0C0?ooo`03
07lZ:P3oool0oooo06/0oooo00<0ObXZ0?ooo`3oool0N@3oool00200oooo
00<000000?ooo`3oool04`3oool00`1o:RX0oooo0?ooo`1Z0?ooo`0307lZ
:P3oool0oooo07X0oooo000P0?ooo`030000003oool0oooo01@0oooo00<0
ObXZ0?ooo`3oool0I`3oool207lZ:Wd0oooo000P0?ooo`030000003oool0
oooo01D0oooo00<0ObXZ0?ooo`3oool0I@3oool00`1o:RX0oooo0?ooo`1m
0?ooo`00803oool00`000000oooo0?ooo`0F0?ooo`0307lZ:P3oool0oooo
06<0oooo00<0ObXZ0?ooo`3oool0OP3oool00200oooo00<000000?ooo`3o
ool05`3oool00`1o:RX0oooo0?ooo`1P0?ooo`80ObXZP@3oool00200oooo
00<000000?ooo`3oool0603oool00`1o:RX0oooo0?ooo`1N0?ooo`0307lZ
:P3oool0oooo0840oooo000P0?ooo`030000003oool0oooo01T0oooo00<0
ObXZ0?ooo`3oool0F`3oool207lZ:X@0oooo000P0?ooo`030000003oool0
oooo01X0oooo00<0ObXZ0?ooo`3oool0F@3oool00`1o:RX0oooo0?ooo`24
0?ooo`00803oool00`000000oooo0?ooo`0K0?ooo`0307lZ:P3oool0oooo
05H0oooo0P1o:RZ70?ooo`00803oool00`000000oooo0?ooo`0L0?ooo`03
07lZ:P3oool0oooo05@0oooo00<0ObXZ0?ooo`3oool0Q`3oool00180oooo
00D000000?ooo`3oool000000=3@d00204i>CP030=3@d03oool0oooo00@0
oooo00<000000?ooo`3oool07@3oool207lZ:U80oooo0P1o:RZ:0?ooo`00
4P3oool01@000000oooo0?ooo`3oool0CTi>0080oooo00<0CTi>0?ooo`3o
ool0103oool3000001l0oooo00<0ObXZ0?ooo`3oool0CP3oool00`1o:RX0
oooo0?ooo`2:0?ooo`004P3oool00`000000oooo0?ooo`040?ooo`0304i>
CP3oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`1o:RX0oooo
0?ooo`1;0?ooo`80ObXZS@3oool00180oooo00@000000?ooo`3oool0oooo
0P1XJ6P00`1>CTh0d=3@0?ooo`050?ooo`030000003oool0oooo0240oooo
00<0ObXZ0?ooo`3oool0B@3oool00`1o:RX0oooo0?ooo`2=0?ooo`004@3o
ool00`2WYjL000000?ooo`020?ooo`030;>c/`37alL0oooo00L0oooo00<0
00000?ooo`3oool08P3oool00`1o:RX0oooo0?ooo`160?ooo`80ObXZT03o
ool00180oooo00D0J6QX0?ooo`3oool0oooo0>WYj@03000000H0oooo00<0
00000?ooo`3oool08`3oool00`1o:RX0oooo0?ooo`140?ooo`0307lZ:P3o
ool0oooo0900oooo000P0?ooo`030000003oool0oooo02@0oooo0P1o:RY2
0?ooo`80ObXZT`3oool00200oooo00<000000?ooo`3oool09P3oool00`1o
:RX0oooo0?ooo`0m0?ooo`80ObXZU@3oool00200oooo00<000000?ooo`3o
ool09`3oool207lZ:S/0oooo0P1o:RZG0?ooo`00803oool00`000000oooo
0?ooo`0Y0?ooo`80ObXZ=P3oool307lZ:YT0oooo000P0?ooo`030000003o
ool0oooo02/0oooo00<0ObXZ0?ooo`3oool0<@3oool207lZ:Y`0oooo000P
0?ooo`030000003oool0oooo02`0oooo0P1o:RX_0?ooo`80ObXZWP3oool0
0200oooo00<000000?ooo`3oool0;P3oool307lZ:RX0oooo0P1o:RZP0?oo
o`00803oool00`000000oooo0?ooo`0a0?ooo`80ObXZ9@3oool307lZ:Z80
oooo000P0?ooo`030000003oool0oooo03<0oooo0P1o:RXQ0?ooo`80ObXZ
Y@3oool00200oooo00<000000?ooo`3oool0=@3oool207lZ:Q/0oooo101o
:RZW0?ooo`00803oool00`000000oooo0?ooo`0g0?ooo`D0ObXZ4`3oool3
07lZ:Z/0oooo000P0?ooo`030000003oool0oooo03`0oooo4`1o:RZ^0?oo
o`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo
0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool0
0`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?oo
o`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo
0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool0
0`000000oooo0?ooo`3m0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`007`3oool00`2KVi/0oooo0?ooo`3n0?ooo`007`3oool00`1>CTh0oooo
0?ooo`3n0?ooo`007P3oool00`3alO4000000>WYj@3o0?ooo`007P3oool0
0`2c/k<0SHf=0:NWY`3o0?ooo`007P3oool00`1>CTh0lO7a06QXJ03o0?oo
o`007@3oool01@3@d=00YjNW0?ooo`2WYjL0d=3@0?h0oooo000M0?ooo`05
07alO03YjNT0oooo0>WYj@1lO7`0oP3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
AP3oool01`2c/k<000000000002c/k<0oooo0000001>CTh00`00000Q0?oo
o`060;>c/`00000000000;>c/`3oool000000P3oool00`000000oooo0?oo
o`0P0?ooo`070;>c/`00000000000;>c/`3oool000000>7Qh@0204i>CP03
0=3@d03oool0oooo01l0oooo00L0/k>c000000000000/k>c0?ooo`000000
d=3@0080CTi>00<0d=3@0?ooo`3oool0903oool00`000000oooo0?ooo`0V
0?ooo`00AP3oool0101XJ6P0lO7a0?7al@1XJ6P20?ooo`030=3@d02=SHd0
oooo0280oooo00@0J6QX0?7al@3alO40J6QX0`3oool300000240oooo00@0
J6QX0?7al@3alO40J6QX0P3oool0101lO7`0lO7a0?ooo`1>CThQ0?ooo`04
06QXJ03alO40lO7a06QXJ080oooo00@0J6QX0?ooo`3oool0CTi>9P3oool0
0`000000oooo0?ooo`0V0?ooo`00AP3oool010000000oooo0?ooo`000004
0?ooo`030:NWY`3oool0oooo0200oooo00@000000?ooo`3oool000000`3o
ool00`1XJ6P000000?ooo`0Q0?ooo`040000003oool0oooo00000080oooo
00@000000>WYj@3oool0CTi>8@3oool010000000oooo0?ooo`0000020?oo
o`0404i>CP3oool0oooo06QXJ2H0oooo00<000000?ooo`3oool09P3oool0
04H0oooo00@000000?ooo`3oool00000103oool00`3YjNT0SHf=0?ooo`0P
0?ooo`040000003oool0oooo000000<0oooo00<0YjNW0000003oool08@3o
ool010000000oooo0?ooo`0000020?ooo`040000002=SHd000000=3@d240
oooo00@000000?ooo`3oool000000P3oool0103@d=0000000000003@d=0V
0?ooo`030000003oool0oooo02H0oooo00160?ooo`0406QXJ03alO40jNWY
07alO080oooo00@0CTi>0>WYj@3YjNT000008@3oool0101XJ6P0lO7a0>WY
j@1lO7`30?ooo`030=3@d0000000oooo0240oooo00@0J6QX0?7al@3YjNT0
O7al0P3oool00`2=SHd0jNWY0?ooo`0R0?ooo`0406QXJ03alO40jNWY07al
O080oooo00@0CTi>0?ooo`3oool0CTi>9@3oool00`2WYjL000000?ooo`0W
0?ooo`00AP3oool0102m_Kd000000000002m_Kd20?ooo`040=3@d01>CTh0
CTi>0=3@d240oooo00@0_Kfm000000000000_Kfm0`3oool00`3alO400000
0?ooo`0Q0?ooo`040;fm_@00000000000;fm_@80oooo00@0jNWY06QXJ000
0000/k>c8@3oool0102m_Kd000000000002m_Kd20?ooo`040;>c/`000000
00000;fm_BH0oooo00<0J6QX0?ooo`3oool09P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo2`3oool00`1lO7`0d=3@
07alO00C0?ooo`005P3ooooQ00000003001T00000000000000T000001`3o
ool00`3@d=0000000=3@d00C0?ooo`00803oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<006@0
0?ooo`3oool0403oool00`3alO4000000?7al@0C0?ooo`00803oool00`00
0000O?`007cl003D07cl0003001T003oool0oooo0100oooo00<0d=3@0000
003@d=004`3oool00200oooo00<0000007cl001lo000e01lo0000`00I000
oooo0?ooo`0@0?ooo`0307alO03@d=00O7al01<0oooo000P0?ooo`030000
001lo000O?`00=@0O?`000<006@00?ooo`3oool09P3oool00200oooo00<0
000007cl001lo000e01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool0
0`000000O?`007cl003D07cl0003001T003oool0oooo02H0oooo000P0?oo
o`030000001lo000O?`00=@0O?`000<006@00?ooo`3oool09P3oool00200
oooo00<0000007cl001lo000e01lo0000`00I000oooo0?ooo`0V0?ooo`00
803oool00`000000O?`007cl003D07cl0003001T003oool0oooo02H0oooo
000P0?ooo`030000001lo000O?`00=@0O?`000<006@00?ooo`3oool09P3o
ool00200oooo00<0000007cl001lo000e01lo0000`00I000oooo0?ooo`0V
0?ooo`00803oool00`000000O?`007cl003D07cl0003001T003oool0oooo
02H0oooo000P0?ooo`030000001lo000O?`00=@0O?`000<006@00?ooo`3o
ool09P3oool00200oooo00<0000007cl001lo000e01lo0000`00I000oooo
0?ooo`0V0?ooo`00803oool00`000000O?`007cl003D07cl0003001T003o
ool0oooo02H0oooo000P0?ooo`030000001lo000O?`00=@0O?`000<006@0
0?ooo`3oool09P3oool00200oooo00<0000007cl001lo000e01lo0000`00
I000oooo0?ooo`0V0?ooo`00803oool00`000000O?`007cl003D07cl0003
001T003oool0oooo02H0oooo000P0?ooo`030000001lo000O?`00=@0O?`0
00<006@00?ooo`3oool09P3oool00200oooo00<0000007cl001lo000e01l
o0000`00I000oooo0?ooo`0V0?ooo`00803oool00`000000O?`007cl003D
07cl0003001T003oool0oooo02H0oooo000P0?ooo`030000001lo000O?`0
0=@0O?`000<006@00?ooo`3oool09P3oool00200oooo00<0000007cl001l
o000e01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool00`000000O?`0
07cl003D07cl0003001T003oool0oooo02H0oooo000P0?ooo`030000001l
o000O?`00=@0O?`000<006@00?ooo`3oool09P3oool00200oooo00<00000
07cl001lo000e01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool00`00
0000O?`007cl003D07cl0003001T003oool0oooo02H0oooo000P0?ooo`03
0000001lo000O?`00=@0O?`000<006@00?ooo`3oool09P3oool00200oooo
00<0000007cl001lo000e01lo0000`00I000oooo0?ooo`0V0?ooo`00803o
ool00`000000O?`007cl003D07cl0003001T003oool0oooo02H0oooo000P
0?ooo`030000001lo000O?`00=@0O?`000<006@00?ooo`3oool09P3oool0
0200oooo00<0000007cl001lo000e01lo0000`00I000oooo0?ooo`0V0?oo
o`00803oool00`000000O?`007cl003D07cl0003001T003oool0oooo02H0
oooo000P0?ooo`030000001lo000O?`00=@0O?`000<006@00?ooo`3oool0
9P3oool00200oooo00<0000007cl001lo000e01lo0000`00I000oooo0?oo
o`0V0?ooo`00803oool00`000000O?`007cl003D07cl0003001T003oool0
oooo02H0oooo000P0?ooo`030000001lo000O?`00=@0O?`000<006@00?oo
o`3oool09P3oool00200oooo00<0000007cl001lo000e01lo0000`00I000
oooo0?ooo`0V0?ooo`00403oool01`2c/k<000000000002c/k<0oooo0000
003@d=000P1>CTh00`3@d=00oooo0?ooo`040?ooo`030000001lo000O?`0
0=@0O?`000<006@00?ooo`3oool09P3oool00100oooo00@0J6QX0?7al@3a
lO40J6QX0P3oool0101>CTh0oooo0?ooo`1>CTh60?ooo`030000001lo000
O?`00=@0O?`000<006@00?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000001@3oool00`1>CTh0oooo0?ooo`040?ooo`030000001lo000
O?`00=@0O?`000<006@00?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000000P3oool206QXJ00304i>CP3@d=00oooo00D0oooo00<00000
07cl001lo000e01lo0000`00I000oooo0?ooo`0V0?ooo`00403oool0101X
J6P0lO7a0>WYj@1lO7`20?ooo`030;>c/`37alL0oooo00L0oooo00<00000
07cl001lo000e01lo0000`00I000oooo0?ooo`0V0?ooo`00403oool0102m
_Kd000000000002m_Kd20?ooo`040>WYj@0000000000000000H0oooo00<0
000007cl001lo000e01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool0
0`000000O?`007cl003D07cl0003001T003oool0oooo02H0oooo000P0?oo
o`030000001lo000O?`00=@0O?`000<006@00?ooo`3oool09P3oool00200
oooo00<0000007cl001lo000e01lo0000`00I000oooo0?ooo`0V0?ooo`00
803oool00`000000O?`007cl003D07cl0003001T003oool0oooo02H0oooo
000P0?ooo`030000001lo000O?`00=@0O?`000<006@00?ooo`3oool09P3o
ool00200oooo00<0000007cl001lo000e01lo0000`00I000oooo0?ooo`0V
0?ooo`00803oool00`000000O?`007cl003D07cl0003001T003oool0oooo
02H0oooo000P0?ooo`030000001lo000O?`00=@0O?`000<006@00?ooo`3o
ool09P3oool00200oooo00<0000007cl001lo000e01lo0000`00I000oooo
0?ooo`0V0?ooo`00803oool00`000000O?`007cl003D07cl0003001T003o
ool0oooo02H0oooo000P0?ooo`030000001lo000O?`00=@0O?`000<006@0
0?ooo`3oool09P3oool00200oooo00<0000007cl001lo000e01lo0000`00
I000oooo0?ooo`0V0?ooo`00803oool00`000000O?`007cl003D07cl0003
001T003oool0oooo00H0oooo0`1o:RXM0?ooo`00803oool00`000000O?`0
07cl003D07cl0003001T001o:RX0oooo0080oooo101o:RXP0?ooo`00803o
ool00`000000O?`007cl003C07cl000307lZ:P00I000ObXZ00<0ObXZ903o
ool00200oooo00<0000007cl001lo000d01lo00707lZ:RH0oooo000P0?oo
o`030000001lo000O?`00<`0O?`0101o:RX207cl0004001T003oool0ObXZ
07lZ:RL0oooo000P0?ooo`030000001lo000O?`00<X0O?`00P1o:RX607cl
0003001T003oool0oooo02P0oooo000P0?ooo`030000001lo000O?`00<P0
O?`00P1o:RX707cl0003001T003oool0oooo02T0oooo000P0?ooo`030000
001lo000O?`00<H0O?`00P1o:RX807cl0003001T003oool0oooo02X0oooo
000P0?ooo`030000001lo000O?`00<<0O?`00`1o:RX907cl0003001T003o
ool0oooo02/0oooo000P0?ooo`030000001lo000O?`00<40O?`00P1o:RX;
07cl0003001T003oool0oooo02`0oooo000P0?ooo`030000001lo000O?`0
0;h0O?`00`1o:RX=07cl0003001T003oool0oooo02`0oooo000P0?ooo`03
0000001lo000O?`00;`0O?`00P1o:RX?07cl0003001T003oool0oooo02d0
oooo000P0?ooo`030000001lo000O?`00;X0O?`00P1o:RX@07cl0003001T
003oool0oooo02h0oooo000P0?ooo`030000001lo000O?`00;P0O?`00P1o
:RXA07cl0003001T003oool0oooo02l0oooo000P0?ooo`030000001lo000
O?`00;L0O?`000<0ObXZ07cl001lo000401lo0000`00I000oooo0?ooo`0`
0?ooo`00803oool00`000000O?`007cl002e07cl0080ObXZ4P1lo0000`00
I000oooo0?ooo`0a0?ooo`00803oool00`000000O?`007cl002d07cl0003
07lZ:P1lo000O?`00140O?`000<006@00?ooo`3oool0<P3oool00200oooo
00<0000007cl001lo000/P1lo00207lZ:Q<0O?`000<006@00?ooo`3oool0
<`3oool00200oooo00<0000007cl001lo000/@1lo0000`1o:RX0O?`007cl
000B07cl0003001T003oool0oooo03@0oooo000P0?ooo`030000001lo000
O?`00:l0O?`00P1o:RXD07cl0003001T003oool0oooo03D0oooo000P0?oo
o`030000001lo000O?`00:d0O?`00P1o:RXE07cl0003001T003oool0oooo
03H0oooo000P0?ooo`030000001lo000O?`00:`0O?`000<0ObXZ07cl001l
o000501lo0000`00I000oooo0?ooo`0g0?ooo`00803oool00`000000O?`0
07cl002Z07cl0080ObXZ5P1lo0000`00I000oooo0?ooo`0h0?ooo`006@3o
ool00`000000oooo0?ooo`030?ooo`80ObXZZ`1lo0000`1o:RX0O?`007cl
000E07cl0003001T003oool0oooo03T0oooo000I0?ooo`030000003oool0
oooo0080oooo101o:RZX07cl0080ObXZ5`1lo0000`00I000oooo0?ooo`0j
0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`@0ObXZYP1lo00207lZ
:QL0O?`00P00I00m0?ooo`006@3oool00`000000oooo0?ooo`030?ooo`<0
ObXZY@1lo0000`1o:RX0O?`007cl000F07cl0003001T003oool0oooo03d0
oooo000H0?ooo`030:NWY`000000oooo00D0oooo00@0000007lZ:P00I000
06@0X@1lo00207lZ:QP0O?`000<006@00?ooo`3oool0?P3oool001T0oooo
00<0J6QX0?ooo`3oool0103oool01@000000oooo07lZ:P3oool006@009h0
O?`00P1o:RXI07cl0003001T003oool0oooo03l0oooo000P0?ooo`060000
003oool0oooo07lZ:P3oool006@0W01lo0000`1o:RX0O?`007cl000H07cl
0003001T003oool0oooo0400oooo000P0?ooo`060000003oool0oooo0?oo
o`1o:RX0oooo0P00I02I07cl000307lZ:P1lo000O?`001P0O?`000<006@0
0?ooo`3oool0@@3oool00200oooo00D000000?ooo`3oool0oooo07lZ:P03
0?ooo`03001T001lo000O?`009@0O?`00P1o:RXJ07cl0003001T003oool0
oooo0480oooo000P0?ooo`030000003oool0oooo0080oooo00D0ObXZ0?oo
o`3oool0oooo001T002D07cl000307lZ:P1lo000O?`001T0O?`000<006@0
0?ooo`3oool0@`3oool00200oooo00<000000?ooo`3oool00`3oool01@1o
:RX0oooo0?ooo`3oool006@00980O?`000<0ObXZ07cl001lo000601lo002
001T04H0oooo000P0?ooo`030000003oool0oooo00@0oooo00@0ObXZ0?oo
o`3oool0oooo0P00I02>07cl0080ObXZ6P1lo0000`00I000oooo0?ooo`16
0?ooo`00803oool00`000000oooo0?ooo`040?ooo`0307lZ:P3oool0oooo
00<0oooo00<006@007cl001lo000RP1lo0000`1o:RX0O?`007cl000I07cl
0003001T003oool0oooo04L0oooo000P0?ooo`030000003oool0oooo00D0
oooo00<0ObXZ0?ooo`3oool00`3oool00`00I000O?`007cl002807cl0003
07lZ:P1lo000O?`001P0O?`000<0oooo001T003oool0B@3oool00200oooo
00<000000?ooo`3oool01P3oool00`1o:RX0oooo0?ooo`030?ooo`03001T
001lo000O?`008H0O?`000<0ObXZ07cl001lo000601lo0000`3oool006@0
0?ooo`1:0?ooo`00803oool00`000000oooo0?ooo`070?ooo`0307lZ:P3o
ool0oooo00<0oooo0P00I02407cl0080ObXZ6P1lo002001T04`0oooo000P
0?ooo`030000003oool0oooo00L0oooo00<0ObXZ0?ooo`3oool01@3oool0
0`00I000O?`007cl002007cl000307lZ:P1lo000O?`001T0O?`000<006@0
0?ooo`3oool0C03oool00200oooo00<000000?ooo`3oool0203oool00`1o
:RX0oooo0?ooo`050?ooo`03001T001lo000O?`007h0O?`000<0ObXZ07cl
001lo000601lo002001T04l0oooo000P0?ooo`030000003oool0oooo00T0
oooo00<0ObXZ0?ooo`3oool01@3oool00`00I000O?`007cl001k07cl0080
ObXZ6P1lo0000`00I000oooo0?ooo`1?0?ooo`00803oool00`000000oooo
0?ooo`0:0?ooo`0307lZ:P3oool0oooo00D0oooo00<006@007cl001lo000
N@1lo0000`1o:RX0O?`007cl000H07cl008006@0DP3oool00200oooo00<0
00000?ooo`3oool02P3oool00`1o:RX0oooo0?ooo`060?ooo`03001T001l
o000O?`007L0O?`000<0ObXZ07cl001lo000601lo0000`00I000oooo0?oo
o`1B0?ooo`00803oool00`000000oooo0?ooo`0;0?ooo`0307lZ:P3oool0
oooo00H0oooo0P00I01f07cl000307lZ:P1lo000O?`001P0O?`000<006@0
0?ooo`3oool0D`3oool00200oooo00<000000?ooo`3oool0303oool00`1o
:RX0oooo0?ooo`070?ooo`03001T001lo000O?`00740O?`00P1o:RXI07cl
008006@0EP3oool00200oooo00<000000?ooo`3oool03@3oool00`1o:RX0
oooo0?ooo`070?ooo`03001T001lo000O?`006l0O?`000<0ObXZ07cl001l
o000601lo0000`00I000oooo0?ooo`1F0?ooo`00803oool00`000000oooo
0?ooo`0=0?ooo`0307lZ:P3oool0oooo00P0oooo00<006@007cl001lo000
K@1lo0000`1o:RX0O?`007cl000G07cl00030?ooo`00I000oooo05P0oooo
000P0?ooo`030000003oool0oooo00h0oooo00<0ObXZ0?ooo`3oool0203o
ool2001T06`0O?`000<0ObXZ07cl001lo0005`1lo002001T05X0oooo000P
0?ooo`030000003oool0oooo00l0oooo00<0ObXZ0?ooo`3oool02@3oool2
001T06T0O?`000<0ObXZ07cl001lo0005P1lo0000`3oool006@00?ooo`1K
0?ooo`00803oool00`000000oooo0?ooo`0@0?ooo`0307lZ:P3oool0oooo
00X0oooo0P00I01U07cl0080ObXZ601lo0000`3oool006@00?ooo`1L0?oo
o`00803oool00`000000oooo0?ooo`0A0?ooo`0307lZ:P3oool0oooo00/0
oooo0P00I01R07cl000307lZ:P1lo000O?`001H0O?`000<0oooo001T0000
I000GP3oool00200oooo00<000000?ooo`3oool04P3oool00`1o:RX0oooo
0?ooo`0<0?ooo`03001T001lo000O?`005h0O?`000<0ObXZ07cl001lo000
5P1lo002001T0600oooo000P0?ooo`030000003oool0oooo01<0oooo00<0
ObXZ0?ooo`3oool0303oool2001T05d0O?`000<0ObXZ07cl001lo0005@1l
o002001T0680oooo000P0?ooo`030000003oool0oooo01<0oooo00<0ObXZ
0?ooo`3oool03P3oool2001T05X0O?`000<0ObXZ07cl001lo000501lo002
001T06@0oooo000P0?ooo`030000003oool0oooo01@0oooo00<0ObXZ0?oo
o`3oool03`3oool2001T05H0O?`00P1o:RXE07cl008006@0IP3oool00200
oooo00<000000?ooo`3oool05@3oool00`1o:RX0oooo0?ooo`0@0?ooo`80
06@0D`1lo0000`1o:RX0O?`007cl000C07cl008006@0J03oool00200oooo
00<000000?ooo`3oool05P3oool00`1o:RX0oooo0?ooo`0A0?ooo`8006@0
D01lo0000`1o:RX0O?`007cl000B07cl008006@0JP3oool00200oooo00<0
00000?ooo`3oool05`3oool00`1o:RX0oooo0?ooo`0B0?ooo`8006@0C01l
o00207lZ:Q<0O?`00P00I01/0?ooo`00803oool00`000000oooo0?ooo`0H
0?ooo`0307lZ:P3oool0oooo01<0oooo0P00I01907cl000307lZ:P1lo000
O?`00100O?`00`00I01^0?ooo`00803oool00`000000oooo0?ooo`0I0?oo
o`0307lZ:P3oool0oooo01@0oooo0P00I01507cl0080ObXZ4@1lo002001T
0740oooo000P0?ooo`030000003oool0oooo01X0oooo00<0ObXZ0?ooo`3o
ool05@3oool3001T0440O?`000<0ObXZ07cl001lo0003`1lo002001T07<0
oooo000P0?ooo`030000003oool0oooo01/0oooo00<0ObXZ0?ooo`3oool0
5`3oool2001T03d0O?`00P1o:RX@07cl008006@0M@3oool00200oooo00<0
00000?ooo`3oool0703oool00`1o:RX0oooo0?ooo`0H0?ooo`8006@0>P1l
o0000`1o:RX0O?`007cl000=07cl00<006@0M`3oool00180oooo00D00000
0?ooo`3oool000000=3@d00204i>CP030=3@d03oool0oooo00@0oooo00<0
00000?ooo`3oool07@3oool207lZ:QX0oooo0P00I00f07cl0080ObXZ3@1l
o003001T07X0oooo000B0?ooo`050000003oool0oooo0?ooo`1>CTh00P3o
ool00`1>CTh0oooo0?ooo`040?ooo`<000007`3oool00`1o:RX0oooo0?oo
o`0I0?ooo`@006@0<@1lo0000`1o:RX0O?`007cl000:07cl00<006@0O@3o
ool00180oooo00<000000?ooo`3oool0103oool00`1>CTh0oooo0?ooo`04
0?ooo`030000003oool0oooo0200oooo00<0ObXZ0?ooo`3oool0703oool4
001T02/0O?`00P1o:RX907cl00@006@0P03oool00180oooo00@000000?oo
o`3oool0oooo0P1XJ6P00`1>CTh0d=3@0?ooo`050?ooo`030000003oool0
oooo0240oooo00<0ObXZ0?ooo`3oool07`3oool5001T02D0O?`000<0ObXZ
07cl001lo0001@1lo004001T08@0oooo000A0?ooo`030:NWY`000000oooo
0080oooo00<0/k>c0<O7a`3oool01`3oool00`000000oooo0?ooo`0R0?oo
o`0307lZ:P3oool0oooo02<0oooo1000I00L07cl0080ObXZ00<0O?`007lZ
:P1o:RX0101lo004001T08P0oooo000B0?ooo`0506QXJ03oool0oooo0?oo
o`3YjNT00`0000060?ooo`030000003oool0oooo02<0oooo00<0ObXZ0?oo
o`3oool09P3oool8001T01<0O?`0101o:RX6001T08`0oooo000P0?ooo`03
0000003oool0oooo02@0oooo0P1o:RX^0?oooa<006@0101o:RZB0?ooo`00
803oool00`000000oooo0?ooo`0V0?ooo`0307lZ:P3oool0oooo03d0oooo
101o:RZC0?ooo`00803oool00`000000oooo0?ooo`0W0?ooo`80ObXZ>`3o
ool207lZ:YL0oooo000P0?ooo`030000003oool0oooo02T0oooo0P1o:RXf
0?ooo`<0ObXZV@3oool00200oooo00<000000?ooo`3oool0:`3oool00`1o
:RX0oooo0?ooo`0a0?ooo`80ObXZW03oool00200oooo00<000000?ooo`3o
ool0;03oool207lZ:Rl0oooo0P1o:RZN0?ooo`00803oool00`000000oooo
0?ooo`0^0?ooo`<0ObXZ:P3oool207lZ:Z00oooo000P0?ooo`030000003o
ool0oooo0340oooo0P1o:RXU0?ooo`<0ObXZXP3oool00200oooo00<00000
0?ooo`3oool0<`3oool207lZ:R40oooo0P1o:RZU0?ooo`00803oool00`00
0000oooo0?ooo`0e0?ooo`80ObXZ6`3oool407lZ:ZL0oooo000P0?ooo`03
0000003oool0oooo03L0oooo1@1o:RXC0?ooo`<0ObXZZ`3oool00200oooo
00<000000?ooo`3oool0?03ooolC07lZ:Zh0oooo000P0?ooo`030000003o
ool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?oo
o`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0
oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003o
ool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?oo
o`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo000O0?ooo`0309^KV`3o
ool0oooo0?h0oooo000O0?ooo`0304i>CP3oool0oooo0?h0oooo000N0?oo
o`030?7al@000000jNWY0?l0oooo000N0?ooo`030;>c/`2=SHd0YjNW0?l0
oooo000N0?ooo`0304i>CP3alO40J6QX0?l0oooo000M0?ooo`050=3@d02W
YjL0oooo0:NWY`3@d=00oP3oool001d0oooo00D0O7al0>WYj@3oool0jNWY
07alO03n0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "\n\t\tT",
  StyleBox["rapezoidal Rule\t\t\t\t\t\tSimpson\[CloseCurlyQuote]s Rule",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
AP3oool01`2c/k<000000000002c/k<0oooo0000001>CTh00`00000Q0?oo
o`060;>c/`00000000000;>c/`3oool000000P3oool00`000000oooo0?oo
o`0P0?ooo`070;>c/`00000000000;>c/`3oool000000>7Qh@0204i>CP03
0=3@d03oool0oooo01l0oooo00L0/k>c000000000000/k>c0?ooo`000000
d=3@0080CTi>00<0d=3@0?ooo`3oool0903oool00`000000oooo0?ooo`0V
0?ooo`00AP3oool0101XJ6P0lO7a0?7al@1XJ6P20?ooo`030=3@d02=SHd0
oooo0280oooo00@0J6QX0?7al@3alO40J6QX0`3oool300000240oooo00@0
J6QX0?7al@3alO40J6QX0P3oool0101lO7`0lO7a0?ooo`1>CThQ0?ooo`04
06QXJ03alO40lO7a06QXJ080oooo00@0J6QX0?ooo`3oool0CTi>9P3oool0
0`000000oooo0?ooo`0V0?ooo`00AP3oool010000000oooo0?ooo`000004
0?ooo`030:NWY`3oool0oooo0200oooo00@000000?ooo`3oool000000`3o
ool00`1XJ6P000000?ooo`0Q0?ooo`040000003oool0oooo00000080oooo
00@000000>WYj@3oool0CTi>8@3oool010000000oooo0?ooo`0000020?oo
o`0404i>CP3oool0oooo06QXJ2H0oooo00<000000?ooo`3oool09P3oool0
04H0oooo00@000000?ooo`3oool00000103oool00`3YjNT0SHf=0?ooo`0P
0?ooo`040000003oool0oooo000000<0oooo00<0YjNW0000003oool08@3o
ool010000000oooo0?ooo`0000020?ooo`040000002=SHd000000=3@d240
oooo00@000000?ooo`3oool000000P3oool0103@d=0000000000003@d=0V
0?ooo`030000003oool0oooo02H0oooo00160?ooo`0406QXJ03alO40jNWY
07alO080oooo00@0CTi>0>WYj@3YjNT000008@3oool0101XJ6P0lO7a0>WY
j@1lO7`30?ooo`030=3@d0000000oooo0240oooo00@0J6QX0?7al@3YjNT0
O7al0P3oool00`2=SHd0jNWY0?ooo`0R0?ooo`0406QXJ03alO40jNWY07al
O080oooo00@0CTi>0?ooo`3oool0CTi>9@3oool00`2WYjL000000?ooo`0W
0?ooo`00AP3oool0102m_Kd000000000002m_Kd20?ooo`040=3@d01>CTh0
CTi>0=3@d240oooo00@0_Kfm000000000000_Kfm0`3oool00`3alO400000
0?ooo`0Q0?ooo`040;fm_@00000000000;fm_@80oooo00@0jNWY06QXJ000
0000/k>c8@3oool0102m_Kd000000000002m_Kd20?ooo`040;>c/`000000
00000;fm_BH0oooo00<0J6QX0?ooo`3oool09P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo2`3oool00`1lO7`0d=3@
07alO00C0?ooo`005P3ooooQ000000030?mo00000000000000T000001`3o
ool00`3@d=0000000=3@d00C0?ooo`00803oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<0ogl0
0?ooo`3oool0403oool00`3alO4000000?7al@0C0?ooo`00803oool00`00
0000ool00?oo003D0?oo00030?mo003oool0oooo0100oooo00<0d=3@0000
003@d=004`3oool00200oooo00<000000?oo003oo`00e03oo`000`3oO`00
oooo0?ooo`0@0?ooo`0307alO03@d=00O7al01<0oooo000P0?ooo`030000
003oo`00ool00=@0ool000<0ogl00?ooo`3oool09P3oool00200oooo00<0
00000?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00803oool0
0`000000ool00?oo003D0?oo00030?mo003oool0oooo02H0oooo000P0?oo
o`030000003oo`00ool00=@0ool000<0ogl00?ooo`3oool09P3oool00200
oooo00<000000?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00
803oool00`000000ool00?oo003D0?oo00030?mo003oool0oooo02H0oooo
000P0?ooo`030000003oo`00ool00=@0ool000<0ogl00?ooo`3oool09P3o
ool00200oooo00<000000?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V
0?ooo`00803oool00`000000ool00?oo003D0?oo00030?mo003oool0oooo
02H0oooo000P0?ooo`030000003oo`00ool00=@0ool000<0ogl00?ooo`3o
ool09P3oool00200oooo00<000000?oo003oo`00e03oo`000`3oO`00oooo
0?ooo`0V0?ooo`00803oool00`000000ool00?oo003D0?oo00030?mo003o
ool0oooo02H0oooo000P0?ooo`030000003oo`00ool00=@0ool000<0ogl0
0?ooo`3oool09P3oool00200oooo00<000000?oo003oo`00e03oo`000`3o
O`00oooo0?ooo`0V0?ooo`00803oool00`000000ool00?oo003D0?oo0003
0?mo003oool0oooo02H0oooo000P0?ooo`030000003oo`00ool00=@0ool0
00<0ogl00?ooo`3oool09P3oool00200oooo00<000000?oo003oo`00e03o
o`000`3oO`00oooo0?ooo`0V0?ooo`00803oool00`000000ool00?oo003D
0?oo00030?mo003oool0oooo02H0oooo000P0?ooo`030000003oo`00ool0
0=@0ool000<0ogl00?ooo`3oool09P3oool00200oooo00<000000?oo003o
o`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00803oool00`000000ool0
0?oo003D0?oo00030?mo003oool0oooo02H0oooo000P0?ooo`030000003o
o`00ool00=@0ool000<0ogl00?ooo`3oool09P3oool00200oooo00<00000
0?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00803oool00`00
0000ool00?oo003D0?oo00030?mo003oool0oooo02H0oooo000P0?ooo`03
0000003oo`00ool00=@0ool000<0ogl00?ooo`3oool09P3oool00200oooo
00<000000?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00803o
ool00`000000ool00?oo003D0?oo00030?mo003oool0oooo02H0oooo000P
0?ooo`030000003oo`00ool00=@0ool000<0ogl00?ooo`3oool09P3oool0
0200oooo00<000000?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?oo
o`00803oool00`000000ool00?oo003D0?oo00030?mo003oool0oooo02H0
oooo000P0?ooo`030000003oo`00ool00=@0ool000<0ogl00?ooo`3oool0
9P3oool00200oooo00<000000?oo003oo`00e03oo`000`3oO`00oooo0?oo
o`0V0?ooo`00803oool00`000000ool00?oo003D0?oo00030?mo003oool0
oooo02H0oooo000P0?ooo`030000003oo`00ool00=@0ool000<0ogl00?oo
o`3oool09P3oool00200oooo00<000000?oo003oo`00e03oo`000`3oO`00
oooo0?ooo`0V0?ooo`00403oool01`2c/k<000000000002c/k<0oooo0000
003@d=000P1>CTh00`3@d=00oooo0?ooo`040?ooo`030000003oo`00ool0
0=@0ool000<0ogl00?ooo`3oool09P3oool00100oooo00@0J6QX0?7al@3a
lO40J6QX0P3oool0101>CTh0oooo0?ooo`1>CTh60?ooo`030000003oo`00
ool00=@0ool000<0ogl00?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000001@3oool00`1>CTh0oooo0?ooo`040?ooo`030000003oo`00
ool00=@0ool000<0ogl00?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000000P3oool206QXJ00304i>CP3@d=00oooo00D0oooo00<00000
0?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00403oool0101X
J6P0lO7a0>WYj@1lO7`20?ooo`030;>c/`37alL0oooo00L0oooo00<00000
0?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00403oool0102m
_Kd000000000002m_Kd20?ooo`040>WYj@0000000000000000H0oooo00<0
00000?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00803oool0
0`000000ool00?oo003D0?oo00030?mo003oool0oooo02H0oooo000P0?oo
o`030000003oo`00ool00=@0ool000<0ogl00?ooo`3oool09P3oool00200
oooo00<000000?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V0?ooo`00
803oool00`000000ool00?oo003D0?oo00030?mo003oool0oooo02H0oooo
000P0?ooo`030000003oo`00ool00=@0ool000<0ogl00?ooo`3oool09P3o
ool00200oooo00<000000?oo003oo`00e03oo`000`3oO`00oooo0?ooo`0V
0?ooo`00803oool00`000000ool00?oo003D0?oo00030?mo003oool0oooo
02H0oooo000P0?ooo`030000003oo`00ool00=@0ool000<0ogl00?ooo`3o
ool09P3oool00200oooo00<000000?oo003oo`00e03oo`000`3oO`00oooo
0?ooo`0V0?ooo`00803oool00`000000ool00?oo003D0?oo00030?mo003o
ool0oooo02H0oooo000P0?ooo`030000003oo`00ool00=@0ool000<0ogl0
0?ooo`3oool09P3oool00200oooo00<000000?oo003oo`00e03oo`000`3o
O`00oooo0?ooo`0V0?ooo`00803oool00`000000ool00?oo003D0?oo0003
0?mo003oool0oooo00H0oooo0`1o:RXM0?ooo`00803oool00`000000ool0
0?oo003D0?oo00030?mo001o:RX0oooo0080oooo101o:RXP0?ooo`00803o
ool00`000000ool00?oo003B0?oo00030?mo001o:RX0ogl000@0ObXZ903o
ool00200oooo00<000000?oo003oo`00c`3oo`000`3oO`00ObXZ07lZ:P05
07lZ:RH0oooo000P0?ooo`030000003oo`00ool00</0ool000<0oooo07lZ
:P1o:RX00P1o:RX40?ooo`80ObXZ9`3oool00200oooo00<000000?oo003o
o`00b@3oo`00103oool0ObXZ07lZ:P3oO`0`0?ooo`00803oool00`000000
ool00?oo00370?oo00030?mo001o:RX0ObXZ03<0oooo000P0?ooo`030000
003oo`00ool00<@0ool00P3oO`0207lZ:SD0oooo000P0?ooo`030000003o
o`00ool00<80ool000@0ogl007lZ:P1o:RX0ObXZ=`3oool00200oooo00<0
00000?oo003oo`00`03oo`000`3oO`00ObXZ07lZ:P0j0?ooo`00803oool0
0`000000ool00?oo002n0?oo00<0ObXZ?03oool00200oooo00<000000?oo
003oo`00_03oo`0207lZ:Sl0oooo000P0?ooo`030000003oo`00ool00;X0
ool00P1o:RY10?ooo`00803oool00`000000ool00?oo002h0?oo0080ObXZ
@`3oool00200oooo00<000000?oo003oo`00]`3oo`000`1o:RX0ogl00?oo
o`130?ooo`00803oool00`000000ool00?oo002e0?oo0080ObXZAP3oool0
0200oooo00<000000?oo003oo`00/`3oo`000`3oO`00ObXZ0?ooo`170?oo
o`00803oool00`000000ool00?oo002a0?oo00030?mo001o:RX0ObXZ04T0
oooo000P0?ooo`030000003oo`00ool00;00ool000<0ogl007lZ:P3oool0
BP3oool00200oooo00<000000?oo003oo`00[P3oo`000`3oO`00ObXZ07lZ
:P1<0?ooo`00803oool00`000000ool00?oo002]0?oo0080ObXZCP3oool0
0200oooo00<000000?oo003oo`00Z`3oo`000`3oO`00ObXZ0?ooo`1?0?oo
o`00803oool00`000000ool00?oo002Z0?oo0080ObXZD@3oool001T0oooo
00<000000?ooo`3oool00`3oool207lZ:ZX0ool000<0ogl007lZ:P3oool0
DP3oool001T0oooo00<000000?ooo`3oool00P3oool407lZ:ZP0ool00P1o
:RYD0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`@0ObXZYP3oo`02
07lZ:UH0oooo000I0?ooo`030000003oool0oooo00<0oooo0`1o:RZU0?oo
000307lZ:P3oO`00oooo05H0oooo000H0?ooo`030:NWY`000000oooo00D0
oooo00<0000007lZ:P3oo`00XP3oo`0207lZ:UT0oooo000I0?ooo`0306QX
J03oool0oooo00@0oooo00<000000?ooo`1o:RX0X03oo`0207lZ:P030?mo
003oool0oooo05P0oooo000P0?ooo`040000003oool0ogl007lZ:Yh0ool0
00<0ObXZ0?mo003oO`00F`3oool00200oooo00D000000?ooo`3oool0ogl0
07lZ:P2L0?oo000307lZ:P3oO`00oooo05`0oooo000P0?ooo`050000003o
ool0oooo0?ooo`1o:RX0VP3oo`0207lZ:P030?mo003oool0oooo05`0oooo
000P0?ooo`060000003oool0oooo0?ooo`3oO`00ObXZV03oo`000`1o:RX0
ool00?mo001O0?ooo`00803oool00`000000oooo0?ooo`020?ooo`030?mo
001o:RX0ool009D0ool000<0ObXZ0?mo003oO`00H03oool00200oooo00<0
00000?ooo`3oool00P3oool00`3oO`00ool007lZ:P2C0?oo0080ObXZ00<0
ogl00?ooo`3oool0H03oool00200oooo00<000000?ooo`3oool00`3oool0
0`3oO`00ObXZ0?oo002A0?oo000307lZ:P3oo`00ogl006<0oooo000P0?oo
o`030000003oool0oooo00@0oooo00<0ogl007lZ:P3oo`00S`3oo`000`1o
:RX0ogl00?mo001T0?ooo`00803oool00`000000oooo0?ooo`040?ooo`03
0?mo003oo`00ObXZ08h0ool000<0ObXZ0?mo003oool0I@3oool00200oooo
00<000000?ooo`3oool01@3oool00`3oO`00ool007lZ:P2;0?oo0080ObXZ
00<0ogl00?ooo`3oool0I@3oool00200oooo00<000000?ooo`3oool01@3o
ool00`3oO`00ool007lZ:P2:0?oo000307lZ:P3oO`00ogl006P0oooo000P
0?ooo`030000003oool0oooo00H0oooo00<0ogl00?oo001o:RX0R03oo`00
0`1o:RX0ogl00?ooo`1Y0?ooo`00803oool00`000000oooo0?ooo`070?oo
o`030?mo003oo`00ObXZ08D0ool00P1o:RX00`3oO`00oooo0?ooo`1Y0?oo
o`00803oool00`000000oooo0?ooo`080?ooo`030?mo003oo`00ObXZ08<0
ool000<0ObXZ0?mo003oO`00K03oool00200oooo00<000000?ooo`3oool0
203oool00`3oO`00ool007lZ:P210?oo0080ObXZ00<0ogl00?ooo`3oool0
K03oool00200oooo00<000000?ooo`3oool02@3oool00`3oO`00ool007lZ
:P1o0?oo00@0ObXZKP3oool00200oooo00<000000?ooo`3oool02P3oool0
0`3oO`00ool007lZ:P1m0?oo00D0ObXZKP3oool00200oooo00<000000?oo
o`3oool02`3oool00`3oO`00ool007lZ:P1k0?oo000307lZ:P3oO`00oooo
0080ObXZK`3oool00200oooo00<000000?ooo`3oool02`3oool00`3oO`00
ool007lZ:P1j0?oo000307lZ:P3oO`00oooo0780oooo000P0?ooo`030000
003oool0oooo00`0oooo00<0ogl00?oo001o:RX0N03oo`000`1o:RX0ogl0
0?ooo`1c0?ooo`00803oool00`000000oooo0?ooo`0=0?ooo`030?mo003o
o`00ObXZ07H0ool000<0ObXZ0?ooo`3oool0M03oool00200oooo00<00000
0?ooo`3oool03P3oool00`3oO`00ool007lZ:P1c0?oo0080ObXZM`3oool0
0200oooo00<000000?ooo`3oool03P3oool0103oO`00ool00?oo001o:RYa
0?oo000307lZ:P3oool0oooo07L0oooo000P0?ooo`030000003oool0oooo
00l0oooo00@0ogl00?oo003oo`00ObXZK`3oo`000`1o:RX0oooo0?ooo`1h
0?ooo`00803oool00`000000oooo0?ooo`0@0?ooo`040?mo003oo`00ool0
07lZ:V`0ool000<0ogl007lZ:P3oool0NP3oool00200oooo00<000000?oo
o`3oool04@3oool00`3oO`00ool007lZ:P1[0?oo00030?mo001o:RX0oooo
07/0oooo000P0?ooo`030000003oool0oooo0180oooo00<0ogl00?oo001o
:RX0J@3oo`0207lZ:Wd0oooo000P0?ooo`030000003oool0oooo0180oooo
00@0ogl00?oo003oo`00ObXZIP3oo`000`3oO`00ObXZ0?ooo`1n0?ooo`00
803oool00`000000oooo0?ooo`0C0?ooo`040?mo003oo`00ool007lZ:V@0
ool000<0ogl007lZ:P3oool0O`3oool00200oooo00<000000?ooo`3oool0
503oool0103oO`00ool00?oo001o:RYQ0?oo00030?mo001o:RX0ObXZ0840
oooo000P0?ooo`030000003oool0oooo01D0oooo00@0ogl00?oo003oo`00
ObXZG`3oo`000`3oO`00ObXZ0?ooo`220?ooo`00803oool00`000000oooo
0?ooo`0F0?ooo`040?mo003oo`00ool007lZ:U`0ool000<0ogl007lZ:P1o
:RX0Q03oool00200oooo00<000000?ooo`3oool05P3oool01@3oO`00ool0
0?oo003oo`00ObXZ05X0ool000<0ogl007lZ:P3oool0Q@3oool00200oooo
00<000000?ooo`3oool05`3oool01@3oO`00ool00?oo003oo`00ObXZ05L0
ool000<0ogl007lZ:P1o:RX0Q`3oool00200oooo00<000000?ooo`3oool0
603oool01@3oO`00ool00?oo003oo`00ObXZ05D0ool000<0ogl007lZ:P3o
ool0R03oool00180oooo00D000000?ooo`3oool000000=3@d00204i>CP03
0=3@d03oool0oooo00@0oooo00<000000?ooo`3oool06@3oool0103oO`00
ool00?oo003oo`0207lZ:U40ool000<0ogl007lZ:P1o:RX0RP3oool00180
oooo00D000000?ooo`3oool0oooo04i>CP020?ooo`0304i>CP3oool0oooo
00@0oooo0`00000J0?ooo`80ogl00`3oo`000`1o:RX0ool00?oo001<0?oo
0080ogl000<0ObXZ0?ooo`3oool0RP3oool00180oooo00<000000?ooo`3o
ool0103oool00`1>CTh0oooo0?ooo`040?ooo`030000003oool0oooo01`0
oooo00D0ogl00?oo003oo`00ool007lZ:P1<0?oo00030?mo001o:RX0ObXZ
08d0oooo000B0?ooo`040000003oool0oooo0?ooo`80J6QX00<0CTi>0=3@
d03oool01@3oool00`000000oooo0?ooo`0M0?ooo`050?mo003oo`00ool0
0?oo001o:RX0B@3oo`020?mo000307lZ:P3oool0oooo08d0oooo000A0?oo
o`030:NWY`000000oooo0080oooo00<0/k>c0<O7a`3oool01`3oool00`00
0000oooo0?ooo`0N0?ooo`80ogl00P3oo`000`1o:RX0ool00?oo00140?oo
0080ogl00P1o:RZ@0?ooo`004P3oool01@1XJ6P0oooo0?ooo`3oool0jNWY
00<000001P3oool00`000000oooo0?ooo`0P0?ooo`040?mo003oo`00ool0
07lZ:T@0ool000<0ogl00?ooo`1o:RX0TP3oool00200oooo00<000000?oo
o`3oool08@3oool00`3oO`00ool00?oo000207lZ:T00ool00P3oO`0207lZ
:Y<0oooo000P0?ooo`030000003oool0oooo0280oooo00D0ogl00?oo003o
o`00ool007lZ:P0n0?oo00030?mo001o:RX0ObXZ09D0oooo000P0?ooo`03
0000003oool0oooo02<0oooo0P3oO`020?oo0080ObXZ>P3oo`000`3oO`00
ObXZ07lZ:P2G0?ooo`00803oool00`000000oooo0?ooo`0U0?ooo`040?mo
003oo`00ool00?oo0080ObXZ=P3oo`0307lZ:YT0oooo000P0?ooo`030000
003oool0oooo02H0oooo00<0ogl00?oo003oo`000P3oo`000`1o:RX0ool0
0?oo000a0?oo0080ObXZW03oool00200oooo00<000000?ooo`3oool09`3o
ool20?mo00<0ool00P1o:RX^0?oo00030?mo001o:RX0ObXZ09h0oooo000P
0?ooo`030000003oool0oooo02T0oooo0`3oO`020?oo00<0ObXZ9`3oo`03
0?mo0080ObXZX03oool00200oooo00<000000?ooo`3oool0;03oool20?mo
00<0ool00P1o:RXS0?oo0080ogl00`1o:RZR0?ooo`00803oool00`000000
oooo0?ooo`0^0?ooo`<0ogl00P3oo`0207lZ:Ql0ool00P3oO`0207lZ:ZD0
oooo000P0?ooo`030000003oool0oooo0340oooo103oO`0207lZ:QT0ool0
0P3oO`0407lZ:ZL0oooo000P0?ooo`030000003oool0oooo03@0oooo00<0
ool00?mo003oO`001@1o:RX80?oo0080ObXZ1@3oo`040?mo00<0ObXZZ`3o
ool00200oooo00<000000?ooo`3oool0>03oool0103oo`00ogl00?mo003o
O`0C07lZ:Zh0oooo000P0?ooo`030000003oool0oooo04<0oooo101o:RZf
0?ooo`00803oool00`000000oooo0?ooo`140?ooo`80ObXZ]`3oool00200
oooo00<000000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0
o@3oool00200oooo00<000000?ooo`3oool0o@3oool00200oooo00<00000
0?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool00200
oooo00<000000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0
o@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001l0oooo00<0Vi^K
0?ooo`3oool0oP3oool001l0oooo00<0CTi>0?ooo`3oool0oP3oool001h0
oooo00<0lO7a0000003YjNT0o`3oool001h0oooo00<0/k>c08f=S@2WYjL0
o`3oool001h0oooo00<0CTi>0?7al@1XJ6P0o`3oool001d0oooo00D0d=3@
0:NWY`3oool0YjNW0=3@d03n0?ooo`007@3oool01@1lO7`0jNWY0?ooo`3Y
jNT0O7al0?h0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
AP3oool01`2c/k<000000000002c/k<0oooo0000001>CTh00`00000Q0?oo
o`060;>c/`00000000000;>c/`3oool000000P3oool00`000000oooo0?oo
o`0P0?ooo`070;>c/`00000000000;>c/`3oool000000>7Qh@0204i>CP03
0=3@d03oool0oooo01l0oooo00L0/k>c000000000000/k>c0?ooo`000000
d=3@0080CTi>00<0d=3@0?ooo`3oool0903oool00`000000oooo0?ooo`0V
0?ooo`00AP3oool0101XJ6P0lO7a0?7al@1XJ6P20?ooo`030=3@d02=SHd0
oooo0280oooo00@0J6QX0?7al@3alO40J6QX0`3oool300000240oooo00@0
J6QX0?7al@3alO40J6QX0P3oool0101lO7`0lO7a0?ooo`1>CThQ0?ooo`04
06QXJ03alO40lO7a06QXJ080oooo00@0J6QX0?ooo`3oool0CTi>9P3oool0
0`000000oooo0?ooo`0V0?ooo`00AP3oool010000000oooo0?ooo`000004
0?ooo`030:NWY`3oool0oooo0200oooo00@000000?ooo`3oool000000`3o
ool00`1XJ6P000000?ooo`0Q0?ooo`040000003oool0oooo00000080oooo
00@000000>WYj@3oool0CTi>8@3oool010000000oooo0?ooo`0000020?oo
o`0404i>CP3oool0oooo06QXJ2H0oooo00<000000?ooo`3oool09P3oool0
04H0oooo00@000000?ooo`3oool00000103oool00`3YjNT0SHf=0?ooo`0P
0?ooo`040000003oool0oooo000000<0oooo00<0YjNW0000003oool08@3o
ool010000000oooo0?ooo`0000020?ooo`040000002=SHd000000=3@d240
oooo00@000000?ooo`3oool000000P3oool0103@d=0000000000003@d=0V
0?ooo`030000003oool0oooo02H0oooo00160?ooo`0406QXJ03alO40jNWY
07alO080oooo00@0CTi>0>WYj@3YjNT000008@3oool0101XJ6P0lO7a0>WY
j@1lO7`30?ooo`030=3@d0000000oooo0240oooo00@0J6QX0?7al@3YjNT0
O7al0P3oool00`2=SHd0jNWY0?ooo`0R0?ooo`0406QXJ03alO40jNWY07al
O080oooo00@0CTi>0?ooo`3oool0CTi>9@3oool00`2WYjL000000?ooo`0W
0?ooo`00AP3oool0102m_Kd000000000002m_Kd20?ooo`040=3@d01>CTh0
CTi>0=3@d240oooo00@0_Kfm000000000000_Kfm0`3oool00`3alO400000
0?ooo`0Q0?ooo`040;fm_@00000000000;fm_@80oooo00@0jNWY06QXJ000
0000/k>c8@3oool0102m_Kd000000000002m_Kd20?ooo`040;>c/`000000
00000;fm_BH0oooo00<0J6QX0?ooo`3oool09P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo2`3oool00`1lO7`0d=3@
07alO00C0?ooo`005P3ooooQ000000030?l000000000000000T000001`3o
ool00`3@d=0000000=3@d00C0?ooo`00803oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<0o`00
0?ooo`3oool0403oool00`3alO4000000?7al@0C0?ooo`00803oool00`00
0000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo0100oooo00<0d=3@0000
003@d=004`3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000
oooo0?ooo`0@0?ooo`0307alO03@d=00O7al01<0oooo000P0?ooo`030000
003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200oooo00<0
00000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803oool0
0`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P0?oo
o`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200
oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00
803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo
000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3o
ool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V
0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo
02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3o
ool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo
0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003o
ool0oooo02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`00
0?ooo`3oool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o
0000oooo0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`03
0?l0003oool0oooo02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;
00<0o`000?ooo`3oool09P3oool00200oooo00<000000?o0b`3o`</0e03o
`</00`3o0000oooo0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D
0?o0b`030?l0003oool0oooo02H0oooo000P0?ooo`030000003o`</0ol3;
0=@0ol3;00<0o`000?ooo`3oool09P3oool00200oooo00<000000?o0b`3o
`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803oool00`000000ol3;
0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P0?ooo`030000003o
`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200oooo00<00000
0?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803oool00`00
0000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P0?ooo`03
0000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200oooo
00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803o
ool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P
0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool0
0200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?oo
o`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0
oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool0
9P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?oo
o`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0
oooo02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?oo
o`3oool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000
oooo0?ooo`0V0?ooo`00403oool01`2c/k<000000000002c/k<0oooo0000
003@d=000P1>CTh00`3@d=00oooo0?ooo`040?ooo`030000003o`</0ol3;
0=@0ol3;00<0o`000?ooo`3oool09P3oool00100oooo00@0J6QX0?7al@3a
lO40J6QX0P3oool0101>CTh0oooo0?ooo`1>CTh60?ooo`030000003o`</0
ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000001@3oool00`1>CTh0oooo0?ooo`040?ooo`030000003o`</0
ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000000P3oool206QXJ00304i>CP3@d=00oooo00D0oooo00<00000
0?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00403oool0101X
J6P0lO7a0>WYj@1lO7`20?ooo`030;>c/`37alL0oooo00L0oooo00<00000
0?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00403oool0102m
_Kd000000000002m_Kd20?ooo`040>WYj@0000000000000000H0oooo00<0
00000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803oool0
0`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P0?oo
o`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200
oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00
803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo
000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3o
ool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V
0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo
02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3o
ool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo
0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003o
ool0oooo02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`00
0?ooo`3oool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o
0000oooo0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`03
0?l0003oool0oooo00H0oooo0`1o:RXM0?ooo`00803oool00`000000ol3;
0?o0b`3D0?o0b`030?l0001o:RX0oooo0080oooo101o:RXP0?ooo`00803o
ool00`000000ol3;0?o0b`3A0?o0b`80o`0000<0ObXZ0?l0001o:RX00`1o
:RXT0?ooo`00803oool00`000000ol3;0?o0b`3>0?o0b`80o`001`1o:RXV
0?ooo`00803oool00`000000ol3;0?o0b`3:0?o0b`80o`00101o:RX40?oo
o`80ObXZ9`3oool00200oooo00<000000?o0b`3o`</0aP3o`</40?l00080
ObXZ<@3oool00200oooo00<000000?o0b`3o`</0a03o`</20?l00080oooo
0P1o:RXc0?ooo`00803oool00`000000ol3;0?o0b`320?o0b`80o`000P3o
ool207lZ:SD0oooo000P0?ooo`030000003o`</0ol3;0<00ol3;0P3o0000
103oool0ObXZ07lZ:P1o:RXg0?ooo`00803oool00`000000ol3;0?o0b`2n
0?o0b`80o`0000<0oooo07lZ:P1o:RX0>P3oool00200oooo00<000000?o0
b`3o`</0_03o`</20?l000<0ObXZ?03oool00200oooo00<000000?o0b`3o
`</0^P3o`</20?l00080ObXZ?`3oool00200oooo00<000000?o0b`3o`</0
^@3o`</00`3o0000ObXZ07lZ:P110?ooo`00803oool00`000000ol3;0?o0
b`2g0?o0b`030?l0001o:RX0ObXZ04<0oooo000P0?ooo`030000003o`</0
ol3;0;D0ol3;0P3o00000`1o:RX0oooo0?ooo`130?ooo`00803oool00`00
0000ol3;0?o0b`2c0?o0b`80o`000P1o:RY60?ooo`00803oool00`000000
ol3;0?o0b`2a0?o0b`80o`0000<0oooo07lZ:P3oool0A`3oool00200oooo
00<000000?o0b`3o`</0/03o`</0103o0000oooo07lZ:P1o:RY90?ooo`00
803oool00`000000ol3;0?o0b`2_0?o0b`030?l0003oool0ObXZ04/0oooo
000P0?ooo`030000003o`</0ol3;0:d0ol3;0P3o000207lZ:T`0oooo000P
0?ooo`030000003o`</0ol3;0:`0ol3;00<0o`0007lZ:P1o:RX0CP3oool0
0200oooo00<000000?o0b`3o`</0ZP3o`</00`3oool0o`0007lZ:P1@0?oo
o`00803oool00`000000ol3;0?o0b`2Y0?o0b`030?l0001o:RX0ObXZ0540
oooo000I0?ooo`030000003oool0oooo00<0oooo0P1o:RZY0?o0b`030?oo
o`3o0000ObXZ05<0oooo000I0?ooo`030000003oool0oooo0080oooo101o
:RZW0?o0b`030?ooo`1o:RX0ObXZ05@0oooo000I0?ooo`030000003oool0
oooo0080oooo101o:RZV0?o0b`80ObXZEP3oool001T0oooo00<000000?oo
o`3oool00`3oool307lZ:ZD0ol3;00<0ObXZ0?ooo`3oool0EP3oool001P0
oooo00<0YjNW0000003oool01@3oool00`000000ObXZ0?o0b`2R0?o0b`80
ObXZF@3oool001T0oooo00<0J6QX0?ooo`3oool0103oool00`000000oooo
07lZ:P2P0?o0b`80ObXZF`3oool00200oooo00@000000?ooo`3oool0ObXZ
W@3o`</207lZ:P030?l0003oool0oooo05X0oooo000P0?ooo`050000003o
ool0oooo0?l0001o:RX0V`3o`</407lZ:U`0oooo000P0?ooo`050000003o
ool0oooo0?ooo`1o:RX0VP3o`</507lZ:U`0oooo000P0?ooo`030000003o
ool0oooo0080oooo00<0ObXZ0?o0b`3o`</0UP3o`</00`1o:RX0o`000?oo
o`0207lZ:Ud0oooo000P0?ooo`030000003oool0oooo00<0oooo00<0ObXZ
0?o0b`3o`</0U03o`</00`1o:RX0o`000?ooo`1P0?ooo`00803oool00`00
0000oooo0?ooo`030?ooo`030?l0001o:RX0ol3;0980ol3;0P1o:RX00`3o
0000oooo0?ooo`1P0?ooo`00803oool00`000000oooo0?ooo`040?ooo`03
07lZ:P3o`</0ol3;0900ol3;00<0ObXZ0?l0003oool0H`3oool00200oooo
00<000000?ooo`3oool01@3oool00`1o:RX0ol3;0?o0b`2>0?o0b`0307lZ
:P3o0000oooo06@0oooo000P0?ooo`030000003oool0oooo00D0oooo00<0
o`0007lZ:P3o`</0S@3o`</00`1o:RX0o`000?ooo`1U0?ooo`00803oool0
0`000000oooo0?ooo`060?ooo`030?l0001o:RX0ol3;08X0ol3;0P1o:RX0
0`3o0000oooo0?ooo`1U0?ooo`00803oool00`000000oooo0?ooo`070?oo
o`0307lZ:P3o`</0ol3;08P0ol3;00<0ObXZ0?l0003o0000J03oool00200
oooo00<000000?ooo`3oool01`3oool00`3o`</0ObXZ0?o0b`270?o0b`03
07lZ:P3o0000oooo06T0oooo000P0?ooo`030000003oool0oooo00P0oooo
00<0o`0007lZ:P3o`</0Q03o`</207lZ:P030?l0003oool0oooo06T0oooo
000P0?ooo`030000003oool0oooo00T0oooo00<0o`0007lZ:P3o`</0PP3o
`</00`1o:RX0ol3;0?l0001/0?ooo`00803oool00`000000oooo0?ooo`0:
0?ooo`0307lZ:P3o`</0ol3;0800ol3;00<0ObXZ0?l0003o0000K@3oool0
0200oooo00<000000?ooo`3oool02`3oool00`1o:RX0ol3;0?o0b`1n0?o0
b`0307lZ:P3o0000oooo06h0oooo000P0?ooo`030000003oool0oooo00/0
oooo00<0o`0007lZ:P3o`</0O03o`</207lZ:P030?l0003oool0oooo06h0
oooo000P0?ooo`030000003oool0oooo00`0oooo00<0o`0007lZ:P3o`</0
NP3o`</00`1o:RX0ol3;0?l0001a0?ooo`00803oool00`000000oooo0?oo
o`0=0?ooo`0307lZ:P3o`</0ol3;07P0ol3;00<0ObXZ0?l0003o0000LP3o
ool00200oooo00<000000?ooo`3oool03P3oool00`1o:RX0ol3;0?o0b`1f
0?o0b`0307lZ:P3o0000oooo07<0oooo000P0?ooo`030000003oool0oooo
00h0oooo00<0o`0007lZ:P3o`</0M@3o`</00`1o:RX0o`000?ooo`1d0?oo
o`00803oool00`000000oooo0?ooo`0?0?ooo`030?l0001o:RX0ol3;0780
ol3;0P1o:RX00`3o0000oooo0?ooo`1d0?ooo`00803oool00`000000oooo
0?ooo`0@0?ooo`030?l0001o:RX0ol3;0700ol3;00<0ObXZ0?l0003oool0
M`3oool00200oooo00<000000?ooo`3oool04@3oool00`3o0000ObXZ0?o0
b`1^0?o0b`0307lZ:P3o0000oooo07P0oooo000P0?ooo`030000003oool0
oooo0180oooo00<0o`0007lZ:P3o`</0K03o`</00`1o:RX0o`000?ooo`1i
0?ooo`00803oool00`000000oooo0?ooo`0B0?ooo`030?l0001o:RX0ol3;
06/0ol3;00<0ObXZ0?ooo`3oool0NP3oool00200oooo00<000000?ooo`3o
ool04`3oool00`3o0000ObXZ0?o0b`1X0?o0b`80ObXZO@3oool00200oooo
00<000000?ooo`3oool0503oool00`3o0000ObXZ0?o0b`1V0?o0b`0307lZ
:P3o0000oooo07d0oooo000P0?ooo`030000003oool0oooo01D0oooo00<0
o`0007lZ:P3o`</0I03o`</00`1o:RX0oooo0?ooo`1n0?ooo`00803oool0
0`000000oooo0?ooo`0F0?ooo`030?l0001o:RX0ol3;0640ol3;0P1o:RZ1
0?ooo`00803oool00`000000oooo0?ooo`0F0?ooo`030?l0003o`</0ObXZ
0600ol3;00<0ObXZ0?l0003oool0P@3oool00200oooo00<000000?ooo`3o
ool05`3oool00`3o0000ol3;07lZ:P1M0?o0b`80ObXZQ03oool00200oooo
00<000000?ooo`3oool0603oool00`3o0000ol3;07lZ:P1K0?o0b`0307lZ
:P3oool0oooo08@0oooo000P0?ooo`030000003oool0oooo01T0oooo00<0
o`000?o0b`1o:RX0F03o`</207lZ:XL0oooo000P0?ooo`030000003oool0
oooo01X0oooo0P3o00000`1o:RX0ol3;0?o0b`1C0?o0b`030?l0001o:RX0
oooo08P0oooo000B0?ooo`050000003oool0oooo0000003@d=000P1>CTh0
0`3@d=00oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<0o`00
07lZ:P1o:RX0DP3o`</207lZ:XX0oooo000B0?ooo`050000003oool0oooo
0?ooo`1>CTh00P3oool00`1>CTh0oooo0?ooo`040?ooo`<000007@3oool0
0`3o0000ol3;07lZ:P1?0?o0b`030?l0001o:RX0oooo08/0oooo000B0?oo
o`030000003oool0oooo00@0oooo00<0CTi>0?ooo`3oool0103oool00`00
0000oooo0?ooo`0N0?ooo`80o`0000<0ObXZ0?o0b`3o`</0B`3o`</207lZ
:Xd0oooo000B0?ooo`040000003oool0oooo0?ooo`80J6QX00<0CTi>0=3@
d03oool01@3oool00`000000oooo0?ooo`0P0?ooo`030?l0001o:RX0ol3;
04T0ol3;00<0o`0007lZ:P3oool0SP3oool00140oooo00<0YjNW0000003o
ool00P3oool00`2c/k<0alO70?ooo`070?ooo`030000003oool0oooo0240
oooo00<0o`0007lZ:P3o`</0A03o`</207lZ:P030?o0b`1o:RX0ObXZ0900
oooo000B0?ooo`0506QXJ03oool0oooo0?ooo`3YjNT00`0000060?ooo`03
0000003oool0oooo0280oooo00<0o`0007lZ:P3o`</0@P3o`</407lZ:Y80
oooo000P0?ooo`030000003oool0oooo02@0oooo0P1o:RY10?o0b`@0ObXZ
TP3oool00200oooo00<000000?ooo`3oool09P3oool00`1o:RX0ol3;0?o0
b`0l0?o0b`030?l0001o:RX0ObXZ0080ObXZT`3oool00200oooo00<00000
0?ooo`3oool09`3oool207lZ:SX0ol3;00<0o`0007lZ:P1o:RX0U`3oool0
0200oooo00<000000?ooo`3oool0:03oool00`3o0000ObXZ07lZ:P0f0?o0
b`<0ObXZV@3oool00200oooo00<000000?ooo`3oool0:P3oool00`3o0000
ObXZ0?o0b`0b0?o0b`80ObXZW03oool00200oooo00<000000?ooo`3oool0
;03oool207lZ:Rl0ol3;0P1o:RZN0?ooo`00803oool00`000000oooo0?oo
o`0^0?ooo`<0ObXZ:@3o`</00`3oool0ObXZ07lZ:P2P0?ooo`00803oool0
0`000000oooo0?ooo`0`0?ooo`040?l0001o:RX0ObXZ07lZ:R<0ol3;00@0
oooo07lZ:P1o:RX0ObXZXP3oool00200oooo00<000000?ooo`3oool0<@3o
ool407lZ:R00ol3;00@0o`0007lZ:P1o:RX0o`00Y03oool00200oooo00<0
00000?ooo`3oool0<@3oool607lZ:P80o`005`3o`</20?l000@0ObXZY`3o
ool00200oooo00<000000?ooo`3oool0<P3oool207lZ:P<0oooo1@1o:RX4
0?l000T0ol3;1P3o000307lZ:Z/0oooo000P0?ooo`030000003oool0oooo
03`0oooo4`1o:RZ^0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00
803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?oo
o`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`00
0000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00
803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?oo
o`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`007`3oool00`2KVi/0oooo0?ooo`3n0?ooo`00
7`3oool00`1>CTh0oooo0?ooo`3n0?ooo`007P3oool00`3alO4000000>WY
j@3o0?ooo`007P3oool00`2c/k<0SHf=0:NWY`3o0?ooo`007P3oool00`1>
CTh0lO7a06QXJ03o0?ooo`007@3oool01@3@d=00YjNW0?ooo`2WYjL0d=3@
0?h0oooo000M0?ooo`0507alO03YjNT0oooo0>WYj@1lO7`0oP3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "\n\t\t",
  StyleBox["Simpson\[CloseCurlyQuote]s 3/8 Rule",
    FontFamily->"Times-Roman"],
  "\t\t\t\t\t\t",
  StyleBox["Boole\[CloseCurlyQuote]s Rule",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        1 + \[ExponentialE]\^\(-x\)\ Sin[
              4\ x];\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["For the trapezoidal ",
    FontFamily->"Times-Roman"],
  StyleBox["rule using  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\  = \ 1.0\)]],
  " we compute:  "
}], "Text"],

Cell[TextData[{
  StyleBox["Using (8) the Trapezoidal Rule: \n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \ f[x] \[DifferentialD]x\)]],
  " ",
  Cell[BoxData[
      \(\(\(\ \)\(\(\[TildeTilde]\)\(\ \)\(\(h\/2\) \((f\_0\  + \ 
              f\_1)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(1\/2\) \((1.00000 + 0.721588)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.5 \((1.7215\ )\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.860794\)\(\ \)\)\)\)]],
  "  \n\t\t\t\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(h = b - a;\)\ \), "\[IndentingNewLine]", 
    \(x\_0 = 0.0; x\_1 = x\_0 + h;\), "\n", 
    \(f\_0 = f[x\_0]; f\_1 = f[x\_1];\), "\[IndentingNewLine]", 
    \(\(Print["\<The Trapezoidal Rule with  h = \>", 
        h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(h\/2\)(\!\(f\_0\) + \!\(f\_1\)) = \>\"", \
\(h\/2\) \((f\_0\  + \ f\_1)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["For Simpson\[CloseCurlyQuote]s rule using  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\  = \ \(1\/2\  = \ 0.5\)\)]],
  " we compute:  "
}], "Text"],

Cell[TextData[{
  StyleBox["Using (9) Simpson\[CloseCurlyQuote]s Rule: \n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \ \)\(\(\[TildeTilde]\)\(\ \)\(\(h\/3\) \((f\_0\  + \ 
              4  f\_1\  + \ f\_2)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(0.5\/3\) \((1.00000\  + \ 4*1.55152\  + \ 
              0.72159)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.166667 \((1.00000\  + \ 6.20608\  + \ 
              0.72159)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.166667 \((7.92767)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(1.32128\)\)\)\)]],
  "  \n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(h = \(b - a\)\/2;\)\ \), "\[IndentingNewLine]", 
    \(x\_0 = 0.0; x\_1 = x\_0 + h; x\_2 = x\_0 + 2  h;\), "\n", 
    \(f\_0 = f[x\_0]; f\_1 = f[x\_1]; 
    f\_2 = f[x\_2];\), "\[IndentingNewLine]", 
    \(\(Print["\<Simpson's Rule with  h = \>", 
        h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(h\/3\)(\!\(f\_0\) + 4\!\(f\_1\) + \!\(f\_2\)) \
= \>\"", \(h\/3\) \((f\_0\  + \ 4  f\_1\  + \ f\_2)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["For Simpson\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(3\/8\)]],
  StyleBox[" rule using  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\  = \ \(1\/3\  = \ 0.333333\)\)]],
  " we compute:  "
}], "Text"],

Cell[TextData[{
  StyleBox["Using (10) Simpson\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(3\/8\)]],
  "R",
  StyleBox["ule:\n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \ \)\(\(\[TildeTilde]\)\(\ \)\(\(\(3  h\)\/8\) \((f\_0\  + \ 
              3  f\_1\  + \ 3  f\_2 + \ f\_3)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(\(3*0.333333\)\/8\) \((1.00000\  + \ 
              3*1.69642\  + \ 3*1.23477 + \ 0.721588)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.125 \((1.00000\  + \ 5.08926\  + \ 
              3.70431 + \ 0.721588)\)\)\)\)\)]],
  "   \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.125 \((10.5152)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(1.3144\)\)\)\)]],
  "  \n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(h = \(b - a\)\/3;\)\ \), "\[IndentingNewLine]", 
    \(x\_0 = 0.0; x\_1 = x\_0 + h; x\_2 = x\_0 + 2  h; 
    x\_3 = x\_0 + 3  h;\), "\n", 
    \(f\_0 = f[x\_0]; f\_1 = f[x\_1]; f\_2 = f[x\_2]; 
    f\_3 = f[x\_3];\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Simpson's \!\(3\/8\) Rule with  h = \>\"", 
        h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(\(3  h\)\/8\)(\!\(f\_0\) + 3\!\(f\_1\) + \
3\!\(f\_2\)+ \!\(f\_3\)) = \>\"", \(\(3  h\)\/8\) \((f\_0\  + \ 3  f\_1\  + \ 
              3  f\_2 + \ f\_3)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["For Boole\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  StyleBox["rule using  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\  = \ \(1\/4\  = \ 0.25\)\)]],
  " we compute:  "
}], "Text"],

Cell[TextData[{
  StyleBox["Using (11) Boole\[CloseCurlyQuote]s Rule:\n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \ \)\(\(\[TildeTilde]\)\(\ \)\(\(\(2  h\)\/45\) \((7 
                 f\_0\  + \ 32  f\_1\  + \ 12  f\_2 + \ 32  f\_3 + 
              7  f\_4)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(\(2*0.25\)\/45\) \((7*1.00000\  + \ 
              32*1.65534\  + \ 12*1.55152 + \ 32*\ 1.06666 + 
              7*0.721588)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.0111111 \((7.00000\  + \ 52.9709\  + \ 
              18.6182 + \ 34.1331 + 5.05112)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.0111111 \((117.7733)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(1.30859\)\)\)\)]],
  "  \n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(h = \(b - a\)\/4;\)\ \), "\[IndentingNewLine]", 
    \(x\_0 = 0.0; x\_1 = x\_0 + h; x\_2 = x\_0 + 2  h; x\_3 = x\_0 + 3  h; 
    x\_4 = x\_0 + 4  h;\), "\n", 
    \(f\_0 = f[x\_0]; f\_1 = f[x\_1]; f\_2 = f[x\_2]; f\_3 = f[x\_3]; 
    f\_4 = f[x\_4];\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Boole's Rule with  h = \>", h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(\(2  \
h\)\/45\)(7\!\(f\_0\)+32\!\(f\_1\)+12\!\(f\_2\)+32\!\(f\_3\)+7\!\(f\_4\)) = \
\>\"", \(\(2  h\)\/45\) \((7  f\_0 + 32  f\_1 + 12  f\_2 + 32  f\_3 + 
              7  f\_4)\)];\)\)}], "Input"],

Cell[TextData[StyleBox["The true value of the definite integral is",
  FontFamily->"Times-Roman"]], "Text"],

Cell[BoxData[{
    \(\(F[
          x_] = \[Integral]f[
              x] \[DifferentialD]x;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<F[x] = \[Integral]f[x]\[DifferentialD]x = \>", 
        F[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<F[1] = \>", F[1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<F[0] = \>", F[0]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = \>\"", \
"\<\[Integral]\>"\+a\%b, "\<(\>", 
        f[x], "\<)\[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = F[1] - \
F[0]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = (\>\"", 
        F[1], "\<) - (\>", F[0], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = \>\"", 
        F[1]\  - \ F[0]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = \>\"", 
        NumberForm[N[F[1]\  - \ F[0]], 16]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We see that the approximation  ",
    FontFamily->"Times-Roman"],
  StyleBox["1",
    FontFamily->"Courier New"],
  StyleBox[".",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["30859",
    FontFamily->"Courier New"],
  StyleBox["  from Boole\[CloseCurlyQuote]s rule is best. The area under each \
of the Lagrange polynomials  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = \(P\_1\) \((x)\)\)]],
  StyleBox[", ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = \(P\_2\) \((x)\)\)]],
  StyleBox[", ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = \(P\_3\) \((x)\)\)]],
  StyleBox[", and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(y = \(P\_4\) \((x)\)\)]],
  StyleBox["  are shown in the figures for this example.",
    FontFamily->"Times-Roman"]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["\tTo make a fair comparison of quadrature methods, we must use \
the same number of function evaluations in each method.  Our final example is \
concerned with comparing\nintegration over a fixed interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox["  ",
    FontFamily->"MTSYN"],
  StyleBox["using exactly five function evaluations  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f\_k = f \((x\_k)\)\)]],
  StyleBox["  for  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "3", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "4"}]]],
  "  ",
  StyleBox["for each method.  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["When the trapezoidal rule is applied on the four subintervals  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(x\_1\)}], "]"}]]],
  StyleBox[", ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(x\_2\)}], "]"}]]],
  StyleBox[", ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_2\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(x\_3\)}], "]"}]]],
  StyleBox[", and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_3\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(x\_4\)}], "]"}]]],
  "  ",
  StyleBox["it is called a ",
    FontFamily->"Times-Roman"],
  StyleBox["composite trapezoidal rule",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[": \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_\(x\_0\)\%\(x\_4\)\ 
          f \((x)\) \[DifferentialD]x\  \[TildeTilde] \ \(h\/2\) \((f\_0 + 
                f\_1)\)\  + \ \(h\/2\) \((f\_1 + 
                f\_2)\)\  + \ \(h\/2\) \((f\_2 + 
                f\_3)\)\  + \ \(h\/2\) \((f\_3 + f\_4)\)\)]],
  "  \n\t\t\n(12)\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(x\_0\)\%\(x\_4\)\ 
          f \((x)\) \[DifferentialD]x\  \[TildeTilde] \ \(h\/2\) \((f\_0\  + \
\ 2  f\_1\  + \ 2  f\_2\  + \ 2  f\_3\  + \ f\_4)\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["When Simpson\[CloseCurlyQuote]s rule is applied on the two \
subintervals  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(x\_2\)}], "]"}]]],
  StyleBox["and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_2\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(x\_4\)}], "]"}]]],
  " ",
  StyleBox[" it is called a ",
    FontFamily->"Times-Roman"],
  StyleBox["composite Simpson's  rule",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[": \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_\(x\_0\)\%\(x\_4\)\ 
          f \((x)\) \[DifferentialD]x\  \[TildeTilde] \ \(h\/3\) \((f\_0 + 
                4  f\_1 + f\_2)\)\  + \ \(h\/3\) \((f\_2 + 4  f\_3 + 
                f\_4)\)\)]],
  "  \n\t\t\n(13)\t\t",
  Cell[BoxData[
      \(\[Integral]\_\(x\_0\)\%\(x\_4\)\ 
          f \((x)\) \[DifferentialD]x\  \[TildeTilde] \ \(h\/3\) \((f\_0\  + \
\ 4  f\_1\  + \ 2  f\_2\  + \ 4  f\_3\  + \ f\_4)\)\)]],
  "  "
}], "Text"],

Cell[TextData[StyleBox["The next example compares the values obtained with \
these formulas. ",
  FontFamily->"Times-Roman"]], "Text"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Consider the integration of the function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\) = 1 + \[ExponentialE]\^\(-x\)\ sin \((4\ x)\)\)]],
  StyleBox["  over  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["[",
            FontFamily->"Courier New"], 
          RowBox[{
            StyleBox["a",
              FontFamily->"Courier New"], 
            StyleBox[",",
              FontFamily->"Times New Roman"], 
            StyleBox["b",
              FontFamily->"Courier New"]}], 
          StyleBox["]",
            FontFamily->"Courier New"]}], 
        StyleBox[" ",
          FontFamily->"Courier New"], 
        StyleBox["=",
          FontFamily->"Courier New"], 
        StyleBox[" ",
          FontFamily->"Courier New"], 
        RowBox[{
          StyleBox["[",
            FontFamily->"Courier New"], 
          RowBox[{
            StyleBox["0",
              FontFamily->"Courier New"], 
            StyleBox[",",
              FontFamily->"Times New Roman"], 
            StyleBox["1",
              FontFamily->"Courier New"]}], 
          StyleBox["]",
            FontFamily->"Courier New"]}]}]]],
  StyleBox[".  Use exactly five function evaluations and compare the results \
from the composite trapezoidal rule, composite Simpson rule, and Boole\
\[CloseCurlyQuote]s rule.  Use the uniform step size  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\  = \ \(1\/4\  = \ 0.25\)\)]],
  StyleBox[".   ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
AP3oool01`2c/k<000000000002c/k<0oooo0000001>CTh00`00000Q0?oo
o`060;>c/`00000000000;>c/`3oool000000P3oool00`000000oooo0?oo
o`0P0?ooo`070;>c/`00000000000;>c/`3oool000000>7Qh@0204i>CP03
0=3@d03oool0oooo01l0oooo00L0/k>c000000000000/k>c0?ooo`000000
d=3@0080CTi>00<0d=3@0?ooo`3oool0903oool00`000000oooo0?ooo`0V
0?ooo`00AP3oool0101XJ6P0lO7a0?7al@1XJ6P20?ooo`030=3@d02=SHd0
oooo0280oooo00@0J6QX0?7al@3alO40J6QX0`3oool300000240oooo00@0
J6QX0?7al@3alO40J6QX0P3oool0101lO7`0lO7a0?ooo`1>CThQ0?ooo`04
06QXJ03alO40lO7a06QXJ080oooo00@0J6QX0?ooo`3oool0CTi>9P3oool0
0`000000oooo0?ooo`0V0?ooo`00AP3oool010000000oooo0?ooo`000004
0?ooo`030:NWY`3oool0oooo0200oooo00@000000?ooo`3oool000000`3o
ool00`1XJ6P000000?ooo`0Q0?ooo`040000003oool0oooo00000080oooo
00@000000>WYj@3oool0CTi>8@3oool010000000oooo0?ooo`0000020?oo
o`0404i>CP3oool0oooo06QXJ2H0oooo00<000000?ooo`3oool09P3oool0
04H0oooo00@000000?ooo`3oool00000103oool00`3YjNT0SHf=0?ooo`0P
0?ooo`040000003oool0oooo000000<0oooo00<0YjNW0000003oool08@3o
ool010000000oooo0?ooo`0000020?ooo`040000002=SHd000000=3@d240
oooo00@000000?ooo`3oool000000P3oool0103@d=0000000000003@d=0V
0?ooo`030000003oool0oooo02H0oooo00160?ooo`0406QXJ03alO40jNWY
07alO080oooo00@0CTi>0>WYj@3YjNT000008@3oool0101XJ6P0lO7a0>WY
j@1lO7`30?ooo`030=3@d0000000oooo0240oooo00@0J6QX0?7al@3YjNT0
O7al0P3oool00`2=SHd0jNWY0?ooo`0R0?ooo`0406QXJ03alO40jNWY07al
O080oooo00@0CTi>0?ooo`3oool0CTi>9@3oool00`2WYjL000000?ooo`0W
0?ooo`00AP3oool0102m_Kd000000000002m_Kd20?ooo`040=3@d01>CTh0
CTi>0=3@d240oooo00@0_Kfm000000000000_Kfm0`3oool00`3alO400000
0?ooo`0Q0?ooo`040;fm_@00000000000;fm_@80oooo00@0jNWY06QXJ000
0000/k>c8@3oool0102m_Kd000000000002m_Kd20?ooo`040;>c/`000000
00000;fm_BH0oooo00<0J6QX0?ooo`3oool09P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo2`3oool00`1lO7`0d=3@
07alO00C0?ooo`005P3ooom0000000030000o`000000000003<0000000<0
003o000000000000<`0000000`000?l000000000000b000000030000o`00
0000000000T000001`3oool00`3@d=0000000=3@d00C0?ooo`00803oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00P0oooo00<0003o
0?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo0180oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`07
0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0403oool0
0`3alO4000000?7al@0C0?ooo`00803oool00`0000000?oo003oo`0c003o
o`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`00
0?l00?oo003oo`0b003oo`030000o`3oool0oooo0100oooo00<0d=3@0000
003@d=004`3oool00200oooo00<00000003oo`00ool0<`00ool00`000?l0
0?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00
ool0<P00ool00`000?l0oooo0?ooo`0@0?ooo`0307alO03@d=00O7al01<0
oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0003o003oo`00ool0
<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03800?oo
00<0003o0?ooo`3oool09P3oool00200oooo00<00000003oo`00ool0<`00
ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0
003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V0?ooo`00803oool0
0`0000000?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o
003oo`00ool0<`00ool00`000?l00?oo003oo`0b003oo`030000o`3oool0
oooo02H0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0003o003o
o`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo
03800?oo00<0003o0?ooo`3oool09P3oool00200oooo00<00000003oo`00
ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<0
0?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V0?ooo`00
803oool00`0000000?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo
00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0b003oo`030000
o`3oool0oooo02H0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0
003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00
ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool00200oooo00<00000
003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo03<00?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V
0?ooo`00803oool00`0000000?oo003oo`0c003oo`030000o`00ool00?oo
03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0b003o
o`030000o`3oool0oooo02H0oooo000P0?ooo`0300000000ool00?oo03<0
0?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`03
0000o`00ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool00200oooo
00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000
o`00ool00?oo03<00?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo
0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`0c003oo`030000o`00
ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003o
o`0b003oo`030000o`3oool0oooo02H0oooo000P0?ooo`0300000000ool0
0?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c
003oo`030000o`00ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool0
0200oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003o
o`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<P00ool00`00
0?l0oooo0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`0c003oo`03
0000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l0
0?oo003oo`0b003oo`030000o`3oool0oooo02H0oooo000P0?ooo`030000
0000ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo
003oo`0c003oo`030000o`00ool00?oo03800?oo00<0003o0?ooo`3oool0
9P3oool00200oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003o
o`0c003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<P00
ool00`000?l0oooo0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`0c
003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool0
0`000?l00?oo003oo`0b003oo`030000o`3oool0oooo02H0oooo000P0?oo
o`0300000000ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`00
0?l00?oo003oo`0c003oo`030000o`00ool00?oo03800?oo00<0003o0?oo
o`3oool09P3oool00200oooo00<00000003oo`00ool0<`00ool00`000?l0
0?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00
ool0<P00ool00`000?l0oooo0?ooo`0V0?ooo`00803oool00`0000000?oo
003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0
<`00ool00`000?l00?oo003oo`0b003oo`030000o`3oool0oooo02H0oooo
000P0?ooo`0300000000ool00?oo03<00?oo00<0003o003oo`00ool0<`00
ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03800?oo00<0
003o0?ooo`3oool09P3oool00200oooo00<00000003oo`00ool0<`00ool0
0`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o
003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V0?ooo`00803oool00`00
00000?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o003o
o`00ool0<`00ool00`000?l00?oo003oo`0b003oo`030000o`3oool0oooo
02H0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0003o003oo`00
ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo0380
0?oo00<0003o0?ooo`3oool09P3oool00200oooo00<00000003oo`00ool0
<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo
00<0003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V0?ooo`00803o
ool00`0000000?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0
003o003oo`00ool0<`00ool00`000?l00?oo003oo`0b003oo`030000o`3o
ool0oooo02H0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0003o
003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo03800?oo00<0003o0?ooo`3oool09P3oool00200oooo00<00000003o
o`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo
03<00?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V0?oo
o`00803oool00`0000000?oo003oo`0c003oo`030000o`00ool00?oo03<0
0?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0b003oo`03
0000o`3oool0oooo02H0oooo000P0?ooo`0300000000ool00?oo03<00?oo
00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000
o`00ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool00200oooo00<0
0000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00
ool00?oo03<00?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo0?oo
o`0V0?ooo`00803oool00`0000000?oo003oo`0c003oo`030000o`00ool0
0?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0b
003oo`030000o`3oool0oooo02H0oooo000P0?ooo`0300000000ool00?oo
03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003o
o`030000o`00ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool00200
oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`03
0000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<P00ool00`000?l0
oooo0?ooo`0V0?ooo`00403oool01`2c/k<000000000002c/k<0oooo0000
003@d=000P1>CTh00`3@d=00oooo0?ooo`040?ooo`0300000000ool00?oo
03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003o
o`030000o`00ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool00100
oooo00@0J6QX0?7al@3alO40J6QX0P3oool0101>CTh0oooo0?ooo`1>CTh6
0?ooo`0300000000ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool0
0`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03800?oo00<0003o
0?ooo`3oool09P3oool00100oooo00@000000?ooo`3oool000001@3oool0
0`1>CTh0oooo0?ooo`040?ooo`0300000000ool00?oo03<00?oo00<0003o
003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo03800?oo00<0003o0?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000000P3oool206QXJ00304i>CP3@d=00oooo00D0oooo00<00000
003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo03<00?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V
0?ooo`00403oool0101XJ6P0lO7a0>WYj@1lO7`20?ooo`030;>c/`37alL0
oooo00L0oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c
003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<P00ool0
0`000?l0oooo0?ooo`0V0?ooo`00403oool0102m_Kd000000000002m_Kd2
0?ooo`040>WYj@0000000000000000H0oooo00<00000003oo`00ool0<`00
ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0
003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V0?ooo`00803oool0
0`0000000?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o
003oo`00ool0<`00ool00`000?l00?oo003oo`0b003oo`030000o`3oool0
oooo02H0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0003o003o
o`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo
03800?oo00<0003o0?ooo`3oool09P3oool00200oooo00<00000003oo`00
ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<0
0?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V0?ooo`00
803oool00`0000000?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo
00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0b003oo`030000
o`3oool0oooo02H0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0
003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00
ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool00200oooo00<00000
003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo03<00?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo0?ooo`0V
0?ooo`00803oool00`0000000?oo003oo`0c003oo`030000o`00ool00?oo
03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0b003o
o`030000o`3oool0oooo02H0oooo000P0?ooo`0300000000ool00?oo03<0
0?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`03
0000o`00ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool00200oooo
00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000
o`00ool00?oo03<00?oo00<0003o003oo`00ool0<P00ool00`000?l0oooo
0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`0c003oo`030000o`00
ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003o
o`0b003oo`030000o`3oool0oooo02H0oooo000P0?ooo`0300000000ool0
0?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c
003oo`030000o`00ool00?oo03800?oo00<0003o0?ooo`3oool09P3oool0
0200oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003o
o`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<P00ool00`00
0?l0oooo0?ooo`0V0?ooo`00803oool00`0000000?oo003oo`0c003oo`03
0000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l0
0?oo003oo`0b003oo`030000o`3oool0oooo02H0oooo000P0?ooo`030000
0000ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo
003oo`0c003oo`030000o`00ool00?oo03800?oo00<0003o07lZ:P3oool0
9P3oool00200oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003o
o`0c003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<@00
ool407lZ:RH0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0003o
003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo02h00?oo1`1o:RXV0?ooo`00803oool00`0000000?oo003oo`0c003o
o`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`00
0?l00?oo003oo`0[003oo`<0ObXZ0P000?l20?ooo`80ObXZ9`3oool00200
oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`03
0000o`00ool00?oo03<00?oo00<0003o003oo`00ool0:000ool307lZ:P03
003oo`3oool0003o02d0oooo000P0?ooo`0300000000ool00?oo03<00?oo
00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000
o`00ool00?oo02H00?oo0P1o:RX3003oo`80003o;P3oool00200oooo00<0
0000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00
ool00?oo03<00?oo00<0003o003oo`00ool09000ool207lZ:P<00?oo0P00
0?l`0?ooo`00803oool00`0000000?oo003oo`0c003oo`030000o`00ool0
0?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0R
003oo`80ObXZ0`00ool20000oc80oooo000P0?ooo`0300000000ool00?oo
03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003o
o`030000o`00ool00?oo01l00?oo0`1o:RX3003oo`80003o=03oool00200
oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`03
0000o`00ool00?oo03<00?oo00<0003o003oo`00ool07@00ool207lZ:P<0
0?oo0`000?lf0?ooo`00803oool00`0000000?oo003oo`0c003oo`030000
o`00ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo
003oo`0K003oo`80ObXZ0`00ool20000ocT0oooo000P0?ooo`0300000000
ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003o
o`0c003oo`030000o`00ool00?oo01T00?oo0P1o:RX4003oo`030000o`3o
ool0oooo03T0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0003o
003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo01L00?oo0P1o:RX5003oo`030000o`3oool0oooo03X0oooo000P0?oo
o`0300000000ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`00
0?l00?oo003oo`0c003oo`030000o`00ool00?oo01D00?oo0P1o:RX5003o
o`80003o?@3oool00200oooo00<00000003oo`00ool0<`00ool00`000?l0
0?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00
ool04`00ool207lZ:P@00?oo0`000?lo0?ooo`00803oool00`0000000?oo
003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0
<`00ool00`000?l00?oo003oo`0A003oo`80ObXZ1000ool20000od80oooo
000P0?ooo`0300000000ool00?oo03<00?oo00<0003o003oo`00ool0<`00
ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo00l00?oo0P1o
:RX4003oo`80003oA03oool00200oooo00<00000003oo`00ool0<`00ool0
0`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00<0003o
003oo`00ool03P00ool00`1o:RX00?oo003oo`02003oo`80003oAP3oool0
0200oooo00<00000003oo`00ool0<`00ool00`000?l00?oo003oo`0c003o
o`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool03000ool207lZ
:P<00?oo00<0oooo0000o`3oool0A`3oool00200oooo00<00000003oo`00
ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<0
0?oo00<0003o003oo`00ool02`00ool0101o:RX00?oo003oo`00ool20?oo
o`030000o`3oool0oooo04L0oooo000P0?ooo`0300000000ool00?oo03<0
0?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c003oo`03
0000o`00ool00?oo00T00?oo0P1o:RX2003oo`040?ooo`000?l0003o0000
odX0oooo000P0?ooo`0300000000ool00?oo03<00?oo00<0003o003oo`00
ool0<`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo00P0
0?oo00@0ObXZ003oo`00ool00?oo0P000?m=0?ooo`006@3oool00`000000
oooo0?ooo`030?ooo`80ObXZ=@00ool00`000?l00?oo003oo`0c003oo`03
0000o`00ool00?oo03<00?oo00<0003o003oo`00ool01P00ool207lZ:P80
0?oo0P000?m?0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`@0ObXZ
=000ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo
00<0003o003oo`00ool01@00ool00`1o:RX00?oo003oo`020000oe40oooo
000I0?ooo`030000003oool0oooo0080oooo101o:RXd003oo`030000o`00
ool00?oo03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003o
o`04003oo`0407lZ:P00ool0003o0000oe<0oooo000I0?ooo`030000003o
ool0oooo00<0oooo0`1o:RXd003oo`030000o`00ool00?oo03<00?oo00<0
003o003oo`00ool0<`00ool00`000?l00?oo003oo`02003oo`80ObXZ0P00
0?mE0?ooo`00603oool00`2WYjL000000?ooo`050?ooo`030000001o:RX0
003o03<00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0c
003oo`070000o`00ool00?oo003oo`1o:RX0oooo0000o`1G0?ooo`006@3o
ool00`1XJ6P0oooo0?ooo`040?ooo`030000003oool0ObXZ0080003o<@00
ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo03<00?oo00@0
003o003oo`00ool0ObXZ0P000?mH0?ooo`00803oool01P000000oooo0?oo
o`1o:RX0oooo0000oc000?oo00<0003o003oo`00ool0<`00ool00`000?l0
0?oo003oo`0b003oo`0507lZ:P000?l0ObXZ07lZ:P000?l0FP3oool00200
oooo00L000000?ooo`3oool0oooo07lZ:P3oool0003o02l00?oo00<0003o
003oo`00ool0<`00ool00`000?l00?oo003oo`0a003oo`@0ObXZG03oool0
0200oooo00D000000?ooo`3oool0oooo07lZ:P020?ooo`030000o`00ool0
0?oo02`00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0a
003oo`@0ObXZG03oool00200oooo00<000000?ooo`3oool00P3oool0101o
:RX0oooo0?ooo`000?l]003oo`030000o`00ool00?oo03<00?oo00<0003o
003oo`00ool0<000ool407lZ:Ud0oooo000P0?ooo`030000003oool0oooo
00<0oooo00<0ObXZ0?ooo`000?l0;@00ool00`000?l00?oo003oo`0c003o
o`030000o`00ool00?oo02h00?oo00<0003o07lZ:P3oool0H03oool00200
oooo00<000000?ooo`3oool0103oool00`1o:RX0oooo0000o`0/003oo`03
0000o`00ool00?oo03<00?oo00<0003o003oo`00ool0;@00ool207lZ:V80
oooo000P0?ooo`030000003oool0oooo00@0oooo00<0ObXZ0?ooo`3oool0
0P000?lZ003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0
;000ool00`1o:RX0oooo0?ooo`1R0?ooo`00803oool00`000000oooo0?oo
o`050?ooo`0507lZ:P3oool0oooo0?ooo`000?l0:@00ool00`000?l00?oo
003oo`0c003oo`030000o`00ool00?oo02X00?oo0P1o:RYU0?ooo`00803o
ool00`000000oooo0?ooo`060?ooo`0507lZ:P3oool0oooo003oo`000?l0
:000ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo02T00?oo
00<0ObXZ0000o`3oool0I@3oool00200oooo00<000000?ooo`3oool01`3o
ool01@1o:RX0oooo0?ooo`3oool0003o02L00?oo00<0003o003oo`00ool0
<`00ool00`000?l00?oo003oo`0W003oo`030000o`1o:RX0oooo06L0oooo
000P0?ooo`030000003oool0oooo00P0oooo00D0ObXZ0?ooo`3oool0oooo
0000o`0V003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool0
9P00ool207lZ:VT0oooo000P0?ooo`030000003oool0oooo00P0oooo00<0
ObXZ0?ooo`3oool00P3oool00`000?l00?oo003oo`0S003oo`030000o`00
ool00?oo03<00?oo00<0003o003oo`00ool09@00ool00`1o:RX0oooo0?oo
o`1Y0?ooo`00803oool00`000000oooo0?ooo`090?ooo`0307lZ:P3oool0
oooo0080oooo00<0003o003oo`00ool08P00ool00`000?l00?oo003oo`0c
003oo`030000o`00ool00?oo02<00?oo00<0oooo07lZ:P3oool0J`3oool0
0200oooo00<000000?ooo`3oool02P3oool01@1o:RX0oooo0?ooo`3oool0
003o02@00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0R
003oo`80ObXZK@3oool00200oooo00<000000?ooo`3oool02`3oool01@1o
:RX0oooo0?ooo`3oool0003o02<00?oo00<0003o003oo`00ool0<`00ool0
0`000?l00?oo003oo`0Q003oo`0307lZ:P000?l0oooo06d0oooo000P0?oo
o`030000003oool0oooo00/0oooo00<0ObXZ0?ooo`3oool00P3oool00`00
0?l00?oo003oo`0P003oo`030000o`00ool00?oo03<00?oo00<0003o003o
o`00ool07`00ool00`000?l0ObXZ0?ooo`1_0?ooo`00803oool00`000000
oooo0?ooo`0<0?ooo`0307lZ:P3oool0oooo0080oooo00<0003o003oo`00
ool07`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo01h0
0?oo00<0003o07lZ:P3oool0L03oool00200oooo00<000000?ooo`3oool0
3@3oool00`1o:RX0oooo0?ooo`020?ooo`80003o7`00ool00`000?l00?oo
003oo`0c003oo`030000o`00ool00?oo01d00?oo0P1o:RYb0?ooo`00803o
ool00`000000oooo0?ooo`0>0?ooo`0307lZ:P3oool0oooo00<0oooo00<0
003o003oo`00ool07000ool00`000?l00?oo003oo`0c003oo`030000o`00
ool00?oo01`00?oo00<0ObXZ0?ooo`3oool0LP3oool00200oooo00<00000
0?ooo`3oool03P3oool00`1o:RX0oooo0?ooo`030?ooo`03003oo`000?l0
0?oo01`00?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0J
003oo`030000o`1o:RX0oooo07@0oooo000P0?ooo`030000003oool0oooo
00l0oooo00<0ObXZ0?ooo`3oool0103oool00`000?l00?oo003oo`0J003o
o`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool06000ool00`3o
ool0ObXZ07lZ:P1f0?ooo`00803oool00`000000oooo0?ooo`0@0?ooo`03
07lZ:P3oool0oooo00@0oooo00<0003o003oo`00ool06@00ool00`000?l0
0?oo003oo`0c003oo`030000o`00ool00?oo01L00?oo00<0oooo07lZ:P3o
ool0M`3oool00200oooo00<000000?ooo`3oool04@3oool00`1o:RX0oooo
0?ooo`040?ooo`030000o`00ool00?oo01P00?oo00<0003o003oo`00ool0
<`00ool00`000?l00?oo003oo`0F003oo`030000o`1o:RX0oooo07P0oooo
000P0?ooo`030000003oool0oooo0180oooo00<0ObXZ0?ooo`3oool0103o
ool00`000?l00?oo003oo`0G003oo`030000o`00ool00?oo03<00?oo00<0
003o003oo`00ool05000ool20000o`0307lZ:P3oool0oooo07P0oooo000P
0?ooo`030000003oool0oooo01<0oooo00<0ObXZ0?ooo`3oool00`3oool0
0`000?l00?oo003oo`0G003oo`030000o`00ool00?oo03<00?oo00<0003o
003oo`00ool04`00ool00`000?l0ObXZ07lZ:P1k0?ooo`00803oool00`00
0000oooo0?ooo`0D0?ooo`0307lZ:P3oool0oooo00<0oooo00<0003o003o
o`00ool05P00ool00`000?l00?oo003oo`0c003oo`030000o`00ool00?oo
01800?oo00<0003o07lZ:P3oool0O03oool00200oooo00<000000?ooo`3o
ool0503oool00`1o:RX0oooo0?ooo`040?ooo`80003o5P00ool00`000?l0
0?oo003oo`0c003oo`030000o`00ool00?oo01400?oo00<0003o07lZ:P3o
ool0O@3oool00200oooo00<000000?ooo`3oool05@3oool00`1o:RX0oooo
0?ooo`050?ooo`030000o`00ool00?oo01<00?oo00<0003o003oo`00ool0
<`00ool00`000?l00?oo003oo`0?003oo`030000o`1o:RX0ObXZ07l0oooo
000P0?ooo`030000003oool0oooo01H0oooo00<0ObXZ0?ooo`3oool01@3o
ool00`000?l00?oo003oo`0B003oo`030000o`00ool00?oo03<00?oo00<0
003o003oo`00ool03@00ool00`3oool0003o07lZ:P210?ooo`00803oool0
0`000000oooo0?ooo`0G0?ooo`0307lZ:P3oool0oooo00D0oooo00<0003o
003oo`00ool04@00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo00`00?oo00<0oooo0000o`1o:RX0PP3oool00200oooo00<000000?oo
o`3oool0603oool00`1o:RX0oooo0?ooo`050?ooo`030000o`00ool00?oo
01000?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0;003o
o`80003o00<0ObXZ0?ooo`3oool0P@3oool00200oooo00<000000?ooo`3o
ool06@3oool00`1o:RX0oooo0?ooo`050?ooo`030000o`00ool00?oo00l0
0?oo00<0003o003oo`00ool0<`00ool00`000?l00?oo003oo`0:003oo`03
0000o`1o:RX0ObXZ08@0oooo000P0?ooo`030000003oool0oooo01X0oooo
00<0ObXZ0?ooo`3oool01@3oool00`000?l00?oo003oo`0>003oo`030000
o`00ool00?oo03<00?oo00<0003o003oo`00ool02000ool20000o`0307lZ
:P3oool0oooo08@0oooo000P0?ooo`030000003oool0oooo01/0oooo00<0
ObXZ0?ooo`3oool01@3oool00`000?l00?oo003oo`0=003oo`030000o`00
ool00?oo03<00?oo00<0003o003oo`00ool01`00ool00`000?l0oooo07lZ
:P270?ooo`00803oool00`000000oooo0?ooo`0L0?ooo`80ObXZ1P3oool0
0`000?l00?oo003oo`0<003oo`030000o`00ool00?oo03<00?oo00<0003o
003oo`00ool01P00ool00`000?l0ObXZ07lZ:P280?ooo`004P3oool01@00
0000oooo0?ooo`000000d=3@0080CTi>00<0d=3@0?ooo`3oool0103oool0
0`000000oooo0?ooo`0N0?ooo`0307lZ:P3oool0oooo00@0oooo00<0003o
003oo`00ool02`00ool00`000?l00?oo003oo`0c003oo`030000o`00ool0
0?oo00@00?oo0P000?l00`1o:RX0oooo0?ooo`280?ooo`004P3oool01@00
0000oooo0?ooo`3oool0CTi>0080oooo00<0CTi>0?ooo`3oool0103oool3
000001l0oooo00<0ObXZ0?ooo`3oool0103oool00`000?l00?oo003oo`0:
003oo`030000o`00ool00?oo03<00?oo00<0003o003oo`00ool00P00ool2
0000o`80ObXZR`3oool00180oooo00<000000?ooo`3oool0103oool00`1>
CTh0oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<0ObXZ0?oo
o`3oool0103oool00`000?l00?oo003oo`09003oo`030000o`00ool00?oo
03<00?oo00D0003o003oo`00ool00?oo0000o`0207lZ:Xd0oooo000B0?oo
o`040000003oool0oooo0?ooo`80J6QX00<0CTi>0=3@d03oool01@3oool0
0`000000oooo0?ooo`0Q0?ooo`0307lZ:P3oool0oooo00@0oooo00<0003o
003oo`00ool02000ool00`000?l00?oo003oo`0c003oo`050000o`00ool0
0?oo0000o`1o:RX0S`3oool00140oooo00<0YjNW0000003oool00P3oool0
0`2c/k<0alO70?ooo`070?ooo`030000003oool0oooo0280oooo00<0ObXZ
0?ooo`3oool0103oool00`000?l00?oo003oo`07003oo`030000o`00ool0
0?oo03800?oo00<0ObXZ0000o`00ool00P1o:RZ@0?ooo`004P3oool01@1X
J6P0oooo0?ooo`3oool0jNWY00<000001P3oool00`000000oooo0?ooo`0S
0?ooo`80ObXZ1@3oool00`000?l00?oo003oo`06003oo`030000o`00ool0
0?oo03400?oo101o:RZB0?ooo`00803oool00`000000oooo0?ooo`0U0?oo
o`0307lZ:P3oool0oooo00<0oooo00<0003o003oo`00ool01@00ool00`00
0?l00?oo003oo`0^003oo`<0003o101o:RZB0?ooo`00803oool00`000000
oooo0?ooo`0V0?ooo`0307lZ:P3oool0oooo00<0oooo00<0003o003oo`00
ool01000ool00`000?l00?oo003oo`0W003oo`L0003o0P3oool407lZ:Y<0
oooo000P0?ooo`030000003oool0oooo02L0oooo00<0ObXZ0?ooo`3oool0
0`3oool00`000?l00?oo003oo`03003oo`030000o`00ool00?oo02400?oo
1P000?l70?ooo`80ObXZU`3oool00200oooo00<000000?ooo`3oool0:03o
ool207lZ:P@0oooo00<0003o003oo`00ool00P00ool00`000?l00?oo003o
o`0J003oo`L0003o2`3oool207lZ:YT0oooo000P0?ooo`030000003oool0
oooo02X0oooo0P1o:RX30?ooo`050000o`00ool00?oo003oo`000?l05@00
ool70000oa00oooo0P1o:RZK0?ooo`00803oool00`000000oooo0?ooo`0/
0?ooo`80ObXZ0P3oool010000?l00?oo003oo`000?l>003oo`L0003o5@3o
ool207lZ:Yd0oooo000P0?ooo`030000003oool0oooo02h0oooo0P1o:RX0
103oool0003o003oo`000?l8003oo`H0003o6@3oool307lZ:Yl0oooo000P
0?ooo`030000003oool0oooo0300oooo0`1o:RX010000?l00?oo003oo`00
ool50000oa`0oooo0`1o:RZR0?ooo`00803oool00`000000oooo0?ooo`0a
0?ooo`@0ObXZ0P000?lN0?ooo`<0ObXZY@3oool00200oooo00<000000?oo
o`3oool0<@3oool807lZ:QP0oooo101o:RZX0?ooo`00803oool00`000000
oooo0?ooo`0b0?ooo`80ObXZ1@3oool407lZ:Q00oooo101o:RZ/0?ooo`00
803oool00`000000oooo0?ooo`0m0?oooa00ObXZ/03oool00200oooo00<0
00000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool0
0200oooo00<000000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3o
ool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool00200oooo00<0
00000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3oool0o@3oool0
0200oooo00<000000?ooo`3oool0o@3oool00200oooo00<000000?ooo`3o
ool0o@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001l0oooo00<0
Vi^K0?ooo`3oool0oP3oool001l0oooo00<0CTi>0?ooo`3oool0oP3oool0
01h0oooo00<0lO7a0000003YjNT0o`3oool001h0oooo00<0/k>c08f=S@2W
YjL0o`3oool001h0oooo00<0CTi>0?7al@1XJ6P0o`3oool001d0oooo00D0
d=3@0:NWY`3oool0YjNW0=3@d03n0?ooo`007@3oool01@1lO7`0jNWY0?oo
o`3YjNT0O7al0?h0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo0000\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
AP3oool01`2c/k<000000000002c/k<0oooo0000001>CTh00`00000Q0?oo
o`060;>c/`00000000000;>c/`3oool000000P3oool00`000000oooo0?oo
o`0P0?ooo`070;>c/`00000000000;>c/`3oool000000>7Qh@0204i>CP03
0=3@d03oool0oooo01l0oooo00L0/k>c000000000000/k>c0?ooo`000000
d=3@0080CTi>00<0d=3@0?ooo`3oool0903oool00`000000oooo0?ooo`0V
0?ooo`00AP3oool0101XJ6P0lO7a0?7al@1XJ6P20?ooo`030=3@d02=SHd0
oooo0280oooo00@0J6QX0?7al@3alO40J6QX0`3oool300000240oooo00@0
J6QX0?7al@3alO40J6QX0P3oool0101lO7`0lO7a0?ooo`1>CThQ0?ooo`04
06QXJ03alO40lO7a06QXJ080oooo00@0J6QX0?ooo`3oool0CTi>9P3oool0
0`000000oooo0?ooo`0V0?ooo`00AP3oool010000000oooo0?ooo`000004
0?ooo`030:NWY`3oool0oooo0200oooo00@000000?ooo`3oool000000`3o
ool00`1XJ6P000000?ooo`0Q0?ooo`040000003oool0oooo00000080oooo
00@000000>WYj@3oool0CTi>8@3oool010000000oooo0?ooo`0000020?oo
o`0404i>CP3oool0oooo06QXJ2H0oooo00<000000?ooo`3oool09P3oool0
04H0oooo00@000000?ooo`3oool00000103oool00`3YjNT0SHf=0?ooo`0P
0?ooo`040000003oool0oooo000000<0oooo00<0YjNW0000003oool08@3o
ool010000000oooo0?ooo`0000020?ooo`040000002=SHd000000=3@d240
oooo00@000000?ooo`3oool000000P3oool0103@d=0000000000003@d=0V
0?ooo`030000003oool0oooo02H0oooo00160?ooo`0406QXJ03alO40jNWY
07alO080oooo00@0CTi>0>WYj@3YjNT000008@3oool0101XJ6P0lO7a0>WY
j@1lO7`30?ooo`030=3@d0000000oooo0240oooo00@0J6QX0?7al@3YjNT0
O7al0P3oool00`2=SHd0jNWY0?ooo`0R0?ooo`0406QXJ03alO40jNWY07al
O080oooo00@0CTi>0?ooo`3oool0CTi>9@3oool00`2WYjL000000?ooo`0W
0?ooo`00AP3oool0102m_Kd000000000002m_Kd20?ooo`040=3@d01>CTh0
CTi>0=3@d240oooo00@0_Kfm000000000000_Kfm0`3oool00`3alO400000
0?ooo`0Q0?ooo`040;fm_@00000000000;fm_@80oooo00@0jNWY06QXJ000
0000/k>c8@3oool0102m_Kd000000000002m_Kd20?ooo`040;>c/`000000
00000;fm_BH0oooo00<0J6QX0?ooo`3oool09P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo2`3oool00`1lO7`0d=3@
07alO00C0?ooo`005P3ooomf00000003001T00000000000006P0000000<0
06@00000000000002@0000070?ooo`030=3@d0000000d=3@01<0oooo000P
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0C0?ooo`03001T003oool0oooo0180oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`03001T003oool0
oooo0100oooo00<0lO7a0000003alO404`3oool00200oooo00<0000007cl
001lo000J@1lo0000`00I000O?`007cl001X07cl0003001T003oool0oooo
0100oooo00<0d=3@0000003@d=004`3oool00200oooo00<0000007cl001l
o000J@1lo0000`00I000O?`007cl001X07cl0003001T003oool0oooo0100
oooo00<0O7al0=3@d01lO7`04`3oool00200oooo00<0000007cl001lo000
J@1lo0000`00I000O?`007cl001X07cl0003001T003oool0oooo02H0oooo
000P0?ooo`030000001lo000O?`006T0O?`000<006@007cl001lo000J01l
o0000`00I000oooo0?ooo`0V0?ooo`00803oool00`000000O?`007cl001Y
07cl0003001T001lo000O?`006P0O?`000<006@00?ooo`3oool09P3oool0
0200oooo00<0000007cl001lo000J@1lo0000`00I000O?`007cl001X07cl
0003001T003oool0oooo02H0oooo000P0?ooo`030000001lo000O?`006T0
O?`000<006@007cl001lo000J01lo0000`00I000oooo0?ooo`0V0?ooo`00
803oool00`000000O?`007cl001Y07cl0003001T001lo000O?`006P0O?`0
00<006@00?ooo`3oool09P3oool00200oooo00<0000007cl001lo000J@1l
o0000`00I000O?`007cl001X07cl0003001T003oool0oooo02H0oooo000P
0?ooo`030000001lo000O?`006T0O?`000<006@007cl001lo000J01lo000
0`00I000oooo0?ooo`0V0?ooo`00803oool00`000000O?`007cl001Y07cl
0003001T001lo000O?`006P0O?`000<006@00?ooo`3oool09P3oool00200
oooo00<0000007cl001lo000J@1lo0000`00I000O?`007cl001X07cl0003
001T003oool0oooo02H0oooo000P0?ooo`030000001lo000O?`006T0O?`0
00<006@007cl001lo000J01lo0000`00I000oooo0?ooo`0V0?ooo`00803o
ool00`000000O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<0
06@00?ooo`3oool09P3oool00200oooo00<0000007cl001lo000J@1lo000
0`00I000O?`007cl001X07cl0003001T003oool0oooo02H0oooo000P0?oo
o`030000001lo000O?`006T0O?`000<006@007cl001lo000J01lo0000`00
I000oooo0?ooo`0V0?ooo`00803oool00`000000O?`007cl001Y07cl0003
001T001lo000O?`006P0O?`000<006@00?ooo`3oool09P3oool00200oooo
00<0000007cl001lo000J@1lo0000`00I000O?`007cl001X07cl0003001T
003oool0oooo02H0oooo000P0?ooo`030000001lo000O?`006T0O?`000<0
06@007cl001lo000J01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool0
0`000000O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<006@0
0?ooo`3oool09P3oool00200oooo00<0000007cl001lo000J@1lo0000`00
I000O?`007cl001X07cl0003001T003oool0oooo02H0oooo000P0?ooo`03
0000001lo000O?`006T0O?`000<006@007cl001lo000J01lo0000`00I000
oooo0?ooo`0V0?ooo`00803oool00`000000O?`007cl001Y07cl0003001T
001lo000O?`006P0O?`000<006@00?ooo`3oool09P3oool00200oooo00<0
000007cl001lo000J@1lo0000`00I000O?`007cl001X07cl0003001T003o
ool0oooo02H0oooo000P0?ooo`030000001lo000O?`006T0O?`000<006@0
07cl001lo000J01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool00`00
0000O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<006@00?oo
o`3oool09P3oool00200oooo00<0000007cl001lo000J@1lo0000`00I000
O?`007cl001X07cl0003001T003oool0oooo02H0oooo000P0?ooo`030000
001lo000O?`006T0O?`000<006@007cl001lo000J01lo0000`00I000oooo
0?ooo`0V0?ooo`00803oool00`000000O?`007cl001Y07cl0003001T001l
o000O?`006P0O?`000<006@00?ooo`3oool09P3oool00200oooo00<00000
07cl001lo000J@1lo0000`00I000O?`007cl001X07cl0003001T003oool0
oooo02H0oooo000P0?ooo`030000001lo000O?`006T0O?`000<006@007cl
001lo000J01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool00`000000
O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<006@00?ooo`3o
ool09P3oool00200oooo00<0000007cl001lo000J@1lo0000`00I000O?`0
07cl001X07cl0003001T003oool0oooo02H0oooo000P0?ooo`030000001l
o000O?`006T0O?`000<006@007cl001lo000J01lo0000`00I000oooo0?oo
o`0V0?ooo`00803oool00`000000O?`007cl001Y07cl0003001T001lo000
O?`006P0O?`000<006@00?ooo`3oool09P3oool00200oooo00<0000007cl
001lo000J@1lo0000`00I000O?`007cl001X07cl0003001T003oool0oooo
02H0oooo000P0?ooo`030000001lo000O?`006T0O?`000<006@007cl001l
o000J01lo0000`00I000oooo0?ooo`0V0?ooo`00403oool01`2c/k<00000
0000002c/k<0oooo0000003@d=000P1>CTh00`3@d=00oooo0?ooo`040?oo
o`030000001lo000O?`006T0O?`000<006@007cl001lo000J01lo0000`00
I000oooo0?ooo`0V0?ooo`00403oool0101XJ6P0lO7a0?7al@1XJ6P20?oo
o`0404i>CP3oool0oooo04i>CPH0oooo00<0000007cl001lo000J@1lo000
0`00I000O?`007cl001X07cl0003001T003oool0oooo02H0oooo000@0?oo
o`040000003oool0oooo000000D0oooo00<0CTi>0?ooo`3oool0103oool0
0`000000O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<006@0
0?ooo`3oool09P3oool00100oooo00@000000?ooo`3oool000000P3oool2
06QXJ00304i>CP3@d=00oooo00D0oooo00<0000007cl001lo000J@1lo000
0`00I000O?`007cl001X07cl0003001T003oool0oooo02H0oooo000@0?oo
o`0406QXJ03alO40jNWY07alO080oooo00<0/k>c0<O7a`3oool01`3oool0
0`000000O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<006@0
0?ooo`3oool09P3oool00100oooo00@0_Kfm000000000000_Kfm0P3oool0
103YjNT000000000000000060?ooo`030000001lo000O?`006T0O?`000<0
06@007cl001lo000J01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool0
0`000000O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<006@0
0?ooo`3oool09P3oool00200oooo00<0000007cl001lo000J@1lo0000`00
I000O?`007cl001X07cl0003001T003oool0oooo02H0oooo000P0?ooo`03
0000001lo000O?`006T0O?`000<006@007cl001lo000J01lo0000`00I000
oooo0?ooo`0V0?ooo`00803oool00`000000O?`007cl001Y07cl0003001T
001lo000O?`006P0O?`000<006@00?ooo`3oool09P3oool00200oooo00<0
000007cl001lo000J@1lo0000`00I000O?`007cl001X07cl0003001T003o
ool0oooo02H0oooo000P0?ooo`030000001lo000O?`006T0O?`000<006@0
07cl001lo000J01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool00`00
0000O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<006@00?oo
o`3oool09P3oool00200oooo00<0000007cl001lo000J@1lo0000`00I000
O?`007cl001X07cl0003001T003oool0oooo02H0oooo000P0?ooo`030000
001lo000O?`006T0O?`000<006@007cl001lo000J01lo0000`00I000oooo
0?ooo`0V0?ooo`00803oool00`000000O?`007cl001Y07cl0003001T001l
o000O?`006P0O?`000<006@00?ooo`3oool09P3oool00200oooo00<00000
07cl001lo000J@1lo0000`00I000O?`007cl001X07cl0003001T003oool0
oooo02H0oooo000P0?ooo`030000001lo000O?`006T0O?`000<006@007cl
001lo000J01lo0000`00I000oooo0?ooo`0V0?ooo`00803oool00`000000
O?`007cl001Y07cl0003001T001lo000O?`006P0O?`000<006@00?ooo`3o
ool09P3oool00200oooo00<0000007cl001lo000J@1lo0000`00I000O?`0
07cl001X07cl0003001T001o:RX0oooo02H0oooo000P0?ooo`030000001l
o000O?`006T0O?`000<006@007cl001lo000I`1lo00407lZ:RH0oooo000P
0?ooo`030000001lo000O?`006T0O?`000<006@007cl001lo000I01lo007
07lZ:RH0oooo000P0?ooo`030000001lo000O?`006T0O?`000<006@007cl
001lo000H@1lo00307lZ:P8006@00P3oool207lZ:RL0oooo000P0?ooo`03
0000001lo000O?`006T0O?`000<006@007cl001lo000GP1lo00307lZ:P80
06@0;P3oool00200oooo00<0000007cl001lo000J@1lo0000`00I000O?`0
07cl001L07cl0080ObXZ00<0O?`0001T0000I000<03oool00200oooo00<0
000007cl001lo000J@1lo0000`00I000O?`007cl001J07cl0080ObXZ00<0
O?`0001T0000I000<P3oool00200oooo00<0000007cl001lo000J@1lo000
0`00I000O?`007cl001H07cl0080ObXZ00<0O?`0001T0000I000=03oool0
0200oooo00<0000007cl001lo000J@1lo0000`00I000O?`007cl001E07cl
00<0ObXZ00<0O?`0001T0000I000=P3oool00200oooo00<0000007cl001l
o000J@1lo0000`00I000O?`007cl001C07cl0080ObXZ00@0O?`0001T0000
I00006@0>03oool00200oooo00<0000007cl001lo000J@1lo0000`00I000
O?`007cl001A07cl0080ObXZ00<0O?`0001T0000I000>`3oool00200oooo
00<0000007cl001lo000J@1lo0000`00I000O?`007cl001?07cl0080ObXZ
00<0O?`0001T0000I000?@3oool00200oooo00<0000007cl001lo000J@1l
o0000`00I000O?`007cl001=07cl0080ObXZ00<0O?`0001T0000I000?`3o
ool00200oooo00<0000007cl001lo000J@1lo0000`00I000O?`007cl001;
07cl0080ObXZ00<0O?`0001T0000I000@@3oool00200oooo00<0000007cl
001lo000J@1lo0000`00I000O?`007cl001907cl0080ObXZ0P1lo0000`00
I000oooo0?ooo`110?ooo`00803oool00`000000O?`007cl001Y07cl0003
001T001lo000O?`004L0O?`00P1o:RX207cl008006@0A03oool00200oooo
00<0000007cl001lo000J@1lo0000`00I000O?`007cl001507cl0080ObXZ
0P1lo002001T04H0oooo000P0?ooo`030000001lo000O?`006T0O?`000<0
06@007cl001lo000A01lo0000`1o:RX0O?`007cl0002001T04P0oooo000P
0?ooo`030000001lo000O?`006T0O?`000<006@007cl001lo000@P1lo002
07lZ:P0307cl0000I00006@004X0oooo000P0?ooo`030000001lo000O?`0
06T0O?`000<006@007cl001lo000@@1lo000101o:RX0O?`0001T0000I01<
0?ooo`00803oool00`000000O?`007cl001Y07cl0003001T001lo000O?`0
03l0O?`00P1o:RX2001T04h0oooo000P0?ooo`030000001lo000O?`006T0
O?`000<006@007cl001lo000?P1lo0000`1o:RX0O?`0001T001@0?ooo`00
6@3oool00`000000oooo0?ooo`030?ooo`80ObXZJ`1lo0000`00I000O?`0
07cl000l07cl0080ObXZ0P00I01A0?ooo`006@3oool00`000000oooo0?oo
o`020?ooo`@0ObXZJP1lo0000`00I000O?`007cl000k07cl000307lZ:P00
I00006@005<0oooo000I0?ooo`030000003oool0oooo0080oooo101o:RYZ
07cl0003001T001lo000O?`003X0O?`000<0ObXZ001T003oool0E03oool0
01T0oooo00<000000?ooo`3oool00`3oool307lZ:VX0O?`000<006@007cl
001lo000>01lo00207lZ:P03001T003oool0oooo05@0oooo000H0?ooo`03
0:NWY`000000oooo00D0oooo00<0000007lZ:P00I000J@1lo0000`00I000
O?`007cl000g07cl000307lZ:P00I000oooo05L0oooo000I0?ooo`0306QX
J03oool0oooo00@0oooo00<000000?ooo`1o:RX0J@1lo0000`00I000O?`0
07cl000f07cl000307lZ:P3oool0oooo05P0oooo000P0?ooo`040000003o
ool0oooo07lZ:VP0O?`000<006@007cl001lo000<P1lo00407lZ:U/0oooo
000P0?ooo`050000003oool0oooo0?ooo`1o:RX0I`1lo0000`00I000O?`0
07cl000a07cl00@0ObXZG03oool00200oooo00H000000?ooo`3oool0oooo
07lZ:P00I01V07cl0003001T001lo000O?`00340O?`0101o:RYL0?ooo`00
803oool00`000000oooo0?ooo`020?ooo`0307lZ:P00I000O?`006@0O?`0
00<006@007cl001lo000;`1lo0000`00I000ObXZ07lZ:P0207lZ:Ud0oooo
000P0?ooo`030000003oool0oooo00<0oooo00<0ObXZ07cl001lo000H`1l
o0000`00I000O?`007cl000^07cl0003001T001o:RX0oooo0600oooo000P
0?ooo`030000003oool0oooo00@0oooo00<0ObXZ07cl001lo000HP1lo000
0`00I000O?`007cl000/07cl00030?ooo`1o:RX0ObXZ0680oooo000P0?oo
o`030000003oool0oooo00@0oooo00<0ObXZ07cl001lo000HP1lo0000`00
I000O?`007cl000Z07cl00030?ooo`00I000ObXZ06@0oooo000P0?ooo`03
0000003oool0oooo00D0oooo00<0ObXZ07cl001lo000H@1lo0000`00I000
O?`007cl000Y07cl00030?ooo`1o:RX0ObXZ06D0oooo000P0?ooo`030000
003oool0oooo00D0oooo00<006@007lZ:P1lo000H@1lo0000`00I000O?`0
07cl000X07cl0003001T001o:RX0oooo06H0oooo000P0?ooo`030000003o
ool0oooo00H0oooo00<006@007lZ:P1lo000H01lo0000`00I000O?`007cl
000V07cl008006@000<0ObXZ0?ooo`3oool0IP3oool00200oooo00<00000
0?ooo`3oool01`3oool00`00I000ObXZ07cl001O07cl0003001T001lo000
O?`002D0O?`000<006@007lZ:P1o:RX0J@3oool00200oooo00<000000?oo
o`3oool0203oool00`1o:RX0O?`007cl001N07cl0003001T001lo000O?`0
02@0O?`000<006@007lZ:P3oool0JP3oool00200oooo00<000000?ooo`3o
ool0203oool00`00I000ObXZ07cl001N07cl0003001T001lo000O?`00280
O?`00P00I0000`1o:RX0oooo0?ooo`1Z0?ooo`00803oool00`000000oooo
0?ooo`090?ooo`03001T001o:RX0O?`005d0O?`000<006@007cl001lo000
8@1lo0000`00I000ObXZ07lZ:P1]0?ooo`00803oool00`000000oooo0?oo
o`0:0?ooo`03001T001o:RX0O?`005`0O?`000<006@007cl001lo0007`1l
o002001T000307lZ:P3oool0oooo06d0oooo000P0?ooo`030000003oool0
oooo00/0oooo00<0ObXZ07cl001lo000F`1lo0000`00I000O?`007cl000M
07cl008006@000<0oooo07lZ:P3oool0K`3oool00200oooo00<000000?oo
o`3oool0303oool00`1o:RX0O?`007cl001J07cl0003001T001lo000O?`0
01`0O?`000@006@00?ooo`3oool0ObXZL@3oool00200oooo00<000000?oo
o`3oool03@3oool00`1o:RX0O?`007cl001I07cl0003001T001lo000O?`0
01/0O?`000@006@00?ooo`1o:RX0ObXZLP3oool00200oooo00<000000?oo
o`3oool03@3oool00`00I000ObXZ07cl001I07cl0003001T001lo000O?`0
01T0O?`00P00I0000`3oool0ObXZ0?ooo`1c0?ooo`00803oool00`000000
oooo0?ooo`0>0?ooo`0307lZ:P1lo000O?`005P0O?`000<006@007cl001l
o000601lo0001000I000oooo0?ooo`1o:RYe0?ooo`00803oool00`000000
oooo0?ooo`0?0?ooo`0307lZ:P1lo000O?`005L0O?`000<006@007cl001l
o0005`1lo0001000I000oooo07lZ:P1o:RYf0?ooo`00803oool00`000000
oooo0?ooo`0@0?ooo`0307lZ:P1lo000O?`005H0O?`000<006@007cl001l
o0005@1lo002001T00030?ooo`1o:RX0oooo07L0oooo000P0?ooo`030000
003oool0oooo0140oooo00<0ObXZ07cl001lo000E@1lo0000`00I000O?`0
07cl000D07cl0004001T003oool0oooo07lZ:WT0oooo000P0?ooo`030000
003oool0oooo0180oooo00<0ObXZ07cl001lo000E01lo0000`00I000O?`0
07cl000C07cl0004001T003oool0oooo07lZ:WX0oooo000P0?ooo`030000
003oool0oooo01<0oooo00<0ObXZ07cl001lo000D`1lo0000`00I000O?`0
07cl000B07cl0004001T003oool0ObXZ07lZ:W/0oooo000P0?ooo`030000
003oool0oooo01@0oooo00<0ObXZ07cl001lo000DP1lo0000`00I000O?`0
07cl000@07cl008006@000<0oooo07lZ:P3oool0O03oool00200oooo00<0
00000?ooo`3oool0503oool00`1o:RX006@007cl001B07cl0003001T001l
o000O?`000l0O?`000@006@00?ooo`3oool0ObXZOP3oool00200oooo00<0
00000?ooo`3oool05@3oool00`1o:RX006@007cl001A07cl0003001T001l
o000O?`000d0O?`00P00I0000`3oool0ObXZ07lZ:P1o0?ooo`00803oool0
0`000000oooo0?ooo`0F0?ooo`0307lZ:P1lo000O?`00500O?`000<006@0
07cl001lo0002`1lo002001T0080oooo00<0ObXZ0?ooo`3oool0O`3oool0
0200oooo00<000000?ooo`3oool05`3oool00`1o:RX0O?`007cl001?07cl
0003001T001lo000O?`000X0O?`000D006@00?ooo`3oool0oooo07lZ:P22
0?ooo`00803oool00`000000oooo0?ooo`0H0?ooo`0307lZ:P1lo000O?`0
04h0O?`000<006@007cl001lo0002@1lo0001@00I000oooo0?ooo`3oool0
ObXZ08<0oooo000P0?ooo`030000003oool0oooo01T0oooo00<0ObXZ07cl
001lo000C@1lo0000`00I000O?`007cl000807cl0003001T003oool0oooo
0080ObXZQ03oool00200oooo00<000000?ooo`3oool06P3oool00`1o:RX0
06@007cl001<07cl0003001T001lo000O?`000L0O?`000@006@00?ooo`3o
ool0ObXZQP3oool00200oooo00<000000?ooo`3oool06`3oool00`1o:RX0
06@007cl001;07cl0003001T001lo000O?`000H0O?`000@006@00?ooo`3o
ool0ObXZQ`3oool00200oooo00<000000?ooo`3oool0703oool207lZ:T/0
O?`000<006@007cl001lo0001@1lo0001000I000oooo07lZ:P1o:RZ80?oo
o`004P3oool01@000000oooo0?ooo`000000d=3@0080CTi>00<0d=3@0?oo
o`3oool0103oool00`000000oooo0?ooo`0N0?ooo`0307lZ:P1lo000O?`0
04P0O?`000<006@007cl001lo0000`1lo002001T00030?ooo`1o:RX0oooo
08T0oooo000B0?ooo`050000003oool0oooo0?ooo`1>CTh00P3oool00`1>
CTh0oooo0?ooo`040?ooo`<000007`3oool00`1o:RX0O?`007cl001707cl
0003001T001lo000O?`00080O?`000@006@00?ooo`1o:RX0ObXZR`3oool0
0180oooo00<000000?ooo`3oool0103oool00`1>CTh0oooo0?ooo`040?oo
o`030000003oool0oooo0200oooo00<0ObXZ07cl001lo000AP1lo0001@00
I000O?`007cl001lo00006@00080ObXZS@3oool00180oooo00@000000?oo
o`3oool0oooo0P1XJ6P00`1>CTh0d=3@0?ooo`050?ooo`030000003oool0
oooo0240oooo00<0ObXZ07cl001lo000A@1lo0001@00I000O?`007cl0000
I000ObXZ08l0oooo000A0?ooo`030:NWY`000000oooo0080oooo00<0/k>c
0<O7a`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`0307lZ:P00I000
O?`004<0O?`000<0ObXZ001T0000I0000P1o:RZ@0?ooo`004P3oool01@1X
J6P0oooo0?ooo`3oool0jNWY00<000001P3oool00`000000oooo0?ooo`0S
0?ooo`80ObXZ00<006@007cl001lo000?`1lo00407lZ:Y80oooo000P0?oo
o`030000003oool0oooo02D0oooo00<0ObXZ001T001lo000?`1lo00407lZ
:Y80oooo000P0?ooo`030000003oool0oooo02H0oooo00<0ObXZ001T001l
o000?@1lo00407lZ:Y<0oooo000P0?ooo`030000003oool0oooo02L0oooo
00<0ObXZ001T0000I000>P1lo00207lZ:YL0oooo000P0?ooo`030000003o
ool0oooo02P0oooo0P1o:RX00`00I000O?`007cl000e07cl0080ObXZ00<0
06@00?ooo`3oool0UP3oool00200oooo00<000000?ooo`3oool0:P3oool2
07lZ:P03001T001lo000O?`00340O?`00P1o:RX2001T09T0oooo000P0?oo
o`030000003oool0oooo02`0oooo0P1o:RX00`00I000O?`007cl000]07cl
0080ObXZ0P00I02K0?ooo`00803oool00`000000oooo0?ooo`0^0?ooo`80
ObXZ:`1lo00307lZ:P03001T003oool0oooo09`0oooo000P0?ooo`030000
003oool0oooo0300oooo101o:RXT07cl00<0ObXZ0P00I02P0?ooo`00803o
ool00`000000oooo0?ooo`0a0?ooo`@0ObXZ801lo00307lZ:P0307cl0000
I00006@00:80oooo000P0?ooo`030000003oool0oooo0340oooo201o:RXH
07cl00@0ObXZ1000I02T0?ooo`00803oool00`000000oooo0?ooo`0b0?oo
o`80ObXZ0`3oool2001T00@0ObXZ401lo00407lZ:P0407cl0000I00006@0
001T0:P0oooo000P0?ooo`030000003oool0oooo03X0oooo0`00I00@07lZ
:P0307cl0000I00006@0008006@0Z`3oool00200oooo00<000000?ooo`3o
ool0@03oool>001T0:l0oooo000P0?ooo`030000003oool0oooo0?d0oooo
000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0
oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`03
0000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo0?d0oooo
000P0?ooo`030000003oool0oooo0?d0oooo000P0?ooo`030000003oool0
oooo0?d0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000O0?ooo`03
09^KV`3oool0oooo0?h0oooo000O0?ooo`0304i>CP3oool0oooo0?h0oooo
000N0?ooo`030?7al@000000jNWY0?l0oooo000N0?ooo`030;>c/`2=SHd0
YjNW0?l0oooo000N0?ooo`0304i>CP3alO40J6QX0?l0oooo000M0?ooo`05
0=3@d02WYjL0oooo0:NWY`3@d=00oP3oool001d0oooo00D0O7al0>WYj@3o
ool0jNWY07alO03n0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "\n\t\tComposite T",
  StyleBox["rapezoidal Rule\t\t\t\t\tComposite Simpson\[CloseCurlyQuote]s \
Rule",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
AP3oool01`2c/k<000000000002c/k<0oooo0000001>CTh00`00000Q0?oo
o`060;>c/`00000000000;>c/`3oool000000P3oool00`000000oooo0?oo
o`0P0?ooo`070;>c/`00000000000;>c/`3oool000000>7Qh@0204i>CP03
0=3@d03oool0oooo01l0oooo00L0/k>c000000000000/k>c0?ooo`000000
d=3@0080CTi>00<0d=3@0?ooo`3oool0903oool00`000000oooo0?ooo`0V
0?ooo`00AP3oool0101XJ6P0lO7a0?7al@1XJ6P20?ooo`030=3@d02=SHd0
oooo0280oooo00@0J6QX0?7al@3alO40J6QX0`3oool300000240oooo00@0
J6QX0?7al@3alO40J6QX0P3oool0101lO7`0lO7a0?ooo`1>CThQ0?ooo`04
06QXJ03alO40lO7a06QXJ080oooo00@0J6QX0?ooo`3oool0CTi>9P3oool0
0`000000oooo0?ooo`0V0?ooo`00AP3oool010000000oooo0?ooo`000004
0?ooo`030:NWY`3oool0oooo0200oooo00@000000?ooo`3oool000000`3o
ool00`1XJ6P000000?ooo`0Q0?ooo`040000003oool0oooo00000080oooo
00@000000>WYj@3oool0CTi>8@3oool010000000oooo0?ooo`0000020?oo
o`0404i>CP3oool0oooo06QXJ2H0oooo00<000000?ooo`3oool09P3oool0
04H0oooo00@000000?ooo`3oool00000103oool00`3YjNT0SHf=0?ooo`0P
0?ooo`040000003oool0oooo000000<0oooo00<0YjNW0000003oool08@3o
ool010000000oooo0?ooo`0000020?ooo`040000002=SHd000000=3@d240
oooo00@000000?ooo`3oool000000P3oool0103@d=0000000000003@d=0V
0?ooo`030000003oool0oooo02H0oooo00160?ooo`0406QXJ03alO40jNWY
07alO080oooo00@0CTi>0>WYj@3YjNT000008@3oool0101XJ6P0lO7a0>WY
j@1lO7`30?ooo`030=3@d0000000oooo0240oooo00@0J6QX0?7al@3YjNT0
O7al0P3oool00`2=SHd0jNWY0?ooo`0R0?ooo`0406QXJ03alO40jNWY07al
O080oooo00@0CTi>0?ooo`3oool0CTi>9@3oool00`2WYjL000000?ooo`0W
0?ooo`00AP3oool0102m_Kd000000000002m_Kd20?ooo`040=3@d01>CTh0
CTi>0=3@d240oooo00@0_Kfm000000000000_Kfm0`3oool00`3alO400000
0?ooo`0Q0?ooo`040;fm_@00000000000;fm_@80oooo00@0jNWY06QXJ000
0000/k>c8@3oool0102m_Kd000000000002m_Kd20?ooo`040;>c/`000000
00000;fm_BH0oooo00<0J6QX0?ooo`3oool09P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo2`3oool00`1lO7`0d=3@
07alO00C0?ooo`005P3ooooQ000000030?l000000000000000T000001`3o
ool00`3@d=0000000=3@d00C0?ooo`00803oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<0o`00
0?ooo`3oool0403oool00`3alO4000000?7al@0C0?ooo`00803oool00`00
0000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo0100oooo00<0d=3@0000
003@d=004`3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000
oooo0?ooo`0@0?ooo`0307alO03@d=00O7al01<0oooo000P0?ooo`030000
003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200oooo00<0
00000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803oool0
0`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P0?oo
o`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200
oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00
803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo
000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3o
ool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V
0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo
02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3o
ool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo
0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003o
ool0oooo02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`00
0?ooo`3oool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o
0000oooo0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`03
0?l0003oool0oooo02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;
00<0o`000?ooo`3oool09P3oool00200oooo00<000000?o0b`3o`</0e03o
`</00`3o0000oooo0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D
0?o0b`030?l0003oool0oooo02H0oooo000P0?ooo`030000003o`</0ol3;
0=@0ol3;00<0o`000?ooo`3oool09P3oool00200oooo00<000000?o0b`3o
`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803oool00`000000ol3;
0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P0?ooo`030000003o
`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200oooo00<00000
0?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803oool00`00
0000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P0?ooo`03
0000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200oooo
00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803o
ool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P
0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool0
0200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?oo
o`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0
oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool0
9P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?oo
o`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0
oooo02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?oo
o`3oool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000
oooo0?ooo`0V0?ooo`00403oool01`2c/k<000000000002c/k<0oooo0000
003@d=000P1>CTh00`3@d=00oooo0?ooo`040?ooo`030000003o`</0ol3;
0=@0ol3;00<0o`000?ooo`3oool09P3oool00100oooo00@0J6QX0?7al@3a
lO40J6QX0P3oool0101>CTh0oooo0?ooo`1>CTh60?ooo`030000003o`</0
ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000001@3oool00`1>CTh0oooo0?ooo`040?ooo`030000003o`</0
ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00100oooo00@000000?oo
o`3oool000000P3oool206QXJ00304i>CP3@d=00oooo00D0oooo00<00000
0?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00403oool0101X
J6P0lO7a0>WYj@1lO7`20?ooo`030;>c/`37alL0oooo00L0oooo00<00000
0?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00403oool0102m
_Kd000000000002m_Kd20?ooo`040>WYj@0000000000000000H0oooo00<0
00000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00803oool0
0`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo000P0?oo
o`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3oool00200
oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V0?ooo`00
803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo02H0oooo
000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3oool09P3o
ool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo0?ooo`0V
0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003oool0oooo
02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`000?ooo`3o
ool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o0000oooo
0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`030?l0003o
ool0oooo02H0oooo000P0?ooo`030000003o`</0ol3;0=@0ol3;00<0o`00
0?ooo`3oool09P3oool00200oooo00<000000?o0b`3o`</0e03o`</00`3o
0000oooo0?ooo`0V0?ooo`00803oool00`000000ol3;0?o0b`3D0?o0b`03
0?l0003oool0oooo00H0oooo0`1o:RXM0?ooo`00803oool00`000000ol3;
0?o0b`3D0?o0b`030?l0001o:RX0oooo0080oooo101o:RXP0?ooo`00803o
ool00`000000ol3;0?o0b`3A0?o0b`80o`0000<0ObXZ0?l0001o:RX00`1o
:RXT0?ooo`00803oool00`000000ol3;0?o0b`3>0?o0b`80o`001`1o:RXV
0?ooo`00803oool00`000000ol3;0?o0b`3:0?o0b`80o`00101o:RX40?oo
o`80ObXZ9`3oool00200oooo00<000000?o0b`3o`</0aP3o`</40?l00080
ObXZ<@3oool00200oooo00<000000?o0b`3o`</0a03o`</20?l00080oooo
0P1o:RXc0?ooo`00803oool00`000000ol3;0?o0b`320?o0b`80o`000P3o
ool207lZ:SD0oooo000P0?ooo`030000003o`</0ol3;0<00ol3;0P3o0000
103oool0ObXZ07lZ:P1o:RXg0?ooo`00803oool00`000000ol3;0?o0b`2n
0?o0b`80o`0000<0oooo07lZ:P1o:RX0>P3oool00200oooo00<000000?o0
b`3o`</0_03o`</20?l000<0ObXZ?03oool00200oooo00<000000?o0b`3o
`</0^P3o`</20?l00080ObXZ?`3oool00200oooo00<000000?o0b`3o`</0
^@3o`</00`3o0000ObXZ07lZ:P110?ooo`00803oool00`000000ol3;0?o0
b`2g0?o0b`030?l0001o:RX0ObXZ04<0oooo000P0?ooo`030000003o`</0
ol3;0;D0ol3;0P3o00000`1o:RX0oooo0?ooo`130?ooo`00803oool00`00
0000ol3;0?o0b`2c0?o0b`80o`000P1o:RY60?ooo`00803oool00`000000
ol3;0?o0b`2a0?o0b`80o`0000<0oooo07lZ:P3oool0A`3oool00200oooo
00<000000?o0b`3o`</0/03o`</0103o0000oooo07lZ:P1o:RY90?ooo`00
803oool00`000000ol3;0?o0b`2_0?o0b`030?l0003oool0ObXZ04/0oooo
000P0?ooo`030000003o`</0ol3;0:d0ol3;0P3o000207lZ:T`0oooo000P
0?ooo`030000003o`</0ol3;0:`0ol3;00<0o`0007lZ:P1o:RX0CP3oool0
0200oooo00<000000?o0b`3o`</0ZP3o`</00`3oool0o`0007lZ:P1@0?oo
o`00803oool00`000000ol3;0?o0b`2Y0?o0b`030?l0001o:RX0ObXZ0540
oooo000I0?ooo`030000003oool0oooo00<0oooo0P1o:RZY0?o0b`030?oo
o`3o0000ObXZ05<0oooo000I0?ooo`030000003oool0oooo0080oooo101o
:RZW0?o0b`030?ooo`1o:RX0ObXZ05@0oooo000I0?ooo`030000003oool0
oooo0080oooo101o:RZV0?o0b`80ObXZEP3oool001T0oooo00<000000?oo
o`3oool00`3oool307lZ:ZD0ol3;00<0ObXZ0?ooo`3oool0EP3oool001P0
oooo00<0YjNW0000003oool01@3oool00`000000ObXZ0?o0b`2R0?o0b`80
ObXZF@3oool001T0oooo00<0J6QX0?ooo`3oool0103oool00`000000oooo
07lZ:P2P0?o0b`80ObXZF`3oool00200oooo00@000000?ooo`3oool0ObXZ
W@3o`</207lZ:P030?l0003oool0oooo05X0oooo000P0?ooo`050000003o
ool0oooo0?l0001o:RX0V`3o`</407lZ:U`0oooo000P0?ooo`050000003o
ool0oooo0?ooo`1o:RX0VP3o`</507lZ:U`0oooo000P0?ooo`030000003o
ool0oooo0080oooo00<0ObXZ0?o0b`3o`</0UP3o`</00`1o:RX0o`000?oo
o`0207lZ:Ud0oooo000P0?ooo`030000003oool0oooo00<0oooo00<0ObXZ
0?o0b`3o`</0U03o`</00`1o:RX0o`000?ooo`1P0?ooo`00803oool00`00
0000oooo0?ooo`030?ooo`030?l0001o:RX0ol3;0980ol3;0P1o:RX00`3o
0000oooo0?ooo`1P0?ooo`00803oool00`000000oooo0?ooo`040?ooo`03
07lZ:P3o`</0ol3;0900ol3;00<0ObXZ0?l0003oool0H`3oool00200oooo
00<000000?ooo`3oool01@3oool00`1o:RX0ol3;0?o0b`2>0?o0b`0307lZ
:P3o0000oooo06@0oooo000P0?ooo`030000003oool0oooo00D0oooo00<0
o`0007lZ:P3o`</0S@3o`</00`1o:RX0o`000?ooo`1U0?ooo`00803oool0
0`000000oooo0?ooo`060?ooo`030?l0001o:RX0ol3;08X0ol3;0P1o:RX0
0`3o0000oooo0?ooo`1U0?ooo`00803oool00`000000oooo0?ooo`070?oo
o`0307lZ:P3o`</0ol3;08P0ol3;00<0ObXZ0?l0003o0000J03oool00200
oooo00<000000?ooo`3oool01`3oool00`3o`</0ObXZ0?o0b`270?o0b`03
07lZ:P3o0000oooo06T0oooo000P0?ooo`030000003oool0oooo00P0oooo
00<0o`0007lZ:P3o`</0Q03o`</207lZ:P030?l0003oool0oooo06T0oooo
000P0?ooo`030000003oool0oooo00T0oooo00<0o`0007lZ:P3o`</0PP3o
`</00`1o:RX0ol3;0?l0001/0?ooo`00803oool00`000000oooo0?ooo`0:
0?ooo`0307lZ:P3o`</0ol3;0800ol3;00<0ObXZ0?l0003o0000K@3oool0
0200oooo00<000000?ooo`3oool02`3oool00`1o:RX0ol3;0?o0b`1n0?o0
b`0307lZ:P3o0000oooo06h0oooo000P0?ooo`030000003oool0oooo00/0
oooo00<0o`0007lZ:P3o`</0O03o`</207lZ:P030?l0003oool0oooo06h0
oooo000P0?ooo`030000003oool0oooo00`0oooo00<0o`0007lZ:P3o`</0
NP3o`</00`1o:RX0ol3;0?l0001a0?ooo`00803oool00`000000oooo0?oo
o`0=0?ooo`0307lZ:P3o`</0ol3;07P0ol3;00<0ObXZ0?l0003o0000LP3o
ool00200oooo00<000000?ooo`3oool03P3oool00`1o:RX0ol3;0?o0b`1f
0?o0b`0307lZ:P3o0000oooo07<0oooo000P0?ooo`030000003oool0oooo
00h0oooo00<0o`0007lZ:P3o`</0M@3o`</00`1o:RX0o`000?ooo`1d0?oo
o`00803oool00`000000oooo0?ooo`0?0?ooo`030?l0001o:RX0ol3;0780
ol3;0P1o:RX00`3o0000oooo0?ooo`1d0?ooo`00803oool00`000000oooo
0?ooo`0@0?ooo`030?l0001o:RX0ol3;0700ol3;00<0ObXZ0?l0003oool0
M`3oool00200oooo00<000000?ooo`3oool04@3oool00`3o0000ObXZ0?o0
b`1^0?o0b`0307lZ:P3o0000oooo07P0oooo000P0?ooo`030000003oool0
oooo0180oooo00<0o`0007lZ:P3o`</0K03o`</00`1o:RX0o`000?ooo`1i
0?ooo`00803oool00`000000oooo0?ooo`0B0?ooo`030?l0001o:RX0ol3;
06/0ol3;00<0ObXZ0?ooo`3oool0NP3oool00200oooo00<000000?ooo`3o
ool04`3oool00`3o0000ObXZ0?o0b`1X0?o0b`80ObXZO@3oool00200oooo
00<000000?ooo`3oool0503oool00`3o0000ObXZ0?o0b`1V0?o0b`0307lZ
:P3o0000oooo07d0oooo000P0?ooo`030000003oool0oooo01D0oooo00<0
o`0007lZ:P3o`</0I03o`</00`1o:RX0oooo0?ooo`1n0?ooo`00803oool0
0`000000oooo0?ooo`0F0?ooo`030?l0001o:RX0ol3;0640ol3;0P1o:RZ1
0?ooo`00803oool00`000000oooo0?ooo`0F0?ooo`030?l0003o`</0ObXZ
0600ol3;00<0ObXZ0?l0003oool0P@3oool00200oooo00<000000?ooo`3o
ool05`3oool00`3o0000ol3;07lZ:P1M0?o0b`80ObXZQ03oool00200oooo
00<000000?ooo`3oool0603oool00`3o0000ol3;07lZ:P1K0?o0b`0307lZ
:P3oool0oooo08@0oooo000P0?ooo`030000003oool0oooo01T0oooo00<0
o`000?o0b`1o:RX0F03o`</207lZ:XL0oooo000P0?ooo`030000003oool0
oooo01X0oooo0P3o00000`1o:RX0ol3;0?o0b`1C0?o0b`030?l0001o:RX0
oooo08P0oooo000B0?ooo`050000003oool0oooo0000003@d=000P1>CTh0
0`3@d=00oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<0o`00
07lZ:P1o:RX0DP3o`</207lZ:XX0oooo000B0?ooo`050000003oool0oooo
0?ooo`1>CTh00P3oool00`1>CTh0oooo0?ooo`040?ooo`<000007@3oool0
0`3o0000ol3;07lZ:P1?0?o0b`030?l0001o:RX0oooo08/0oooo000B0?oo
o`030000003oool0oooo00@0oooo00<0CTi>0?ooo`3oool0103oool00`00
0000oooo0?ooo`0N0?ooo`80o`0000<0ObXZ0?o0b`3o`</0B`3o`</207lZ
:Xd0oooo000B0?ooo`040000003oool0oooo0?ooo`80J6QX00<0CTi>0=3@
d03oool01@3oool00`000000oooo0?ooo`0P0?ooo`030?l0001o:RX0ol3;
04T0ol3;00<0o`0007lZ:P3oool0SP3oool00140oooo00<0YjNW0000003o
ool00P3oool00`2c/k<0alO70?ooo`070?ooo`030000003oool0oooo0240
oooo00<0o`0007lZ:P3o`</0A03o`</207lZ:P030?o0b`1o:RX0ObXZ0900
oooo000B0?ooo`0506QXJ03oool0oooo0?ooo`3YjNT00`0000060?ooo`03
0000003oool0oooo0280oooo00<0o`0007lZ:P3o`</0@P3o`</407lZ:Y80
oooo000P0?ooo`030000003oool0oooo02@0oooo0P1o:RY10?o0b`@0ObXZ
TP3oool00200oooo00<000000?ooo`3oool09P3oool00`1o:RX0ol3;0?o0
b`0l0?o0b`030?l0001o:RX0ObXZ0080ObXZT`3oool00200oooo00<00000
0?ooo`3oool09`3oool207lZ:SX0ol3;00<0o`0007lZ:P1o:RX0U`3oool0
0200oooo00<000000?ooo`3oool0:03oool00`3o0000ObXZ07lZ:P0f0?o0
b`<0ObXZV@3oool00200oooo00<000000?ooo`3oool0:P3oool00`3o0000
ObXZ0?o0b`0b0?o0b`80ObXZW03oool00200oooo00<000000?ooo`3oool0
;03oool207lZ:Rl0ol3;0P1o:RZN0?ooo`00803oool00`000000oooo0?oo
o`0^0?ooo`<0ObXZ:@3o`</00`3oool0ObXZ07lZ:P2P0?ooo`00803oool0
0`000000oooo0?ooo`0`0?ooo`040?l0001o:RX0ObXZ07lZ:R<0ol3;00@0
oooo07lZ:P1o:RX0ObXZXP3oool00200oooo00<000000?ooo`3oool0<@3o
ool407lZ:R00ol3;00@0o`0007lZ:P1o:RX0o`00Y03oool00200oooo00<0
00000?ooo`3oool0<@3oool607lZ:P80o`005`3o`</20?l000@0ObXZY`3o
ool00200oooo00<000000?ooo`3oool0<P3oool207lZ:P<0oooo1@1o:RX4
0?l000T0ol3;1P3o000307lZ:Z/0oooo000P0?ooo`030000003oool0oooo
03`0oooo4`1o:RZ^0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00
803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?oo
o`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`00
0000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00
803oool00`000000oooo0?ooo`3m0?ooo`00803oool00`000000oooo0?oo
o`3m0?ooo`00803oool00`000000oooo0?ooo`3m0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`007`3oool00`2KVi/0oooo0?ooo`3n0?ooo`00
7`3oool00`1>CTh0oooo0?ooo`3n0?ooo`007P3oool00`3alO4000000>WY
j@3o0?ooo`007P3oool00`2c/k<0SHf=0:NWY`3o0?ooo`007P3oool00`1>
CTh0lO7a06QXJ03o0?ooo`007@3oool01@3@d=00YjNW0?ooo`2WYjL0d=3@
0?h0oooo000M0?ooo`0507alO03YjNT0oooo0>WYj@1lO7`0oP3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"], "Graphics",
    Evaluatable->False,
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "\n\t\t",
  StyleBox["Boole\[CloseCurlyQuote]s Rule",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        1 + \[ExponentialE]\^\(-x\)\ Sin[
              4\ x];\)\ \), "\[IndentingNewLine]", 
    \(\(h = 0.25;\)\ \), "\[IndentingNewLine]", 
    \(x\_0 = 0.0; x\_1 = x\_0 + h; x\_2 = x\_0 + 2  h; x\_3 = x\_0 + 3  h; 
    x\_4 = x\_0 + 4  h;\), "\n", 
    \(f\_0 = f[x\_0]; f\_1 = f[x\_1]; f\_2 = f[x\_2]; f\_3 = f[x\_3]; 
    f\_4 = f[x\_4];\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Using the Composite Trapezoidal Rule: \n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \ \)\(\(\[TildeTilde]\)\(\(h\/2\) \((f\_0\  + \ 2  f\_1 + \ 
              2  f\_2 + \ 2  f\_3 + \ f\_4)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(0.25\/2\) \((1.00000 + 2*1.65534 + 
              2*1.55152 + 2*1.06666 + 0.721588)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.125 \((1.00000 + 3.31068 + 3.10303 + 
              2.13332 + 0.721588)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.125 \((10.2686)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(1.28358\)\)\)\)]],
  "  \n\t\n\t",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<The Composite Trapezoidal Rule with  h = \>", 
        h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(h\/2\)(\!\(f\_0\)+2\!\(f\_1\)+2\!\(f\_2\)+2\!\
\(f\_3\)+\!\(f\_4\)) = \>\"", \(h\/2\) \((f\_0 + 2  f\_1 + 2  f\_2 + 
              2  f\_3 + f\_4)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Using the Composite Simpson\[CloseCurlyQuote]s Rule: \n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \ \)\(\(\[TildeTilde]\)\(\ \)\(\(h\/3\) \((f\_0\  + \ 
              4  f\_1\  + \ 2  f\_2 + \ 4  f\_3 + \ f\_4)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(0.25\/3\) \((1.00000 + 4*1.65534 + 
              2*1.55152 + 4*1.06666 + 0.721588)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.083333 \((1.00000 + 6.62136 + 3.10304 + 
              4.26664 + 0.721588)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.083333 \((15.7126)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(1.30938\)\)\)\)]],
  "  \n\t\n\t",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<Composite Simpson's Rule with  h = \>", 
        h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(h\/3\)(\!\(f\_0\)+4\!\(f\_1\)+2\!\(f\_2\)+4\!\
\(f\_3\)+\!\(f\_4\)) = \>\"", \(h\/3\) \((f\_0 + 4  f\_1 + 2  f\_2 + 
              4  f\_3 + f\_4)\)];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Using Boole\[CloseCurlyQuote]s Rule:\n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Integral]\_0\%1\ \ f[x] \[DifferentialD]x\)]],
  Cell[BoxData[
      \(\(\(\ \ \)\(\(\[TildeTilde]\)\(\ \)\(\(\(2  h\)\/45\) \((7 
                 f\_0\  + \ 32  f\_1\  + \ 12  f\_2 + \ 32  f\_3 + 
              7  f\_4)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(\(2*0.25\)\/45\) \((7*1.00000\  + \ 
              32*1.65534\  + \ 12*1.55152 + \ 32*\ 1.06666 + 
              7*0.721588)\)\)\)\)\)]],
  "   \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.0111111 \((7.00000\  + \ 52.9709\  + \ 
              18.6182 + \ 34.1331 + 5.05112)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(0.0111111 \((117.773)\)\)\)\)\)]],
  "  \n\t\t\t",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(1.3085875803`\)\)\)\)]],
  "  \n\t\n\t",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Computation is: "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<Boole's Rule with  h = \>", h];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x \
\[TildeTilde] \>\"", \*"\"\<\!\(\(2  \
h\)\/45\)(7\!\(f\_0\)+32\!\(f\_1\)+12\!\(f\_2\)+32\!\(f\_3\)+7\!\(f\_4\)) = \
\>\"", \(\(2  h\)\/45\) \((7  f\_0 + 32  f\_1 + 12  f\_2 + 32  f\_3 + 
              7  f\_4)\)];\)\)}], "Input"],

Cell[TextData[StyleBox["The true value of the definite integral is",
  FontFamily->"Times-Roman"]], "Text"],

Cell[BoxData[{
    \(\(F[
          x_] = \[Integral]f[
              x] \[DifferentialD]x;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<F[x] = \[Integral]f[x]\[DifferentialD]x = \>", 
        F[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<F[1] = \>", F[1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<F[0] = \>", F[0]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = \>\"", \
"\<\[Integral]\>"\+a\%b, "\<(\>", 
        f[x], "\<)\[DifferentialD]x\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = F[1] - \
F[0]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = (\>\"", 
        F[1], "\<) - (\>", F[0], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = \>\"", 
        F[1]\  - \ F[0]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Integral]\_0\%1\)f[x]\[DifferentialD]x = \>\"", 
        NumberForm[N[F[1]\  - \ F[0]], 16]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["We see that the approximation  ",
    FontFamily->"Times-Roman"],
  StyleBox["1",
    FontFamily->"Courier New"],
  StyleBox[".",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["30938",
    FontFamily->"Courier New"],
  StyleBox["  from Simpson\[CloseCurlyQuote]s rule is much better than the \
value  ",
    FontFamily->"Times-Roman"],
  StyleBox["1",
    FontFamily->"Courier New"],
  StyleBox[".",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["28358",
    FontFamily->"Courier New"],
  StyleBox["  obtained from the trapezoidal rule.  Again, the approximation  \
",
    FontFamily->"Times-Roman"],
  StyleBox["1",
    FontFamily->"Courier New"],
  StyleBox[".",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["30859",
    FontFamily->"Courier New"],
  StyleBox["  from Boole\[CloseCurlyQuote]s rule is closest.  Graphs for the \
areas under the trapezoids and parabolas are shown in the figures for this \
example. ",
    FontFamily->"Times-Roman"]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Degree of Precision of the Quadrature Rules",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["We can use formula (3) to determine the degree of precision the \
trapezoidal rule, composite Simpson rule, and Boole\[CloseCurlyQuote]s rule.  \
Assume that \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(E \((f)\)\), " ", "=", " ", 
        RowBox[{"K", " ", 
          SuperscriptBox["f", 
            TagBox[\((n + 1)\),
              Derivative],
            MultilineFunction->None], \((c)\)}]}]]],
  ",",
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  StyleBox["\n\n",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["where  ",
    FontFamily->"Times-Roman"],
  StyleBox["K",
    FontFamily->"Courier New"],
  StyleBox["  is a suitably chosen constant and  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  is the degree of precision.  It will suffice to use  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(f\_i\) \((x)\)\  = \ x\^i\)]],
  StyleBox["  and find the largest power  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  for which the quadrature formula is exact, i. e.\n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(E[
          f]\  = \ \(\[Integral]\_a\%b\ \(f\_n\) \((x)\) \[DifferentialD]x\ \ \
 - \ \[Sum]\+\(k = 0\)\%m\( w\_k\) \(f\_n\) \((x\_k)\)\  = \ 0\)\)]],
  ". ",
  StyleBox["\n\nThe constant  ",
    FontFamily->"Times-Roman"],
  StyleBox["K",
    FontFamily->"Courier New"],
  StyleBox["  is determined by solving\n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      StyleBox[\(E[
            f]\  = \ \(\[Integral]\_a\%b\ \(f\_\(n + 
                        1\)\) \((x)\) \[DifferentialD]x\ \  - \ \[Sum]\+\(j = \
0\)\%m\( w\_j\) \(f\_\(n + 1\)\) \((x\_j)\)\  = \ \ K\ \(f\_\(n + 
                    1\)\%\((n + 1)\)\) \((x)\)\)\),
        FontWeight->"Plain"]], "Input"],
  ". \n\nSince this involves  ",
  Cell[BoxData[
      \(\(f\_\(n + 1\)\) \((x)\)\  = \ x\^\(n + 1\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(\(f\_\(n + 1\)\%\((n + 1)\)\) \((x)\)\  = \ \(\((n + 1)\)!\)\)]],
  " is will be easy to solve for ",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  StyleBox["K",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 4.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Show that the degree of precision of the Trapezoidal Rule is  ",
    
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(E[f]\), " ", "=", " ", 
        RowBox[{\(-\ \(1\/12\)\), 
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((2)\),
                Derivative],
              MultilineFunction->None], "[", "c", "]"}], \(h\^2\)}]}]]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["It will suffice to apply Trapezoidal Rule over the interval  ",
    FontFamily->"Times-Roman"],
  StyleBox["[0",
    FontFamily->"Courier New"],
  ",",
  StyleBox["1]",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"MTSYN"],
  StyleBox["with the three test functions  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(f[x]\  = \ 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "x", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^2\)}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(n = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\), "\[IndentingNewLine]", 
    \(\(b = 1;\)\), "\[IndentingNewLine]", 
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(For[i = 0, 
      i \[LessEqual] n, \(i++\), \[IndentingNewLine]f[x_]\  = \ 
        x\^i; \[IndentingNewLine]F[
          x_] = \[Integral]f[
              x] \[DifferentialD]x; \ \[IndentingNewLine]val = \[Integral]\_a\
\%b f[x] \[DifferentialD]x; \[IndentingNewLine]rule = \(1\/2\) \((f[
                0]\  + \ \ f[
                1])\); \ \[IndentingNewLine]Print["\<\n\n\>", "\<f[x] = \>", 
        f[x]]; \[IndentingNewLine]Print["\<F[x] = \[Integral] \>", 
        f[x], "\< \[DifferentialD]x = \>", 
        F[x]]; \[IndentingNewLine]Print["\<\[Integral]\>"\+a\%b, "\< \>", 
        f[x], "\< \[DifferentialD]x = \>", 
        val]; \[IndentingNewLine]Print[\*"\"\<\!\(1\/2\)(f[0] +  f[1]) = \
\>\"", rule]; \[IndentingNewLine]Print["\<E[\>", f[x], "\<] = \>", 
        val, "\< - \>", rule, "\< = \>", val - rule];\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["The function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[x]\  = \ x\^2\)]],
  "  ",
  StyleBox["is the lowest power of  ",
    FontFamily->"Times-Roman"],
  StyleBox["x",
    FontFamily->"Courier New"],
  StyleBox["  for which the trapezoidal rule is not exact.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{\(Print["\<\n\>", "\<Solve the equation\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{
          RowBox[{"K", " ", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((n)\),
                  Derivative],
                MultilineFunction->None], "[", "c", "]"}]}], " ", "\[Equal]", 
          " ", \(val - rule\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<For  K,  and get\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"solset", "=", 
        RowBox[{"Solve", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"K", " ", 
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((n)\),
                      Derivative],
                    MultilineFunction->None], "[", "c", "]"}]}], " ", 
              "\[Equal]", " ", \(val - rule\)}], ",", "K"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\), "\[IndentingNewLine]", \(Print["\<\n\>", \
"\<The degree of precision for\>"];\), "\[IndentingNewLine]", \(Print["\<The \
Trapezoidal Rule is  n = \>", 
        n - 1];\), "\[IndentingNewLine]", \(Print["\<And the error term has \
the form\>"];\), "\[IndentingNewLine]", \(Print["\<\n\>", "\<E[f] = \>", 
      solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), "\<f\>"\^"\<(\>", "\<\>"\^n, "\<\>"\^"\<)\>", \
"\<[c]\>", h\^n]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Show that the degree of precision of  \
Simpson\[CloseCurlyQuote]s Rule is  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(E[f]\), " ", "=", " ", 
        RowBox[{\(-\ \(1\/90\)\), 
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((4)\),
                Derivative],
              MultilineFunction->None], "[", "c", "]"}], \(h\^4\)}]}]]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["It will suffice to apply Simpson\[CloseCurlyQuote]s Rule over the \
interval  ",
    FontFamily->"Times-Roman"],
  StyleBox["[0",
    FontFamily->"Courier New"],
  ",",
  StyleBox["2]",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"MTSYN"],
  StyleBox["with the five test functions  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(f[x]\  = \ 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "x", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^4\)}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\), "\[IndentingNewLine]", 
    \(\(b = 2;\)\), "\[IndentingNewLine]", 
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(For[i = 0, 
      i \[LessEqual] n, \(i++\), \[IndentingNewLine]f[x_]\  = \ 
        x\^i; \[IndentingNewLine]F[
          x_] = \[Integral]f[
              x] \[DifferentialD]x; \ \[IndentingNewLine]val = \[Integral]\_a\
\%b f[x] \[DifferentialD]x; \[IndentingNewLine]rule = \(1\/3\) \((f[0]\  + \ 
              4  f[1]\  + \ 
              f[2])\); \ \[IndentingNewLine]Print["\<\n\n\>", "\<f[x] = \>", 
        f[x]]; \[IndentingNewLine]Print["\<F[x] = \[Integral] \>", 
        f[x], "\< \[DifferentialD]x = \>", 
        F[x]]; \[IndentingNewLine]Print["\<\[Integral]\>"\+a\%b, "\< \>", 
        f[x], "\< \[DifferentialD]x = \>", 
        val]; \[IndentingNewLine]Print[\*"\"\<\!\(1\/3\)(f[0] + 4f[1] + f[2]) \
= \>\"", rule]; \[IndentingNewLine]Print["\<E[\>", f[x], "\<] = \>", 
        val, "\< - \>", rule, "\< = \>", val - rule];\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["The function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[x]\  = \ x\^4\)]],
  "  ",
  StyleBox["is the lowest power of  ",
    FontFamily->"Times-Roman"],
  StyleBox["x",
    FontFamily->"Courier New"],
  StyleBox["  for which the Simpson\[CloseCurlyQuote]s rule is not exact.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{\(Print["\<\n\>", "\<Solve the equation\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{
          RowBox[{"K", " ", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((n)\),
                  Derivative],
                MultilineFunction->None], "[", "c", "]"}]}], " ", "\[Equal]", 
          " ", \(val - rule\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<For  K,  and get\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"solset", "=", 
        RowBox[{"Solve", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"K", " ", 
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((n)\),
                      Derivative],
                    MultilineFunction->None], "[", "c", "]"}]}], " ", 
              "\[Equal]", " ", \(val - rule\)}], ",", "K"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\), "\[IndentingNewLine]", \(Print["\<\n\>", \
"\<The degree of precision for\>"];\), "\[IndentingNewLine]", \
\(Print["\<Simpson's Rule is  n = \>", 
        n - 1];\), "\[IndentingNewLine]", \(Print["\<And the error term has \
the form\>"];\), "\[IndentingNewLine]", \(Print["\<\n\>", "\<E[f] = \>", 
      solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), "\<f\>"\^"\<(\>", "\<\>"\^n, "\<\>"\^"\<)\>", \
"\<[c]\>", h\^n]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Show that the degree of precision of  \
Simpson\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(3\/8\)]],
  " ",
  StyleBox["Rule is  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(E[f]\), " ", "=", " ", 
        RowBox[{\(-\ \(3\/80\)\), 
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((4)\),
                Derivative],
              MultilineFunction->None], "[", "c", "]"}], \(h\^4\)}]}]]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["It will suffice to apply Simpson\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(3\/8\)]],
  " ",
  StyleBox["Rule over the interval  ",
    FontFamily->"Times-Roman"],
  StyleBox["[0",
    FontFamily->"Courier New"],
  ",",
  StyleBox["3]",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"MTSYN"],
  StyleBox["with the five test functions  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(f[x]\  = \ 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "x", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^4\)}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(n = 4;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\), "\[IndentingNewLine]", 
    \(\(b = 3;\)\), "\[IndentingNewLine]", 
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(For[i = 0, 
      i \[LessEqual] n, \(i++\), \[IndentingNewLine]f[x_]\  = \ 
        x\^i; \[IndentingNewLine]F[
          x_] = \[Integral]f[
              x] \[DifferentialD]x; \ \[IndentingNewLine]val = \[Integral]\_a\
\%b f[x] \[DifferentialD]x; \[IndentingNewLine]rule = \(3\/8\) \((f[0]\  + \ 
              3  f[1]\  + \ 3  f[2] + \ 
              f[3])\); \ \[IndentingNewLine]Print["\<\n\n\>", "\<f[x] = \>", 
        f[x]]; \[IndentingNewLine]Print["\<F[x] = \[Integral] \>", 
        f[x], "\< \[DifferentialD]x = \>", 
        F[x]]; \[IndentingNewLine]Print["\<\[Integral]\>"\+a\%b, "\< \>", 
        f[x], "\< \[DifferentialD]x = \>", 
        val]; \[IndentingNewLine]Print[\*"\"\<\!\(3\/8\)(f[0] + 3f[1] + \
3f[2]+ f[3]) = \>\"", rule]; \[IndentingNewLine]Print["\<E[\>", 
        f[x], "\<] = \>", val, "\< - \>", rule, "\< = \>", 
        val - rule];\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["The function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[x]\  = \ x\^4\)]],
  "  ",
  StyleBox["is the lowest power of  ",
    FontFamily->"Times-Roman"],
  StyleBox["x",
    FontFamily->"Courier New"],
  StyleBox["  for which the Simpson\[CloseCurlyQuote]s ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(3\/8\)]],
  " ",
  StyleBox["rule is not exact.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{\(Print["\<\n\>", "\<Solve the equation\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{
          RowBox[{"K", " ", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((n)\),
                  Derivative],
                MultilineFunction->None], "[", "c", "]"}]}], " ", "\[Equal]", 
          " ", \(val - rule\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<For  K,  and get\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"solset", "=", 
        RowBox[{"Solve", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"K", " ", 
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((n)\),
                      Derivative],
                    MultilineFunction->None], "[", "c", "]"}]}], " ", 
              "\[Equal]", " ", \(val - rule\)}], ",", "K"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\), "\[IndentingNewLine]", \(Print["\<\n\>", \
"\<The degree of precision for\>"];\), "\[IndentingNewLine]", \
\(Print[\*"\"\<Simpson's \!\(3\/8\) Rule is  n = \>\"", 
        n - 1];\), "\[IndentingNewLine]", \(Print["\<And the error term has \
the form\>"];\), "\[IndentingNewLine]", \(Print["\<\n\>", "\<E[f] = \>", 
      solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), "\<f\>"\^"\<(\>", "\<\>"\^n, "\<\>"\^"\<)\>", \
"\<[c]\>", h\^n]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Show that the degree of precision of  Boole's Rule is  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(E[f]\), " ", "=", " ", 
        RowBox[{\(-\(8\/945\)\), 
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((6)\),
                Derivative],
              MultilineFunction->None], "[", "c", "]"}], \(h\^6\)}]}]]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["It will suffice to apply Boole's rule over the interval  ",
    FontFamily->"Times-Roman"],
  StyleBox["[0",
    FontFamily->"Courier New"],
  ",",
  StyleBox["4]",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"MTSYN"],
  StyleBox["with the seven test functions  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(f[x]\  = \ 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "x", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^4\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^5\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\^6\)}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(n = 6;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\), "\[IndentingNewLine]", 
    \(\(b = 4;\)\), "\[IndentingNewLine]", 
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(For[i = 0, 
      i \[LessEqual] n, \(i++\), \[IndentingNewLine]f[x_]\  = \ 
        x\^i; \[IndentingNewLine]F[
          x_] = \[Integral]f[
              x] \[DifferentialD]x; \ \[IndentingNewLine]val = \[Integral]\_a\
\%b f[x] \[DifferentialD]x; \[IndentingNewLine]rule = \(2\/45\) \((7 
                 f[0]\  + \ 32  f[1]\  + \ 12  f[2] + \ 32  f[3] + \ 
              7  f[4])\); \ \[IndentingNewLine]Print["\<\n\n\>", "\<f[x] = \
\>", f[x]]; \[IndentingNewLine]Print["\<F[x] = \[Integral] \>", 
        f[x], "\< \[DifferentialD]x = \>", 
        F[x]]; \[IndentingNewLine]Print["\<\[Integral]\>"\+a\%b, "\< \>", 
        f[x], "\< \[DifferentialD]x = \>", 
        val]; \[IndentingNewLine]Print[\*"\"\<\!\(2\/45\)(7f[0] + 32f[1] + \
12f[2]+ 32f[3]+ 7f[4]) = \>\"", rule]; \[IndentingNewLine]Print["\<E[\>", 
        f[x], "\<] = \>", val, "\< - \>", rule, "\< = \>", 
        val - rule];\ ]\)}], "Input"],

Cell[TextData[{
  StyleBox["The function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[x]\  = \ x\^6\)]],
  "  ",
  StyleBox["is the lowest power of  ",
    FontFamily->"Times-Roman"],
  StyleBox["x",
    FontFamily->"Courier New"],
  StyleBox["  for which the Boole's rule is not exact.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{\(Print["\<\n\>", "\<Solve the equation\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", 
        RowBox[{
          RowBox[{"K", " ", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((n)\),
                  Derivative],
                MultilineFunction->None], "[", "c", "]"}]}], " ", "\[Equal]", 
          " ", \(val - rule\)}], "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<For  K,  and get\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"solset", "=", 
        RowBox[{"Solve", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"K", " ", 
                RowBox[{
                  SuperscriptBox["f", 
                    TagBox[\((n)\),
                      Derivative],
                    MultilineFunction->None], "[", "c", "]"}]}], " ", 
              "\[Equal]", " ", \(val - rule\)}], ",", "K"}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\), "\[IndentingNewLine]", \(Print["\<\n\>", \
"\<The degree of precision for\>"];\), "\[IndentingNewLine]", \
\(Print["\<Boole's Rule is  n = \>", 
        n - 1];\), "\[IndentingNewLine]", \(Print["\<And the error term has \
the form\>"];\), "\[IndentingNewLine]", \(Print["\<\n\>", "\<E[f] = \>", 
      solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), "\<f\>"\^"\<(\>", "\<\>"\^n, "\<\>"\^"\<)\>", \
"\<[c]\>", h\^n]\)}], "Input"]
}, Closed]],

Cell["", "Text"],

Cell[TextData[{
  StyleBox["Various Scenarios",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" and Animations",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Trapezoidal Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Trapezoidal/Trapezoidal.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Trapezoidal Rule",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Quadrature/\
Trapezoidal/Trapezoidal.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Simpson's Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Simpson/Simpson.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's Rule",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Quadrature/Simpson/\
Simpson.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Simpson38/Simpson.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Quadrature/\
Simpson38/Simpson.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Boole's Rule",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/Boole/\
Boole.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Boole's Rule",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Quadrature/Boole/\
Boole.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Simpson's Rule",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/sq.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/sq.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell["", "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Newton-Cotes Numerical Integration",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/NewtonCotesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Newton-Cotes Numerical Integration",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/NewtonCotesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Trapezoidal Rule for Numerical Integration",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/TrapezoidalRuleBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Trapezoidal Rule for Numerical Integration",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/TrapezoidalRuleBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Simpson's Rule for Numerical Integration",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/SimpsonsRuleBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's Rule for Numerical Integration",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/SimpsonsRuleBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  ",
  "Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{948, 641},
WindowMargins->{{12, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 177, 4, 35, "Text"],
Cell[1956, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3435, 111, 760, 23, 106, "Text"],
Cell[4198, 136, 2028, 64, 205, "Text"],
Cell[6229, 202, 864, 18, 90, "Text"],
Cell[7096, 222, 1816, 64, 130, "Text"],
Cell[8915, 288, 4929, 154, 280, "Text"],
Cell[13847, 444, 2747, 78, 220, "Text"],
Cell[16597, 524, 669, 22, 33, "Text"],
Cell[17269, 548, 536, 16, 33, "Text"],
Cell[17808, 566, 957, 28, 75, "Text"],
Cell[18768, 596, 987, 28, 75, "Text"],
Cell[19758, 626, 1105, 33, 78, "Text"],
Cell[20866, 661, 1043, 29, 75, "Text"],
Cell[21912, 692, 628, 22, 33, "Text"],
Cell[22543, 716, 616, 21, 33, "Text"],
Cell[23162, 739, 624, 21, 33, "Text"],
Cell[23789, 762, 605, 21, 33, "Text"],
Cell[24397, 785, 1412, 52, 71, "Text"],
Cell[25812, 839, 33403, 557, 211, "Text"],
Cell[59218, 1398, 33005, 552, 211, "Text"],

Cell[CellGroupData[{
Cell[92248, 1954, 101, 2, 33, "Text"],
Cell[92352, 1958, 453, 9, 110, "Input"],
Cell[92808, 1969, 664, 21, 172, "Text"],
Cell[93475, 1992, 303, 5, 63, "Input"],
Cell[93781, 1999, 879, 26, 191, "Text"],
Cell[94663, 2027, 325, 5, 63, "Input"],
Cell[94991, 2034, 1013, 31, 194, "Text"],
Cell[96007, 2067, 396, 6, 76, "Input"],
Cell[96406, 2075, 999, 27, 191, "Text"],
Cell[97408, 2104, 393, 6, 63, "Input"],
Cell[97804, 2112, 994, 32, 52, "Text"]
}, Closed]],
Cell[98813, 2147, 1420, 45, 71, "Text"],
Cell[100236, 2194, 1462, 45, 33, "Text"],
Cell[101701, 2241, 29393, 491, 211, "Text"],
Cell[131097, 2734, 28267, 474, 211, "Text"],

Cell[CellGroupData[{
Cell[159389, 3212, 101, 2, 33, "Text"],
Cell[159493, 3216, 271, 6, 90, "Input"],
Cell[159767, 3224, 213, 8, 33, "Text"],
Cell[159983, 3234, 692, 22, 172, "Text"],
Cell[160678, 3258, 461, 8, 123, "Input"],
Cell[161142, 3268, 192, 6, 36, "Text"],
Cell[161337, 3276, 879, 26, 191, "Text"],
Cell[162219, 3304, 531, 9, 136, "Input"],
Cell[162753, 3315, 279, 10, 36, "Text"],
Cell[163035, 3327, 1018, 31, 194, "Text"],
Cell[164056, 3360, 643, 11, 150, "Input"],
Cell[164702, 3373, 238, 8, 36, "Text"],
Cell[164943, 3383, 1017, 28, 191, "Text"],
Cell[165963, 3413, 678, 11, 136, "Input"],
Cell[166644, 3426, 107, 1, 33, "Text"],
Cell[166754, 3429, 1143, 19, 299, "Input"],
Cell[167900, 3450, 863, 29, 53, "Text"]
}, Closed]],
Cell[168778, 3482, 951, 28, 49, "Text"],
Cell[169732, 3512, 1651, 49, 117, "Text"],
Cell[171386, 3563, 1195, 35, 117, "Text"],
Cell[172584, 3600, 134, 2, 33, "Text"],
Cell[172721, 3604, 1698, 51, 55, "Text"],
Cell[174422, 3657, 41971, 698, 211, "Text"],
Cell[216396, 4357, 14008, 235, 211, "Text"],

Cell[CellGroupData[{
Cell[230429, 4596, 101, 2, 33, "Text"],
Cell[230533, 4600, 454, 9, 110, "Input"],
Cell[230990, 4611, 919, 26, 191, "Text"],
Cell[231912, 4639, 386, 6, 63, "Input"],
Cell[232301, 4647, 948, 26, 191, "Text"],
Cell[233252, 4675, 380, 6, 63, "Input"],
Cell[233635, 4683, 1022, 28, 191, "Text"],
Cell[234660, 4713, 391, 6, 63, "Input"],
Cell[235054, 4721, 107, 1, 33, "Text"],
Cell[235164, 4724, 1143, 19, 299, "Input"],
Cell[236310, 4745, 1056, 34, 53, "Text"]
}, Closed]],
Cell[237381, 4782, 2502, 73, 317, "Text"],
Cell[239886, 4857, 581, 18, 36, "Text"],

Cell[CellGroupData[{
Cell[240492, 4879, 101, 2, 33, "Text"],
Cell[240596, 4883, 969, 31, 33, "Text"],
Cell[241568, 4916, 1045, 19, 369, "Input"],
Cell[242616, 4937, 352, 12, 33, "Text"],
Cell[242971, 4951, 1532, 35, 193, "Input"]
}, Closed]],
Cell[244518, 4989, 590, 18, 33, "Text"],

Cell[CellGroupData[{
Cell[245133, 5011, 101, 2, 33, "Text"],
Cell[245237, 5015, 1539, 48, 33, "Text"],
Cell[246779, 5065, 1060, 19, 369, "Input"],
Cell[247842, 5086, 367, 12, 33, "Text"],
Cell[248212, 5100, 1526, 35, 193, "Input"]
}, Closed]],
Cell[249753, 5138, 678, 23, 33, "Text"],

Cell[CellGroupData[{
Cell[250456, 5165, 101, 2, 33, "Text"],
Cell[250560, 5169, 1625, 52, 36, "Text"],
Cell[252188, 5223, 1088, 20, 369, "Input"],
Cell[253279, 5245, 455, 17, 36, "Text"],
Cell[253737, 5264, 1543, 35, 207, "Input"]
}, Closed]],
Cell[255295, 5302, 568, 17, 33, "Text"],

Cell[CellGroupData[{
Cell[255888, 5323, 101, 2, 33, "Text"],
Cell[255992, 5327, 2073, 63, 33, "Text"],
Cell[258068, 5392, 1118, 20, 369, "Input"],
Cell[259189, 5414, 348, 12, 33, "Text"],
Cell[259540, 5428, 1524, 35, 193, "Input"]
}, Closed]],
Cell[261079, 5466, 16, 0, 30, "Text"],
Cell[261098, 5468, 280, 10, 35, "Text"],
Cell[261381, 5480, 744, 24, 33, "Text"],
Cell[262128, 5506, 724, 24, 33, "Text"],
Cell[262855, 5532, 768, 24, 33, "Text"],
Cell[263626, 5558, 742, 24, 33, "Text"],
Cell[264371, 5584, 691, 20, 33, "Text"],
Cell[265065, 5606, 16, 0, 33, "Text"],
Cell[265084, 5608, 158, 3, 35, "Text"],
Cell[265245, 5613, 585, 16, 33, "Text"],
Cell[265833, 5631, 621, 17, 33, "Text"],
Cell[266457, 5650, 617, 18, 33, "Text"],
Cell[267077, 5670, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

