(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     48860,       1585]*)
(*NotebookOutlinePosition[     49686,       1612]*)
(*  CellTagsIndexPosition[     49642,       1608]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Simpson's 3/8 Rule for Numerical \
Integration",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tThe numerical integration technique known as \"",
  "Simpson's 3/8 rule",
  "\" is credited to the mathematician ",
  ButtonBox["Thomas Simpson",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Simpson.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " (1710-1761) of  Leicestershire, England. His also worked in the areas of \
numerical interpolation and probability theory. "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem  (",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Simpsons38Rule.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[")",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Consider ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  " over",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_3\)}], "]"}]]],
  StyleBox[", where ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_1 = x\_0 + h\)]],
  ",",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_2 = x\_0 + 2  h\)]],
  ", ",
  StyleBox["and ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_3 = x\_0 + 3  h\)]],
  ".  Simpson's 3/8 rule",
  StyleBox[" is   \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"SE", 
          RowBox[{"(", 
            RowBox[{"f", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "h"}], ")"}]}], " ", "=", " "}]]],
  Cell[BoxData[
      \(\(\(3  h\)\/8\) \((f \((x\_0)\)\  + \ 3  f \((x\_1)\)\  + \ 
            3  f \((x\_2)\) + \ f \((x\_3)\))\)\)]],
  ".   ",
  StyleBox["\n\nThis is an numerical approximation to the integral of ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox[" over ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{\(x\_0\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(x\_3\)}], "]"}]]],
  StyleBox[" and we have the expression  \n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(x\_0\)\%\(x\_3\)\ 
          f \((x)\) \[DifferentialD]x\), " ", "\[TildeTilde]", " ", 
        RowBox[{"SE", 
          RowBox[{"(", 
            RowBox[{"f", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "h"}], ")"}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The remainder term for ",
  "Simpson's 3/8 rule",
  " is  ",
  Cell[BoxData[
      InterpretationBox[
        RowBox[{\(\(R\_SE\) \((f, h)\)\), " ", "=", " ", 
          RowBox[{
            RowBox[{"-", 
              InterpretationBox[
                RowBox[{\(3\/80\), " ", 
                  SuperscriptBox["f", 
                    TagBox[\((4)\),
                      Derivative],
                    MultilineFunction->None], \((c)\)}],
                SeriesData[ h, 0, {
                  Times[ 
                    Rational[ 1, 24], 
                    Derivative[ 2][ f][ x]]}, 3, 4, 1]]}], \(h\^5\)}]}],
        SeriesData[ h, 0, {
          Times[ 
            Rational[ 1, 24], 
            Derivative[ 2][ f][ x]]}, 3, 4, 1]]]],
  ",  where ",
  Cell[BoxData[
      \(c\)]],
  " lies somewhere between ",
  Cell[BoxData[
      RowBox[{\(x\_0\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(x\_3\)}]]],
  ", and have the equality  \n\n\t",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_\(x\_0\)\%\(x\_3\)\ 
          f \((x)\) \[DifferentialD]x\), " ", "=", " ", 
        RowBox[{\(\(\(3  h\)\/8\) \((f \((x\_0)\)\  + \ 3  f \((x\_1)\)\  + \ 
                3  f \((x\_2)\) + \ f \((x\_3)\))\)\), " ", "-", 
          RowBox[{
            InterpretationBox[
              RowBox[{\(3\/80\), " ", 
                SuperscriptBox["f", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], \((c)\)}],
              SeriesData[ h, 0, {
                Times[ 
                  Rational[ 1, 24], 
                  Derivative[ 2][ f][ x]]}, 3, 4, 1]], \(h\^5\)}]}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Simpson38RuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Simpson38RuleProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[StyleBox["Composite Simpson's 3/8 Rule",
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["\tOur next method of finding the area under a curve ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  " ",
  StyleBox["is by approximating that curve with a series of cubic segments \
that lie above the intervals  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          RowBox[{"[", 
            RowBox[{\(x\_\(k - 1\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(x\_k\)}], "]"}], "}"}], \(k = 
          1\), \(3  m\)]]],
  StyleBox[".  When several cubics are used, we call it the ",
    FontFamily->"Times New Roman"],
  StyleBox["composite Simpson's 3/8 rule",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Composite Simpson's 3/8 Rule",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[")",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Consider ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y = f \((x)\)\)]],
  " over",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  StyleBox[".  Suppose that the interval ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  StyleBox[" is subdivided into ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(3  m\)]],
  " ",
  StyleBox[" subintervals  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          RowBox[{"[", 
            RowBox[{\(x\_\(k - 1\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(x\_k\)}], "]"}], "}"}], \(k = 
          1\), \(3  m\)]]],
  StyleBox["  of equal width  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(h = \(b\  - \ a\)\/\(3  m\)\)]],
  StyleBox["  by using the equally spaced sample points  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_k\  = \ x\_0\  + \ k\ h\)]],
  "  ",
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(3  m\)}]]],
  StyleBox[".   The ",
    FontFamily->"Times New Roman"],
  StyleBox["composite Simpson's 3/8 rule for ",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(3  m\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" subintervals",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  is  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"SC", 
          RowBox[{"(", 
            RowBox[{"f", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "h"}], ")"}]}], " ", "=", 
        " ", \(\(\(3  
                h\)\/8\) \(\[Sum]\+\(k = 1\)\%m\((f \((x\_\(3  k - 3\))\) + 
                3  f \((x\_\(3  k - 2\))\) + 3  f \((x\_\(3  k - 1\))\) + 
                f \((x\_\(3  k\))\))\)\)\)}]]],
  Cell[BoxData[Cell[""]]],
  Cell[BoxData[Cell[""]]],
  ".  ",
  StyleBox["\n\nThis is an numerical approximation to the integral of ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox[" over ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  StyleBox[" and we write  \n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->6],
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Integral]\_a\%b\ f \((x)\) \[DifferentialD]x\), " ", 
        "\[TildeTilde]", " ", 
        RowBox[{"SC", 
          RowBox[{"(", 
            RowBox[{"f", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "h"}], ")"}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Simpson38RuleProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Simpson38RuleProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[StyleBox["Remainder term for the Composite Simpson's 3/8 Rule",
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Corollary  (Simpson's 3/8 Rule:  Remainder term)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["   Suppose that ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], "]"}]]],
  StyleBox[" is subdivided into ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(3  m\)]],
  " ",
  StyleBox[" subintervals  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          RowBox[{"[", 
            RowBox[{\(x\_\(k - 1\)\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(x\_k\)}], "]"}], "}"}], \(k = 
          1\), \(3  m\)]]],
  StyleBox["  of width  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(h = \(b\  - \ a\)\/\(3  m\)\)]],
  StyleBox[".  The ",
    FontFamily->"Times New Roman"],
  StyleBox["composite Simpson's 3/8 rule",
    FontFamily->"Times New Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"SC", 
          RowBox[{"(", 
            RowBox[{"f", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "h"}], ")"}]}], " ", "=", 
        " ", \(\(\(3  
                h\)\/8\) \(\[Sum]\+\(k = 1\)\%m\((f \((x\_\(3  k - 3\))\) + 
                3  f \((x\_\(3  k - 2\))\) + 3  f \((x\_\(3  k - 1\))\) + 
                f \((x\_\(3  k\))\))\)\)\)}]]],
  Cell[BoxData[Cell[""]]],
  Cell[BoxData[Cell[""]]],
  ".  ",
  StyleBox["\n\nis an numerical approximation to the integral, and  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\[Integral]\_a\%b\ f \((x)\) \[DifferentialD]x\), "  ", "=", 
        "  ", 
        RowBox[{
          RowBox[{"SC", 
            RowBox[{"(", 
              RowBox[{"f", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "h"}], ")"}]}], " ", "+", " ", 
          RowBox[{\(E\_SC\), 
            RowBox[{"(", 
              RowBox[{"f", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "h"}], ")"}]}]}]}]]],
  ".  \n\nFurthermore, if ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(f \((x)\)\), "\[Element]", 
        RowBox[{
          SuperscriptBox[
            StyleBox["C",
              FontWeight->"Bold"], "4"], "[", 
          RowBox[{"a", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "b"}], "]"}]}]]],
  ",  then there exists a value ",
  Cell[BoxData[
      \(c\)]],
  " with  ",
  Cell[BoxData[
      \(a < c < b\)]],
  "  so that the error term  ",
  Cell[BoxData[
      RowBox[{\(E\_SC\), 
        RowBox[{"(", 
          RowBox[{"f", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "h"}], ")"}]}]]],
  "  has the form\n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(E\_SC\), 
          RowBox[{"(", 
            RowBox[{"f", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "h"}], ")"}]}], " ", "=", 
        " ", \(\(-\ \(\(\((b\  - \ a)\) \(f\^4\) \((c)\)\)\/80\)\) 
          h\^4\)}]]],
  ".  \n\nThis is expressed using the \"big ",
  Cell[BoxData[
      StyleBox["O",
        FontWeight->"Bold",
        FontSlant->"Italic"]]],
  "\" notation  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(E\_SE\), 
          RowBox[{"(", 
            RowBox[{"f", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "h"}], ")"}]}], " ", "=", " ", 
        RowBox[{
          StyleBox["O",
            FontWeight->"Bold",
            FontSlant->"Italic"], \((h\^4)\)}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  When the step size is reduced by a factor of ",
  Cell[BoxData[
      \(1\/2\)]],
  " the remainder term  ",
  Cell[BoxData[
      RowBox[{\(E\_SC\), 
        RowBox[{"(", 
          RowBox[{"f", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "h"}], ")"}]}]]],
  " should be reduced by approximately ",
  Cell[BoxData[
      \(\((1\/2)\)\^4\  = \ 0.0625`\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm Composite Simpson's 3/8 Rule.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  To approximate the integral  \n\n",
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            SubsuperscriptBox["\[Integral]", 
              StyleBox["a",
                FontSize->10], 
              StyleBox["b",
                FontSize->10]],
            FontSize->18], \(f \((x)\) \[DifferentialD]x\)}], " ", 
        "\[TildeTilde]", 
        " ", \(\(\(3  
                h\)\/8\) \(\[Sum]\+\(k = 1\)\%m\((f \((x\_\(3  k - 3\))\) + 
                3  f \((x\_\(3  k - 2\))\) + 3  f \((x\_\(3  k - 1\))\) + 
                f \((x\_\(3  k\))\))\)\)\)}]]],
  ",  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  "\n\nby sampling  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  at the  ",
  Cell[BoxData[
      \(3  m + 1\)]],
  "  equally spaced ",
  StyleBox["sample points",
    FontFamily->"Times New Roman"],
  "  ",
  Cell[BoxData[
      \(x\_k = a + k\ h\)]],
  " for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(3  m\)}]]],
  ",  where  ",
  Cell[BoxData[
      \(h = \(b\  - \ a\)\/\(3  m\)\)],
    AspectRatioFixed->False],
  ".  Notice that  ",
  Cell[BoxData[
      \(x\_0 = a\)]],
  "  and  ",
  Cell[BoxData[
      \(x\_\(3  m\) = b\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Simpson38/Simpson.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Simpson38/Simpson.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Simpson38RuleProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Simpson38RuleProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (Simpson's 3/8 Rule). ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Object oriented programming.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[
    \(\(\(Simpson38[a0_, b0_, 
          m0_] := \[IndentingNewLine]Module[{a = N[a0], b = N[b0], h, m = m0, 
            X}, \[IndentingNewLine]h = \(b - a\)\/\(3  m\); \ \
\[IndentingNewLine]X\_k_ = 
            a + k\ h\ ; \ \[IndentingNewLine]Return[\ \(\(3  
                    h\)\/8\) \((\[Sum]\+\(k = 1\)\%m\((f[X\_\(3  k - 3\)] + 
                      3  f[X\_\(3  k - 2\)] + 3  f[X\_\(3  k - 1\)] + 
                      f[X\_\(3  k\)])\))\)\ ];\ ];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Numerically approximate the integral  ",
  Cell[BoxData[
      \(\[Integral]\_0\%2\((2 + Cos[2 \@ x])\) \[DifferentialD]x\)]],
  "  by using Simpson's 3/8 rule with  m = 1, 2, 4."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_]\ \  = \ 2 + Cos[2 \@ x];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(FilledPlot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2}, {0, 3}}, 
        PlotStyle \[Rule] {{Thickness[0.01], Magenta}}, Fills \[Rule] Cyan, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["We will use simulated hand computations for the solution.", "Text"],

Cell[BoxData[
    \(\(\(f[x_] = 2 + Cos[2 \@ x];\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[{
    \(s1 = \(\(3 \( 2 - 0\)\/3\)\/8\) \((f[0] + 3  f[2\/3] + 3  f[4\/3] + 
            f[2])\)\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[N[s1], 12]\ \ \)}], "Input"],

Cell[BoxData[{
    \(s2 = \(\(3 \( 2 - 0\)\/6\)\/8\) \((f[0] + 3  f[1\/3] + 3  f[2\/3] + 
            2  f[1] + 3  f[4\/3] + 3  f[5\/3] + 
            f[2])\)\ \ \ \), "\[IndentingNewLine]", 
    \(NumberForm[N[s2]\ , 12]\ \ \)}], "Input"],

Cell[BoxData[{
    \(s4 = \(\(\(3 \( 2 - 0\)\/12\)\/8\) \((f[0] + 3  f[1\/6] + 3  f[1\/3] + 
            2  f[1\/2] + 3  f[2\/3] + 3  f[5\/6] + 2  f[1] + 3  f[7\/6] + 
            3  f[4\/3] + 2  f[3\/2] + 3  f[5\/3] + 3  f[11\/6] + 
            f[2])\)\(\ \ \ \)\)\), "\[IndentingNewLine]", 
    \(NumberForm[N[s4], 12]\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Numerically approximate the integral  ",
  Cell[BoxData[
      \(\[Integral]\_0\%2\((2 + Cos[2 \@ x])\) \[DifferentialD]x\)]],
  "  by using ",
  "Simpson's 3/8 rule",
  " with  m = 10, 20, 40, 80,  and 160."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["We will use the subroutine for the solution.", "Text"],

Cell[BoxData[
    \(\(\(f[x_] = 2 + Cos[2 \@ x];\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(s10 = Simpson38[0, 2, 10]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[s10, 17]\ \ \)}], "Input"],

Cell[BoxData[{
    \(s20 = Simpson38[0, 2, 20]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[s20, 17]\ \ \)}], "Input"],

Cell[BoxData[{
    \(s40 = Simpson38[0, 2, 40]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[s40, 17]\ \ \)}], "Input"],

Cell[BoxData[{
    \(s80 = Simpson38[0, 2, 80]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[s80, 17]\ \ \)}], "Input"],

Cell[BoxData[{
    \(s160 = Simpson38[0, 2, 160]\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[s160, 17]\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the analytic value of the integral  ",
  Cell[BoxData[
      \(\[Integral]\_0\%2\((2 + Cos[2 \@ x])\) \[DifferentialD]x\)]],
  "  (i.e. find the \"true value\").   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The integral of  ",
  Cell[BoxData[
      \(f[x] = 2 + Cos[2 \@ x]\)]],
  "  can be determined."
}], "Text"],

Cell[BoxData[
    \(\[Integral]\((2 + Cos[2 \@ x])\) \[DifferentialD]x\)], "Input"],

Cell["The value of the definite integral", "Text"],

Cell[BoxData[
    \(val = \[Integral]\_0\%2\((2 + 
              Cos[2 \@ x])\) \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(\(\(N[val]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(NumberForm[N[val]\ , 17]\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the \"true value\" in example 3 and find the error for the Simpson' \
3/8 rule approximations in example 2.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s10\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s20\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s40\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s80\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(val - s160\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  When the step size is reduced by a factor of ",
  Cell[BoxData[
      \(1\/2\)]],
  " the ",
  "error term",
  "  ",
  Cell[BoxData[
      RowBox[{\(E\_SC\), 
        RowBox[{"(", 
          RowBox[{"f", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "h"}], ")"}]}]]],
  " should be reduced by approximately ",
  Cell[BoxData[
      \(\((1\/2)\)\^4\  = \ 0.0625`\)]],
  ".  Explore this phenomenon. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s20\)\(\ \)\)\/\(\(val\)\(-\)\(s10\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s40\)\(\ \)\)\/\(\(val\)\(-\)\(s20\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s80\)\(\ \)\)\/\(\(val\)\(-\)\(s40\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s160\)\(\ \)\)\/\(\(val\)\(-\)\(s80\)\(\ \)\)\)], \
"Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Numerically approximate the integral ",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_0\%3\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", 
                StyleBox[\(\[ExponentialE]\^\(-x\)\),
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox[\(Sin[x\^2]\),
                  FontSize->12]}], 
              StyleBox["+",
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox["1",
                FontSize->12]}], ")"}], \(\[DifferentialD]x\)}]}]]],
  " by using Simpson's 3/8 rule with  m = 1, 2, 4."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["We will use simulated hand computations for the solution.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(f[x_]\), "  ", "=", " ", 
          RowBox[{
            RowBox[{"3", 
              StyleBox[\(\[ExponentialE]\^\(-x\)\),
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox[\(Sin[x\^2]\),
                FontSize->12]}], 
            StyleBox["+",
              FontSize->12], 
            StyleBox[" ",
              FontSize->12], 
            StyleBox["1",
              FontSize->12]}]}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`FilledPlot`\>"];\), " "}], "\n", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\n", 
    RowBox[{\(FilledPlot[f[x], {x, 0, 3}, PlotRange \[Rule] {{0, 3}, {0, 2}}, 
          PlotStyle \[Rule] {{Thickness[0.01], Magenta}}, Fills \[Rule] Cyan, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<f[x] = \>", f[x]\ ];\), " "}]}], "Input"],

Cell[BoxData[
    \(\(\(f[x_] = 2 + Cos[2 \@ x];\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[{
    \(s1 = \(\(3 \( 3 - 0\)\/3\)\/8\) \((f[0] + 3  f[1] + 3  f[2] + 
            f[3])\)\ \ \), "\[IndentingNewLine]", 
    \(NumberForm[N[s1], 12]\ \ \)}], "Input"],

Cell[BoxData[{
    \(s2 = \(\(3 \( 3 - 0\)\/6\)\/8\) \((f[0] + 3  f[1\/2] + 3  f[1] + 
            2  f[3\/2] + 3  f[2] + 3  f[5\/2] + 
            f[3])\)\ \ \ \), "\[IndentingNewLine]", 
    \(NumberForm[N[s2]\ , 12]\ \ \)}], "Input"],

Cell[BoxData[{
    \(s4 = \(\(3 \( 3 - 0\)\/12\)\/8\) \((f[0] + 3  f[1\/4] + 3  f[1\/2] + 
            2  f[3\/4] + 3  f[1] + 3  f[5\/4] + 2  f[3\/2] + 3  f[7\/4] + 
            3  f[2] + 2  f[9\/4] + 3  f[5\/2] + 3  f[11\/4] + 
            f[3])\)\ \ \ \), "\[IndentingNewLine]", 
    \(NumberForm[N[s4], 12]\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Numerically approximate the integral  ",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_0\%3\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", 
                StyleBox[\(\[ExponentialE]\^\(-x\)\),
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox[\(Sin[x\^2]\),
                  FontSize->12]}], 
              StyleBox["+",
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox["1",
                FontSize->12]}], ")"}], \(\[DifferentialD]x\)}]}]]],
  "  by using Simpson's 3/8 rule with  m = 10, 20, 40, 80,  and 160."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["We will use the subroutine for the solution.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(f[x_]\), "=", 
          RowBox[{
            RowBox[{"3", 
              StyleBox[\(\[ExponentialE]\^\(-x\)\),
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox[\(Sin[x\^2]\),
                FontSize->12]}], 
            StyleBox["+",
              FontSize->12], 
            StyleBox[" ",
              FontSize->12], 
            StyleBox["1",
              FontSize->12]}]}], ";"}], " "}]], "Input"],

Cell[BoxData[{
    \(s10 = Simpson38[0, 3, 10]\ \), "\[IndentingNewLine]", 
    \(NumberForm[s10, 17]\ \)}], "Input"],

Cell[BoxData[{
    \(s20 = Simpson38[0, 3, 20]\ \), "\[IndentingNewLine]", 
    \(NumberForm[s20, 17]\ \)}], "Input"],

Cell[BoxData[{
    \(s40 = Simpson38[0, 3, 40]\ \), "\[IndentingNewLine]", 
    \(NumberForm[s40, 17]\ \)}], "Input"],

Cell[BoxData[{
    \(s80 = Simpson38[0, 3, 80]\ \), "\[IndentingNewLine]", 
    \(NumberForm[s80, 17]\ \)}], "Input"],

Cell[BoxData[{
    \(s160 = Simpson38[0, 3, 160]\ \), "\[IndentingNewLine]", 
    \(NumberForm[s80, 17]\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the analytic value of the integral  ",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_0\%3\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", 
                StyleBox[\(\[ExponentialE]\^\(-x\)\),
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox[\(Sin[x\^2]\),
                  FontSize->12]}], 
              StyleBox["+",
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox["1",
                FontSize->12]}], ")"}], \(\[DifferentialD]x\)}]}]]],
  "  (i.e. find the \"true value\").   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    RowBox[{"val", "=", 
      RowBox[{\(\[Integral]\_0\%3\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"3", 
                StyleBox[\(\[ExponentialE]\^\(-x\)\),
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox[\(Sin[x\^2]\),
                  FontSize->12]}], 
              StyleBox["+",
                FontSize->12], 
              StyleBox[" ",
                FontSize->12], 
              StyleBox["1",
                FontSize->12]}], ")"}], \(\[DifferentialD]x\)}]}]}]], "Input"],

Cell[BoxData[
    \(val = N[Re[val]]\)], "Input"],

Cell[BoxData[
    \(\(\(NumberForm[val, 17]\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the \"true value\" in example 8 and find the error for the Simpson's \
3/8 rule approximations in example 7.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(val - s10\)], "Input"],

Cell[BoxData[
    \(val - s20\)], "Input"],

Cell[BoxData[
    \(val - s40\)], "Input"],

Cell[BoxData[
    \(val - s80\)], "Input"],

Cell[BoxData[
    \(val - s160\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  When the step size is reduced by a factor of ",
  Cell[BoxData[
      \(1\/2\)]],
  " the ",
  "error term",
  "  ",
  Cell[BoxData[
      RowBox[{\(E\_SC\), 
        RowBox[{"(", 
          RowBox[{"f", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "h"}], ")"}]}]]],
  " should be reduced by approximately ",
  Cell[BoxData[
      \(\((1\/2)\)\^4\  = \ 0.0625`\)]],
  ".  Explore this phenomenon. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s20\)\(\ \)\)\/\(\(val\)\(-\)\(s10\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s40\)\(\ \)\)\/\(\(val\)\(-\)\(s20\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s80\)\(\ \)\)\/\(\(val\)\(-\)\(s40\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(val\)\(-\)\(s160\)\(\ \)\)\/\(\(val\)\(-\)\(s80\)\(\ \)\)\)], \
"Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Various Scenarios",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" and Animations for Simpson's 3/8 Rule.",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Let  ",
  Cell[BoxData[
      \(f[x] = 1 + \[ExponentialE]\^\(-x\)\ Sin[8\ x\^\(2/3\)]\)]],
  "  over  ",
  Cell[BoxData[
      \(\([0, 2]\)\)]],
  ".  Use ",
  "Simpson's 3/8 rule",
  " to approximate the value of the integral. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        1 + \[ExponentialE]\^\(-x\)\ Sin[
              8\ x\^\(2/3\)];\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 2.0;\)\ \), "\[IndentingNewLine]", 
    \(\(M = {1, 2, 3, 4, 5, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 
          35, 40};\)\), "\[IndentingNewLine]", 
    \(\(tbl = Table[j, {j, 1, 20}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(For[j = 1, 
        j \[LessEqual] 
          20, \(j++\), \ \[IndentingNewLine]\(tbl\_\(\(\[LeftDoubleBracket]\)\
\(j\)\(\[RightDoubleBracket]\)\) = {3 
                   M\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\) + 1, NumberForm[
                Simpson38[a, b, 
                  M\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\)], {8, 6}]};\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[tbl, 
          TableHeadings \[Rule] {None, {"\<m sample points\>", \
"\<Simpson38[a,b,m]\>"}}, 
          TableSpacing \[Rule] {2, 1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 2}, PlotRange \[Rule] {{0, 2.01}, {0, 2.01}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
        Axes \[Rule] True, PlotStyle \[Rule] Magenta];\)\ \)}], "Input",
  AnimationDisplayTime->0.371293],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Simpson38/Simpsonaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Quadrature/\
Simpson38/Simpsonaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Simpson38/Simpson.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's 3/8 Rule",
    ButtonData:>{
      URL[ 
      "http://ecs.fullerton.edu/~mathews/a2001/Animations/Quadrature/\
Simpson38/Simpson.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Simpson's Rule for Numerical Integration",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/SimpsonsRuleBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Simpson's Rule for Numerical Integration",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/SimpsonsRuleBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  ",
  "Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 199, 5, 35, "Text"],
Cell[1978, 60, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3457, 112, 459, 12, 49, "Text"],
Cell[3919, 126, 3351, 106, 145, "Text"],
Cell[7273, 234, 1915, 55, 78, "Text"],
Cell[9191, 291, 624, 21, 33, "Text"],
Cell[9818, 314, 167, 4, 35, "Text"],
Cell[9988, 320, 1092, 30, 52, "Text"],
Cell[11083, 352, 6214, 191, 165, "Text"],
Cell[17300, 545, 624, 21, 33, "Text"],
Cell[17927, 568, 190, 4, 35, "Text"],
Cell[18120, 574, 5950, 175, 274, "Text"],
Cell[24073, 751, 733, 24, 36, "Text"],
Cell[24809, 777, 2487, 83, 139, "Text"],
Cell[27299, 862, 766, 24, 33, "Text"],
Cell[28068, 888, 629, 22, 33, "Text"],
Cell[28700, 912, 261, 7, 33, "Text"],
Cell[28964, 921, 499, 8, 149, "Input"],
Cell[29466, 931, 296, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[29787, 943, 101, 2, 33, "Text"],
Cell[29891, 947, 478, 7, 113, "Input"],
Cell[30372, 956, 73, 0, 33, "Text"],
Cell[30448, 958, 73, 1, 33, "Input"],
Cell[30524, 961, 186, 3, 72, "Input"],
Cell[30713, 966, 239, 4, 72, "Input"],
Cell[30955, 972, 338, 5, 72, "Input"]
}, Closed]],
Cell[31308, 980, 325, 10, 31, "Text"],

Cell[CellGroupData[{
Cell[31658, 994, 101, 2, 33, "Text"],
Cell[31762, 998, 60, 0, 33, "Text"],
Cell[31825, 1000, 71, 1, 33, "Input"],
Cell[31899, 1003, 121, 2, 50, "Input"],
Cell[32023, 1007, 121, 2, 50, "Input"],
Cell[32147, 1011, 121, 2, 50, "Input"],
Cell[32271, 1015, 121, 2, 50, "Input"],
Cell[32395, 1019, 124, 2, 50, "Input"]
}, Closed]],
Cell[32534, 1024, 287, 8, 31, "Text"],

Cell[CellGroupData[{
Cell[32846, 1036, 101, 2, 33, "Text"],
Cell[32950, 1040, 127, 5, 33, "Text"],
Cell[33080, 1047, 83, 1, 41, "Input"],
Cell[33166, 1050, 50, 0, 33, "Text"],
Cell[33219, 1052, 110, 2, 42, "Input"],
Cell[33332, 1056, 53, 1, 30, "Input"],
Cell[33388, 1059, 73, 1, 30, "Input"]
}, Closed]],
Cell[33476, 1063, 231, 6, 30, "Text"],

Cell[CellGroupData[{
Cell[33732, 1073, 101, 2, 33, "Text"],
Cell[33836, 1077, 62, 1, 30, "Input"],
Cell[33901, 1080, 62, 1, 30, "Input"],
Cell[33966, 1083, 62, 1, 30, "Input"],
Cell[34031, 1086, 62, 1, 30, "Input"],
Cell[34096, 1089, 43, 1, 30, "Input"]
}, Closed]],
Cell[34154, 1093, 769, 26, 33, "Text"],

Cell[CellGroupData[{
Cell[34948, 1123, 101, 2, 33, "Text"],
Cell[35052, 1127, 93, 1, 42, "Input"],
Cell[35148, 1130, 93, 1, 42, "Input"],
Cell[35244, 1133, 93, 1, 42, "Input"],
Cell[35340, 1136, 96, 2, 42, "Input"]
}, Closed]],
Cell[35451, 1141, 797, 24, 31, "Text"],

Cell[CellGroupData[{
Cell[36273, 1169, 101, 2, 33, "Text"],
Cell[36377, 1173, 73, 0, 33, "Text"],
Cell[36453, 1175, 997, 24, 111, "Input"],
Cell[37453, 1201, 73, 1, 33, "Input"],
Cell[37529, 1204, 180, 3, 72, "Input"],
Cell[37712, 1209, 236, 4, 72, "Input"],
Cell[37951, 1215, 327, 5, 72, "Input"]
}, Closed]],
Cell[38293, 1223, 816, 24, 31, "Text"],

Cell[CellGroupData[{
Cell[39134, 1251, 101, 2, 33, "Text"],
Cell[39238, 1255, 60, 0, 33, "Text"],
Cell[39301, 1257, 530, 17, 31, "Input"],
Cell[39834, 1276, 117, 2, 50, "Input"],
Cell[39954, 1280, 117, 2, 50, "Input"],
Cell[40074, 1284, 117, 2, 50, "Input"],
Cell[40194, 1288, 117, 2, 50, "Input"],
Cell[40314, 1292, 119, 2, 50, "Input"]
}, Closed]],
Cell[40448, 1297, 790, 24, 31, "Text"],

Cell[CellGroupData[{
Cell[41263, 1325, 101, 2, 33, "Text"],
Cell[41367, 1329, 621, 18, 42, "Input"],
Cell[41991, 1349, 49, 1, 30, "Input"],
Cell[42043, 1352, 66, 1, 30, "Input"]
}, Closed]],
Cell[42124, 1356, 232, 6, 30, "Text"],

Cell[CellGroupData[{
Cell[42381, 1366, 101, 2, 33, "Text"],
Cell[42485, 1370, 42, 1, 30, "Input"],
Cell[42530, 1373, 42, 1, 30, "Input"],
Cell[42575, 1376, 42, 1, 30, "Input"],
Cell[42620, 1379, 42, 1, 30, "Input"],
Cell[42665, 1382, 43, 1, 30, "Input"]
}, Closed]],
Cell[42723, 1386, 770, 26, 33, "Text"],

Cell[CellGroupData[{
Cell[43518, 1416, 102, 2, 33, "Text"],
Cell[43623, 1420, 93, 1, 42, "Input"],
Cell[43719, 1423, 93, 1, 42, "Input"],
Cell[43815, 1426, 93, 1, 42, "Input"],
Cell[43911, 1429, 96, 2, 42, "Input"]
}, Closed]],
Cell[44022, 1434, 304, 10, 32, "Text"],
Cell[44329, 1446, 349, 13, 33, "Text"],

Cell[CellGroupData[{
Cell[44703, 1463, 102, 2, 33, "Text"],
Cell[44808, 1467, 1414, 28, 231, "Input"],
Cell[46225, 1497, 773, 26, 33, "Text"]
}, Closed]],
Cell[47013, 1526, 766, 24, 30, "Text"],
Cell[47782, 1552, 158, 3, 35, "Text"],
Cell[47943, 1557, 617, 18, 33, "Text"],
Cell[48563, 1577, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

