(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     68785,       2005]*)
(*NotebookOutlinePosition[     70035,       2044]*)
(*  CellTagsIndexPosition[     69991,       2040]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Euler's Method for O.D.E.'s",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell["\<\
\tThe first method we shall study for solving differential \
equations is called Euler's method, it serves to illustrate the concepts \
involved in the advanced methods. It has limited use because of the larger \
error that is accumulated with each successive step.  However, it is \
important to study Euler's method because the remainder term and error \
analysis is easier to understand. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem  (",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Euler's Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/EulerForwardMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[")",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times New Roman"],
  StyleBox["f(t,y)",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "is continuous and satisfies a ",
  ButtonBox["Lipschits condition",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LipschitzCondition.html"], None},
    ButtonStyle->"Hyperlink"],
  " in the variable  ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ",  and consider the  I. V. P. (initial value problem)",
  StyleBox[" \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y'\  = \ f \((t, y)\)\)]],
  StyleBox[" with ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((a)\) = \(t\_0 = \[Alpha]\)\)]],
  ",  over the interval  ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ". \n\t\t\nEuler's method uses the formulas ",
  Cell[BoxData[
      \(t\_\(k + 1\)\  = \ t\_k + h\)]],
  ",  and  \n\n\t\t",
  Cell[BoxData[
      \(y\_\(k + 1\)\  = \ y\_k\  + \ h\ f \((t\_k, y\_k)\)\)]],
  "     for  ",
  Cell[BoxData[
      RowBox[{\(k = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "1", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(m - 1\)}]]],
  "  \n \nas an approximate solution to the differential equation using the \
discrete set of points",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\((t\_k, y\_k)\)}\_\(k = 0\)\%m\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Euler's Method for O. D. E.'s",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Euler'sMethodProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Euler's Method for O. D. E.'s",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Euler'sMethodProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Error analysis for Euler's Method",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n\n\tWhen we obtained the formula  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y\_\(k + 1\)\  = \ y\_k\  + \ h\ f \((t\_k, y\_k)\)\)]],
  "  ",
  StyleBox["for Euler's method, the neglected term for each step has the form \
",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(\(y\^\((2)\)\) \((c\_k)\)\)\/2\) h\^2\)]],
  StyleBox[".  If this was the only error at each step, then at the end of \
the interval ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[", after ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(m\)]],
  StyleBox[" steps have been made, the accumulated error would be\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\[Sum]\+\(k = 1\)\%m\(\(\( y\^\((2)\)\) \((c\_k)\)\)\/2\) h\^2\  = \ 
        m \(\(\( y\^\((2)\)\) \((c)\)\)\/2\) h\^2\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\(\(h\ m\ \(y\^\((2)\)\) \((c)\)\)\/2\) 
          h\)\)\)\)]],
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"=", " ", 
          
          RowBox[{\(\(\(\((b\  - \ a)\)\ \(y\^\((2)\)\) \((c)\)\)\/2\) h\), 
            " ", "=", " ", 
            RowBox[{
              StyleBox["O",
                FontWeight->"Bold",
                FontSlant->"Italic"], \((h\^1)\)}]}]}]}]]],
  ".  ",
  StyleBox["\n\nThe error is more complicated, but this estimate \
predominates.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Precision of Euler's Method)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(\ \)\(y = y \((t)\)\)\)\)]],
  StyleBox["  is the solution to the I.V.P.  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y'\  = \ f \((t, y)\)\)]],
  StyleBox["  with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((t\_0)\) = y\_0\)]],
  StyleBox[".  If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(y \((t)\)\), "\[Element]", 
        RowBox[{
          SuperscriptBox[
            StyleBox["C",
              FontWeight->"Bold"], "2"], "[", \(t\_0, b\), "]"}]}]]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\((t\_k, y\_k)\)}\_\(k = 0\)\%m\)]],
  StyleBox["  is the sequence of approximations generated by Euler's method, \
then at each step, the local trunctaion error ",
    FontFamily->"Times New Roman"],
  "is of the order  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h\^2)\)}]]],
  ",  and the overall ",
  StyleBox["global truncation error  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(e\_k\)]],
  " ",
  StyleBox[" is of the order\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\(|\)\(e\_k\)\(|\)\), " ", "=", " ", 
        RowBox[{\(\(|\)\(y \((t\_k)\)\  - \ y\_k\)\(|\)\), " ", "=", " ", 
          RowBox[{
            StyleBox["O",
              FontWeight->"Bold",
              FontSlant->"Italic"], \((h\^1)\)}]}]}]]],
  ",  for  ",
  Cell[BoxData[
      RowBox[{\(k = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "m"}]]],
  ".  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->4],
  StyleBox["\n",
    FontFamily->"Times New Roman",
    FontSize->4],
  StyleBox["The error at the right end of the interval is called the final \
global error  ",
    FontFamily->"Times New Roman"],
  StyleBox["\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(E \((y \((b)\), h)\)\), " ", "=", " ", 
        RowBox[{\(\(|\)\(y \((b)\)\  - \ y\_m\)\(|\)\), " ", "=", " ", 
          RowBox[{
            StyleBox["O",
              FontWeight->"Bold",
              FontSlant->"Italic"], \((h\^1)\)}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["  The global truncation error  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(E \((y \((b)\), h)\)\)]],
  StyleBox["  is used to study the behavior of the error for various step \
sizes.  It can be used to give us an idea of how much computing effort must \
be done to obtain an accurate approximation.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Euler's Method for O. D. E.'s",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Euler'sMethodProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Euler's Method for O. D. E.'s",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Euler'sMethodProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical methods used in this module.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Use Euler's method and the modified Euler's method. Construct numerical \
solutions of order  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h)\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h\^2)\)}]]],
  ", respectively.  The theory for the modified Euler method is not presented \
at this time, we are to trust that its development is similar, but the order \
for the error is better and is known to be ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h\^2)\)}]]],
  ".   "
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Euler's Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
Euler1/Euler.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Euler's Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/Euler1/\
Euler.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Modified Euler's Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
MEuler1/MEuler.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Modified Euler's Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/MEuler1/\
MEuler.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (Euler's",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" Method",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  To approximate the solution of the initial value problem ",
  Cell[BoxData[
      \(y' = f \((t, y)\)\)]],
  " with ",
  Cell[BoxData[
      \(\(\(\ \)\(y \((a)\) = \(y\_0 = \[Alpha]\)\)\)\)]],
  "  over  ",
  Cell[BoxData[
      \(\([t\_0, b]\) = \([a, b]\)\)]],
  "  at a discrete set of points using the formulas  \n\n\t\t",
  Cell[BoxData[
      \(t\_\(k + 1\)\  = \ t\_k + h\)]],
  ",  and  ",
  Cell[BoxData[
      \(y\_\(k + 1\)\  = \ y\_k\  + \ h\ f \((t\_k, y\_k)\)\)]],
  "  for  ",
  Cell[BoxData[
      \(k = 0, 1, 2,  ... , m - 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Euler's Method for O. D. E.'s",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Euler'sMethodProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Euler's Method for O. D. E.'s",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Euler'sMethodProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Euler's Method",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    \(\(\(Euler[a0_, b0_, \[Alpha]_, 
        m0_]\)\(:=\)\(\ \)\(\[IndentingNewLine]\)\(Module[{a = a0, b = b0, j, 
          m = m0}, \[IndentingNewLine]h\  = \ \(b - a\)\/m; \ \
\[IndentingNewLine]T\  = \ 
          Table[\ a + \((j - 1)\) h, {j, 1, 
              m + 1}]; \ \[IndentingNewLine]Y = \ 
          Table[\ \[Alpha], {j, 1, m + 1}]; \ \ \[IndentingNewLine]For[\ 
          j = 1, \ j \[LessEqual] 
            m, \ \(j++\), \
\[IndentingNewLine]\(Y\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\
\[RightDoubleBracket]\)\)\  = \ 
              Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\), 
                    Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\)];\)\ ]; \ \[IndentingNewLine]Return[
          Transpose[{T, Y}]];\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Algorithm (Modified Euler's",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" Method",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "To approximate the solution of the initial value problem ",
  Cell[BoxData[
      \(y' = f \((t, y)\)\)]],
  " with ",
  Cell[BoxData[
      \(\(\(\ \)\(y \((a)\) = \(y\_0 = \[Alpha]\)\)\)\)]],
  "  over  ",
  Cell[BoxData[
      \(\([t\_0, b]\) = \([a, b]\)\)]],
  "  at a discrete set of points using the formulas\n\n\t\t  ",
  Cell[BoxData[
      \(t\_\(k + 1\)\  = \ t\_k + h\)]],
  ",  and  ",
  Cell[BoxData[
      \(y\_\(k + 1\)\  = \ 
        y\_k\  + \ 
          h\ f \((t\_k + h\/2, y\_k\  + \ h\/2\ f \((t\_k, y\_k)\))\)\)]],
  "  for  ",
  Cell[BoxData[
      \(k = 0, 1, 2,  ... , m - 1\)]],
  ".  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Modified Euler's Method).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(MEuler[a0_, b0_, \[Alpha]_, 
        m0_]\)\(:=\)\(\ \)\(\[IndentingNewLine]\)\(Module[{a = a0, b = b0, j, 
          m = m0}, \[IndentingNewLine]h\  = \ \(b - a\)\/m; \ \
\[IndentingNewLine]T\  = \ 
          Table[\ a + \((j - 1)\) h, {j, 1, 
              m + 1}]; \ \[IndentingNewLine]Y = \ 
          Table[\ \[Alpha], {j, 1, m + 1}]; \ \ \[IndentingNewLine]For[\ 
          j = 1, j \[LessEqual] 
            m, \(j++\), \[IndentingNewLine]\(Y\_\(\(\[LeftDoubleBracket]\)\(j \
+ 1\)\(\[RightDoubleBracket]\)\) = 
              Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\) + h\/2, 
                    Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + \(h\/2\) 
                        f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\), 
                          Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\)]];\)\ ]; \ \[IndentingNewLine]Return[
          Transpose[{T, Y}]];\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", 
            RowBox[{"t", " ", "y", "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Compute the Euler and modified Euler solutions based on 25 \
subintervals and plot the results.\
\>", "Text"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 1\  - \ t\ \ y;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the D.E.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f[t, y]\ ];\)\ \)}], "Input"],

Cell["First, find Euler's solution.", "Text"],

Cell[BoxData[{
    \(\(n = 25;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = Euler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Green, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell["Second, find the modified Euler solution.", "Text"],

Cell[BoxData[{
    \(\(n = 25;\)\ \), "\[IndentingNewLine]", 
    \(\(pts2\  = \ MEuler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2\  = \ Y;\)\ \), "\n", 
    \(\(graph2\  = \ 
        ListPlot[pts2, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Blue, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The modified Euler solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell["\<\
Just for fun, plot both the Euler solution and the modified Euler \
solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler and modified Euler solutions for  y' = \>", 
        f[t, y]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the analytic solution and graph for the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", 
            RowBox[{"t", " ", "y", "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(de\  = \ \(y'\)[t] \[Equal] 
          1 - \ t\ \ y[t];\)\ \), "\[IndentingNewLine]", 
    \(\(ic\  = \ y[0] \[Equal] 1;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = DSolve[{de, ic}, y[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the differential equation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[ic];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \)}], "Input"],

Cell["\<\
Dig out the formula for the solution out of the data structure of  \
solset and put it in  f[t].
Plot the analytic solution at the same sample points that were used for the \
numerical approximations.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[t_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(pts3 = Transpose[{T, f[T]}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ListPlot[pts3, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The analytic solution is:\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<f[t] = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Just for fun, plot the Euler and modified Euler solutions and the \
analytic solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph2, graph3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler modified Euler and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Plot the error for Euler's method and the modified Euler's method."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(pts4 = Transpose[{T, f[T] - Y1}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph4 = 
        ListPlot[pts4, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] \ Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Euler's method using \>", 
        n, "\< subintervals,\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(pts5 = Transpose[{T, f[T] - Y2}];\)\), "\[IndentingNewLine]", 
    \(\(graph5 = 
        ListPlot[pts5, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] \ Blue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for modified Euler's method using \>", 
        n, "\< subintervals,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\)}], "Input"],

Cell["\<\
Just for fun, compare the error for the Euler and modified Euler \
solutions. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph4, graph5, 
        PlotRange \[Rule] {{0, 5}, {\(-0.2\), 
              0.025}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the Euler and modified Euler's methods using \>", 
        n, "\< subintervals,\>"];\)\ \)}], "Input"],

Cell[TextData[{
  "Since we have the analytic or \"true solution\" at hand, we can run \
experiments to verify that Euler's method has order  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold"], \((h)\)}]]],
  ",  and   the Modified Euler's method has order  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold"], \((h\^2)\)}]]],
  ".   Reduce the step size by  ",
  Cell[BoxData[
      \(1\/2\)]],
  " and see what happens to the error."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Reduce the step size by  ",
  Cell[BoxData[
      \(1\/2\)]],
  " and see what happens to the error.\nRecalculate points for Euler's \
method, the Modified Euler's method, and the analytic solution using twice as \
many subintervals.\nThen Plot the error for Euler's method and the Modified \
Euler's method."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(n = 50;\)\ \), "\[IndentingNewLine]", 
    \(\(Euler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1 = Y;\)\ \), "\n", 
    \(\(MEuler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2 = Y;\)\ \), "\n", 
    \(\(pts = Transpose[{T, f[T]}];\)\)}], "Input"],

Cell["The error for Euler's method.", "Text"],

Cell[BoxData[{
    \(\(pts6 = Transpose[{T, f[T] - Y1}];\)\), "\[IndentingNewLine]", 
    \(\(graph6 = 
        ListPlot[pts6, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Euler's method using \>", 
        n, "\< subintervals,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\)}], "Input"],

Cell["The error for the Modified Euler's method.", "Text"],

Cell[BoxData[{
    \(\(pts7 = Transpose[{T, f[T] - Y2}];\)\), "\[IndentingNewLine]", 
    \(\(graph7 = 
        ListPlot[pts7, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Blue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Modified Euler's method using \>", 
        n, "\< subintervals.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\)}], "Input"],

Cell[TextData[{
  "Compare the error for Euler's method with 25 and 50 subintervals. \n",
  StyleBox["Question 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " When the step size is reduced by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " estimate how much is the error reduced ?  (Theoretically is is ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  ".)  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph4, graph6, PlotRange \[Rule] {{0, 5}, {\(-0.11\), 0.02}}, 
        Ticks \[Rule] {Automatic, 
            Range[\(-0.1\), 0.05, 0.021]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Euler's method using \>", n/2, "\< and \>", 
        n, "\< subintervals.\>"];\)\ \)}], "Input"],

Cell[TextData[{
  "Compare the error for the Modified Euler's method with 25 and 50 \
subintervals. \n",
  StyleBox["Question 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " When the step size is reduced by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " estimate how much is the error reduced ?  (Theoretically is is ",
  Cell[BoxData[
      \(TraditionalForm\`1\/4\)]],
  ".)  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph5, graph7, PlotRange \[Rule] {{0, 5}, {\(-0.002\), 0.005}}, 
        Ticks \[Rule] {Automatic, 
            Range[\(-0.005\), 0.005, 0.001]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The error for the modified Euler's method using \>", 
        n/2, "\< and \>", n, "\< subintervals.\>"];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Question 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Which method, Euler's method, or the Modified Euler's method, is better \
to use ?  Why ?"
}], "Text"],

Cell[TextData[{
  StyleBox["Question 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Suppose that  100 subintervals are to be used.  Can you predict \
(estimate) the largest error for Euler's method, and the Modified Euler's \
method without doing the calculations ?  Just look at the results in problem \
4.  You can read the values off the graph with the cross-hairs by \
highlighting the graph and holding down on the Ctrl key.  Do it."
}], "Text"],

Cell["\<\
Now suppose that an applied mathematician seeks a numerical \
solution that has 8 correct digits to the right of the decimal point.\
\>", \
"Text"],

Cell[TextData[{
  StyleBox["Question 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  What value of  m  would you predict that one should use in Euler's \
method to achieve the desired accuracy."
}], "Text"],

Cell[TextData[{
  StyleBox["Question 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  What value of  m  would you predict that one should use in the modified \
Euler's method to achieve the desired accuracy.\n\n",
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Do not execute the Euler and MEuler subroutines to answer this question. \
Their might be too many computations involved and it will take a long time to \
do them.  You are to estimate an answer based on your knowledge about the ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h)\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h\^2)\)}]]],
  " behavior of the error. "
}], "Text"],

Cell["\<\
Now suppose that an applied mathematician seeks a numerical \
solution that has 8 correct digits to the right of the decimal point.\
\>", \
"Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve  ",
  Cell[BoxData[
      \(y' = \ 30 - 5  y\)]],
  "  with  ",
  Cell[BoxData[
      \(y \((0)\) = 1\)]],
  "  over  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 5\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[t_, y_] = 30 - 5\ y\ ;\)\ \), "\n", 
    \(\(n = 50;\)\ \ \), "\[IndentingNewLine]", 
    \(\(pts1\  = Euler[0.0, 5.0, 1, n];\)\ \), "\n", 
    \(\(Y1\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, 5.2}, {0, 7.4}}, 
          PlotStyle \[Rule] Green];\)\ \), "\n", 
    \(\(Print["\<The Euler solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[t_, y_] = 30 - 5\ y\ ;\)\ \), "\n", 
    \(\(n = 50;\)\ \ \), "\[IndentingNewLine]", 
    \(\(pts2 = MEuler[0.0, 5.0, 1, n];\)\ \), "\n", 
    \(\(Y2\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(graph2\  = \ 
        ListPlot[pts2, PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, 5.2}, {0, 7.4}}, 
          PlotStyle \[Rule] Blue];\)\ \), "\n", 
    \(\(Print["\<The modified Euler solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell["\<\
Just for fun, plot both the Euler solution and the modified Euler \
solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph2];\)\), "\n", 
    \(\(Print["\<The Euler and modified Euler solutions for  y' = \>", 
        f[t, y]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the analytic solution and graph for the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", 
            RowBox[{"t", " ", "y", "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(de\  = \ \(y'\)[t] \[Equal] 
          30 - 5  y[t];\)\ \), "\[IndentingNewLine]", 
    \(\(ic\  = \ y[0] \[Equal] 1;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = DSolve[{de, ic}, y[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the differential equation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[ic];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MapAll[Expand, solset]];\)\ \)}], "Input"],

Cell["\<\
Dig out the formula for the solution out of the data structure of  \
solset and put it in  f[t].
Plot the analytic solution at the same sample points that were used for the \
numerical approximations.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[t_] = 
        MapAll[Expand, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(pts3 = Transpose[{T, f[T]}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ListPlot[pts3, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 5.2}, {0, 
                7.4}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The analytic solution is:\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<f[t] = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Just for fun, plot the Euler and modified Euler solutions and the \
analytic solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph2, graph3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler modified Euler and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Plot the absolute value of the error for Euler's method and the modified \
Euler's method."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(pts4 = Transpose[{T, f[T] - Y1}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph4 = 
        ListPlot[Abs[pts4], PlotJoined \[Rule] True, 
          PlotStyle \[Rule] \ Green, 
          PlotRange \[Rule] All];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Euler's method using \>", 
        n, "\< subintervals,\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(pts5 = Transpose[{T, f[T] - Y2}];\)\), "\[IndentingNewLine]", 
    \(\(graph5 = 
        ListPlot[Abs[pts5], PlotJoined \[Rule] True, 
          PlotStyle \[Rule] \ Blue, 
          PlotRange \[Rule] All];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for modified Euler's method using \>", 
        n, "\< subintervals,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\)}], "Input"],

Cell["\<\
Just for fun, compare the error for the Euler and modified Euler \
solutions. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph4, graph5, 
        PlotRange \[Rule] {{0, 5}, {0, 0.6}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Error for the Euler and modified Euler's methods using \>", 
        n, "\< subintervals,\>"];\)\ \)}], "Input"],

Cell[TextData[{
  "Since we have the analytic or \"true solution\" at hand, we can run \
experiments to verify that Euler's method has order  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold"], \((h)\)}]]],
  ",  and   the Modified Euler's method has order  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold"], \((h\^2)\)}]]],
  ".   Reduce the step size by  ",
  Cell[BoxData[
      \(1\/2\)]],
  " and see what happens to the error."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Reduce the step size by  ",
  Cell[BoxData[
      \(1\/2\)]],
  " and see what happens to the error.\nRecalculate points for Euler's \
method, the Modified Euler's method, and the analytic solution using twice as \
many subintervals.\nThen Plot the error for Euler's method and the Modified \
Euler's method."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(n = 100;\)\ \), "\[IndentingNewLine]", 
    \(\(Euler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1 = Y;\)\ \), "\n", 
    \(\(MEuler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2 = Y;\)\ \), "\n", 
    \(\(pts = Transpose[{T, f[T]}];\)\)}], "Input"],

Cell["The error for Euler's method.", "Text"],

Cell[BoxData[{
    \(\(pts6 = Transpose[{T, f[T] - Y1}];\)\), "\[IndentingNewLine]", 
    \(\(graph6 = 
        ListPlot[Abs[pts6], PlotJoined \[Rule] True, PlotStyle \[Rule] Green, 
          PlotRange \[Rule] All];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Euler's method using \>", 
        n, "\< subintervals,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\)}], "Input"],

Cell["The error for the Modified Euler's method.", "Text"],

Cell[BoxData[{
    \(\(pts7 = Transpose[{T, f[T] - Y2}];\)\), "\[IndentingNewLine]", 
    \(\(graph7 = 
        ListPlot[Abs[pts7], PlotJoined \[Rule] True, 
          PlotStyle \[Rule] \ Blue, 
          PlotRange \[Rule] All];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Modified Euler's method using \>", 
        n, "\< subintervals,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\)}], "Input"],

Cell[TextData[{
  "Compare the error for Euler's method with 50 and 100 subintervals. \n",
  StyleBox["Question 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " When the step size is reduced by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " estimate how much is the error reduced ?  (Theoretically is is ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  ".)  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph4, graph6, 
        PlotRange \[Rule] All];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Euler's method using \>", n/2, "\< and \>", 
        n, "\< subintervals.\>"];\)\ \)}], "Input"],

Cell[TextData[{
  "Compare the error for the Modified Euler's method with 50 and 100 \
subintervals. \n",
  StyleBox["Question 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " When the step size is reduced by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " estimate how much is the error reduced ?  (Theoretically is is ",
  Cell[BoxData[
      \(TraditionalForm\`1\/4\)]],
  ".)  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph5, graph7, 
        PlotRange \[Rule] All];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for the modified Euler's method using \>", 
        n/2, "\< and \>", n, "\< subintervals.\>"];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Question 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Which method, Euler's method, or the Modified Euler's method, is better \
to use ?  Why ?"
}], "Text"],

Cell[TextData[{
  StyleBox["Question 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Suppose that  500 subintervals are to be used.  Can you predict \
(estimate) the largest error for Euler's method, and the Modified Euler's \
method without doing the calculations ?  Just look at the results in problem \
4.  You can read the values off the graph with the cross-hairs by \
highlighting the graph and holding down on the Ctrl key.  Do it."
}], "Text"],

Cell[TextData[{
  "Now suppose that an applied mathematician seeks a numerical solution that \
has 8 correct digits to the right of the decimal point.\n",
  StyleBox["Question 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  What value of  m  would you predict that one should use in Euler's \
method to achieve the desired accuracy.\n",
  StyleBox["Question 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  What value of  m  would you predict that one should use in the modified \
Euler's method to achieve the desired accuracy.\n",
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  Do not execute the Euler and MEuler subroutines to answer this question. \
Their might be too many computations involved and it will take a long time to \
do them.  You are to estimate an answer based on your knowledge about the ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h)\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h\^2)\)}]]],
  " behavior of the error. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{\(t\^2\), " ", "+", 
            RowBox[{\(y\^2\), "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "1"}]}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Compute the Euler and modified Euler solutions based on 50 \
subintervals and plot the results.
Note, for this example we will extend one subinterval more to the right of  \
t=1.\
\>", "Text"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ t\^2\  + y\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the D.E.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f[t, y]\ ];\)\ \)}], "Input"],

Cell["First, find Euler's solution.", "Text"],

Cell[BoxData[{
    \(\(n = 51;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = Euler[0.0, 1.02, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Green, 
          PlotRange \[Rule] {{0, 1}, {0, 
                30}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell["\<\
Second, find the modified Euler solution.
Note, for this example we will extend one subinterval more to the right of  \
t=1.\
\>", "Text"],

Cell[BoxData[{
    \(\(n = 51;\)\ \), "\[IndentingNewLine]", 
    \(\(pts2\  = \ MEuler[0.0, 1.02, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y2\  = \ Y;\)\ \), "\n", 
    \(\(graph2\  = \ 
        ListPlot[pts2, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Blue, 
          PlotRange \[Rule] {{0, 1}, {0, 
                30}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The modified Euler solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell["\<\
Just for fun, plot both the Euler solution and the modified Euler \
solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph2];\)\), "\n", 
    \(\(Print["\<The Euler and modified Euler solutions for  y' = \>", 
        f[t, y]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the analytic solution and graph for the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{\(t\^2\), " ", "+", 
            RowBox[{\(y\^2\), "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", "1"}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(de\  = \ \(y'\)[t] \[Equal] 
          t\^2 + \ y[t]\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(ic\  = \ y[0] \[Equal] 1;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = DSolve[{de, ic}, y[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(f[t_] = 
        MapAll[FullSimplify, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the differential equation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[ic];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", f[t]\ ];\)\ \)}], "Input"],

Cell["\<\
Dig out the formula for the solution out of the data structure of  \
solset and put it in  f[t].
Plot the analytic solution at the same sample points that were used for the \
numerical approximations.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[t_] = 
        MapAll[FullSimplify, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        Plot[f[t], {t, 0, 0.969}, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0.001, 0.98}, {0, 
                30}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The analytic solution is:\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<f[t] = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Just for fun, plot the Euler and modified Euler solutions and the \
analytic solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph2, graph3, 
        PlotRange \[Rule] {{0.001, 0.98}, {0, 
              50}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler modified Euler and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[graph1, graph2, graph3, 
        PlotRange \[Rule] {{0.001, 0.98}, {0, 
              100}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler modified Euler and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[graph1, graph2, graph3, 
        PlotRange \[Rule] {{0.001, 0.98}, {0, 
              1000}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler modified Euler and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Something strange is happening, it appears that the solution to  ",
  Cell[BoxData[
      \(y' = \ \(\(t\^2\)\(+\)\(\ \)\(y\^2\)\(\ \)\)\)]],
  "has a vertical asymptote, yet Euler's method and the modified Euler's \
method are able to move past this asymptote!  How can this happen?  If the \
step size is chosen smaller, then these methods will not tend to overshoot \
the asymptote. The location of the asymptote can be found using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s procedure FindRoot."
}], "Text"],

Cell[BoxData[
    \(FindRoot[
      16\ \((\(-32\)\ \[Pi]\ BesselJ[1\/4, 
                t\^2\/2] + \@2\ BesselJ[\(-\(1\/4\)\), 
                t\^2\/2]\ \((\(-4\)\ Gamma[\(-\(1\/4\)\)]\^2 + 
                  30\ Gamma[\(-\(5\/4\)\)]\ Gamma[3\/4])\))\), {t, 
        0.9}]\)], "Input"],

Cell["\<\
Numerical methods with a higher order of precision will not tend to \
overshoot the asymptote. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Various Scenarios",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" and Animations for Euler's Method for O.D.E's",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", " ", 
            RowBox[{"t", " ", \(\@y\%3\), "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".    Compute Euler's solution to the I.V.P."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 40;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = Euler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = Euler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 150;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = Euler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Euler solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Euler's Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
Euler1/Euleraa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Euler's Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/Euler1/\
Euleraa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", " ", 
            RowBox[{"t", " ", \(\@y\%3\), "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".    ",
  " Compute the Modified Euler solution to the I.V.P."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 40;\)\ \), "\[IndentingNewLine]", 
    \(\(pts2\  = \ MEuler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2\  = \ 
        ListPlot[pts2, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The modified Euler solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \), "\[IndentingNewLine]", 
    \(\(pts2\  = \ MEuler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2\  = \ 
        ListPlot[pts2, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The modified Euler solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 150;\)\ \), "\[IndentingNewLine]", 
    \(\(pts2\  = \ MEuler[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2\  = \ 
        ListPlot[pts2, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The modified Euler solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Modified Euler's Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
MEuler1/MEuleraa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Modified Euler's Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/MEuler1/\
MEuleraa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Euler's Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
Euler1/Euler.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Euler's Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/Euler1/\
Euler.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Modified Euler's Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
MEuler1/MEuler.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Modified Euler's Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/MEuler1/\
MEuler.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Euler's Method for O.D.E.'s",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/eu.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Euler's Method for O.D.E.'s",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/eu.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Euler's Method for O. D. E.'s",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Euler'sMethodBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Euler's Method for O. D. E.'s",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Euler'sMethodBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 180, 4, 35, "Text"],
Cell[1959, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3438, 111, 415, 7, 68, "Text"],
Cell[3856, 120, 3415, 105, 185, "Text"],
Cell[7274, 227, 648, 21, 33, "Text"],
Cell[7925, 250, 1619, 46, 181, "Text"],
Cell[9547, 298, 3815, 118, 165, "Text"],
Cell[13365, 418, 511, 13, 52, "Text"],
Cell[13879, 433, 648, 21, 33, "Text"],
Cell[14530, 456, 858, 26, 52, "Text"],
Cell[15391, 484, 752, 24, 33, "Text"],
Cell[16146, 510, 774, 24, 33, "Text"],
Cell[16923, 536, 955, 31, 90, "Text"],
Cell[17881, 569, 634, 20, 33, "Text"],
Cell[18518, 591, 365, 11, 33, "Text"],
Cell[18886, 604, 898, 17, 186, "Input"],
Cell[19787, 623, 1073, 35, 93, "Text"],
Cell[20863, 660, 153, 2, 33, "Text"],
Cell[21019, 664, 1091, 20, 201, "Input"],
Cell[22113, 686, 619, 19, 33, "Text"],

Cell[CellGroupData[{
Cell[22757, 709, 101, 2, 33, "Text"],
Cell[22861, 713, 119, 3, 33, "Text"],
Cell[22983, 718, 234, 4, 70, "Input"],
Cell[23220, 724, 45, 0, 33, "Text"],
Cell[23268, 726, 908, 17, 210, "Input"],
Cell[24179, 745, 57, 0, 33, "Text"],
Cell[24239, 747, 849, 16, 190, "Input"],
Cell[25091, 765, 137, 3, 33, "Text"],
Cell[25231, 770, 183, 3, 50, "Input"]
}, Closed]],
Cell[25429, 776, 720, 22, 30, "Text"],

Cell[CellGroupData[{
Cell[26174, 802, 101, 2, 33, "Text"],
Cell[26278, 806, 559, 11, 170, "Input"],
Cell[26840, 819, 224, 5, 52, "Text"],
Cell[27067, 826, 598, 12, 150, "Input"],
Cell[27668, 840, 146, 3, 33, "Text"],
Cell[27817, 845, 195, 3, 50, "Input"]
}, Closed]],
Cell[28027, 851, 258, 8, 30, "Text"],

Cell[CellGroupData[{
Cell[28310, 863, 101, 2, 33, "Text"],
Cell[28414, 867, 415, 7, 90, "Input"],
Cell[28832, 876, 417, 7, 90, "Input"],
Cell[29252, 885, 102, 3, 33, "Text"],
Cell[29357, 890, 276, 5, 50, "Input"],
Cell[29636, 897, 516, 16, 55, "Text"]
}, Closed]],
Cell[30167, 916, 426, 11, 71, "Text"],

Cell[CellGroupData[{
Cell[30618, 931, 101, 2, 33, "Text"],
Cell[30722, 935, 302, 6, 130, "Input"],
Cell[31027, 943, 45, 0, 33, "Text"],
Cell[31075, 945, 407, 7, 90, "Input"],
Cell[31485, 954, 58, 0, 33, "Text"],
Cell[31546, 956, 415, 7, 90, "Input"],
Cell[31964, 965, 407, 12, 55, "Text"],
Cell[32374, 979, 327, 5, 50, "Input"],
Cell[32704, 986, 422, 13, 55, "Text"],
Cell[33129, 1001, 345, 5, 50, "Input"],
Cell[33477, 1008, 208, 6, 33, "Text"],
Cell[33688, 1016, 472, 9, 52, "Text"],
Cell[34163, 1027, 157, 4, 33, "Text"],
Cell[34323, 1033, 227, 6, 33, "Text"],
Cell[34553, 1041, 863, 24, 90, "Text"],
Cell[35419, 1067, 157, 4, 33, "Text"]
}, Closed]],
Cell[35591, 1074, 359, 16, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[35975, 1094, 101, 2, 33, "Text"],
Cell[36079, 1098, 888, 18, 210, "Input"],
Cell[36970, 1118, 868, 17, 210, "Input"],
Cell[37841, 1137, 137, 3, 33, "Text"],
Cell[37981, 1142, 166, 3, 50, "Input"]
}, Closed]],
Cell[38162, 1148, 808, 26, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[38995, 1178, 101, 2, 33, "Text"],
Cell[39099, 1182, 572, 11, 170, "Input"],
Cell[39674, 1195, 224, 5, 52, "Text"],
Cell[39901, 1202, 626, 13, 150, "Input"],
Cell[40530, 1217, 146, 3, 33, "Text"],
Cell[40679, 1222, 195, 3, 50, "Input"]
}, Closed]],
Cell[40889, 1228, 208, 6, 30, "Text"],

Cell[CellGroupData[{
Cell[41122, 1238, 101, 2, 33, "Text"],
Cell[41226, 1242, 454, 8, 90, "Input"],
Cell[41683, 1252, 458, 8, 90, "Input"],
Cell[42144, 1262, 102, 3, 33, "Text"],
Cell[42249, 1267, 252, 4, 50, "Input"],
Cell[42504, 1273, 516, 16, 55, "Text"]
}, Closed]],
Cell[43035, 1292, 426, 11, 71, "Text"],

Cell[CellGroupData[{
Cell[43486, 1307, 101, 2, 33, "Text"],
Cell[43590, 1311, 303, 6, 130, "Input"],
Cell[43896, 1319, 45, 0, 33, "Text"],
Cell[43944, 1321, 435, 7, 90, "Input"],
Cell[44382, 1330, 58, 0, 33, "Text"],
Cell[44443, 1332, 456, 8, 90, "Input"],
Cell[44902, 1342, 408, 12, 55, "Text"],
Cell[45313, 1356, 235, 4, 50, "Input"],
Cell[45551, 1362, 423, 13, 55, "Text"],
Cell[45977, 1377, 248, 4, 50, "Input"],
Cell[46228, 1383, 208, 6, 33, "Text"],
Cell[46439, 1391, 472, 9, 52, "Text"],
Cell[46914, 1402, 1203, 31, 109, "Text"]
}, Closed]],
Cell[48132, 1436, 624, 19, 30, "Text"],

Cell[CellGroupData[{
Cell[48781, 1459, 101, 2, 33, "Text"],
Cell[48885, 1463, 202, 5, 52, "Text"],
Cell[49090, 1470, 233, 4, 70, "Input"],
Cell[49326, 1476, 45, 0, 33, "Text"],
Cell[49374, 1478, 903, 17, 210, "Input"],
Cell[50280, 1497, 148, 4, 52, "Text"],
Cell[50431, 1503, 844, 16, 190, "Input"],
Cell[51278, 1521, 137, 3, 33, "Text"],
Cell[51418, 1526, 166, 3, 50, "Input"]
}, Closed]],
Cell[51599, 1532, 529, 17, 30, "Text"],

Cell[CellGroupData[{
Cell[52153, 1553, 102, 2, 33, "Text"],
Cell[52258, 1557, 740, 15, 190, "Input"],
Cell[53001, 1574, 224, 5, 52, "Text"],
Cell[53228, 1581, 554, 12, 130, "Input"],
Cell[53785, 1595, 146, 3, 33, "Text"],
Cell[53934, 1600, 263, 5, 50, "Input"],
Cell[54200, 1607, 264, 5, 50, "Input"],
Cell[54467, 1614, 265, 5, 50, "Input"],
Cell[54735, 1621, 547, 11, 52, "Text"],
Cell[55285, 1634, 288, 6, 45, "Input"],
Cell[55576, 1642, 119, 3, 33, "Text"]
}, Closed]],
Cell[55710, 1648, 311, 10, 32, "Text"],
Cell[56024, 1660, 672, 19, 33, "Text"],

Cell[CellGroupData[{
Cell[56721, 1683, 102, 2, 33, "Text"],
Cell[56826, 1687, 1025, 19, 238, "Input"],
Cell[57854, 1708, 1026, 19, 238, "Input"],
Cell[58883, 1729, 1026, 19, 238, "Input"],
Cell[59912, 1750, 759, 26, 33, "Text"]
}, Closed]],
Cell[60686, 1779, 690, 20, 30, "Text"],

Cell[CellGroupData[{
Cell[61401, 1803, 102, 2, 33, "Text"],
Cell[61506, 1807, 1056, 19, 238, "Input"],
Cell[62565, 1828, 1057, 19, 238, "Input"],
Cell[63625, 1849, 1057, 19, 238, "Input"],
Cell[64685, 1870, 781, 26, 33, "Text"]
}, Closed]],
Cell[65481, 1899, 752, 24, 30, "Text"],
Cell[66236, 1925, 774, 24, 33, "Text"],
Cell[67013, 1951, 717, 20, 33, "Text"],
Cell[67733, 1973, 158, 3, 35, "Text"],
Cell[67894, 1978, 591, 17, 33, "Text"],
Cell[68488, 1997, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

