(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56305,       1628]*)
(*NotebookOutlinePosition[     57053,       1654]*)
(*  CellTagsIndexPosition[     57009,       1650]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Adams-Bashforth-Moulton Method for \
O.D.E.'s",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tThe methods of Euler, Heun, Taylor and Runge-Kutta are called \
single-step methods because they use only the information from one previous \
point to compute the successive point, that is, only the initial point  ",
  Cell[BoxData[
      \(\((t\_0, y\_0)\)\)]],
  "  is used to compute  ",
  Cell[BoxData[
      \(\((t\_1, y\_1)\)\)]],
  "  and in general  ",
  Cell[BoxData[
      \(y\_k\)]],
  "  is needed to compute  ",
  Cell[BoxData[
      \(y\_\(k + 1\)\)]],
  ".  After several points have been found it is feasible to use several \
prior points in the calculation.  The Adams-Bashforth-Moulton method uses ",
  Cell[BoxData[
      RowBox[{\(y\_\(k - 3\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(y\_\(k - 2\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(y\_\(k - 1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["  ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(y\_k\)}]}]]],
  "  in the calculation of ",
  Cell[BoxData[
      \(y\_\(k + 1\)\)]],
  ".  This method is not self-starting;  four initial points  ",
  Cell[BoxData[
      \(\((t\_0, y\_0)\)\)]],
  ", ",
  Cell[BoxData[
      \(\((t\_1, y\_1)\)\)]],
  ", ",
  Cell[BoxData[
      \(\((t\_2, y\_2)\)\)]],
  ",  and ",
  Cell[BoxData[
      \(\((t\_3, y\_3)\)\)]],
  " must be given in advance in order to generate the points ",
  Cell[BoxData[
      \({\((t\_k, y\_k)\)}\_\(k = 4\)\%m\)]],
  ".  \n\n\tA desirable feature of a multistep method is that the local \
truncation error (L. T. E.) can be determined and a correction term can be \
included, which improves the accuracy of the answer at each step.  Also, it \
is possible to determine if the step size is small enough to obtain an \
accurate value for  ",
  Cell[BoxData[
      \(y\_\(k + 1\)\)]],
  ", yet large enough so that unnecessary and time-consuming calculations are \
eliminated.  If the code for the subroutine is fine-tuned, then the \
combination of a  predictor and corrector requires only two function \
evaluations of",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["f(t,y)",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "per step.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem  (Adams-Bashforth-MoultonMethod)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times New Roman"],
  StyleBox["f(t,y)",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "is continuous and satisfies a ",
  ButtonBox["Lipschits condition",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LipschitzCondition.html"], None},
    ButtonStyle->"Hyperlink"],
  " in the variable  ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ",  and consider the  I. V. P. (initial value problem)",
  StyleBox[" \n\n\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y'\  = \ f \((t, y)\)\)]],
  StyleBox[" with ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((a)\) = \(t\_0 = \[Alpha]\)\)]],
  ",  over the interval  ",
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ". \n\t\t\nThe Adams-Bashforth-Moulton method uses the formulas ",
  Cell[BoxData[
      \(t\_\(k + 1\)\  = \ t\_k + h\)]],
  ",  and  \n\n",
  StyleBox["the predictor",
    FontFamily->"Times New Roman"],
  "  \t\t",
  Cell[BoxData[
      \(p\_\(k + 1\) = 
        y\_k + \(h\/24\) \((\ \(-\ 9\)\ f\_\(k - 3\) + 37\ f\_\(k - 2\) - 
                59  f\_\(k - 1\) + 55\ f\_k\ )\)\)]],
  ",  and\n\nthe corrector  \t \t",
  Cell[BoxData[
      \(y\_\(k + 1\) = 
        y\_k + h\/24\ \((\ 
              f\_\(k - 2\) - 5  f\_\(k - 1\) + 19  f\_k + 
                9  f[t\_\(k + 1\), p\_\(k + 1\)]\ )\)\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"k", "=", 
          StyleBox["3",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["4",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(m - 1\)}]]],
  "  \n\nas an approximate solution to the differential equation using the \
discrete set of points",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\((t\_k, y\_k)\)}\_\(k = 0\)\%m\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The Adams-Bashforth-Moulton method is not a self-starting method.  Three \
additional starting values ",
  Cell[BoxData[
      RowBox[{\(y\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(y\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["  ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(y\_3\)}]}]]],
  "  must be given.  They are usually computed using the Runge-Kutta method. \
"
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/AdamsBashforthProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/AdamsBashforthProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "    "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Precision of Adams-Bashforth-MoultonMethod)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Assume that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(\(\ \)\(y = y \((t)\)\)\)\)]],
  StyleBox["  is the solution to the I.V.P.  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y'\  = \ f \((t, y)\)\)]],
  StyleBox["  with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((t\_0)\) = y\_0\)]],
  StyleBox[".  If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(y \((t)\)\), "\[Element]", 
        RowBox[{
          SuperscriptBox[
            StyleBox["C",
              FontWeight->"Bold"], "5"], "[", \(t\_0, b\), "]"}]}]]],
  StyleBox["  and  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \({\((t\_k, y\_k)\)}\_\(k = 0\)\%m\)]],
  StyleBox["  is the sequence of approximations generated by ",
    FontFamily->"Times New Roman"],
  "Adams-Bashforth-Moulton method",
  StyleBox[", then at each step, the local truncation error ",
    FontFamily->"Times New Roman"],
  "is of the order  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic"], \((h\^5)\)}]]],
  ",  and the overall ",
  StyleBox["global truncation error  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(e\_k\)]],
  " ",
  StyleBox[" is of the order\n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(\(|\)\(e\_k\)\(|\)\), " ", "=", " ", 
        RowBox[{\(\(|\)\(y \((t\_k)\)\  - \ y\_k\)\(|\)\), " ", "=", " ", 
          RowBox[{
            StyleBox["O",
              FontWeight->"Bold",
              FontSlant->"Italic"], \((h\^4)\)}]}]}]]],
  ",  for  ",
  Cell[BoxData[
      RowBox[{\(k = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "m"}]]],
  ".  ",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["\n\n",
    FontFamily->"Times New Roman",
    FontSize->4],
  StyleBox["The error at the right end of the interval is called the final \
global error  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(E \((y \((b)\), h)\)\), " ", "=", " ", 
        RowBox[{\(\(|\)\(y \((b)\)\  - \ y\_m\)\(|\)\), " ", "=", " ", 
          RowBox[{
            StyleBox["O",
              FontWeight->"Bold",
              FontSlant->"Italic"], \((h\^4)\)}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/AdamsBashforthProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/AdamsBashforthProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "    "
}], "Text"],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
Adams1/Adams.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/Adams1/\
Adams.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Adams-Bashforth-Moulton Method",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[").",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  To approximate the solution of the initial value problem ",
  Cell[BoxData[
      \(y' = f \((t, y)\)\)]],
  " with ",
  Cell[BoxData[
      \(\(\(\ \)\(y \((a)\) = \(y\_0 = \[Alpha]\)\)\)\)]],
  "  over  ",
  Cell[BoxData[
      \(\([t\_0, b]\) = \([a, b]\)\)]],
  "  at a discrete set of points using the formulas:\n\n",
  StyleBox["use the predictor",
    FontFamily->"Times New Roman"],
  "  \t",
  Cell[BoxData[
      \(p\_\(k + 1\) = 
        y\_k + \(h\/24\) \((\ \(-\ 9\)\ f\_\(k - 3\) + 37\ f\_\(k - 2\) - 
                59  f\_\(k - 1\) + 55\ f\_k\ )\)\)]],
  "  \n\nand  the corrector   \t",
  Cell[BoxData[
      \(y\_\(k + 1\) = 
        y\_k + h\/24\ \((\ 
              f\_\(k - 2\) - 5  f\_\(k - 1\) + 19  f\_k + 
                9  f[t\_\(k + 1\), p\_\(k + 1\)]\ )\)\)]],
  "  for  ",
  Cell[BoxData[
      RowBox[{\(k = 3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["4",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["...",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(m - 1\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/AdamsBashforthProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/AdamsBashforthProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "    "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Adams-Bashforth-Moulton \
Method).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(ABM[a0_, b0_, \[Alpha]_, 
          m0_] := \[IndentingNewLine]Module[{a = a0, b = b0, F, j, k, m = m0, 
            p}, \[IndentingNewLine]h = \(b - a\)\/m; \ \[IndentingNewLine]T = 
            Table[a, {m + 1}]; \ \[IndentingNewLine]Y = 
            Table[\[Alpha], {m + 1}]; \ \[IndentingNewLine]For[\ j = 1, \ 
            j \[LessEqual] 3, \ \(j++\), \[IndentingNewLine]k\_1\  = \ 
              h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\), Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\)]; \ \
\[IndentingNewLine]k\_2\  = \ 
              h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h\/2, Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_1\/2]; \ \[IndentingNewLine]k\_3\  = \ 
              h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h\/2, Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_2\/2]; \ \[IndentingNewLine]k\_4\  = \ 
              h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h, Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_3]; \ \[IndentingNewLine]Y\_\(\(\[LeftDoubleBracket]\)\
\(j + 1\)\(\[RightDoubleBracket]\)\)\  = \ 
              Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + \
\(1\/6\) \((k\_1 + 2  k\_2 + 2  k\_3 + 
                      k\_4)\); \ \[IndentingNewLine]T\_\(\(\
\[LeftDoubleBracket]\)\(j + 1\)\(\[RightDoubleBracket]\)\)\  = \ 
              a + h\ \ j;\ ]; \ \[IndentingNewLine]F\_0 = 
            f[T\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), 
              Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]; \
\ \[IndentingNewLine]F\_1 = 
            f[T\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), 
              Y\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]; \
\ \[IndentingNewLine]F\_2 = 
            f[T\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\), 
              Y\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)]; \
\ \[IndentingNewLine]F\_3 = 
            f[T\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\), 
              
              Y\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)]; \
\ \[IndentingNewLine]For[\ j = 4, \ 
            j \[LessEqual] m, \ \(j++\)\ , \[IndentingNewLine]p = 
              Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + \
\(h\/24\) \((\(-9\) F\_0 + 37  F\_1 - 59  F\_2 + 
                      55  F\_3)\); \ \[IndentingNewLine]T\_\(\(\
\[LeftDoubleBracket]\)\(j + 1\)\(\[RightDoubleBracket]\)\) = 
              a + h\ \ j; \ \[IndentingNewLine]p = 
              Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + \
\(h\/24\) \((F\_1 - 5  F\_2 + 19  F\_3 + 
                      9  f[T\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\
\[RightDoubleBracket]\)\), 
                          p])\); \ \[IndentingNewLine]Y\_\(\(\
\[LeftDoubleBracket]\)\(j + 1\)\(\[RightDoubleBracket]\)\) = 
              p; \ \[IndentingNewLine]F\_0 = 
              F\_1; \ \[IndentingNewLine]F\_1 = 
              F\_2; \ \[IndentingNewLine]F\_2 = 
              F\_3; \ \[IndentingNewLine]F\_3 = 
              f[T\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\[RightDoubleBracket]\
\)\), Y\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\[RightDoubleBracket]\)\)];\ \ \
]; \ \[IndentingNewLine]Return[Transpose[{T, Y}]]\ ];\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", 
            RowBox[{"t", " ", "y", "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Compute the Adams-Bashforth-Moulton solution based on 25 \
subintervals and plot the results.\
\>", "Text"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 1\  - \ t\ \ y;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the D.E.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f[t, y]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 25;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = ABM[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Green, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Adams-Bashforth-Moulton solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the analytic solution and graph for the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", 
            RowBox[{"t", " ", "y", "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(de\  = \ \(y'\)[t] \[Equal] 
          1 - \ t\ \ y[t];\)\ \), "\[IndentingNewLine]", 
    \(\(ic\  = \ y[0] \[Equal] 1;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = DSolve[{de, ic}, y[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the differential equation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[ic];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \)}], "Input"],

Cell["\<\
Dig out the formula for the solution out of the data structure of  \
solset and put it in  f[t].
Plot the analytic solution at the same sample points that were used for the \
numerical approximations.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[t_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(pts3 = Transpose[{T, f[T]}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ListPlot[pts3, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The analytic solution is:\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<f[t] = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Just for fun, plot the Adams-Bashforth-Moulton solution and the \
analytic solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Adams-Bashforth-Moulton and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Plot the error for ",
  "Adams-Bashforth-Moulton",
  "'s method."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(pts4 = Transpose[{T, f[T] - Y1}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph4 = 
        ListPlot[pts4, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] \ Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Adams-Bashforth-Moulton's method using \>", 
        n, "\< subintervals,\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\ \)}], "Input"],

Cell[TextData[{
  "Since we have the analytic or \"true solution\" at hand, we can run \
experiments to verify that ",
  "Adams-Bashforth-Moulton",
  "'s method has order  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["O",
          FontWeight->"Bold"], \((h\^4)\)}]]],
  ".   Reduce the step size by  ",
  Cell[BoxData[
      \(1\/2\)]],
  " and see what happens to the error."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Reduce the step size by  ",
  Cell[BoxData[
      \(1\/2\)]],
  " and see what happens to the error.\nRecalculate points for \
Adams-Bashforth-Moulton's method, and the analytic solution using twice as \
many subintervals.\nThen Plot the error for ",
  "Adams-Bashforth-Moulton",
  "'s method."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(n = 50;\)\), "\[IndentingNewLine]", 
    \(\(ABM[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1 = Y;\)\ \)}], "Input"],

Cell["The error for Adams-Bashforth-Moulton's method.", "Text"],

Cell[BoxData[{
    \(\(pts6 = Transpose[{T, f[T] - Y1}];\)\), "\[IndentingNewLine]", 
    \(\(graph6 = 
        ListPlot[pts6, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Green];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Adams-Bashforth-Moulton's method using \>", 
        n, "\< subintervals,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\)}], "Input"],

Cell[TextData[{
  "Compare the error for ",
  "Adams-Bashforth-Moulton",
  "'s method with 25 and 50 subintervals. \n",
  StyleBox["Question 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " When the step size is reduced by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " estimate how much is the error reduced ?  (Theoretically is is ",
  Cell[BoxData[
      \(TraditionalForm\`1\/16\)]],
  ".)  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph4, graph6, 
        PlotRange \[Rule] All];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Adams-Bashforth-Moulton's method using \>", 
        n/2, "\< and \>", n, "\< subintervals.\>"];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve  ",
  Cell[BoxData[
      \(y' = \ 30 - 5  y\)]],
  "  with  ",
  Cell[BoxData[
      \(y \((0)\) = 1\)]],
  "  over  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] 5\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[t_, y_] = 30 - 5\ y\ ;\)\ \), "\n", 
    \(\(n = 50;\)\ \ \), "\[IndentingNewLine]", 
    \(\(pts1\  = ABM[0.0, 5.0, 1, n];\)\ \), "\n", 
    \(\(Y1\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, 5.2}, {0, 7.4}}, 
          PlotStyle \[Rule] Green];\)\ \), "\n", 
    \(\(Print["\<The Adams-Bashforth-Moulton solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input",
  AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the analytic solution and graph for the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", 
            RowBox[{"t", " ", "y", "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(de\  = \ \(y'\)[t] \[Equal] 
          30 - 5  y[t];\)\ \), "\[IndentingNewLine]", 
    \(\(ic\  = \ y[0] \[Equal] 1;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = DSolve[{de, ic}, y[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the differential equation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[ic];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[MapAll[Expand, solset]];\)\ \)}], "Input"],

Cell["\<\
Dig out the formula for the solution out of the data structure of  \
solset and put it in  f[t].
Plot the analytic solution at the same sample points that were used for the \
numerical approximations.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[t_] = 
        MapAll[Expand, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(pts3 = Transpose[{T, f[T]}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ListPlot[pts3, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 5.2}, {0, 
                7.4}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The analytic solution is:\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<f[t] = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Just for fun, plot the Adams-Bashforth-Moulton solution and the \
analytic solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Adams-Bashforth-Moulton and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Plot the absolute value of the error for ",
  "Adams-Bashforth-Moulton",
  "'s method."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(pts4 = Transpose[{T, f[T] - Y1}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph4 = 
        ListPlot[Abs[pts4], PlotJoined \[Rule] True, 
          PlotStyle \[Rule] \ Green, 
          PlotRange \[Rule] All];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Adams-Bashforth-Moulton's method using \>", 
        n, "\< subintervals,\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Reduce the step size by  ",
  Cell[BoxData[
      \(1\/2\)]],
  " and see what happens to the error.\nRecalculate points for \
Adams-Bashforth-Moulton's method, and the analytic solution using twice as \
many subintervals.\nThen Plot the error for ",
  "Adams-Bashforth-Moulton",
  "'s method."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(n = 100;\)\ \), "\[IndentingNewLine]", 
    \(\(ABM[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1 = Y;\)\ \)}], "Input"],

Cell["The error for Adams-Bashforth-Moulton's method.", "Text"],

Cell[BoxData[{
    \(\(pts6 = Transpose[{T, f[T] - Y1}];\)\), "\[IndentingNewLine]", 
    \(\(graph6 = 
        ListPlot[Abs[pts6], PlotJoined \[Rule] True, PlotStyle \[Rule] Green, 
          PlotRange \[Rule] All];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Adams-Bashforth-Moulton's method using \>", 
        n, "\< subintervals,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and the step size  h = \>", h];\)\)}], "Input"],

Cell[TextData[{
  "Compare the error for ",
  "Adams-Bashforth-Moulton",
  "'s method with 50 and 100 subintervals. \n",
  StyleBox["Question 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " When the step size is reduced by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " estimate how much is the error reduced ?  (Theoretically is is ",
  Cell[BoxData[
      \(TraditionalForm\`1\/16\)]],
  ".)  "
}], "Text"],

Cell[BoxData[{
    \(\(Show[graph4, graph6, 
        PlotRange \[Rule] All];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The error for Adams-Bashforth-Moulton's method using \>", 
        n/2, "\< and \>", n, "\< subintervals.\>"];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{\(t\^2\), " ", "+", 
            RowBox[{\(y\^2\), "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "1"}]}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Compute the Adams-Bashforth-Moulton solution based on 50 \
subintervals and plot the results.\
\>", "Text"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ t\^2\  + y\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the D.E.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f[t, y]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 50;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = ABM[0.0, 1.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Green, 
          PlotRange \[Rule] {{0, 1}, {0, 
                30}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Adams-Bashforth-Moulton solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell["\<\
Compute the Adams-Bashforth-Moulton solution based on 100 \
subintervals and plot the results.
Observe that one fewer subinterval is computed for this case.\
\>", "Text"],

Cell[BoxData[{
    \(\(n = 99;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = ABM[0.0, 0.99, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Green, 
          PlotRange \[Rule] {{0, 1}, {0, 
                30}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Adams-Bashforth-Moulton solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(\>", 
        T\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\), \
"\<) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell["\<\
Compute the Adams-Bashforth-Moulton solution based on 200 \
subintervals and plot the results.
Observe that four fewer subintervals are computed for this case.\
\>", "Text"],

Cell[BoxData[{
    \(\(n = 196;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = ABM[0.0, 0.98, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Y1\  = \ Y;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Green, 
          PlotRange \[Rule] {{0, 1}, {0, 
                30}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Adams-Bashforth-Moulton solution for  y' = \>", 
        f[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(\>", 
        T\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\), \
"\<) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find the analytic solution and graph for the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{\(t\^2\), " ", "+", 
            RowBox[{\(y\^2\), "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", "1"}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(de\  = \ \(y'\)[t] \[Equal] 
          t\^2 + \ y[t]\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(ic\  = \ y[0] \[Equal] 1;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = DSolve[{de, ic}, y[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(f[t_] = 
        MapAll[FullSimplify, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the differential equation\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[ic];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", f[t]\ ];\)\ \)}], "Input"],

Cell["\<\
Dig out the formula for the solution out of the data structure of  \
solset and put it in  f[t].
Plot the analytic solution at the same sample points that were used for the \
numerical approximations.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[t_] = 
        MapAll[FullSimplify, 
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        Plot[f[t], {t, 0, 0.969}, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0.001, 0.98}, {0, 
                30}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The analytic solution is:\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<f[t] = \>", f[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Just for fun, plot the Adams-Bashforth-Moulton solution and the \
analytic solution. Notice that there is a difference. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph3, 
        PlotRange \[Rule] {{0.001, 0.98}, {0, 
              100}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Adams-Bashforth-Moulton and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[graph1, graph3, 
        PlotRange \[Rule] {{0.001, 0.98}, {0, 
              1000}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Adams-Bashforth-Moulton and analytic solutions for  y' = \
\>", f[t, y]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Something strange is happening, it appears that the solution to  ",
  Cell[BoxData[
      \(y' = \ \(\(t\^2\)\(+\)\(\ \)\(y\^2\)\(\ \)\)\)]],
  "has a vertical asymptote, yet ",
  "Adams-Bashforth-Moulton",
  "'s method is able to move past this asymptote!  How can this happen?  If \
the step size is chosen smaller, then these methods will not tend to \
overshoot the asymptote. The location of the asymptote can be found using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s procedure FindRoot."
}], "Text"],

Cell[BoxData[
    \(FindRoot[
      16\ \((\(-32\)\ \[Pi]\ BesselJ[1\/4, 
                t\^2\/2] + \@2\ BesselJ[\(-\(1\/4\)\), 
                t\^2\/2]\ \((\(-4\)\ Gamma[\(-\(1\/4\)\)]\^2 + 
                  30\ Gamma[\(-\(5\/4\)\)]\ Gamma[3\/4])\))\), {t, 
        0.9}]\)], "Input"],

Cell["\<\
Numerical methods with a higher order of precision will not tend to \
overshoot the asymptote. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Various Scenarios",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" and Animations for the Adams-Bashforth-Moulton Method.",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the I.V.P.  ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", " ", 
        RowBox[{
          RowBox[{"1", "-", " ", 
            RowBox[{"t", " ", \(\@y\%3\), "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "   ", "y", \((0)\)}]}], " ", 
          "=", " ", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["over",
                FontFamily->"Times New Roman"], "  ", "0"}], "\[LessEqual]", 
            "t", "\[LessEqual]", "5"}]}]}]]],
  ".    Compute the Adams-Bashforth-Moulton solution to the I.V.P."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 50;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = ABM[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Adams-Bashforth-Moulton solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = ABM[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Adams-Bashforth-Moulton solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[t_, y_]\  = \ 
        1 - \ t\ Sign[y] \@\(Abs[y]\)\%3;\)\), "\[IndentingNewLine]", 
    \(\(f1[t_, y_]\  = \ 1 - \ t\ \@y\%3;\)\), "\[IndentingNewLine]", 
    \(\(n = 150;\)\ \), "\[IndentingNewLine]", 
    \(\(pts1\  = ABM[0.0, 5.0, 1.0, n];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(graph1\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] Magenta, 
          PlotRange \[Rule] {{0, 5}, {0, 
                1.55}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Adams-Bashforth-Moulton solution for  y' = \>", 
        f1[t, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using  n = \>", 
        n + 1, "\<  points.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[pts1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The final value is  y(5) = \>", y\_\(n + 1\), "\< = \>", 
        Y\_\(\(\[LeftDoubleBracket]\)\(n + 1\)\(\[RightDoubleBracket]\)\)];\)\
\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
Adams1/Adamsaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/Adams1/\
Adamsaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/a2001/Animations/OrdinaryDE/\
Adams1/Adams.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/OrdinaryDE/Adams1/\
Adams.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations."
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical/ab.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical/ab.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/AdamsBashforthBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Adams-Bashforth-Moulton Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/AdamsBashforthBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles. "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 198, 5, 35, "Text"],
Cell[1977, 60, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3456, 112, 3661, 104, 163, "Text"],
Cell[7120, 218, 3804, 115, 229, "Text"],
Cell[10927, 335, 1752, 51, 52, "Text"],
Cell[12682, 388, 661, 22, 33, "Text"],
Cell[13346, 412, 3782, 115, 184, "Text"],
Cell[17131, 529, 661, 22, 33, "Text"],
Cell[17795, 553, 784, 24, 33, "Text"],
Cell[18582, 579, 2887, 87, 134, "Text"],
Cell[21472, 668, 640, 20, 33, "Text"],
Cell[22115, 690, 162, 3, 33, "Text"],
Cell[22280, 695, 3543, 56, 620, "Input"],
Cell[25826, 753, 619, 19, 33, "Text"],

Cell[CellGroupData[{
Cell[26470, 776, 101, 2, 33, "Text"],
Cell[26574, 780, 117, 3, 33, "Text"],
Cell[26694, 785, 234, 4, 70, "Input"],
Cell[26931, 791, 924, 17, 210, "Input"]
}, Closed]],
Cell[27870, 811, 720, 22, 30, "Text"],

Cell[CellGroupData[{
Cell[28615, 837, 101, 2, 33, "Text"],
Cell[28719, 841, 559, 11, 170, "Input"],
Cell[29281, 854, 224, 5, 52, "Text"],
Cell[29508, 861, 598, 12, 150, "Input"],
Cell[30109, 875, 144, 3, 33, "Text"],
Cell[30256, 880, 190, 3, 50, "Input"]
}, Closed]],
Cell[30461, 886, 182, 7, 30, "Text"],

Cell[CellGroupData[{
Cell[30668, 897, 101, 2, 33, "Text"],
Cell[30772, 901, 433, 7, 90, "Input"],
Cell[31208, 910, 395, 13, 36, "Text"]
}, Closed]],
Cell[31618, 926, 411, 12, 71, "Text"],

Cell[CellGroupData[{
Cell[32054, 942, 101, 2, 33, "Text"],
Cell[32158, 946, 155, 3, 70, "Input"],
Cell[32316, 951, 63, 0, 33, "Text"],
Cell[32382, 953, 425, 7, 90, "Input"],
Cell[32810, 962, 438, 14, 55, "Text"],
Cell[33251, 978, 251, 4, 50, "Input"]
}, Closed]],
Cell[33517, 985, 359, 16, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[33901, 1005, 101, 2, 33, "Text"],
Cell[34005, 1009, 904, 18, 210, "Input"]
}, Closed]],
Cell[34924, 1030, 808, 26, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[35757, 1060, 101, 2, 33, "Text"],
Cell[35861, 1064, 572, 11, 170, "Input"],
Cell[36436, 1077, 224, 5, 52, "Text"],
Cell[36663, 1084, 626, 13, 150, "Input"],
Cell[37292, 1099, 144, 3, 33, "Text"],
Cell[37439, 1104, 190, 3, 50, "Input"]
}, Closed]],
Cell[37644, 1110, 204, 7, 30, "Text"],

Cell[CellGroupData[{
Cell[37873, 1121, 101, 2, 33, "Text"],
Cell[37977, 1125, 472, 8, 90, "Input"]
}, Closed]],
Cell[38464, 1136, 411, 12, 71, "Text"],

Cell[CellGroupData[{
Cell[38900, 1152, 101, 2, 33, "Text"],
Cell[39004, 1156, 158, 3, 70, "Input"],
Cell[39165, 1161, 63, 0, 33, "Text"],
Cell[39231, 1163, 453, 7, 90, "Input"],
Cell[39687, 1172, 439, 14, 55, "Text"],
Cell[40129, 1188, 253, 4, 50, "Input"]
}, Closed]],
Cell[40397, 1195, 624, 19, 30, "Text"],

Cell[CellGroupData[{
Cell[41046, 1218, 101, 2, 33, "Text"],
Cell[41150, 1222, 117, 3, 33, "Text"],
Cell[41270, 1227, 233, 4, 70, "Input"],
Cell[41506, 1233, 922, 17, 210, "Input"],
Cell[42431, 1252, 180, 4, 52, "Text"],
Cell[42614, 1258, 1008, 19, 210, "Input"],
Cell[43625, 1279, 183, 4, 52, "Text"],
Cell[43811, 1285, 1009, 19, 210, "Input"]
}, Closed]],
Cell[44835, 1307, 529, 17, 30, "Text"],

Cell[CellGroupData[{
Cell[45389, 1328, 102, 2, 33, "Text"],
Cell[45494, 1332, 740, 15, 190, "Input"],
Cell[46237, 1349, 224, 5, 52, "Text"],
Cell[46464, 1356, 554, 12, 130, "Input"],
Cell[47021, 1370, 144, 3, 33, "Text"],
Cell[47168, 1375, 259, 5, 50, "Input"],
Cell[47430, 1382, 260, 5, 50, "Input"],
Cell[47693, 1389, 542, 12, 52, "Text"],
Cell[48238, 1403, 288, 6, 45, "Input"],
Cell[48529, 1411, 119, 3, 33, "Text"]
}, Closed]],
Cell[48663, 1417, 320, 10, 32, "Text"],
Cell[48986, 1429, 692, 19, 33, "Text"],

Cell[CellGroupData[{
Cell[49703, 1452, 102, 2, 33, "Text"],
Cell[49808, 1456, 1037, 19, 238, "Input"],
Cell[50848, 1477, 1038, 19, 238, "Input"],
Cell[51889, 1498, 1038, 19, 238, "Input"],
Cell[52930, 1519, 791, 26, 33, "Text"]
}, Closed]],
Cell[53736, 1548, 784, 24, 30, "Text"],
Cell[54523, 1574, 724, 20, 33, "Text"],
Cell[55250, 1596, 158, 3, 35, "Text"],
Cell[55411, 1601, 594, 17, 33, "Text"],
Cell[56008, 1620, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

