(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51342,       1447]*)
(*NotebookOutlinePosition[     52036,       1471]*)
(*  CellTagsIndexPosition[     51992,       1467]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Module for ",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["the Lotka-Volterra Model",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["Math-Model (Lotka-Volterra Equations)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The \"",
  ButtonBox["Lotka-Volterra equations",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Lotka-VolterraEquations.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  "\" refer to two coupled differential equations \n\n\t\t",
  Cell[BoxData[
      \(dx\/dt\  = \ \ k\_1\ x\  - \ k\_2\ x\ y\)]],
  "  \n\t\n\t\t",
  Cell[BoxData[
      \(dy\/dt\  = \ \(-\ k\_3\)\ y\  + k\_4\ x\ y\)]],
  "\n\nThere is one critical point which occurs when ",
  Cell[BoxData[
      RowBox[{\(dx\/dt\), "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(dy\/dt\)}], "=", "0"}]}]]],
  " and it is ",
  Cell[BoxData[
      \(\((x\_0, y\_0)\) = \((k\_3\/k\_4, k\_1\/k\_2)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " ",
  StyleBox[ButtonBox["Lotka-Volterra Model",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Lotka-VolterraProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lotka-Volterra Model",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/Lotka-VolterraProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  "The Runge-Kutta method is used to numerically solve O.D.E.'s over",
  StyleBox[" an interval  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(a \[LessEqual] t \[LessEqual] b\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " ",
  StyleBox[ButtonBox["Lotka-Volterra Model",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Lotka-VolterraProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Lotka-Volterra Model",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Lotka-VolterraProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(Runge-Kutta Method)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To compute a numerical approximation for the solution of the \
initial value problem  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y'\  = \ f \((t, y)\)\)]],
  " ",
  StyleBox[" with ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((a)\) = \[Alpha]\)]],
  "  over the interval",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["  ",
          FontFamily->"Times New Roman"], \(a \[LessEqual] t \[LessEqual] 
          b\)}]]],
  "  at a discrete set of points using the formula  \n\n\t",
  Cell[BoxData[
      \(y\_\(j + 1\)\  = \ 
        y\_j + \(1\/6\) \((k\_1 + 2  k\_2 + 2  k\_3 + k\_4)\)\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      RowBox[{\(k\_1\), "=", 
        RowBox[{"h", " ", "f", 
          RowBox[{"(", 
            RowBox[{\(t\_j\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y\_j\)}], ")"}]}]}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{\(k\_2\), "=", 
        RowBox[{"h", " ", "f", 
          RowBox[{"(", 
            RowBox[{\(t\_j + h\/2\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y\_j + k\_1\/2\)}], ")"}]}]}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{\(k\_3\), "=", 
        RowBox[{"h", " ", "f", 
          RowBox[{"(", 
            RowBox[{\(t\_j + h\/2\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y\_j + k\_2\/2\)}], ")"}]}]}]]],
  ", and  ",
  Cell[BoxData[
      RowBox[{\(k\_4\), "=", 
        RowBox[{"h", " ", "f", 
          RowBox[{"(", 
            RowBox[{\(t\_j + h\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(y\_j + k\_3\)}], ")"}]}]}]]],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(\(Runge[a0_, b0_, \[Alpha]_, 
        m0_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{a = a0, b = b0, j, k, 
          m = m0}, \[IndentingNewLine]h = \(b - a\)\/m; \ \
\[IndentingNewLine]Y\  = \ \(T\  = \ 
            Table[0, {m + 
                  1}]\); \ \
\[IndentingNewLine]T\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)\  = \ a; \ \[IndentingNewLine]Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\  = \ \[Alpha]; \ \[IndentingNewLine]For[\ j = 1, \ 
          j \[LessEqual] m, \ \(j++\), \[IndentingNewLine]k\_1\  = \ 
            h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\), Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\)]; \ \
\[IndentingNewLine]k\_2\  = \ 
            h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\) + h\/2, Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                  k\_1\/2]; \ \[IndentingNewLine]k\_3\  = \ 
            h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\) + h\/2, Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                  k\_2\/2]; \ \[IndentingNewLine]k\_4\  = \ 
            h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\) + h, Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                  k\_3]; \ \
\[IndentingNewLine]Y\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\
\[RightDoubleBracket]\)\)\  = \ 
            Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + \
\(1\/6\) \((k\_1 + 2  k\_2 + 2  k\_3 + 
                    k\_4)\); \ \[IndentingNewLine]T\_\(\(\[LeftDoubleBracket]\
\)\(j + 1\)\(\[RightDoubleBracket]\)\)\  = \ 
            a + h\ \ j;\ ]; \ \[IndentingNewLine]Return[
          Transpose[{T, Y}]]\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Solve the I.V.P.   ",
  Cell[BoxData[
      RowBox[{\(y'\), "=", 
        RowBox[{
          RowBox[{\(t\^2\), "-", 
            RowBox[{"y", "  ", 
              StyleBox["with",
                FontFamily->"Times New Roman"], "  ", "y", \((0)\)}]}], "=", 
          "1"}]}]]],
  "  over  ",
  Cell[BoxData[
      \(\([0, \ 10]\)\)]],
  ".",
  StyleBox["  ",
    FontWeight->"Bold"],
  "Use the Runge-Kutta method."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[t_, y_] = 1 - t\ \ y;\)\ \ \), "\[IndentingNewLine]", 
    \(\(points\  = \ 
        Runge[0.0, \ 10.0, \ 0.0, \ \ 50];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(gr10 = 
        ListPlot[points, PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, 10}, {0, 0.8}}, 
          PlotStyle \[Rule] Magenta];\)\ \ \), "\n", 
    \(\(Print["\<y' = \>", f[t, y]];\)\ \ \), "\n", 
    \(\(Print[{T\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\),\
 Y\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\)}];\)\ \ \)}], \
"Input"],

Cell[TextData[{
  StyleBox["Remember.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The Runge-Kutta solution is nothing more than a discrete set of points \
that we use to approximate the solution to the D. E.. "
}], "Text"],

Cell[BoxData[
    \(\(\(Print[
        TableForm[points, 
          TableHeadings \[Rule] {None, {\*"\"\<\!\(t\_j\)\>\"", \
\*"\"\<\!\(y\_j\)\>\""}}]];\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extension to 2D.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The Runge-Kutta method is easily extended to solve a system of D.E.'s ",
  StyleBox["over the interval  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(a\  \[LessEqual] \ t\  \[LessEqual] \ b\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(Runge-Kutta Method in 2D space)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To compute a numerical approximation for the solution of the \
initial value problem  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x'\  = \ \(f\_1\) \((t, x, y)\)\)]],
  StyleBox["  with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x \((a)\) = \[Alpha]\)]],
  ",  ",
  StyleBox["\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y'\  = \ \(f\_2\) \((t, x, y)\)\)]],
  StyleBox["  with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((a)\) = \[Beta]\)]],
  StyleBox[",  \n\nover the interval  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(a\  \[LessEqual] \ t\  \[LessEqual] \ b\)]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "at a discrete set of points. "
}], "Text"],

Cell[BoxData[
    \(\(\(Runge2D[a0_, b0_, \[Alpha]_, \[Beta]_, 
        m0_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{a = a0, b = b0, j, k, 
          m = m0}, \[IndentingNewLine]h = \(b - a\)\/m; \ \
\[IndentingNewLine]T\  = \ 
          Table[\ a + \((j - 1)\) h, {j, 1, 
              m + 1}]; \ \[IndentingNewLine]Z = \ 
          Table[\ {\[Alpha], \[Beta]}, {j, 1, 
              m + 1}]; \ \ \[IndentingNewLine]For[\ j = 1, \ 
          j \[LessEqual] m, \ \(j++\), \[IndentingNewLine]k\_1\  = \ 
            h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\), Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\)]; \ \
\[IndentingNewLine]k\_2\  = \ 
            h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\) + h\/2, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                  k\_1\/2]; \ \[IndentingNewLine]k\_3\  = \ 
            h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\) + h\/2, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                  k\_2\/2]; \ \[IndentingNewLine]k\_4\  = \ 
            h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\) + h, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                  k\_3]; \ \
\[IndentingNewLine]Z\_\(\(\[LeftDoubleBracket]\)\(j + 1\)\(\
\[RightDoubleBracket]\)\)\  = \ 
            Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + \
\(1\/6\) \((k\_1 + 2  k\_2 + 2  k\_3 + 
                    k\_4)\);\ \ ]; \ \[IndentingNewLine]Return[
          Z];\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The Runge-Kutta method in 2D is a \"vector form\" of the one-dimensional \
method, here the function ",
  StyleBox["f",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " is replaced with ",
  StyleBox["F",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Lotka-Volterra Model.  Solve the I.V.P.  \n\n\t",
  Cell[BoxData[
      \(x'\  = \ \ x - x\ y\)]],
  "  ",
  StyleBox["with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x \((0)\) = 2\)]],
  ",  \nand\n\t",
  Cell[BoxData[
      \(y' = \(-y\) + x\ y\)]],
  "  ",
  StyleBox["with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((0)\) = 1\)]],
  ".  ",
  StyleBox["  \n\nUse several intervals  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(a\  \[LessEqual] \ t\  \[LessEqual] \ b\)]],
  StyleBox[". \n\n",
    FontFamily->"Times New Roman"],
  StyleBox["2 (a).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the interval ",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(0\  \[LessEqual] \ t\  \[LessEqual] \ 3.3\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["2 (b).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the interval ",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(-3.3\)\  \[LessEqual] \ t\  \[LessEqual] \ 0\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  "\n",
  StyleBox["2 (c).",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the interval ",
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(0\  \[LessEqual] \ t\  \[LessEqual] \ 6.6\)]],
  StyleBox[". \n\nCan you discover if the solution form an \"orbit.\" ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the functions  ",
  Cell[BoxData[
      \(f\_1[t, x, y]\)]],
  "  and  ",
  Cell[BoxData[
      \(f\_2[t, x, y]\)]],
  "  and form the vector function  ",
  Cell[BoxData[
      \(F[t, {x, y}]\  = \ {f\_1[t, x, y], f\_2[t, x, y]\ }\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(k\_1 = 1;\)\), "\[IndentingNewLine]", 
    \(\(k\_2 = 1;\)\), "\[IndentingNewLine]", 
    \(\(k\_3 = 1;\)\), "\[IndentingNewLine]", 
    \(\(k\_4 = 1;\)\), "\[IndentingNewLine]", 
    \(\(f\_1[t_, x_, 
          y_] = \ \(k\_1\) x\  - \ \(k\_2\) 
            x\ y;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_2[t_, x_, 
          y_] = \(-\ k\_3\) y\  + \ \(k\_4\) 
            x\ y;\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[t_, {x_, y_}]\  = \ {f\_1[t, x, y], 
          f\_2[t, x, y]\ };\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the system of D.E.'s\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<x' = \>", f\_1[t, x, y]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f\_2[t, x, y]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[t,{x,y}] = \>", F[t, {x, y}]\ ];\)\ \ \)}], "Input"],

Cell["Compute the Runge-Kutta solution.", "Text"],

Cell[BoxData[{
    \(\(x\_0\  = \ 2.0;\)\ \), "\[IndentingNewLine]", 
    \(\(y\_0\  = \ 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 3.3;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 50;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(pts1\  = Runge2D[a, b, x\_0, y\_0, n];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(graph1 = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
          Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
          AspectRatio \[Rule] 1];\)\ \ \), "\n", 
    \(\(Print["\<The Runge-Kutta solution for\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[{x', y'}], "\< = \>", 
        MatrixForm[F[t, {x, y}]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[
        MatrixForm[{\*"\"\<\!\(x\_0\)\>\"", \*"\"\<\!\(y\_0\)\>\""}], "\< = \
\>", MatrixForm[{x\_0, y\_0}]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Over the interval [a,b] = [\>", a, "\< , \>", 
        b, "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<When t = \>", 
        T\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\), \ "\< \
 we have arrived at the point \>", 
        MatrixForm[{\*"\"\<\!\(x\_n\)\>\"", \*"\"\<\!\(y\_n\)\>\""}], "\< = \
\>", MatrixForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\)]\ ];\
\)\), "\[IndentingNewLine]", 
    \(\(time1 = 
        T\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(end1 = 
        Z\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\);\)\ \
\)}], "Input"],

Cell[BoxData[{
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = \(-3.3\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 50;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(pts1\  = Runge2D[a, b, 2.0, 1.0, n];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(graph2\  = \ 
        ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Blue, 
          PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
          Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
          AspectRatio \[Rule] 1];\)\ \ \), "\n", 
    \(\(Print["\<The Runge-Kutta solution for\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[{x', y'}], "\< = \>", 
        MatrixForm[F[t, {x, y}]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[
        MatrixForm[{\*"\"\<\!\(x\_0\)\>\"", \*"\"\<\!\(y\_0\)\>\""}], "\< = \
\>", MatrixForm[{x\_0, y\_0}]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Over the interval [a,b] = [\>", a, "\< , \>", 
        b, "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<When t = \>", 
        T\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\), \ "\< \
 we have arrived at the point \>", 
        MatrixForm[{\*"\"\<\!\(x\_n\)\>\"", \*"\"\<\!\(y\_n\)\>\""}], "\< = \
\>", MatrixForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\)]\ ];\
\)\), "\[IndentingNewLine]", 
    \(\(time2 = 
        T\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(end2 = 
        Z\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\);\)\ \
\)}], "Input"],

Cell[BoxData[{
    \(\(Show[graph1, graph2, PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
        AspectRatio \[Rule] 1];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution for\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[{x', y'}], "\< = \>", 
        MatrixForm[F[t, {x, y}]]\ ];\)\ \ \)}], "Input"],

Cell["Do the two curves join up?", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph2, PlotRange \[Rule] {{0.4, 0.5}, {0.6, 0.8}}, 
        Ticks \[Rule] Automatic];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution for\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[{x', y'}], "\< = \>", 
        MatrixForm[F[t, {x, y}]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<When t = \>", time1, \ "\<  we arrived at the point \>", 
        MatrixForm[{\*"\"\<\!\(x\_n\)\>\"", \*"\"\<\!\(y\_n\)\>\""}], "\< = \
\>", MatrixForm[end1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<When t = \>", time2, \ "\<  we arrived at the point \>", 
        MatrixForm[{\*"\"\<\!\(x\_n\)\>\"", \*"\"\<\!\(y\_n\)\>\""}], "\< = \
\>", MatrixForm[end2]\ ];\)\)}], "Input"],

Cell["\<\
The \"true solution\" is known to be a closed curve, and there is \
no known analytic formulas for the solution curve.  \
\>", "Text"],

Cell[BoxData[{
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 6.6;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(pts3 = Runge2D[a, b, 2.0, 1.0, n];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(graph3 = 
        ListPlot[pts3, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
          Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
          AspectRatio \[Rule] 1];\)\ \ \), "\n", 
    \(\(Print[MatrixForm[{x', y'}], "\< = \>", 
        MatrixForm[F[t, {x, y}]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[
        MatrixForm[{\*"\"\<\!\(x\_0\)\>\"", \*"\"\<\!\(y\_0\)\>\""}], "\< = \
\>", MatrixForm[{x\_0, y\_0}]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Over the interval [a,b] = [\>", a, "\< , \>", 
        b, "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<When t = \>", 
        T\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\), \ "\< \
 we have arrived at the point \>", 
        MatrixForm[{\*"\"\<\!\(x\_n\)\>\"", \*"\"\<\!\(y\_n\)\>\""}], "\< = \
\>", MatrixForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\)]\ ];\
\)\)}], "Input"],

Cell["More subintervals will produce better results.  ", "Text"],

Cell[BoxData[{
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 6.6084827203;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 200;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(pts3 = Runge2D[a, b, 2.0, 1.0, n];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(graph4 = 
        ListPlot[pts3, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
          PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
          Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
          AspectRatio \[Rule] 1];\)\ \ \), "\n", 
    \(\(Print["\<The Runge-Kutta solution for\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[{x', y'}], "\< = \>", 
        MatrixForm[F[t, {x, y}]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[
        MatrixForm[{\*"\"\<\!\(x\_0\)\>\"", \*"\"\<\!\(y\_0\)\>\""}], "\< = \
\>", MatrixForm[{x\_0, y\_0}]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Over the interval [a,b] = [\>", a, "\< , \>", 
        b, "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<When t = \>", 
        T\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\), \ "\< \
 we have arrived at the point \>", 
        MatrixForm[{\*"\"\<\!\(x\_n\)\>\"", \*"\"\<\!\(y\_n\)\>\""}], "\< = \
\>", MatrixForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\)]\ ];\
\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  \n\nLet us investigate the critical point of the D. E."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(a = 0.0;\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(b = 6.6;\), "  "}], "\[IndentingNewLine]", 
    RowBox[{\(n = 50;\), "   "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), 
      "  "}], "\[IndentingNewLine]", \(dots = 
        Graphics[{Red, PointSize[0.02], 
            Point[{k\_3\/k\_4, k\_1\/k\_2}]}];\), "\n", 
    RowBox[{\(pts1\  = Runge2D[a, b, 2.0, 1.0, n];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(gr1 = \ 
          ListPlot[pts1, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Cyan, 
            DisplayFunction \[Rule] Identity];\), "  "}], "\n", 
    RowBox[{\(pts2\  = Runge2D[a, b, 1.8, 1.0, n];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(gr2 = \ 
          ListPlot[pts2, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Red, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(pts3\  = Runge2D[a, b, 1.6, 1.0, n];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(gr3 = \ 
          ListPlot[pts3, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Blue, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(pts4\  = Runge2D[a, b, 1.4, 1.0, n];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(gr4 = \ 
          ListPlot[pts4, PlotJoined \[Rule] True, 
            PlotStyle \[Rule] \ Magenta, DisplayFunction \[Rule] Identity];\),
       "  "}], "\[IndentingNewLine]", 
    RowBox[{\(pts5\  = Runge2D[a, b, 1.2, 1.0, n];\), 
      "  "}], "\[IndentingNewLine]", 
    RowBox[{\(gr5 = \ 
          ListPlot[pts5, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Green, 
            DisplayFunction \[Rule] Identity];\), 
      "  "}], "\[IndentingNewLine]", \(Show[gr1, gr2, gr3, gr4, gr5, dots, 
        PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\), "\[IndentingNewLine]", \
\(Print[\*"\"\<\!\(k\_1\) = \>\"", 
        k\_1, "\<,   \>", \*"\"\<\!\(k\_2\) = \>\"", 
        k\_2, "\<,   \>", \ \ \ \ \*"\"\<\!\(k\_3\) = \>\"", 
        k\_3, "\<,   \>", \*"\"\<\!\(k\_4\) = \>\"", 
        k\_4];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{\(MatrixForm[{x', y'}]\), ",", "\"\< = (\!\(\*GridBox[{
{\(\(\\\ \\\ \\\ \)\(k\_1\\\ x\\\  - \\\ k\_2\\\ x\\\ y\)\)},
{\(\(-\\\ k\_3\) y\\\  + k\_4\\\ x\\\ y\)}
}]\)) = \>\"", ",", \(MatrixForm[F[t, {x, y}]]\)}], " ", "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", \(Print[\*"\"\<The critical point is (\!\
\(x\_0\),\!\(y\_0\)) = (\!\(k\_3\/k\_4\),\!\(k\_1\/k\_2\)) = (\>\"", 
        k\_3\/k\_4, "\< , \>", k\_1\/k\_2, "\<)\>"];\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Lotka-Volterra Model.  Solve the I.V.P.  \n\n\t",
  Cell[BoxData[
      \(x'\  = \ \ x - x\ y\)]],
  "  ",
  StyleBox["with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x \((0)\) = 2\)]],
  ",  \nand\n\t",
  Cell[BoxData[
      \(y' = \(-y\) + x\ y\)]],
  "  ",
  StyleBox["with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((0)\) = 1\)]],
  ".  ",
  StyleBox["  \n\nCombine the system of D. E.'s to form a separable \
first-order differential equation and solve the D. E..",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Write down the two equations.", "Text"],

Cell[BoxData[{
    \(eqn1\  = \ 
      x'\  \[Equal] \ \ \ x\  - \ \(\(x\)\(\ \)\(y\)\(\ \ \)\)\), "\n", 
    \(eqn2\  = \ 
      y'\  \[Equal] \(-y\)\ \  + \ \(\(x\)\(\ \)\(y\)\(\ \)\)\)}], "Input"],

Cell["Use the Leibniz notation for the derivative.", "Text"],

Cell[BoxData[{
    \(eqn1\  = \ 
      dx\/dt\ \  \[Equal] \ \ \ x\  - \ \(\(x\)\(\ \)\(y\)\(\ \ \)\)\), "\n", \

    \(eqn2\  = \ 
      dy\/dt\ \  \[Equal] \ \(-y\)\  + \ \(\(x\)\(\ \)\(y\)\(\ \ \)\)\)}], \
"Input"],

Cell[TextData[{
  "Divide the left sides and divide the right sides using the idea that ",
  Cell[BoxData[
      \(\(dy\/dt\)/\(dx\/dt\) \[Equal] dy\/dx\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(eqn2\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\/\
eqn1\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)\(\[Equal]\)\
\(Factor[eqn2\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\/\
Factor[eqn1\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)]\)\(\ \
\)\)\)], "Input"],

Cell["Separate the variables. ", "Text"],

Cell[BoxData[
    \(\(\(\t\)\(\(\(\(\ \)\((1 - y)\)\)\/\(\(\ \)\(y\)\)\) 
        dy\  \[Equal] \ \(\(\(\((x - 
                1)\)\(\ \)\)\/\(\(x\)\(\ \)\)\) \(dx\)\(\ \ \)\)\)\)\)], \
"Text"],

Cell[TextData[{
  "Integrate both sides and supply a constant of integration in the form  ",
  StyleBox["Log[c]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[
    \(eqn3\  = \ \[Integral]\(\(\(\ \)\((1 - 
                    y)\)\)\/\(\(\ \)\(y\)\)\) \[DifferentialD]y\  \[Equal] \ \
\ \(\(\[Integral]\(\(\((x - 
                      1)\)\(\ \)\)\/\(\(x\)\(\ \)\)\) \[DifferentialD]x\)\(\ \
\)\(+\)\(\ \)\(Log[c]\)\(\ \)\)\)], "Input"],

Cell["Simplify the form of the solution. ", "Text"],

Cell[BoxData[
    \(\(\(eqn4\)\(\ \)\(=\)\(\ \)\(Thread[eqn3 - x + Log[x], 
        Equal]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(eqn5\)\(=\)\(Thread[\[ExponentialE]\^eqn4, 
        Equal]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(eqn6\)\(=\)\(FullSimplify[eqn5]\)\(\ \)\)\)], "Input"],

Cell["\<\
Solve for the constant  c  using the fact that the curve goes \
through the initial point  (2,1).\
\>", "Text"],

Cell[BoxData[
    \(\(\(eqn7\)\(=\)\(ReplaceAll[
        eqn6, {x \[Rule] 2, y \[Rule] 1}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(solset\)\(=\)\(Solve[eqn7, c]\)\(\ \)\)\)], "Input"],

Cell["\<\
Replace the constant and form the implicit equation for the \
solution curve. \
\>", "Text"],

Cell[BoxData[
    \(\(\(eqn\)\(=\)\(ReplaceAll[eqn6, 
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)]\)\
\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Graph the curve using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s the graphics package ",
  StyleBox["ImplicitPlot",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ImplicitPlot`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph5 = 
        ImplicitPlot[eqn, {x, 0, 2}, {y, 0, 2}, 
          PlotStyle \[Rule] Blue];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solution to the system of D.E.'s\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The implicit solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For the  I.V.P.  \n\n\t",
  Cell[BoxData[
      \(x'\  = \ \ x - x\ y\)]],
  "   ",
  StyleBox["with   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x \((0)\) = 2\)]],
  ",  \nand\n\t",
  Cell[BoxData[
      \(y' = \(-y\) + x\ y\)]],
  "   ",
  StyleBox["with   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((0)\) = 1\)]],
  ".  ",
  StyleBox["  \n\nShow that the numerical solution in Example 3 and the \
analytic solution in Example 4 are in agreement. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Show[GraphicsArray[{graph4, graph5}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solution to the system of D.E.'s\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn2];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[graph4, graph5];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solution to the system of D.E.'s\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn2];\)\ \)}], "Input"],

Cell[TextData[{
  "Or we could plot several curves for the implicit solution  ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(-x\) - y\)\ x\ y\  = \ c\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(ContourPlot[\[ExponentialE]\^\(\(-x\) - y\)\ x\ y, {x, 0, 2}, {y, 0, 
          2}, ColorFunction \[Rule] Hue];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solution to the system of D.E.'s\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The implicit solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[ExponentialE]\^\(\(-x\) - y\)\ x\ y \[Equal] 
          c];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For the  I.V.P.  \n\n\t",
  Cell[BoxData[
      \(x'\  = \ \ x - x\ y\)]],
  "   ",
  StyleBox["with   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x \((0)\) = 2\)]],
  ",  \nand\n\t",
  Cell[BoxData[
      \(y' = \(-y\) + x\ y\)]],
  "   ",
  StyleBox["with   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((0)\) = 1\)]],
  ".  ",
  StyleBox["  \n\nThe implicit solution is  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(-x\) - y\)\ x\ y == 2\/\[ExponentialE]\^3\)]],
  ".\nDetermine if y can be solved as a function of x. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(solset\  = \ 
      Solve[\[ExponentialE]\^\(\(-x\) - y\)\ x\ y\  \[Equal] \ 
          2\/\[ExponentialE]\^3, y]\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[x_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(graph6\  = \ 
        Plot[f[x], {x, 0.40638, 2}, \ 
          PlotStyle \[Rule] {Thickness[ .01], Red}, 
          PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
          Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
          AspectRatio \[Rule] 1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The explicit solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[graph5, graph6, PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
        AspectRatio \[Rule] 1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The implicit solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The explicit solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell["\<\
Unfortunately, only the lower half of the curve can be solved \
explicitly. 

If x is solved in terms of y, then a curve for the left half can be obtained. \
\
\>", "Text"],

Cell[BoxData[{
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(solset\  = \ 
      Solve[\[ExponentialE]\^\(\(-x\) - y\)\ x\ y\  \[Equal] \ 
          2\/\[ExponentialE]\^3, x]\)}], "Input"],

Cell[BoxData[{
    \(\(g[y_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x = g[y] = \>", g[y]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(graph7\  = \ 
        ParametricPlot[{g[y], y}, {y, 0.40638, 2}, \ 
          PlotStyle \[Rule] {Thickness[ .01], Green}, 
          PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
          Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
          AspectRatio \[Rule] 1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The explicit solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x = g[y] = \>", g[y]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Show[graph5, graph7, PlotRange \[Rule] {{0, 2.0}, {0, 2.0}}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 2, 0.5]}, 
        AspectRatio \[Rule] 1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The implicit solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The explicit solution is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x = g[y] = \>", g[y]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Predator-Prey Model",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe study of population dynamics of competing species is attributed \
two two independently published works by ",
  StyleBox[ButtonBox["Alfred James Lotka",
    ButtonData:>{
      URL[ "http://www.libsci.sc.edu/bob/ISP/lotka.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  " (1880 - 1949) and ",
  StyleBox[ButtonBox["Vito Volterra",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Volterra.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 1]],
  " (1860-1940).\n\nConsider two two species, the predator is population is \
",
  StyleBox["y(t)",
    FontFamily->"Courier New"],
  " (foxes), and the prey population is  ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  " (rabbits).  It is assumed that the prey, ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  ", has adequate food and ",
  Cell[BoxData[
      \(c\_1\)]],
  ", ",
  Cell[BoxData[
      \(c\_2\)]],
  " are the birth rate and death rates, respectively.  An additional term,  \
",
  Cell[BoxData[
      \(k\_2\ y\ x\)]],
  ",  contributing to the decrease of prey is due to successful hunting of \
the predators.  Combining these 3 quantities, we obtain the rate of change of \
 \n\n\t\t",
  Cell[BoxData[
      \(dx\/dt\  = \ \ \(c\_1\ x\  - \ \ c\_2\ x\  - 
            k\_2\ y\ x\ \  = \ \((c\_1 - \ \ c\_2\ )\) x - k\_2\ y\ x\)\)]],
  ".  \n\nThe substitution  ",
  Cell[BoxData[
      \(k\_1\  = \ c\_1 - \ c\_2\)]],
  ", will help simplify this result, and we obtain  \n\n\t\t",
  Cell[BoxData[
      \(dx\/dt\  = \ \ k\_1\ x\  - \ k\_2\ x\ y\)]],
  ".\n\nThe birth rate for the predator is proportional to its food supply, \
x(t),  i.e.the birth rate (predators) is  ",
  Cell[BoxData[
      \(k\_4\ x\)]],
  ",  and the death rate of the predators is ",
  Cell[BoxData[
      \(k\_3\)]],
  ", and we obtain  \n\n\t\t",
  Cell[BoxData[
      \(dy\/dt\  = \ \(-\ k\_3\)\ y\  + k\_4\ x\ y\)]],
  ".\n\nThese two equations are an application of the Lotka-Volterra \
equations. "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Assume that the initial number of foxes and rabbits are  ",
  Cell[BoxData[
      \(y\_0\  = \ 100\)]],
  " and  ",
  Cell[BoxData[
      \(x\_0\  = \ 5000\)]],
  ", respectively,  and that the coefficients  ",
  Cell[BoxData[
      RowBox[{\(k\_1 = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(k\_2 = 0.01\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(k\_3 = 0.8\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[
              RowBox[{
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], " "}]], \(k\_4\)}], "=", 
          "0.0002"}]}]]],
  ",  are used to form the system of D. E.'s \n\n\t\t",
  Cell[BoxData[
      \(dx\/dt\  = \ \ \ \(k\_1\ x\  - \ k\_2\ x\ y\  = 
          2\ x\  - \ 0.01\ x\ y\)\)]],
  "  \n\t\n\t\t",
  Cell[BoxData[
      \(dy\/dt\  = \(\(-\ k\_3\)\ y\  + 
            k\_4\ x\ y\  = \ \(-\ 
                0.8\)\ y\  + \ \(\(0.0002\)\(\ \)\(x\)\(\ \)\(y\)\(\ \
\)\)\)\)]],
  "\n\n",
  StyleBox["Solve the system of D. E.'s for ",
    FontFamily->"Times New Roman"],
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  StyleBox["and ",
    FontFamily->"Times New Roman"],
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  StyleBox[" over the interval  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(0.0 \[LessEqual] t \[LessEqual] 5.0\)]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the functions  ",
  Cell[BoxData[
      \(f\_1[t, x, y]\)]],
  "  and  ",
  Cell[BoxData[
      \(f\_2[t, x, y]\)]],
  "  and form the vector function  ",
  Cell[BoxData[
      \(F[t, {x, y}]\  = \ {f\_1[t, x, y], f\_2[t, x, y]\ }\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(k\_1 = 2;\)\), "\[IndentingNewLine]", 
    \(\(k\_2 = 0.01;\)\), "\[IndentingNewLine]", 
    \(\(k\_3 = 0.8;\)\), "\[IndentingNewLine]", 
    \(\(k\_4 = 0.0002;\)\), "\[IndentingNewLine]", 
    \(\(f\_1[t_, x_, 
          y_] = \ \(k\_1\) x\  - \ \(k\_2\) 
            x\ y;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_2[t_, x_, 
          y_] = \(-\ k\_3\) y\  + \ \(k\_4\) 
            x\ y;\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[t_, {x_, y_}]\  = \ {f\_1[t, x, y], 
          f\_2[t, x, y]\ };\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the system of D.E.'s\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<x' = \>", f\_1[t, x, y]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f\_2[t, x, y]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[t,{x,y}] = \>", F[t, {x, y}]\ ];\)\ \ \)}], "Input"],

Cell["Compute the Runge-Kutta solution.", "Text"],

Cell[BoxData[{
    \(\(x\_0\  = \ 5000;\)\ \), "\[IndentingNewLine]", 
    \(\(y\_0\  = \ 100;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 5.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 200;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Z\  = Runge2D[a, b, x\_0, y\_0, n];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(ListPlot[Z, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
        PlotRange \[Rule] {{0, 10000}, {0, 360}}, Ticks \[Rule] Automatic, 
        AspectRatio \[Rule] 1];\)\ \ \), "\n", 
    \(\(Print["\<The Runge-Kutta solution for\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[{x', y'}], "\< = \>", 
        MatrixForm[F[t, {x, y}]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[
        MatrixForm[{\*"\"\<\!\(x\_0\)\>\"", \*"\"\<\!\(y\_0\)\>\""}], "\< = \
\>", MatrixForm[{x\_0, y\_0}]\ ];\)\ \ \)}], "Input"],

Cell[BoxData[{\(Print[\*"\"\<\!\(k\_1\) = \>\"", 
        k\_1, "\<,   \>", \*"\"\<\!\(k\_2\) = \>\"", 
        k\_2, "\<,   \>", \ \ \ \ \*"\"\<\!\(k\_3\) = \>\"", 
        k\_3, "\<,   \>", \*"\"\<\!\(k\_4\) = \>\"", 
        k\_4];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"Print", "[", 
          RowBox[{\(MatrixForm[{x', y'}]\), ",", "\"\< = (\!\(\*GridBox[{
{\(\(\\\ \\\ \\\ \)\(k\_1\\\ x\\\  - \\\ k\_2\\\ x\\\ y\)\)},
{\(\(-\\\ k\_3\) y\\\  + k\_4\\\ x\\\ y\)}
}]\)) = \>\"", ",", \(MatrixForm[F[t, {x, y}]]\)}], " ", "]"}], ";"}], 
      "  "}], "\[IndentingNewLine]", \(Print[\*"\"\<The critical point is (\!\
\(x\_0\),\!\(y\_0\)) = (\!\(k\_3\/k\_4\),\!\(k\_1\/k\_2\)) = (\>\"", 
        k\_3\/k\_4, "\< , \>", k\_1\/k\_2, "\<)\>"];\)}], "Input"],

Cell["\<\
If we graph the solution over a larger time interval the graph \
traces over itself, because the solution is periodic. \
\>", "Text"],

Cell[BoxData[{
    \(\(x\_0\  = \ 5000;\)\ \), "\[IndentingNewLine]", 
    \(\(y\_0\  = \ 100;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 12;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 600;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Z\  = Runge2D[a, b, x\_0, y\_0, n];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(ListPlot[Z, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Magenta, 
        PlotRange \[Rule] {{0, 10000}, {0, 360}}, Ticks \[Rule] Automatic, 
        AspectRatio \[Rule] 1];\)\ \ \), "\n", 
    \(\(Print["\<The Runge-Kutta solution for\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[{x', y'}], "\< = \>", 
        MatrixForm[F[t, {x, y}]]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[
        MatrixForm[{\*"\"\<\!\(x\_0\)\>\"", \*"\"\<\!\(y\_0\)\>\""}], "\< = \
\>", MatrixForm[{x\_0, y\_0}]\ ];\)\ \ \)}], "Input"],

Cell[TextData[{
  "The graph of the number of prey is formed by using the first coordinate ",
  Cell[BoxData[
      \(x \((t)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(TX = 
        Transpose[{T, \(Transpose[Z]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[TX, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Blue, 
        PlotRange \[Rule] {{0, 12}, {0, 10000}}, 
        Ticks \[Rule] Automatic];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The number of rabbits.\>"];\)\)}], "Input"],

Cell[TextData[{
  "The graph of the number of predators is formed by using the second \
coordinate ",
  Cell[BoxData[
      \(y \((t)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(TY = 
        Transpose[{T, \(Transpose[Z]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[TY, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Red, 
        PlotRange \[Rule] {{0, 12}, {0, 400}}, 
        Ticks \[Rule] Automatic];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The number of foxes.\>"];\)\)}], "Input"],

Cell["\<\
The periodic behavior is clearly present in the latter two graphs.  \
Notice the phase lag for the number of prey.  Did you expect this to happen? \
\
\>", "Text"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The Lotka-Volterra Model",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/Lotka-VolterraBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Lotka-Volterra Model",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/Lotka-VolterraBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 321, 11, 35, "Text"],
Cell[2100, 66, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3579, 118, 1231, 37, 194, "Text"],
Cell[4813, 157, 645, 23, 33, "Text"],
Cell[5461, 182, 231, 7, 33, "Text"],
Cell[5695, 191, 624, 21, 33, "Text"],
Cell[6322, 214, 2973, 87, 134, "Text"],
Cell[9298, 303, 1831, 30, 350, "Input"],
Cell[11132, 335, 621, 24, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11778, 363, 101, 2, 33, "Text"],
Cell[11882, 367, 625, 12, 130, "Input"],
Cell[12510, 381, 244, 6, 33, "Text"],
Cell[12757, 389, 174, 4, 30, "Input"]
}, Closed]],
Cell[12946, 396, 340, 10, 30, "Text"],
Cell[13289, 408, 1074, 33, 128, "Text"],
Cell[14366, 443, 1619, 27, 309, "Input"],
Cell[15988, 472, 390, 14, 34, "Text"],
Cell[16381, 488, 1634, 59, 261, "Text"],

Cell[CellGroupData[{
Cell[18040, 551, 101, 2, 33, "Text"],
Cell[18144, 555, 280, 11, 33, "Text"],
Cell[18427, 568, 881, 17, 230, "Input"],
Cell[19311, 587, 49, 0, 33, "Text"],
Cell[19363, 589, 1713, 34, 310, "Input"],
Cell[21079, 625, 1605, 32, 270, "Input"],
Cell[22687, 659, 401, 7, 70, "Input"],
Cell[23091, 668, 42, 0, 33, "Text"],
Cell[23136, 670, 760, 12, 110, "Input"],
Cell[23899, 684, 144, 3, 33, "Text"],
Cell[24046, 689, 1271, 24, 210, "Input"],
Cell[25320, 715, 64, 0, 33, "Text"],
Cell[25387, 717, 1366, 26, 230, "Input"],
Cell[26756, 745, 168, 5, 71, "Text"],
Cell[26927, 752, 2804, 55, 454, "Input"]
}, Closed]],
Cell[29746, 810, 668, 24, 144, "Text"],

Cell[CellGroupData[{
Cell[30439, 838, 101, 2, 33, "Text"],
Cell[30543, 842, 45, 0, 33, "Text"],
Cell[30591, 844, 199, 4, 50, "Input"],
Cell[30793, 850, 60, 0, 33, "Text"],
Cell[30856, 852, 217, 6, 76, "Input"],
Cell[31076, 860, 177, 5, 36, "Text"],
Cell[31256, 867, 347, 5, 49, "Input"],
Cell[31606, 874, 40, 0, 33, "Text"],
Cell[31649, 876, 194, 4, 46, "Text"],
Cell[31846, 882, 188, 6, 34, "Text"],
Cell[32037, 890, 291, 5, 44, "Input"],
Cell[32331, 897, 51, 0, 33, "Text"],
Cell[32385, 899, 113, 2, 30, "Input"],
Cell[32501, 903, 105, 2, 31, "Input"],
Cell[32609, 907, 78, 1, 30, "Input"],
Cell[32690, 910, 121, 3, 33, "Text"],
Cell[32814, 915, 113, 2, 30, "Input"],
Cell[32930, 919, 76, 1, 30, "Input"],
Cell[33009, 922, 102, 3, 33, "Text"],
Cell[33114, 927, 154, 3, 30, "Input"],
Cell[33271, 932, 227, 9, 34, "Text"],
Cell[33501, 943, 533, 10, 150, "Input"]
}, Closed]],
Cell[34049, 956, 647, 24, 144, "Text"],

Cell[CellGroupData[{
Cell[34721, 984, 101, 2, 33, "Text"],
Cell[34825, 988, 271, 5, 90, "Input"],
Cell[35099, 995, 254, 5, 90, "Input"],
Cell[35356, 1002, 175, 5, 33, "Text"],
Cell[35534, 1009, 527, 9, 130, "Input"]
}, Closed]],
Cell[36076, 1021, 718, 26, 166, "Text"],

Cell[CellGroupData[{
Cell[36819, 1051, 101, 2, 33, "Text"],
Cell[36923, 1055, 201, 4, 63, "Input"],
Cell[37127, 1061, 206, 4, 50, "Input"],
Cell[37336, 1067, 443, 8, 70, "Input"],
Cell[37782, 1077, 473, 7, 110, "Input"],
Cell[38258, 1086, 182, 6, 71, "Text"],
Cell[38443, 1094, 199, 4, 63, "Input"],
Cell[38645, 1100, 206, 4, 50, "Input"],
Cell[38854, 1106, 460, 8, 90, "Input"],
Cell[39317, 1116, 473, 7, 110, "Input"]
}, Closed]],
Cell[39805, 1126, 2201, 63, 381, "Text"],
Cell[42009, 1191, 2775, 83, 172, "Text"],

Cell[CellGroupData[{
Cell[44809, 1278, 101, 2, 33, "Text"],
Cell[44913, 1282, 280, 11, 33, "Text"],
Cell[45196, 1295, 891, 17, 230, "Input"],
Cell[46090, 1314, 49, 0, 33, "Text"],
Cell[46142, 1316, 942, 17, 230, "Input"],
Cell[47087, 1335, 787, 14, 98, "Input"],
Cell[47877, 1351, 143, 3, 33, "Text"],
Cell[48023, 1356, 941, 17, 230, "Input"],
Cell[48967, 1375, 152, 5, 33, "Text"],
Cell[49122, 1382, 412, 7, 71, "Input"],
Cell[49537, 1391, 160, 6, 33, "Text"],
Cell[49700, 1399, 407, 7, 71, "Input"],
Cell[50110, 1408, 173, 4, 33, "Text"]
}, Closed]],
Cell[50298, 1415, 158, 3, 32, "Text"],
Cell[50459, 1420, 583, 17, 33, "Text"],
Cell[51045, 1439, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

