(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    112081,       2951]*)
(*NotebookOutlinePosition[    113331,       2990]*)
(*  CellTagsIndexPosition[    113287,       2986]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Module for Projectile Motion",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", a second order D. E.",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIn calculus, a model for ",
  ButtonBox["projectile motion",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/Projectile.html"], None},
    ButtonStyle->"Hyperlink"],
  " with no friction is considered, and a \"parabolic trajectory\" is \
obtained.  If the initial velocity is  ",
  Cell[BoxData[
      \(v\_0\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  "  is the initial angle to the horizontal, then the parametric equations \
for the horizontal and vertical components of the position vector are \n\t\n\
(1)\t\t",
  Cell[BoxData[
      \(x \((t)\)\ \  = \ \ v\_0\ cos \((\[Theta])\) t\)]],
  ",  \n\tand\n(2)\t\t",
  Cell[BoxData[
      \(y \((t)\)\ \  = \ \ v\_0\ sin \((\[Theta])\) t\  - \ \(1\/2\) 
            g\ t\^2\)]],
  ".  \n\nSolve equation (1) for ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " and get  ",
  Cell[BoxData[
      \(t = \(\(\(\ \)\(sec \((\[Theta])\)\)\)\/v\_0\) x\)]],
  ",  then replace this value of ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " in equation (2) and the result is \n\n \t\t",
  Cell[BoxData[
      \(y\ \  = \ \ tan \((\[Theta])\) 
            x - \(g\ \ [sec \((\[Theta])\)]\^2\/\(2\ v\_0\%2\)\) x\^2\)]],
  ",\n\nwhich is an equation of a parabola.  "
}], "Text"],

Cell[TextData[{
  "\tThe time ",
  Cell[BoxData[
      \(t\_1\)]],
  " required to reach the ",
  ButtonBox["maximum height",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/Height.html"], None},
    ButtonStyle->"Hyperlink"],
  " is found by solving  ",
  Cell[BoxData[
      \(y' \((t)\) = 0\)]],
  ":  \n\n\t\t",
  Cell[BoxData[
      \(y' \((t)\)\  = \(sin \((\[Theta])\)\ v\_0\ \  - g\ t\  = \ \ 0\)\)]],
  ", \nyields  \n\t\t",
  Cell[BoxData[
      \(t\_1\  = \ \(sin \((\[Theta])\)\ v\_0\)\/g\)]],
  ",\n\t\t\nand the maximum height is \n\n\t\t",
  Cell[BoxData[
      \(y\_max\  = \ \(y \((t\_1)\)\  = \ \(\([sin \((\[Theta])\)]\)\^2\ v\_0\
\%2\)\/\(2\ g\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe time ",
  Cell[BoxData[
      \(t\_2\)]],
  " till impact is found by solving  ",
  Cell[BoxData[
      \(y \((t)\) = 0\)]],
  ", which yields  ",
  Cell[BoxData[
      \(t\_2\  = \ \(2\ sin \((\[Theta])\)\ v\_0\)\/g\)]],
  ", and for this model,  ",
  Cell[BoxData[
      \(t\_2\  = 2  t\_1\)]],
  ".  The ",
  ButtonBox["range",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/Range.html"], None},
    ButtonStyle->"Hyperlink"],
  " is found by calculating  ",
  Cell[BoxData[
      \(x \((t\_2)\)\)]],
  ":  \n\n\t\t",
  Cell[BoxData[
      \(x\_range\  = \ \(x \((t\_2)\) = \ \(\(\(\ \)\(v\_0\%2\)\)\/g\) 
            sin \((2\ \[Theta])\)\)\)]],
  ".\n\t\t\nFor a fixed initial velocity  ",
  Cell[BoxData[
      \(v\_0\)]],
  ", the range  ",
  Cell[BoxData[
      \(x\_range\)]],
  "  is a function of  ",
  Cell[BoxData[
      \(\[Theta]\)]],
  ",  and is maximum when  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Theta]\  = \ \[Pi]\/4\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical solution of second order D. E.'s",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThis module illustrates numerical solutions of a second order \
differential equation.  First, we consider the special case where the \
projectile is fired vertically along the y-axis and has no horizontal motion, \
i. e.  ",
  StyleBox["x(t)= 0",
    FontFamily->"Courier New"],
  ".  The effect of changing the amount of air drag or air resistance is \
investigated.  It is known that the drag force acting on an object which \
moves very slowly through a viscous fluid is directly proportional to the \
velocity of that object.  However, there are \nexamples, such as Millikan's \
oil drop experiment, when the drag force is proportional to the square of the \
velocity.  Further investigations into the situation could involve the ",
  ButtonBox["Reynolds number",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/ReynoldsNumber.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Math-Models (Projectile Motion I)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The following mathematical models are are considered.  \n",
  StyleBox["(i).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \tNo air resistance  ",
  Cell[BoxData[
      \(m\ dv\/dt\ \  = \ \ \(-\ m\)\ g\)]],
  ",   and\n\t\t",
  Cell[BoxData[
      \(y''\  = \ \(-\ g\)\)]],
  ". \n\n",
  StyleBox["(ii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \tAir resistance proportional to velocity  ",
  Cell[BoxData[
      \(m\ dv\/dt\ \  = \ \ \(-\ k\)\ v\  - \ m\ g\)]],
  ",  and\n\t\t",
  Cell[BoxData[
      \(y''\  = \ \(-\ \(k\/m\)\)\ y'\  - \ g\)]],
  ". \n\n",
  StyleBox["(iii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \tAir resistance proportional to the square of the velocity  ",
  Cell[BoxData[
      \(m\ dv\/dt\ \  = \ \ \(-\ k\)\ v\^2\  - \ m\ g\)]],
  ",  for the ascent, and  ",
  Cell[BoxData[
      \(m\ dv\/dt\ \  = \ \ \ k\ v\^2\  - \ m\ g\)]],
  ",  for the descent, and \n\t\t",
  Cell[BoxData[
      \(y''\  = \(-\ \(k\/m\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(y'\  | y' | \ \ \(-\ \ g\)\)\)\)]],
  "\n\n",
  StyleBox["(iv).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \tAir resistance proportional to the ",
  Cell[BoxData[
      \(3\/2\)]],
  " power of the velocity \n\t\t",
  Cell[BoxData[
      \(y''\  = \(-\ \(k\/m\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(y'\ \@\(\(|\)\(y'\)\(|\)\)\ \  - \ \ g\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Projectile Motion",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/ProjectileMotionProof.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Projectile Motion",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/ProjectileMotionProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Projectile Motion",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/ProjectileMotionProg.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox[ButtonBox["Projectile Motion",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/ProjectileMotionProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(Runge-Kutta Method for second order D.E.'s)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To compute a numerical approximation for the solution of the \
initial value problem  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y''\  = \ f \((t, y, y')\)\)]],
  StyleBox["  with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((a)\) = \[Alpha]\)]],
  ", ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y' \((a)\) = \[Beta]\)]],
  StyleBox[",  \n\nover the interval  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(a\  \[LessEqual] \ t\  \[LessEqual] \ b\)]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "at a discrete set of points.  "
}], "Text"],

Cell[BoxData[
    \(\(\(Runge2D[a0_, b0_, \[Alpha]_, \[Beta]_, 
          m0_] := \[IndentingNewLine]Module[{a = a0, b = b0, j, m = m0, 
            Z}, \[IndentingNewLine]h = \(b - a\)\/m; \ \[IndentingNewLine]T\  \
= \ Table[\ a + \((j - 1)\) h, {j, 1, m + 1}]; \ \[IndentingNewLine]Z = \ 
            Table[\ {\[Alpha], \[Beta]}, {j, 1, 
                m + 1}]; \ \ \[IndentingNewLine]For[\ j = 1, \ 
            j \[LessEqual] m, \ \(j++\), \[IndentingNewLine]k\_1\  = \ 
              h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\), Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\)]; \ \
\[IndentingNewLine]k\_2\  = \ 
              h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h\/2, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_1\/2]; \ \[IndentingNewLine]k\_3\  = \ 
              h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h\/2, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_2\/2]; \ \[IndentingNewLine]k\_4\  = \ 
              h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_3]; \ \[IndentingNewLine]Z\_\(\(\[LeftDoubleBracket]\)\
\(j + 1\)\(\[RightDoubleBracket]\)\)\  = \ 
              Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + \
\(1\/6\) \((k\_1 + 2  k\_2 + 2  k\_3 + 
                      k\_4)\);\ \ ]; \ \[IndentingNewLine]Return[
            Z];\ ];\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  An arrow is shot upward from the origin with an initial velocity of  300 \
ft/sec.  Assume that there is no air resistance and use the model  \n\t\t",
  Cell[BoxData[
      \(m\ dv\/dt\ \  = \ \ \(-\ m\)\ g\)]],
  ".  \nFind the velocity and position as a function of time.  Find the \
ascent time, the descent time, maximum height, and the impact velocity."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, compute the solution using the Runge-Kutta method for second \
order D.E.'s.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f, g, t, v, y];\)\), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_0 = 300;\)\ \), "\n", 
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 20.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(f[t_, y_, v_] := \(-\ g\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_1[t_, y_, v_] = \ v;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_2[t_, y_, v_] = f[t, y, v];\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[t_, {y_, v_}]\  = \ {f\_1[t, y, v], 
          f\_2[t, y, v]\ };\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the system of D.E.'s\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f\_1[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<v' = \>", f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The solution to the second order \
equation\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   y'' = \>", 
        f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y'(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\(W\  = \ Runge2D[a, b, Y\_0, V\_0, n];\)\ \ \)}], "Input"],

Cell["\<\
The solution we seek is the first coordinate in the 2D \
system.\
\>", "Text"],

Cell[BoxData[{
    \(\(X = \(Transpose[W]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Transpose[{T, X}];\)\ \)}], "Input"],

Cell["Now we can plot the solution. ", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(graph0 = 
        ListPlot[pts, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Purple, 
          PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
          Ticks \[Rule] {Range[0, 20, 5], 
              Range[0, 1500, 500]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution to the D. E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<   y'' = \>", 
        f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y'(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Second, compute the analytic solution to the D.E.'s.", "Text"],

Cell[BoxData[{
    RowBox[{\(g = 32;\), " "}], "\n", 
    RowBox[{\(V\_0 = 300;\), " "}], "\n", 
    RowBox[{\(Y\_0 = 0;\), " "}], "\n", 
    RowBox[{\(Clear[v, t];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"de", "=", 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], 
            "\[Equal]", \(\(-m\)\ g\)}]}], ";"}], " "}], "\n", 
    RowBox[{\(ic = v[0] \[Equal] V\_0;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(sol1 = DSolve[\ {de, v[0] \[Equal] V\_0}, v[t], t];\), 
      " "}], "\n", 
    RowBox[{\(V[t_] = \ 
          Expand[sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\), " "}], "\n", 
    RowBox[{\(Y[t_] = \[Integral]V[t] \[DifferentialD]t + Y\_0;\), 
      " "}], "\n", 
    RowBox[{\(f\_1[t_] = Y[t];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(graph1 = 
          Plot[Y[t], {t, 0, 20}, PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
            PlotStyle \[Rule] Green, 
            Ticks \[Rule] {Range[0, 20, 5], Range[0, 1500, 500]}];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Solve\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print[de];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<  \>", ic];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print["\<V[t] = \>", V[t]\ ];\), " "}], "\n", 
    RowBox[{\(Print["\<V[0] = \>", V[0]\ ];\), " "}], "\n", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Integrate V[t]\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<  \!\(Y\_0\) = \>\"", Y\_0\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<Y[t] = \[Integral] V[t]\[DifferentialD]t + \
\!\(Y\_0\)\>\""];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Y[t] = \>", Y[t]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Y[0] = \>", Y[0]\ ];\), " "}]}], "Input"],

Cell["Compare the Runge-Kutta solution with the analytic solution.", "Text"],

Cell[BoxData[{
    \(\(Show[graph0, graph1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution and the analytic \
solution.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<They are in agreement.\>"];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Notice that the maximum altitude will occur when the time is near t \
= 9,
and the arrow will hit the ground when the time is near t = 19.\
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1];\)\ \), "\[IndentingNewLine]", 
    \(\(tsol1 = FindRoot[V[t] \[Equal] 0, {t, 9}];\)\ \), "\n", 
    \(\(t\_max = 
        tsol1\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(t\_max\)  = \>\"", t\_max\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<V[\!\(t\_max\)] = \>\"", 
        Chop[V[t\_max]]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Y[\!\(t\_max\)] = \>\"", Y[t\_max]\ ];\)\ \), "\n", 
    \(\(Print["\<Ascent time = \>", t\_max\ ];\)\ \), "\n", 
    \(\(tsol2 = FindRoot[Y[t] \[Equal] 0, {t, 19}];\)\ \), "\n", 
    \(\(t\_range = 
        tsol2\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(t\_range\)  = \>\"", t\_range\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<V[\!\(t\_range\)] = \>\"", V[t\_range]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Y[\!\(t\_range\)] = \>\"", 
        Chop[Y[t\_range]]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Descent time = \!\(t\_range\) - \!\(t\_max\) = \>\"", 
        t\_range - t\_max\ ];\)\ \)}], "Input"],

Cell["\<\
In this model, the ascent time is equal to the descent time. \
\>", \
"Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  An arrow is shot upward from the origin with an initial velocity of  300 \
ft/sec.  Assume that air resistance is proportional to the velocity, ",
  Cell[BoxData[
      \(F\_R\  = \ 0.04\ m\ v\)]],
  ", \nand use the model  \n\t\t",
  Cell[BoxData[
      \(m\ dv\/dt\ \  = \ \ \(-\ k\)\ v\  - \ m\ g\)]],
  ".  \nFind the velocity and position as a function of time, and plot the \
position function.  Find the ascent time, the descent time, maximum height, \
and the impact velocity."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, compute the solution using the Runge-Kutta method for second \
order D.E.'s.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f, g, t, v, y];\)\), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = \(4\/100\) m;\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_0 = 300;\)\ \), "\n", 
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 20.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(f[t_, y_, v_] := \(-\ \(k\/m\)\)\ v\  - \ 
          g;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_1[t_, y_, v_] = \ v;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_2[t_, y_, v_] = f[t, y, v];\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[t_, {y_, v_}]\  = \ {f\_1[t, y, v], 
          f\_2[t, y, v]\ };\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the system of D.E.'s\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f\_1[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<v' = \>", f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The solution to the second order \
equation\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   y'' = \>", 
        f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y'(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\(W\  = Runge2D[a, b, Y\_0, V\_0, n];\)\ \ \)}], "Input"],

Cell["\<\
The solution we seek is the first coordinate in the 2D \
system.\
\>", "Text"],

Cell[BoxData[{
    \(\(X = \(Transpose[W]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Transpose[{T, X}];\)\ \)}], "Input"],

Cell["Now we can plot the solution. ", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(graph0 = 
        ListPlot[pts, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Purple, 
          PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
          Ticks \[Rule] {Range[0, 20, 5], 
              Range[0, 1500, 500]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution to the D. E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<   y'' = \>", 
        f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y'(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    RowBox[{\(g = 32;\), " "}], "\n", 
    RowBox[{\(k = \(4\/100\) m;\), " "}], "\n", 
    RowBox[{\(V\_0 = 300;\), " "}], "\n", 
    RowBox[{\(Y\_0 = 0;\), " "}], "\n", 
    RowBox[{\(Clear[v, t]\), " "}], "\n", 
    RowBox[{
      RowBox[{"de", "=", 
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{
              SuperscriptBox["v", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "\[Equal]", \(\(-k\)\ v[t] - \ m\ g\)}]}], ";"}], "\n", 
    RowBox[{\(ic = v[0] \[Equal] V\_0;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(sol1 = DSolve[\ {de, v[0] \[Equal] V\_0}, v[t], t];\), 
      " "}], "\n", 
    RowBox[{\(V[t_] = \ 
          Expand[\ 
            sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\), " "}], "\n", 
    RowBox[{\(Y[t_] = 
          Expand[\[Integral]\_0\%t V[s] \[DifferentialD]s + Y\_0\ ];\), 
      " "}], "\n", 
    RowBox[{\(f\_2[t_] = Y[t];\), 
      " "}], "\[IndentingNewLine]", \(lim = 
        Limit[V[t], t \[Rule] \[Infinity]];\), "\n", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(graph2\  = \ 
          Plot[Y[t], {t, 0, 20}, PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
            PlotStyle \[Rule] Blue, 
            Ticks \[Rule] {Range[0, 20, 5], Range[0, 1500, 500]}];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Solve\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print[de];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<  \>", ic];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print["\<V[t] = \>", V[t]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<V[0] = \>", V[0]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Integrate V[t]\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<  \!\(Y\_0\) = \>\"", Y\_0\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<Y[t] = \[Integral] V[t]\[DifferentialD]t + \
\!\(Y\_0\)\>\""];\), " "}], "\n", 
    RowBox[{\(Print["\<Y[t] = \>", Y[t]\ ];\), " "}], "\n", 
    RowBox[{\(Print["\<Y[0] = \>", Y[0]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<The limiting velocity \
is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<\!\(lim\+\(t \[Rule] \
\[Infinity]\)\)\>\"", "\< V[t] = \>", \*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\
\)\)\>\"", "\<(\>", V[t], "\<) = \>", N[lim]\ ];\)}], "Input"],

Cell["Compare the Runge-Kutta solution with the analytic solution.", "Text"],

Cell[BoxData[{
    \(\(Show[graph0, graph2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution and the analytic \
solution.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<They are in agreement.\>"];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Notice that the maximum altitude will occur when the time is near t \
= 8,
and the arrow will hit the ground when the time is near t = 17.\
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph2];\)\), "\[IndentingNewLine]", 
    \(\(tsol1 = FindRoot[V[t] \[Equal] 0, {t, 8}];\)\ \), "\n", 
    \(\(t\_max = 
        tsol1\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(t\_max\)  = \>\"", t\_max\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<V[\!\(t\_max\)] = \>\"", 
        Chop[V[t\_max], 10\^\(-8\)]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Y[\!\(t\_max\)] = \>\"", Y[t\_max]\ ];\)\ \), "\n", 
    \(\(Print["\<Ascent time = \>", t\_max\ ];\)\ \), "\n", 
    \(\(tsol2 = FindRoot[Y[t] \[Equal] 0, {t, 17}];\)\ \), "\n", 
    \(\(t\_range = 
        tsol2\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(t\_range\)  = \>\"", t\_range\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<V[\!\(t\_range\)] = \>\"", V[t\_range]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Y[\!\(t\_range\)] = \>\"", 
        Chop[Y[t\_range]]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Descent time = \!\(t\_\(\(range\)\(\\\ \)\)\)- \
\!\(t\_max\) = \>\"", t\_range - t\_max\ ];\)\ \)}], "Input"],

Cell["\<\
In this model, the descent time is larger that the ascent time. 
Don't we expect this to happen in the \"real world.\" \
\>", "Text"],

Cell["Compare the two models of examples 1, and 2.", "Text"],

Cell[BoxData[{
    \(\(Show[{graph1, graph2}, PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
        Ticks \[Rule] {Range[0, 20, 5], 
            Range[0, 1500, 500]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_1\)[t] = \>\"", 
        f\_1[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_2\)[t] = \>\"", f\_2[t]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  An arrow is shot upward from the origin with an initial velocity of  300 \
ft/sec.  Assume that air resistance is proportional to the square of the \
velocity,  ",
  Cell[BoxData[
      \(F\_R\  = \ 1\/2048\ m\ v\^2\)]],
  ", \nand use the model  \n\t\t",
  Cell[BoxData[
      \(m\ dv\/dt\ \  = \ \ \(\[MinusPlus]\ k\)\ v\^2\  - \ m\ g\)]],
  ".  \nFind the velocity and position as a function of time, and plot the \
position function.  Find the ascent time, the descent time, maximum height, \
and the impact velocity."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{\(g = 32;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(k = \(1\/2048\) m;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(V\_0 = 300;\), " "}], "\n", 
    RowBox[{\(Y\_0 = 0;\), " "}], "\n", 
    RowBox[{\(Clear[v, t];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"de", "=", 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], 
            "\[Equal]", \(\(-k\)\ v[t]\^2 - \ m\ g\)}]}], ";"}], " "}], "\n", 
  
    RowBox[{\(ic = v[0] \[Equal] V\_0;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(sol1 = DSolve[\ {de, v[0] \[Equal] V\_0}, v[t], t];\), 
      " "}], "\n", 
    RowBox[{\(V[t_] = \ 
          Expand[\ 
            sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)\ ];\), " "}], "\n", 
    RowBox[{\(V[t_] = FunctionExpand[V[t]];\), " "}], "\n", 
    RowBox[{\(q[s_] = \[Integral]V[s] \[DifferentialD]s;\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Y[t_] = q[t] - q[0];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(f\_3[t_] = Y[t];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), " "}], "\[IndentingNewLine]", 
  
    RowBox[{\(graph3 = 
          Plot[Y[t], {t, 0, 17}, PlotRange \[Rule] {{0, 17}, {0, 1200}}, 
            PlotStyle \[Rule] Magenta, 
            Ticks \[Rule] {Range[0, 20, 5], Range[0, 1500, 500]}];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Solve\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print[de];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[ic];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print["\<V[t] = \>", V[t]\ ];\), " "}], "\n", 
    RowBox[{\(Print["\<V[0] = \>", V[0]\ ];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Integrate\>"];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<  \!\(Y\_0\) = \>\"", Y\_0\ ];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<Y[t] = \[Integral] V[t]\[DifferentialD]t + \
\!\(Y\_0\)\>\""];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<Y[t] = \>", Y[t]\ ];\), " "}], "\n", 
    RowBox[{\(Print["\<Y[0] = \>", Y[0]\ ];\), " "}]}], "Input"],

Cell["\<\
Notice that the maximum altitude will occur when the time is near t \
= 7,
and the arrow will hit the ground when the time is near t = 14.\
\>", "Text"],

Cell[BoxData[{
    \(\(tsol1 = FindRoot[V[t] \[Equal] 0, {t, 7}];\)\ \), "\n", 
    \(\(t\_max = 
        tsol1\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\ \), "\n", 
    \(\(ymax = Y[t\_max];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(t\_max\)  = \>\"", t\_max\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<V[\!\(t\_max\)] = \>\"", V[t\_max]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Y[\!\(t\_max\)] = \>\"", Y[t\_max]\ ];\)\ \), "\n", 
    \(\(Print["\<Ascent time = \>", t\_max\ ];\)\ \), "\n", 
    \(\(tsol2 = FindRoot[Y[t] \[Equal] 0, {t, 14}];\)\ \), "\n", 
    \(\(t\_range = 
        tsol2\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(t\_range\)  = \>\"", t\_range\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<V[\!\(t\_range\)] = \>\"", V[t\_range]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Y[\!\(t\_range\)] = \>\"", 
        Chop[Y[t\_range], 10\^\(-8\)]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Descent time = \!\(t\_range\) - \!\(t\_max\) = \>\"", 
        t\_range - t\_max\ ];\)\ \)}], "Input"],

Cell["\<\
Notice that the ascent time is the same as the descent time. 
We desire to have a model in which the descent time is larger that the ascent \
time. 
We expect this to happen in the \"real world.\" \
\>", "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " No matter how much you like the above model, it isn't right.  Indeed, the \
velocity function  ",
  StyleBox["V[t]",
    FontFamily->"Courier New"],
  "  has a vertical asymptote at  ",
  Cell[BoxData[
      \(t\  = \ \(8\ \[Pi] + 
            8\ \((\(-\(\[Pi]\/2\)\) + 
                  ArcTan[75\/64])\)\  = \ \(8\ \((\[Pi]\/2 + 
                  ArcTan[75\/64])\)\  = \ 19.481332783469895`\)\)\)]]
}], "Text"],

Cell[BoxData[{
    \(\(eqn = 1\/V[t] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[1\/V[t] \[Equal] 0, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<To find the vertical asymptote, solve \!\(1\/V[t]\) = 0. \
\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<1/\>", V[t], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(tlim = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A vertical asymptote occurs at\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<t = \>", tlim, "\< = \>", 
        N[tlim]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The vertical asymptote we need is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(tlim = 8  \[Pi] + tlim;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<t = \>", tlim, "\< = \>", N[tlim]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Graph the ",
  StyleBox["V[t]",
    FontFamily->"Courier New"],
  " and the vertical asymptote."
}], "Text"],

Cell[BoxData[{
    \(\(Plot[V[t], {t, 0, 20}, PlotRange \[Rule] {{0, 20}, {\(-4000\), 300}}, 
        PlotStyle \[Rule] Green];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<V[t] = \>", V[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The vertical asymptote is\>"];\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\<t = \>", tlim, "\< = \>", N[tlim]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Find the limiting velocity for  ",
  StyleBox["V[t]",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(lim = 
        Limit[V[t], t \[Rule] tlim, 
          Direction \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[V[t], {t, 0, 20}, PlotRange \[Rule] {{0, 20}, {\(-4000\), 300}}, 
        PlotStyle \[Rule] Green];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<V[t] = \>", V[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The limiting velocity is\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<lim\>"\+\(t \[Rule] tlim\), "\< V[t] = \>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<lim\>"\+\(t \[Rule] tlim\), "\<(\>", V[t], "\<) = \>", 
        lim\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Do we really believe that the limiting velocity for  ",
  StyleBox["V[t]",
    FontFamily->"Courier New"],
  "  is  ",
  Cell[BoxData[
      \(\(-\[Infinity]\)\)]],
  " ?"
}], "Text"],

Cell[TextData[{
  StyleBox["Model for the Ascent",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nWe can use the above solution for the ascent portion of the curve \
only. "
}], "Text"],

Cell[BoxData[{
    \(\(g = 32;\)\ \), "\[IndentingNewLine]", 
    \(\(k = \(1\/2048\) m;\)\ \), "\n", 
    \(\(V\_0 = 300;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\n", 
    \(\(Clear[v, t];\)\ \), "\n", 
    \(\(deup = m\ \(v'\)[t] \[Equal] \(-k\)\ v[t]\^2 - \ m\ g;\)\ \), "\n", 
    \(\(sol1 = DSolve[\ {deup, v[0] \[Equal] V\_0}, v[t], t];\)\ \), "\n", 
    \(\(V[t_] = \ 
        Expand[\ 
          sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)\ ];\)\ \), "\n", 
    \(\(V[t_] = FunctionExpand[V[t]];\)\ \), "\n", 
    \(\(q[
          s_] = \[Integral]V[
              s] \[DifferentialD]s;\)\ \), "\[IndentingNewLine]", 
    \(\(Y[t_] = q[t] - q[0];\)\ \), "\[IndentingNewLine]", 
    \(\(graph31 = 
        Plot[Y[t], {t, 0, t\_max}, PlotRange \[Rule] {{0, 17}, {0, 1200}}, 
          PlotStyle \[Rule] Magenta, 
          Ticks \[Rule] {Range[0, 20, 5], 
              Range[0, 1500, 500]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The differential equation for the ascent is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[deup];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<V[t] = \>", V[t]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Y[t] = \>", Y[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Valid for the ascent: 0 \[LessEqual] t \[LessEqual] \>", 
        t\_max];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<V[\!\(t\_max\)] = V[\>\"", t\_max, "\<] = \>", 
        V[t\_max]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Y[\!\(t\_max\)] = Y[\>\"", t\_max, "\<] = \>", 
        Y[t\_max]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " With air resistance the descent time must be greater than the ascent \
time!  The D. E. for the descent must have the sign of the term with  ",
  Cell[BoxData[
      \(v[t]\^2\)]],
  "  positive. Let's call the velocity function  ",
  StyleBox["U[t]",
    FontFamily->"Courier New"],
  "  on the descent portion of the curve. "
}], "Text"],

Cell[TextData[{
  StyleBox["Model for the Descent",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nWe muse use the differential equation  ",
  Cell[BoxData[
      \(m\ \(u'\)[t] = k\ u[t]\^2 - \ m\ g\)]],
  "  for the descent portion of the curve. "
}], "Text"],

Cell[BoxData[{
    \(\(g = 32;\)\ \), "\[IndentingNewLine]", 
    \(\(k = \(1\/2048\) m;\)\ \), "\n", 
    \(\(V\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\n", 
    \(\(Clear[v, t, U, Z];\)\ \), "\n", 
    \(\(dedown = m\ \(u'\)[t] \[Equal] k\ u[t]\^2 - \ m\ g;\)\ \), "\n", 
    \(\(sol1 = DSolve[\ {dedown, u[0] \[Equal] V\_0}, u[t], t];\)\ \), "\n", 
    \(\(U[t_] = \ 
        Expand[\ 
          sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)\ \ ];\)\ \), "\n", 
    \(\(U[t_] = U[t - t\_max];\)\ \), "\n", 
    \(\(Z[t_] = 
        Expand[ymax + \[Integral]\_\(t\_max\)\%t U[
                  s] \[DifferentialD]s];\)\ \), "\n", 
    \(\(tsol2 = FindRoot[Z[t] \[Equal] 0, {t, 17}];\)\), "\n", 
    \(\(t\_range = 
        tsol2\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\), "\[IndentingNewLine]", 
    \(\(lim = Limit[TrigToExp[U[t]], t \[Rule] \[Infinity]];\)\ \), "\n", 
    \(\(graph32 = 
        Plot[Z[t], {t, t\_max, 17}, PlotRange \[Rule] {{0, 17}, {0, 1200}}, 
          PlotStyle \[Rule] Red, 
          Ticks \[Rule] {Range[0, 20, 5], 
              Range[0, 1500, 500]}];\)\ \), "\n", 
    \(\(Print["\<The differential equation for the descent is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[dedown];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<U[t] = \>", U[t]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Z[t] = \>", Z[t]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<U[\!\(t\_max\)] = U[\>\"", t\_max, "\<] = \>", 
        U[t\_max]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Z[\!\(t\_max\)] = Z[\>\"", t\_max, "\<] = \>", 
        Z[t\_max]\ ];\)\ \), "\n", 
    \(\(Print["\<Valid for the descent: \>", 
        t\_max, "\< \[LessEqual] t \[LessEqual] \>", 
        t\_range];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The limiting velocity is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\< U[t] = \
\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\<(\>", 
        U[t], "\<) = \>", N[lim]\ ];\)\)}], "Input"],

Cell[TextData[StyleBox["Combine the Ascent and Descent",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Show[graph31, graph32];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The differential equation for the ascent is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[deup];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<V[t] = \>", V[t]\ ];\)\ \), "\n", 
    \(\(Print["\<Y[t] = \>", Y[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The differential equation for the descent is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[dedown];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    U[t] = \>", U[t]\ ];\)\ \), "\n", 
    \(\(Print["\<    Z[t] = \>", Z[t]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<  U[\!\(t\_max\)] = U[\>\"", t\_max, "\<] = \>", 
        U[t\_max]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<  Z[\!\(t\_max\)] = Z[\>\"", t\_max, "\<] = \>", 
        Z[t\_max]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<U[\!\(t\_range\)] = U[\>\"", t\_range, "\<] = \>", 
        U[t\_range]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Z[\!\(t\_range\)] = Z[\>\"", t\_range, "\<] = \>", 
        Chop[Z[t\_range], 10\^\(-6\)]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The limiting velocity is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\< U[t] = \
\>"\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\<(\>", 
        U[t], "\<) = \>", N[lim]\ ];\)\)}], "Input"],

Cell[TextData[{
  "We expect that the limiting velocity for ",
  StyleBox["U[t]",
    FontFamily->"Courier New"],
  " should be finite !  "
}], "Text"],

Cell["\<\
Notice that the maximum altitude will occur when the time is near t \
= 7,
and the arrow will hit the ground when the time is near t = 15.\
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph31, graph32];\)\ \), "\[IndentingNewLine]", 
    \(\(tsol1 = FindRoot[V[t] \[Equal] 0, {t, 8}];\)\), "\n", 
    \(\(t\_max = 
        tsol1\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\), "\n", 
    \(\(Print[\*"\"\<  \!\(t\_max\)  = \>\"", t\_max\ ];\)\), "\n", 
    \(\(Print[\*"\"\<V[\!\(t\_max\)] = \>\"", 
        Chop[V[t\_max], 10\^\(-6\)]\ ];\)\), "\n", 
    \(\(Print[\*"\"\<Y[\!\(t\_max\)] = \>\"", Y[t\_max]\ ];\)\), "\n", 
    \(\(Print["\<Ascent time = \>", t\_max\ ];\)\), "\n", 
    \(\(tsol2 = FindRoot[Z[t] \[Equal] 0, {t, 17}];\)\), "\n", 
    \(\(t\_range = 
        tsol2\_\(\(\[LeftDoubleBracket]\)\(1, 2\)\(\[RightDoubleBracket]\)\);\
\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(t\_range\)  = \>\"", t\_range\ ];\)\), "\n", 
    \(\(Print[\*"\"\<U[\!\(t\_range\)] = U[\>\"", t\_range, "\<] = \>", 
        U[t\_range]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<Z[\!\(t\_range\)] = Z[\>\"", t\_range, "\<] = \>", 
        Chop[Z[t\_range], 10\^\(-6\)]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Descent time = \!\(t\_range\) - \!\(t\_max\) = \>\"", 
        t\_range - t\_max];\)\)}], "Input"],

Cell["\<\
In this model, the descent time is larger that the ascent time. 
It took quite a bit of effort to make an ascent function and a descent \
function ! \
\>", "Text"],

Cell["Compare the three models of examples 1, 2, and 3.", "Text"],

Cell[BoxData[{
    \(\(Show[{graph1, graph2, graph31, graph32}, 
        PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
        Ticks \[Rule] {Range[0, 20, 5], 
            Range[0, 1500, 500]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_1\)[t] = \>\"", 
        f\_1[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(f\_2\)[t] = \>\"", 
        f\_2[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<and\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Y[t] = \>", Y[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Z[t] = \>", Z[t]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["The Runge-Kutta solution.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nNow compute the solution using the Runge-Kutta method for second order \
D.E.'s."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, g, t, v, y];\)\), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = \(1\/2048\) m;\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_0 = 300;\)\ \), "\n", 
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 20.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(f[t_, y_, v_] := \(-\ \(k\/m\)\)\ v\ Abs[v]\  - \ 
          g;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_1[t_, y_, v_] = \ v;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_2[t_, y_, v_] = f[t, y, v];\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[t_, {y_, v_}]\  = \ {f\_1[t, y, v], 
          f\_2[t, y, v]\ };\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the system of D.E.'s\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f\_1[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<v' = \>", f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The solution to the second order \
equation\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   y'' = \>", 
        f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y'(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\(W = Runge2D[a, b, Y\_0, V\_0, n];\)\ \ \)}], "Input"],

Cell["\<\
The solution we seek is the first coordinate in the 2D \
system.\
\>", "Text"],

Cell[BoxData[{
    \(\(X = \(Transpose[W]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Transpose[{T, X}];\)\ \)}], "Input"],

Cell["Now we can plot the solution. ", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(graph0 = 
        ListPlot[pts, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Purple, 
          PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
          Ticks \[Rule] {Range[0, 20, 5], 
              Range[0, 1500, 500]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution to the D. E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<   y'' = \>", 
        f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y'(\>", a, "\<) = \>", V\_0];\)\)}], "Input"],

Cell["Compare the Runge-Kutta solution with the analytic solution.", "Text"],

Cell[BoxData[{
    \(\(Show[{graph0, graph31, graph32}, 
        PlotRange \[Rule] {{0, 15}, {0, 900}}, 
        Ticks \[Rule] {Range[0, 20, 5], 
            Range[0, 1000, 200]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution and the analytic \
solution.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<They are in agreement.\>"];\)\)}], "Input"],

Cell["\<\
Notice how easy it is to obtain a Runge-Kutta solution.  

Often times there is not analytic solution and a numerical solution must be \
used.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  An arrow is shot upward from the origin with an initial velocity of  300 \
ft/sec.\nAssume that air resistance is proportional to the ",
  Cell[BoxData[
      \(3\/2\)]],
  "power of the velocity,  ",
  Cell[BoxData[
      \(F\_R\  = \ \(- .005\)\ m\ v\^\(3/2\)\)]],
  ",   and use the model  \n\t\t",
  Cell[BoxData[
      \(m\ dv\/dt\ \  = \ \ k\ v\  | v\( | \^\(1/2\)\)\ \(-\ \(m\ g\)\)\)]],
  ".  \nFind the velocity and position as a function of time, and plot the \
position function."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Compute the solution using the Runge-Kutta method for second order \
D.E.'s.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f, g, t, v, y];\)\), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = \(1\/200\) m;\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V\_0 = 300;\)\ \), "\n", 
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 20.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(f[t_, y_, v_] := \(-\ \(k\/m\)\)\ v\ \((Abs[v])\)\^\(1/2\)\  - \ 
          g;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_1[t_, y_, v_] = \ v;\)\ \ \), "\[IndentingNewLine]", 
    \(\(f\_2[t_, y_, v_] = f[t, y, v];\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[t_, {y_, v_}]\  = \ {f\_1[t, y, v], 
          f\_2[t, y, v]\ };\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Find numerical solutions to the system of D.E.'s\>"];\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<y' = \>", f\_1[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<v' = \>", f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<v(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The solution to the second order \
equation\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   y'' = \>", 
        f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y'(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\(W = Runge2D[a, b, Y\_0, V\_0, n];\)\ \ \)}], "Input"],

Cell["\<\
The solution we seek is the first coordinate in the 2D \
system.\
\>", "Text"],

Cell[BoxData[{
    \(\(X = \(Transpose[W]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(pts = Transpose[{T, X}];\)\ \)}], "Input"],

Cell["Now we can plot the solution. ", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\n", 
    \(\(graph4 = 
        ListPlot[pts, PlotJoined \[Rule] True, PlotStyle \[Rule] \ Purple, 
          PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
          Ticks \[Rule] {Range[0, 20, 5], 
              Range[0, 1500, 500]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Runge-Kutta solution to the D. E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<   y'' = \>", 
        f\_2[t, y, v]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<With the initial conditions\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< y(\>", a, "\<) = \>", Y\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y'(\>", a, "\<) = \>", V\_0];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
The graph should lie between the ones obtained in examples 2 and 3.
Let's see if this happens.\
\>", "Text"],

Cell[BoxData[
    \(\(\(Show[{graph2, graph4, graph31, graph32}, 
        PlotRange \[Rule] {{0, 20}, {0, 1500}}, 
        Ticks \[Rule] {Range[0, 20, 5], 
            Range[0, 1500, 500]}];\)\(\ \)\)\)], "Input"],

Cell["The graph does lie where it should lie.", "Text"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can \"try\" to get an analytic solution."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(g = 32;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(k = \(1\/200\) m;\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(V\_0 = 300;\), " "}], "\n", 
    RowBox[{\(Y\_0 = 0;\), " "}], "\n", 
    RowBox[{\(Clear[v, t];\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"de", "=", 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], 
            "\[Equal]", \(\(-k\)\ v[t]\^\(3/2\) - \ m\ g\)}]}], ";"}], 
      " "}], "\n", 
    RowBox[{\(ic = v[0] \[Equal] V\_0;\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Solve the D. E.  \>", 
        de];\), "\[IndentingNewLine]", \(Print["\<With  the I. C.  \>", 
        v[0] \[Equal] V\_0];\), "\[IndentingNewLine]", \(DSolve[\ {de, 
        v[0] \[Equal] V\_0}, v[t], t]\)}], "Input"],

Cell[TextData[{
  "Clearly, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is having a difficult time of it.\nIf the initial condition is not used \
then ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can go a little further in the solution."
}], "Text"],

Cell[BoxData[
    RowBox[{"DSolve", "[", " ", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["v", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "==", \(\(-32\)\  - 1\/200\ \ v[t]\^\(3/2\)\)}], " ", ",", \(v[t]\),
         ",", "t"}], "]"}]], "Input"],

Cell["We should trust our Runge-Kutta solution.", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Trajectory of a baseball.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n",
  StyleBox["More Math-Models (Projectile Motion II)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The following mathematical models are are considered.  \n",
  StyleBox["(v).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \tNo air resistance  \n\t\t",
  Cell[BoxData[{
      \(x'' \((t)\)\  = \ 0\), "\n", 
      \(y'' \((t)\)\  = \ \(-\ g\)\)}]],
  "  \n\n",
  StyleBox["(vi).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \tAir resistance proportional to velocity \n\t\t",
  Cell[BoxData[{
      \(x'' \((t)\)\  = \ \(-\ k\)\ x' \((t)\)\), "\n", 
      \(y'' \((t)\)\  = \ \(-\ k\)\ y' \((t)\)\  - \ g\)}]],
  "  \n\n",
  StyleBox["(vii).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " \tAir resistance proportional to the square of the velocity \n\t\t",
  Cell[BoxData[{
      \(x'' \((t)\)\  = \ \(-\ 
            k\)\ x' \((t)\)\ \@\(\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\)\(\ \ \)\)\), "\n", 
      \(y'' \((t)\)\  = \ \(\(\(-\ 
              k\)\ y' \((t)\)\ \@\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\)\)\(\ \)\(-\)\(\ \)\(g\)\(\ \ \)\)\)}]]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Projectile Motion",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/ProjectileMotionProof.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Projectile Motion",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/ProjectileMotionProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(Runge-Kutta Method for two second order D.E.'s)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To compute a numerical approximation for the solution of the \
initial value problem  \n\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x''\  = \ f \((t, x, x', y, y')\)\)]],
  StyleBox["  with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x \((a)\) = \[Alpha]\)]],
  ", ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x' \((a)\) = \[Beta]\)]],
  StyleBox[",  \nand\n\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y''\  = \ f \((t, x, x', y, y')\)\)]],
  StyleBox["  with  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((a)\) = \[Gamma]\)]],
  ", ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y' \((a)\) = \[Delta]\)]],
  StyleBox[",  over the interval  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(a\  \[LessEqual] \ t\  \[LessEqual] \ b\)]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "at a discrete set of points.  "
}], "Text"],

Cell[BoxData[
    \(\(\(Runge4D[a0_, b0_, \[Alpha]_, \[Beta]_, \[Gamma]_, \[Delta]_, 
          m0_] := \[IndentingNewLine]Module[{a = a0, b = b0, j, 
            m = m0}, \[IndentingNewLine]h = \(b - a\)\/m; \ \
\[IndentingNewLine]T\  = \ 
            Table[\ a + \((j - 1)\) h, {j, 1, 
                m + 1}]; \ \[IndentingNewLine]Z = \ 
            Table[{{\[Alpha], \[Beta]}, {\[Gamma], \[Delta]}}, {j, 1, 
                m + 1}]; \ \ \[IndentingNewLine]For[\ j = 1, \ 
            j \[LessEqual] m, \ \(j++\), \[IndentingNewLine]k\_1\  = \ 
              h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\), Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\)]; \ \
\[IndentingNewLine]k\_2\  = \ 
              h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h\/2, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_1\/2]; \ \[IndentingNewLine]k\_3\  = \ 
              h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h\/2, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_2\/2]; \ \[IndentingNewLine]k\_4\  = \ 
              h\ \ F[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + h, Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                    k\_3]; \ \[IndentingNewLine]Z\_\(\(\[LeftDoubleBracket]\)\
\(j + 1\)\(\[RightDoubleBracket]\)\)\  = \ 
              Z\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + \
\(1\/6\) \((k\_1 + 2  k\_2 + 2  k\_3 + 
                      k\_4)\);\ \ ]; \ \[IndentingNewLine]Return[
            Transpose[{\(Transpose[Z\_\(\(\[LeftDoubleBracket]\)\(All, 1\)\(\
\[RightDoubleBracket]\)\)]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), \(Transpose[Z\_\(\(\[LeftDoubleBracket]\)\(All, \
2\)\(\[RightDoubleBracket]\)\)]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)}]];\ ];\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the frictionless model for the path of a baseball.  \n\t\t",
  Cell[BoxData[{
      \(x'' \((t)\)\  = \ 0\), "\n", 
      \(y'' \((t)\)\  = \ \(-\ g\)\)}]],
  "  \nCheck out this mathematical model for several cases.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 127;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 43;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 5.447778;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, w_}}]\  = \ {{v, 
            0}, {w, \(-g\)}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Green];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {1, 2}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Willie Stargell was the first player ever to hit a baseball out of \
Dodger stadium, with his 506-foot, 6 1/2-inch blast off Alan Foster in 1969, \
still the longest home run ever hit at Dodger stadium.  \n",
  StyleBox["Question.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Would this ball clear the outfield wall of the stadium ?  At x = 400 \
feet, the height is only about 80 feet high !\nThe next solution has the same \
initial velocity, but a slightly larger angle of 47 degrees."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 127;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 47;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 5.837241;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, w_}}]\  = \ {{v, 
            0}, {w, \(-g\)}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ListPlot[Zs, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Green];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {1, 2}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Willie Stargell was the first player ever to hit a baseball out of \
Dodger stadium, with his 506-foot, 6 1/2-inch blast off Alan Foster in 1969, \
still the longest home run ever hit at Dodger stadium.  \n",
  StyleBox["Question.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Would this ball clear the outfield wall of the stadium ?  At x = 400 \
feet, the height is only about 94 feet high !"
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 122;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 45;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 5.426243;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, w_}}]\  = \ {{v, 
            0}, {w, \(-g\)}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ListPlot[Zs, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Green];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {1, 2}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Willie Stargell was the first player ever to hit a baseball out of \
Dodger Stadium - and he did it twice, second time with a 470-foot shot off \
Andy Messersmith in 1973.  \n",
  StyleBox["Question.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Would this ball clear the outfield wall of the stadium ?  "
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 128;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 49;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 4.4;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, w_}}]\  = \ {{v, 
            0}, {w, \(-g\)}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ListPlot[Zs, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Green];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Mickey Mantle hit a ball May 22,1963:  370 feet from home plate and 115 \
feet above field level. \n",
  "This case gets",
  " close to the data point  (370, 115)."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 129;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 45;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 4.545;\)\ \ \), "\[IndentingNewLine]", 
    \(\(k = 0.30;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, w_}}]\  = \ {{v, 
            0}, {w, \(-g\)}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ListPlot[Zs, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Dick Allen hit a ball July 6,1974:   415 feet and an altitude of 85 \
feet.\n",
  "This case gets",
  " close to the data point  (415, 85)."
}], "Text"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " The above cases with no air resistance seem to fit the position of the \
final point. \nHowever, the initial speeds are  86.6,  86.6,  83.2,  87.3, \
and  88  miles per hour.  It is believed that a \"power hitter\" will hit the \
ball 120-136 mph. \nSince these initial speeds seem too low, models that \
include friction are more realistic and will be considered in the next \
examples."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the linear drag model for the path of a baseball.  \n\t\t",
  Cell[BoxData[{
      \(x'' \((t)\)\  = \ \(-\ k\)\ x' \((t)\)\), "\n", 
      \(y'' \((t)\)\  = \ \(-\ k\)\ y' \((t)\)\  - \ g\)}]],
  "  \nCheck out this mathematical model for several cases.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The coefficient  k = 0.25  has been chosen arbitrarily.  It does produce \
a higher altitude than the cases in Example 5."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 207;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 42;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 6.84889;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = 0.25;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ k\)\ v}, {w, \(-\ k\)\ w - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Willie Stargell was the first player ever to hit a baseball out of \
Dodger Stadium, with his 506-foot, 6 1/2-inch blast off Alan Foster in 1969 \
still the longest home run ever hit at the stadium.  \n",
  "This case gets",
  " close to the data point  (506.5, 0)."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 193;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 39;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 6.139;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = 0.25;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ k\)\ v}, {w, \(-\ k\)\ w - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Willie Stargell was the first player ever to hit a baseball out of \
Dodger Stadium - and he did it twice, the second time with a 470-foot shot \
off Andy Messersmith in 1973.  \n",
  "This case gets",
  " close to the data point  (470, 0)."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 187;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 44;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 4.65;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = 0.25;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ k\)\ v}, {w, \(-\ k\)\ w - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Mickey Mantle hit a ball May 22,1963:  370 feet from home plate and 115 \
feet above field level. \n",
  "This case gets",
  " close to the data point  (370, 115)."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 192;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 39;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 4.75;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = 0.25;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ k\)\ v}, {w, \(-\ k\)\ w - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Dick Allen hit a ball July 6,1974:   415 feet and an altitude of 85 \
feet.\n",
  "This case gets",
  " close to the data point  (415, 85)."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the quadratic drag model for the path of a baseball.  \n\t\t",
  Cell[BoxData[{
      \(x'' \((t)\)\  = \ \(-\ 
            k\)\ x' \((t)\)\ \@\(\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\)\(\ \ \)\)\), "\n", 
      \(y'' \((t)\)\  = \ \(\(\(-\ 
              k\)\ y' \((t)\)\ \@\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\)\)\(\ \)\(-\)\(\ \)\(g\)\(\ \ \)\)\)}]],
  "\nCheck out this mathematical model for several cases."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The coefficient  k = 0.002  has been chosen arbitrarily. "
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 208;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 43;\)\ \ \), "\n", 
    \(\(a = 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b = 6.47859;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = 0.002;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ 
                k\)\ v\ \@\(v\^2 + w\^2\)}, {w, \(-\ 
                  k\)\ w\ \@\(v\^2 + w\^2\) - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Willie Stargell was the first player ever to hit a baseball out of \
Dodger Stadium, with his 506-foot, 6 1/2-inch blast off Alan Foster in 1969 \
still the longest home run ever hit at the stadium.  \n",
  "This case gets",
  " close to the data point  (506.5, 0)."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 194;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 45;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 6.4087;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = 0.002;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ 
                k\)\ v\ \@\(v\^2 + w\^2\)}, {w, \(-\ 
                  k\)\ w\ \@\(v\^2 + w\^2\) - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Willie Stargell was the first player ever to hit a baseball out of \
Dodger Stadium - and he did it twice, the second time with a 470-foot shot \
off Andy Messersmith in 1973.  \n",
  "This case gets",
  " close to the data point  (470, 0)."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 190;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 42;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 4.175;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = 0.002;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ 
                k\)\ v\ \@\(v\^2 + w\^2\)}, {w, \(-\ 
                  k\)\ w\ \@\(v\^2 + w\^2\) - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Mickey Mantle hit a ball May 22,1963:  370 feet from home plate and 115 \
feet above field level. \n",
  "This case gets",
  " close to the data point  (370, 115)."
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 195;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 44;\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\ \ \), "\n", 
    \(\(b = 5.1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 32;\)\ \), "\n", 
    \(\(k = 0.002;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ 
                k\)\ v\ \@\(v\^2 + w\^2\)}, {w, \(-\ 
                  k\)\ w\ \@\(v\^2 + w\^2\) - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(\(Print["\<Final point x = \>", 
          NumberForm[
            Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, 1\)\(\
\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
          NumberForm[
            Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, 1\)\(\
\[RightDoubleBracket]\)\), \ {4, 1}]];\);\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Fact.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Dick Allen hit a ball July 6,1974:   415 feet and an altitude of 85 \
feet.\n",
  "This case gets",
  " close to the data point  (415, 85)."
}], "Text"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The model in Example 3 is the quadratic drag model.  The following is \
not.\n\t\t",
  Cell[BoxData[{
      \(x'' \((t)\)\  = \ \(-\ k\)\ \((x' \((t)\))\)\^2\), "\n", 
      \(y'' \((t)\)\  = \ \(-\ k\)\ \((y' \((t)\))\)\^2\  - g\)}]],
  "  \nLet's check it out."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Use the same initial conditions as in the first case in Example \
7.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\n", 
    \(\(Y\_0 = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(V = 217;\)\), "\[IndentingNewLine]", 
    \(\(\[Theta] = 43;\)\ \ \), "\n", 
    \(\(a = 0;\)\), "\[IndentingNewLine]", 
    \(\(b = 6.186;\)\ \ \), "\[IndentingNewLine]", 
    \(\(g = 35;\)\ \), "\n", 
    \(\(k = 0.002;\)\ \), "\[IndentingNewLine]", 
    \(\(n = 100;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(V\_x = 
        V\ Cos[\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(V\_y = 
        V\ Sin\ [\(\[Pi]\ \[Theta]\)\/180.0];\)\ \), "\[IndentingNewLine]", 
    \(\(F[
          t_, {{y_, v_}, {x_, 
              w_}}]\  = \ {{v, \(-\ k\)\ v\^2}, {w, \(-\ k\)\ w\^2 - 
              g}};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Zs = 
        Runge4D[a, b, X\_0, V\_x, Y\_0, V\_y, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ListPlot[Zs, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Angle  \[Theta] = \>", \[Theta], "\< degrees\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Initial speed = \>", V, "\< ft/sec  =  \>", 
        NumberForm[V\ 60. /88, \ 
          4], "\< miles/hr\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Final point x = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, \
1\)\(\[RightDoubleBracket]\)\), \ 4], "\<,  y = \>", 
        NumberForm[
          Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, \
1\)\(\[RightDoubleBracket]\)\), \ {4, 1}]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00175333 0.0147151 0.00285878 [
[.19914 .00222 -9 -9 ]
[.19914 .00222 9 0 ]
[.37448 .00222 -9 -9 ]
[.37448 .00222 9 0 ]
[.54981 .00222 -9 -9 ]
[.54981 .00222 9 0 ]
[.72514 .00222 -9 -9 ]
[.72514 .00222 9 0 ]
[.90048 .00222 -9 -9 ]
[.90048 .00222 9 0 ]
[.01131 .15765 -12 -4.5 ]
[.01131 .15765 0 4.5 ]
[.01131 .30059 -18 -4.5 ]
[.01131 .30059 0 4.5 ]
[.01131 .44353 -18 -4.5 ]
[.01131 .44353 0 4.5 ]
[.01131 .58647 -18 -4.5 ]
[.01131 .58647 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19914 .01472 m
.19914 .02097 L
s
[(100)] .19914 .00222 0 1 Mshowa
.37448 .01472 m
.37448 .02097 L
s
[(200)] .37448 .00222 0 1 Mshowa
.54981 .01472 m
.54981 .02097 L
s
[(300)] .54981 .00222 0 1 Mshowa
.72514 .01472 m
.72514 .02097 L
s
[(400)] .72514 .00222 0 1 Mshowa
.90048 .01472 m
.90048 .02097 L
s
[(500)] .90048 .00222 0 1 Mshowa
.125 Mabswid
.05888 .01472 m
.05888 .01847 L
s
.09394 .01472 m
.09394 .01847 L
s
.12901 .01472 m
.12901 .01847 L
s
.16408 .01472 m
.16408 .01847 L
s
.23421 .01472 m
.23421 .01847 L
s
.26928 .01472 m
.26928 .01847 L
s
.30434 .01472 m
.30434 .01847 L
s
.33941 .01472 m
.33941 .01847 L
s
.40954 .01472 m
.40954 .01847 L
s
.44461 .01472 m
.44461 .01847 L
s
.47968 .01472 m
.47968 .01847 L
s
.51474 .01472 m
.51474 .01847 L
s
.58488 .01472 m
.58488 .01847 L
s
.61994 .01472 m
.61994 .01847 L
s
.65501 .01472 m
.65501 .01847 L
s
.69008 .01472 m
.69008 .01847 L
s
.76021 .01472 m
.76021 .01847 L
s
.79528 .01472 m
.79528 .01847 L
s
.83034 .01472 m
.83034 .01847 L
s
.86541 .01472 m
.86541 .01847 L
s
.93554 .01472 m
.93554 .01847 L
s
.97061 .01472 m
.97061 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .15765 m
.03006 .15765 L
s
[(50)] .01131 .15765 1 0 Mshowa
.02381 .30059 m
.03006 .30059 L
s
[(100)] .01131 .30059 1 0 Mshowa
.02381 .44353 m
.03006 .44353 L
s
[(150)] .01131 .44353 1 0 Mshowa
.02381 .58647 m
.03006 .58647 L
s
[(200)] .01131 .58647 1 0 Mshowa
.125 Mabswid
.02381 .0433 m
.02756 .0433 L
s
.02381 .07189 m
.02756 .07189 L
s
.02381 .10048 m
.02756 .10048 L
s
.02381 .12907 m
.02756 .12907 L
s
.02381 .18624 m
.02756 .18624 L
s
.02381 .21483 m
.02756 .21483 L
s
.02381 .24342 m
.02756 .24342 L
s
.02381 .27201 m
.02756 .27201 L
s
.02381 .32918 m
.02756 .32918 L
s
.02381 .35777 m
.02756 .35777 L
s
.02381 .38636 m
.02756 .38636 L
s
.02381 .41494 m
.02756 .41494 L
s
.02381 .47212 m
.02756 .47212 L
s
.02381 .50071 m
.02756 .50071 L
s
.02381 .5293 m
.02756 .5293 L
s
.02381 .55788 m
.02756 .55788 L
s
.02381 .61506 m
.02756 .61506 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .02329 m
.04086 .04904 L
.05758 .07395 L
.07399 .09806 L
.09009 .1214 L
.10591 .14398 L
.12144 .16583 L
.13671 .18698 L
.15171 .20744 L
.16647 .22724 L
.18097 .24639 L
.19524 .26491 L
.20929 .28281 L
.22311 .30011 L
.23672 .31683 L
.25011 .33297 L
.26331 .34856 L
.27631 .3636 L
.28912 .3781 L
.30175 .39208 L
.3142 .40554 L
.32647 .4185 L
.33858 .43097 L
.35051 .44294 L
.36229 .45444 L
.37392 .46546 L
.38539 .47603 L
.39671 .48613 L
.40789 .49578 L
.41892 .50499 L
.42982 .51376 L
.44059 .52209 L
.45122 .52999 L
.46173 .53747 L
.47212 .54453 L
.48238 .55118 L
.49252 .55741 L
.50255 .56323 L
.51246 .56865 L
.52227 .57367 L
.53196 .57829 L
.54155 .58251 L
.55103 .58634 L
.56042 .58977 L
.5697 .59282 L
.57889 .59548 L
.58798 .59774 L
.59698 .59963 L
.60588 .60113 L
.6147 .60224 L
Mistroke
.62343 .60297 L
.63207 .60332 L
.64063 .60328 L
.64911 .60287 L
.6575 .60206 L
.66582 .60088 L
.67405 .59931 L
.68221 .59736 L
.6903 .59502 L
.69831 .59229 L
.70625 .58917 L
.71412 .58566 L
.72191 .58176 L
.72964 .57747 L
.7373 .57278 L
.7449 .56769 L
.75243 .56219 L
.75989 .5563 L
.7673 .54999 L
.77464 .54327 L
.78192 .53613 L
.78914 .52857 L
.7963 .52059 L
.8034 .51218 L
.81045 .50333 L
.81743 .49404 L
.82437 .48431 L
.83125 .47412 L
.83807 .46347 L
.84485 .45236 L
.85157 .44078 L
.85824 .42871 L
.86486 .41616 L
.87143 .40311 L
.87795 .38955 L
.88442 .37547 L
.89085 .36087 L
.89723 .34573 L
.90356 .33005 L
.90985 .3138 L
.91609 .29697 L
.92229 .27956 L
.92845 .26155 L
.93456 .24292 L
.94063 .22365 L
.94666 .20373 L
.95264 .18315 L
.95859 .16187 L
.9645 .13988 L
.97036 .11716 L
Mistroke
.97619 .09369 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000mOol5
0002Ool20004Ool2000POol40003Ool20004Ool2000ROol20004Ool20004Ool2000SOol30002Ool2
0004Ool2000QOol20004Ool20004Ool2000FOol003moo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol07Goo00<007ooOol00goo00@007ooOol0009oo`04001oogoo000POol01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo000SOol01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo01eoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol001Eoo`00?goo00D007oo
Oomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0NOol00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol0029oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol07Woo1@0000Eo
o`00Oomoo`00009oo`04001oogoo000ROol01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo
01=oo`00?goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0OOol01@00Oomoogoo
00000Woo00@007ooOol0009oo`03001oogoo025oo`04001oogoo0002Ool01000Oomoo`000Woo00<0
07ooOol07Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0087oo0P000goo00@007oo
Ool0009oo`04001oogoo000EOol003moo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool07Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0087oo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`008Goo00<007oo00000Woo00@007ooOol0009oo`04001oogoo000P
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol001Eoo`00?Woo0P0017oo0P0017oo0P00
8Goo0P0017oo0P0017oo0P008Woo0P0017oo0P0017oo0P008goo0P000goo0P0017oo0P008Goo0`00
0goo0P0017oo0P005Woo003oOolQOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo
2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`003Wooo`004`00000EOol0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool001Eoo`0301moogoo02eoo`03001oogoo
02aoo`03001oogoo02eoo`03001oogoo02eoo`03001oogoo02aoo`03001oogoo01Yoo`005Goo00<0
000OOol0ogoo2Goo000EOol00`0001moo`3oOol9Ool001Eoo`03001oo`0O0?moo`Uoo`005Goo00@0
07ooOol07omoo`Qoo`005Goo00D007ooOomoo`0O0?moo`Moo`005Goo0P000Woo00<07gooOol0ogoo
1Goo000EOol00`00Oomoo`02Ool00`0OOomoo`3oOol4Ool001Eoo`03001oogoo00=oo`0301moogoo
0?moo`=oo`005Goo00<007ooOol00goo00<07gooOol0ogoo0goo000EOol00`00Oomoo`04Ool00`0O
Oomoo`3oOol2Ool001Eoo`03001oogoo00Aoo`0301moogoo0?moo`9oo`005Goo00<007ooOol01Goo
00<07gooOol0ogoo0Goo000EOol00`00Oomoo`05Ool00`0OOomoo`3oOol1Ool001Eoo`8000Moo`03
01moogoo0?moo`005Goo00<007ooOol01goo00<07gooOol0oWoo000EOol00`00Oomoo`07Ool00`0O
Oomoo`3nOol001Eoo`03001oogoo00Qoo`0301moogoo0?eoo`005Goo00<007ooOol02Goo00<07goo
Ool0o7oo000EOol00`00Oomoo`0:Ool00`0OOomoo`3kOol001Eoo`03001oogoo00Yoo`0301moogoo
0?=oo`0301moogoo00Eoo`005Goo0P0037oo00<07gooOol0lWoo00<07gooOol01Goo000EOol00`00
Oomoo`0<Ool00`0OOomoo`3`Ool00`0OOomoo`06Ool001Eoo`03001oogoo00aoo`0301moogoo0?1o
o`0301moogoo00Ioo`005Goo00<007ooOol03Goo00<07gooOol0kgoo00<07gooOol01Woo000EOol0
0`00Oomoo`0>Ool00`0OOomoo`3]Ool00`0OOomoo`07Ool001Eoo`03001oogoo00ioo`0301moogoo
0>eoo`0301moogoo00Moo`005Goo00<007ooOol03goo00<07gooOol0k7oo00<07gooOol01goo000E
Ool00`00Oomoo`0@Ool00`0OOomoo`3[Ool00`0OOomoo`07Ool001Eoo`80015oo`0301moogoo0>]o
o`0301moogoo00Moo`005Goo00<007ooOol04Goo00<07gooOol0jGoo00<07gooOol027oo000EOol0
0`00Oomoo`0BOol00`0OOomoo`3XOol00`0OOomoo`08Ool001Eoo`03001oogoo019oo`0301moogoo
0>Qoo`0301moogoo00Qoo`005Goo00<007ooOol04goo00<07gooOol0igoo00<07gooOol027oo000E
Ool00`00Oomoo`0DOol00`0OOomoo`3UOol00`0OOomoo`09Ool000Qoo`8000Aoo`8000Eoo`03001o
ogoo01Aoo`0301moogoo0>Eoo`0301moogoo00Uoo`001goo00@007ooOol0009oo`04001oogoo0004
Ool00`00Oomoo`0EOol00`0OOomoo`3TOol00`0OOomoo`09Ool000Yoo`04001oogoo0002Ool00`00
Oomoo`02Ool3000FOol00`0OOomoo`3ROol00`0OOomoo`0:Ool000Qoo`8000=oo`04001oogoo0004
Ool00`00Oomoo`0FOol00`0OOomoo`3ROol00`0OOomoo`0:Ool000Qoo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`0GOol00`0OOomoo`3QOol00`0OOomoo`0:Ool000Qoo`<000=oo`8000Eo
o`03001oogoo01Qoo`0301moogoo0>1oo`0301moogoo00Yoo`005Goo00<007ooOol06Goo00<07goo
Ool0ggoo00<07gooOol02Woo000EOol00`00Oomoo`0JOol00`0OOomoo`3MOol00`0OOomoo`0;Ool0
01Eoo`03001oogoo01Yoo`0301moogoo0=eoo`0301moogoo00]oo`005Goo00<007ooOol06goo00<0
7gooOol0g7oo00<07gooOol02goo000EOol2000MOol00`0OOomoo`3KOol00`0OOomoo`0;Ool001Eo
o`03001oogoo01eoo`0301moogoo0=Uoo`0301moogoo00aoo`005Goo00<007ooOol07Goo00<07goo
Ool0fGoo00<07gooOol037oo000EOol00`00Oomoo`0NOol00`0OOomoo`3HOol00`0OOomoo`0<Ool0
01Eoo`03001oogoo01moo`0301moogoo0=Ioo`0301moogoo00eoo`005Goo00<007ooOol07goo00<0
7gooOol0eWoo00<07gooOol03Goo000EOol00`00Oomoo`0POol00`0OOomoo`3EOol00`0OOomoo`0=
Ool001Eoo`03001oogoo025oo`0301moogoo0==oo`0301moogoo00ioo`005Goo0P008goo00<07goo
Ool0dWoo00<07gooOol03Woo000EOol00`00Oomoo`0ROol00`0OOomoo`3AOol00`0OOomoo`0?Ool0
01Eoo`03001oogoo02=oo`0301moogoo0=1oo`0301moogoo00moo`005Goo00<007ooOol097oo00<0
7gooOol0cgoo00<07gooOol03goo000EOol00`00Oomoo`0UOol00`0OOomoo`3>Ool00`0OOomoo`0?
Ool001Eoo`03001oogoo02Ioo`0301moogoo0<aoo`0301moogoo011oo`005Goo00<007ooOol09Woo
00<07gooOol0c7oo00<07gooOol047oo000EOol2000XOol00`0OOomoo`3;Ool00`0OOomoo`0@Ool0
01Eoo`03001oogoo02Qoo`0301moogoo0<Yoo`0301moogoo011oo`005Goo00<007ooOol0:Goo00<0
7gooOol0b7oo00<07gooOol04Goo000EOol00`00Oomoo`0ZOol00`0OOomoo`37Ool00`0OOomoo`0A
Ool001Eoo`03001oogoo02Yoo`0301moogoo0<Ioo`0301moogoo019oo`005Goo00<007ooOol0:goo
00<07gooOol0aGoo00<07gooOol04Woo000EOol00`00Oomoo`0/Ool00`0OOomoo`34Ool00`0OOomo
o`0BOol001Eoo`03001oogoo02eoo`0301moogoo0<9oo`0301moogoo01=oo`005Goo0P00;Woo00<0
7gooOol0`Woo00<07gooOol04goo000EOol00`00Oomoo`0^Ool00`0OOomoo`30Ool00`0OOomoo`0D
Ool001Eoo`03001oogoo02ioo`0301moogoo0<1oo`0301moogoo01Aoo`005Goo00<007ooOol0;goo
00<07gooOol0_goo00<07gooOol057oo000EOol00`00Oomoo`0`Ool00`0OOomoo`2nOol00`0OOomo
o`0DOol001Eoo`03001oogoo035oo`0301moogoo0;aoo`0301moogoo01Eoo`0000=oo`0000000`00
0Woo0P0017oo0P001Goo00<007ooOol0<Goo00<07gooOol0_7oo00<07gooOol05Goo0003Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo039oo`0301moogoo0;]o
o`0301moogoo01Eoo`000goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool3
000cOol00`0OOomoo`2jOol00`0OOomoo`0EOol000=oo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00<007ooOol0=7oo00<07gooOol0^7oo00<07gooOol05Woo0003Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo03Eoo`0301moogoo0;Mo
o`0301moogoo01Ioo`000Woo0P0017oo0P0017oo0P001Goo00<007ooOol0=Woo00<07gooOol0]Goo
00<07gooOol05goo000EOol00`00Oomoo`0gOol00`0OOomoo`2dOol00`0OOomoo`0GOol001Eoo`03
001oogoo03Qoo`0301moogoo0;=oo`0301moogoo01Moo`005Goo00<007ooOol0>7oo00<07gooOol0
/Woo00<07gooOol067oo000EOol00`00Oomoo`0iOol00`0OOomoo`2aOol00`0OOomoo`0HOol001Eo
o`8003Yoo`0301moogoo0;1oo`0301moogoo01Uoo`005Goo00<007ooOol0>Woo00<07gooOol0[goo
00<07gooOol06Goo000EOol00`00Oomoo`0kOol00`0OOomoo`2^Ool00`0OOomoo`0IOol001Eoo`03
001oogoo03aoo`0301moogoo0:aoo`0301moogoo01Yoo`005Goo00<007ooOol0?Goo00<07gooOol0
Zgoo00<07gooOol06Woo000EOol00`00Oomoo`0nOol00`0OOomoo`2ZOol00`0OOomoo`0JOol001Eo
o`03001oogoo03moo`0301moogoo0:Qoo`0301moogoo01]oo`005Goo0P00@Goo00<07gooOol0Ygoo
00<07gooOol06goo000EOol00`00Oomoo`11Ool00`0OOomoo`2UOol00`0OOomoo`0LOol001Eoo`03
001oogoo049oo`0301moogoo0:Aoo`0301moogoo01aoo`005Goo00<007ooOol0@goo00<07gooOol0
XWoo00<07gooOol07Goo000EOol00`00Oomoo`14Ool00`0OOomoo`2QOol00`0OOomoo`0MOol001Eo
o`03001oogoo04Aoo`0301moogoo0:1oo`0301moogoo01ioo`005Goo00<007ooOol0AGoo00<07goo
Ool0Wgoo00<07gooOol07Woo000EOol00`00Oomoo`16Ool00`0OOomoo`2MOol00`0OOomoo`0OOol0
01Eoo`8004Qoo`0301moogoo09aoo`0301moogoo01moo`005Goo00<007ooOol0B7oo00<07gooOol0
VWoo00<07gooOol087oo000EOol00`00Oomoo`19Ool00`0OOomoo`2IOol00`0OOomoo`0POol001Eo
o`03001oogoo04Yoo`0301moogoo09Qoo`0301moogoo021oo`005Goo00<007ooOol0Bgoo00<07goo
Ool0UWoo00<07gooOol08Goo000EOol00`00Oomoo`1<Ool00`0OOomoo`2EOol00`0OOomoo`0QOol0
01Eoo`03001oogoo04eoo`0301moogoo09=oo`0301moogoo029oo`005Goo00<007ooOol0CWoo00<0
7gooOol0TWoo00<07gooOol08Woo000EOol2001?Ool00`0OOomoo`2AOol00`0OOomoo`0SOol001Eo
o`03001oogoo04moo`0301moogoo091oo`0301moogoo02=oo`005Goo00<007ooOol0D7oo0P0OSgoo
00<07gooOol097oo000EOol00`00Oomoo`1BOol00`0OOomoo`2<Ool00`0OOomoo`0TOol001Eoo`03
001oogoo05=oo`0301moogoo08Yoo`0301moogoo02Eoo`005Goo00<007ooOol0E7oo00<07gooOol0
R7oo00<07gooOol09Woo00000goo000000030002Ool20004Ool20005Ool00`00Oomoo`1EOol00`0O
Oomoo`27Ool00`0OOomoo`0VOol000=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007oo
Ool00Woo00<007ooOol0EGoo00<07gooOol0QWoo00<07gooOol09goo0003Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00<007ooOol00Woo0`00EWoo00<07gooOol0Q7oo00<07gooOol0:7oo0003Ool0
0`00Oomoo`02Ool20003Ool01000Oomoo`0017oo00<007ooOol0Egoo00<07gooOol0Pgoo00<07goo
Ool0:7oo0003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0F7oo
00<07gooOol0PGoo00<07gooOol0:Goo0002Ool20004Ool30003Ool20005Ool00`00Oomoo`1IOol0
0`0OOomoo`1oOol00`0OOomoo`0ZOol001Eoo`03001oogoo05Yoo`0301moogoo07ioo`0301moogoo
02Yoo`005Goo00<007ooOol0Fgoo00<07gooOol0O7oo00<07gooOol0:goo000EOol00`00Oomoo`1L
Ool00`0OOomoo`1kOol00`0OOomoo`0[Ool001Eoo`03001oogoo05eoo`0301moogoo07Uoo`0301mo
ogoo02aoo`005Goo0P00Ggoo00<07gooOol0N7oo00<07gooOol0;7oo000EOol00`00Oomoo`1OOol0
0`0OOomoo`1fOol00`0OOomoo`0]Ool001Eoo`03001oogoo061oo`807gIoo`0301moogoo02eoo`00
5Goo00<007ooOol0HWoo00<07gooOol0LWoo00<07gooOol0;Woo000EOol00`00Oomoo`1SOol00`0O
Oomoo`1`Ool00`0OOomoo`0_Ool001Eoo`03001oogoo06Aoo`0301moogoo06moo`0301moogoo02mo
o`005Goo00<007ooOol0IGoo00<07gooOol0KGoo00<07gooOol0<7oo000EOol2001WOol00`0OOomo
o`1[Ool00`0OOomoo`0aOol001Eoo`03001oogoo06Moo`0301moogoo06Uoo`0301moogoo039oo`00
5Goo00<007ooOol0J7oo00<07gooOol0Igoo00<07gooOol0<goo000EOol00`00Oomoo`1YOol201mW
Ool00`0OOomoo`0cOol001Eoo`03001oogoo06]oo`0301moogoo06=oo`0301moogoo03Aoo`005Goo
00<007ooOol0K7oo0P0OHWoo00<07gooOol0=Goo000EOol00`00Oomoo`1^Ool00`0OOomoo`1NOol0
0`0OOomoo`0fOol001Eoo`03001oogoo06moo`807eeoo`0301moogoo03Moo`005Goo0P00LWoo00<0
7gooOol0FGoo00<07gooOol0>7oo000EOol00`00Oomoo`1bOol201mHOol00`0OOomoo`0iOol001Eo
o`03001oogoo07Aoo`0301moogoo05Aoo`0301moogoo03Yoo`005Goo00<007ooOol0MGoo0P0ODgoo
00<07gooOol0>goo000EOol00`00Oomoo`1gOol00`0OOomoo`1?Ool00`0OOomoo`0lOol001Eoo`03
001oogoo07Qoo`807dioo`0301moogoo03eoo`005Goo00<007ooOol0NWoo00<07gooOol0BWoo00<0
7gooOol0?Woo000EOol00`00Oomoo`1kOol00`0OOomoo`18Ool00`0OOomoo`0oOol001Eoo`8007eo
o`807dIoo`807d9oo`005Goo00<007ooOol0OWoo0P0O@goo00<07gooOol0@Woo000EOol00`00Oomo
o`20Ool201m0Ool00`0OOomoo`13Ool001Eoo`03001oogoo089oo`807caoo`807dIoo`005Goo00<0
07ooOol0Q7oo0`0O=goo0P0OB7oo000EOol00`00Oomoo`27Ool00`0OOomoo`0bOol201m:Ool00003
Ool00000008000=oo`8000Aoo`8000Eoo`03001oogoo08Qoo`807c1oo`807daoo`0000=oo`00Ool0
17oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`2:Ool201l/Ool201m>Ool0009oo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo0`00S7oo0P0O:7oo0P0OD7oo0003Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo08ioo`D07b1oo`<0
7e9oo`0000Eoo`00Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0Tgoo
0`0O6goo0P0OEGoo0002Ool20004Ool20004Ool20005Ool00`00Oomoo`2FOol501lBOol401mGOol0
01Eoo`03001oogoo09]ooa807e]oo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9
Ool001Eoo`800?moo`Yoo`005Goo00<007ooOol0ogoo2Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-44.8648, -16.1934, 2.09628, \
1.28568}}],

Cell[BoxData[
    InterpretationBox[\("Angle  \[Theta] = "\[InvisibleSpace]43\
\[InvisibleSpace]" degrees"\),
      SequenceForm[ "Angle  \[Theta] = ", 43, " degrees"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Initial speed = \"\>", "\[InvisibleSpace]", "217", 
        "\[InvisibleSpace]", "\<\" ft/sec  =  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"148.\"\>",
            147.95454545454544,
            AutoDelete->True],
          (NumberForm[ #, 4]&)], "\[InvisibleSpace]", "\<\" miles/hr\"\>"}],
      SequenceForm[ "Initial speed = ", 217, " ft/sec  =  ", 
        NumberForm[ 147.95454545454544, 4], " miles/hr"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Final point x = \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"543.2\"\>",
            543.18260410697599,
            AutoDelete->True],
          (NumberForm[ #, 4]&)], "\[InvisibleSpace]", "\<\",  y = \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"27.6\"\>",
            27.62511813527744,
            AutoDelete->True],
          (NumberForm[ #, {4, 1}]&)]}],
      SequenceForm[ "Final point x = ", 
        NumberForm[ 543.18260410697599, 4], ",  y = ", 
        NumberForm[ 27.62511813527744, {4, 1}]],
      Editable->False]], "Print"]
}, Open  ]],

Cell["Observe that this is different from our previous result.", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      StyleBox[\(\(Print["Angle  \[Theta] = ", \[Theta], " degrees"];\)\n
        \(Print["Initial speed = ", V, " ft/sec  =  ", 
            NumberForm[V\ 60. /88, \ 4], " miles/hr"];\)\n
        \(Print["Final point x = ", 
            NumberForm[
              Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 1, 1\)\(\
\[RightDoubleBracket]\)\), \ 4], ",  y = ", 
            NumberForm[
              Z\_\(\(\[LeftDoubleBracket]\)\(\(-1\), 2, 1\)\(\
\[RightDoubleBracket]\)\), \ {4, 1}]];\)\),
        FontWeight->"Bold"]]],
  "\n\n",
  StyleBox["\t Angle  \[Theta] = \[InvisibleSpace]42\[InvisibleSpace] degrees\
\n\t \n\t Initial speed = \[InvisibleSpace]207\[InvisibleSpace] ft/sec  =  \
\[InvisibleSpace]141.1\[InvisibleSpace] miles/hr\n\t \n\t Final point x = \
\[InvisibleSpace]504.3\[InvisibleSpace],  y = \[InvisibleSpace]0.",
    FontFamily->"Courier New"]
}], "Text"],

Cell[TextData[{
  "\tTo convince ourselves that the model in Example 3 is correct, recall \
that velocity is a vector valued function, and its magnitude is  ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            StyleBox[\(V\&\[RightVector]\),
              FontWeight->"Bold"], \((t)\)}], " ", "=", 
          " ", \(\@\(\((x' \((t)\))\)\^2 + \((y' \((t)\))\)\^2\)\)}]}]]],
  ".  \nThe tangent vector to the curve is  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(T\&\[RightVector]\),
            FontWeight->"Bold"], \((t)\)}], " ", "=", 
        " ", \({\(x' \((t)\)\)\/\(\(\ \)\(\@\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\)\)\), \(x' \((t)\)\)\/\(\(\ \)\(\@\(\((x' \((t)\))\)\^2 + \
\((y' \((t)\))\)\^2\)\)\)}\)}]]],
  ",  and the component of air resistance in the direction of the x-axis is  \
\n",
  Cell[BoxData[
      \(\(-\ 
          k\) \(\(x' \((t)\)\)\/\(\(\ \)\(\@\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\)\)\)\) \((\@\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\))\)\^2\)]],
  "  which simplifies to be  ",
  Cell[BoxData[
      \(\(-\ 
          k\)\ x' \((t)\)\ \@\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\)\)]],
  ".  \nSimilarly, the component of air resistance in the direction of the \
y-axis is  ",
  Cell[BoxData[
      \(\(-\ 
          k\)\ y' \((t)\)\ \@\(\((x' \((t)\))\)\^2 + \((y' \
\((t)\))\)\^2\)\)]],
  ".  \nHence, the model in Example 7 is correct.  "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Projectile Motion",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/ProjectileMotionBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Projectile Motion",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/ProjectileMotionBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 336, 11, 35, "Text"],
Cell[2115, 66, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3594, 118, 1375, 39, 295, "Text"],
Cell[4972, 159, 713, 23, 198, "Text"],
Cell[5688, 184, 1012, 38, 125, "Text"],
Cell[6703, 224, 1067, 22, 147, "Text"],
Cell[7773, 248, 1561, 51, 263, "Text"],
Cell[9337, 301, 632, 22, 33, "Text"],
Cell[9972, 325, 658, 23, 33, "Text"],
Cell[10633, 350, 959, 29, 109, "Text"],
Cell[11595, 381, 1612, 24, 309, "Input"],
Cell[13210, 407, 475, 10, 74, "Text"],

Cell[CellGroupData[{
Cell[13710, 421, 101, 2, 33, "Text"],
Cell[13814, 425, 107, 3, 33, "Text"],
Cell[13924, 430, 1646, 29, 470, "Input"],
Cell[15573, 461, 88, 3, 33, "Text"],
Cell[15664, 466, 188, 3, 51, "Input"],
Cell[15855, 471, 46, 0, 33, "Text"],
Cell[15904, 473, 763, 15, 170, "Input"],
Cell[16670, 490, 68, 0, 33, "Text"],
Cell[16741, 492, 2123, 44, 504, "Input"],
Cell[18867, 538, 76, 0, 33, "Text"],
Cell[18946, 540, 273, 5, 90, "Input"],
Cell[19222, 547, 162, 4, 52, "Text"],
Cell[19387, 553, 1143, 21, 290, "Input"],
Cell[20533, 576, 87, 3, 33, "Text"]
}, Closed]],
Cell[20635, 582, 602, 14, 90, "Text"],

Cell[CellGroupData[{
Cell[21262, 600, 101, 2, 33, "Text"],
Cell[21366, 604, 107, 3, 33, "Text"],
Cell[21476, 609, 1730, 31, 518, "Input"],
Cell[23209, 642, 88, 3, 33, "Text"],
Cell[23300, 647, 188, 3, 51, "Input"],
Cell[23491, 652, 46, 0, 33, "Text"],
Cell[23540, 654, 763, 15, 170, "Input"],
Cell[24306, 671, 2593, 53, 626, "Input"],
Cell[26902, 726, 76, 0, 33, "Text"],
Cell[26981, 728, 273, 5, 90, "Input"],
Cell[27257, 735, 162, 4, 52, "Text"],
Cell[27422, 741, 1161, 21, 291, "Input"],
Cell[28586, 764, 143, 3, 52, "Text"],
Cell[28732, 769, 60, 0, 33, "Text"],
Cell[28795, 771, 363, 6, 70, "Input"]
}, Closed]],
Cell[29173, 780, 639, 15, 93, "Text"],

Cell[CellGroupData[{
Cell[29837, 799, 101, 2, 33, "Text"],
Cell[29941, 803, 2369, 49, 578, "Input"],
Cell[32313, 854, 162, 4, 52, "Text"],
Cell[32478, 860, 1127, 20, 291, "Input"],
Cell[33608, 882, 221, 5, 71, "Text"],
Cell[33832, 889, 515, 14, 36, "Text"],
Cell[34350, 905, 1101, 20, 337, "Input"],
Cell[35454, 927, 127, 5, 33, "Text"],
Cell[35584, 934, 381, 6, 90, "Input"],
Cell[35968, 942, 123, 5, 33, "Text"],
Cell[36094, 949, 622, 11, 146, "Input"],
Cell[36719, 962, 202, 8, 33, "Text"],
Cell[36924, 972, 204, 6, 71, "Text"],
Cell[37131, 980, 1673, 34, 457, "Input"],
Cell[38807, 1016, 440, 12, 33, "Text"],
Cell[39250, 1030, 280, 8, 71, "Text"],
Cell[39533, 1040, 2201, 44, 576, "Input"],
Cell[41737, 1086, 120, 2, 33, "Text"],
Cell[41860, 1090, 1508, 26, 387, "Input"],
Cell[43371, 1118, 151, 5, 33, "Text"],
Cell[43525, 1125, 162, 4, 52, "Text"],
Cell[43690, 1131, 1231, 22, 292, "Input"],
Cell[44924, 1155, 173, 4, 52, "Text"],
Cell[45100, 1161, 65, 0, 33, "Text"],
Cell[45168, 1163, 594, 11, 130, "Input"],
Cell[45765, 1176, 215, 6, 71, "Text"],
Cell[45983, 1184, 1737, 31, 518, "Input"],
Cell[47723, 1217, 88, 3, 33, "Text"],
Cell[47814, 1222, 188, 3, 51, "Input"],
Cell[48005, 1227, 46, 0, 33, "Text"],
Cell[48054, 1229, 729, 14, 150, "Input"],
Cell[48786, 1245, 76, 0, 33, "Text"],
Cell[48865, 1247, 377, 7, 70, "Input"],
Cell[49245, 1256, 166, 5, 71, "Text"]
}, Closed]],
Cell[49426, 1264, 608, 16, 93, "Text"],

Cell[CellGroupData[{
Cell[50059, 1284, 101, 2, 33, "Text"],
Cell[50163, 1288, 100, 3, 33, "Text"],
Cell[50266, 1293, 1751, 31, 518, "Input"],
Cell[52020, 1326, 88, 3, 33, "Text"],
Cell[52111, 1331, 188, 3, 51, "Input"],
Cell[52302, 1336, 46, 0, 33, "Text"],
Cell[52351, 1338, 763, 15, 170, "Input"],
Cell[53117, 1355, 118, 3, 52, "Text"],
Cell[53238, 1360, 213, 4, 30, "Input"],
Cell[53454, 1366, 55, 0, 33, "Text"],
Cell[53512, 1368, 255, 9, 71, "Text"],
Cell[53770, 1379, 907, 20, 224, "Input"],
Cell[54680, 1401, 278, 9, 52, "Text"],
Cell[54961, 1412, 316, 8, 42, "Input"],
Cell[55280, 1422, 57, 0, 33, "Text"]
}, Closed]],
Cell[55352, 1425, 1274, 36, 272, "Text"],
Cell[56629, 1463, 632, 22, 33, "Text"],
Cell[57264, 1487, 1312, 42, 109, "Text"],
Cell[58579, 1531, 1987, 30, 311, "Input"],
Cell[60569, 1563, 345, 9, 88, "Text"],

Cell[CellGroupData[{
Cell[60939, 1576, 101, 2, 33, "Text"],
Cell[61043, 1580, 1530, 33, 378, "Input"],
Cell[62576, 1615, 621, 13, 71, "Text"],
Cell[63200, 1630, 1550, 34, 378, "Input"],
Cell[64753, 1666, 526, 12, 52, "Text"],
Cell[65282, 1680, 1580, 35, 398, "Input"],
Cell[66865, 1717, 437, 11, 52, "Text"],
Cell[67305, 1730, 1545, 34, 378, "Input"],
Cell[68853, 1766, 276, 8, 52, "Text"],
Cell[69132, 1776, 1595, 35, 398, "Input"],
Cell[70730, 1813, 252, 8, 52, "Text"],
Cell[70985, 1823, 501, 10, 71, "Text"]
}, Closed]],
Cell[71501, 1836, 383, 9, 85, "Text"],

Cell[CellGroupData[{
Cell[71909, 1849, 101, 2, 33, "Text"],
Cell[72013, 1853, 236, 6, 33, "Text"],
Cell[72252, 1861, 1598, 35, 398, "Input"],
Cell[73853, 1898, 378, 9, 52, "Text"],
Cell[74234, 1909, 1596, 35, 398, "Input"],
Cell[75833, 1946, 353, 9, 52, "Text"],
Cell[76189, 1957, 1595, 35, 398, "Input"],
Cell[77787, 1994, 276, 8, 52, "Text"],
Cell[78066, 2004, 1595, 35, 398, "Input"],
Cell[79664, 2041, 252, 8, 52, "Text"]
}, Closed]],
Cell[79931, 2052, 554, 13, 86, "Text"],

Cell[CellGroupData[{
Cell[80510, 2069, 101, 2, 33, "Text"],
Cell[80614, 2073, 172, 5, 33, "Text"],
Cell[80789, 2080, 1678, 37, 402, "Input"],
Cell[82470, 2119, 378, 9, 71, "Text"],
Cell[82851, 2130, 1675, 37, 402, "Input"],
Cell[84529, 2169, 353, 9, 52, "Text"],
Cell[84885, 2180, 1674, 37, 402, "Input"],
Cell[86562, 2219, 276, 8, 52, "Text"],
Cell[86841, 2229, 1685, 37, 402, "Input"],
Cell[88529, 2268, 252, 8, 52, "Text"]
}, Open  ]],
Cell[88796, 2279, 380, 10, 88, "Text"],

Cell[CellGroupData[{
Cell[89201, 2293, 101, 2, 33, "Text"],
Cell[89305, 2297, 92, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[89422, 2304, 1599, 35, 399, "Input"],
Cell[91024, 2341, 16107, 471, 186, 4720, 326, "GraphicsData", "PostScript", \
"Graphics"],
Cell[107134, 2814, 202, 4, 25, "Print"],
Cell[107339, 2820, 536, 11, 25, "Print"],
Cell[107878, 2833, 670, 17, 25, "Print"]
}, Open  ]],
Cell[108563, 2853, 72, 0, 33, "Text"],
Cell[108638, 2855, 912, 20, 186, "Text"],
Cell[109553, 2877, 1471, 38, 129, "Text"]
}, Closed]],
Cell[111039, 2918, 158, 3, 32, "Text"],
Cell[111200, 2923, 581, 18, 33, "Text"],
Cell[111784, 2943, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

