(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    152611,       4832]*)
(*NotebookOutlinePosition[    153277,       4855]*)
(*  CellTagsIndexPosition[    153233,       4851]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Harvesting Model",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe exponential model  ",
  Cell[BoxData[
      \(y'\  = \ a\ y\)]],
  "  is used to study uninhibited population growth and solution is the \
exponential function  ",
  Cell[BoxData[
      \(y \((t)\)\  = \ c\ \[ExponentialE]\^\(a\ t\)\)]],
  ".  When the term  ",
  Cell[BoxData[
      \(\(-\ b\)\ y\^2\)]],
  " is added we obtain the logistic differential equation which is used to \
model inhibited population growth or bounded population growth.  The logistic \
differential equation is \n\n\t\t\t",
  Cell[BoxData[
      \(y'\  = \ a\ y\  - \ b\ y\^2\)]],
  ".  \n\nOne form of the solution is  \n\n\t\t\t",
  Cell[BoxData[
      \(y \((t)\)\  = \ 
        a\/\(b\  + \ \((a\/y\_0\  - \ b)\) \[ExponentialE]\^\(\(-a\)\ \
t\)\)\)]],
  ".  \n\t\t\t\nThe terms have been carefully determined so that the initial \
condition is  \n\n\t\t\t",
  Cell[BoxData[
      \(y \((0)\) = y\_0\)]],
  ". \n\nThe limiting value  ",
  StyleBox["L",
    FontFamily->"Courier New"],
  "  of  ",
  StyleBox["y(t)",
    FontFamily->"Courier New"],
  "  is given by  \n\t\n\t\t\t",
  Cell[BoxData[
      \(L\  = \ \(lim\+\(t \[Rule] \[Infinity]\)\ y \((t)\)\  = \ a\/b\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "The graph is the so called \"S-shaped\" curve. The choice of parameters  \
",
  Cell[BoxData[
      \(a \[Rule] 0.01, b \[Rule] 0.00001, y\_0 \[Rule] 100\)]],
  "  creates the curve shown below.  \n\n\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.0147151 0.000588844 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .13248 -18 -4.5 ]
[.01131 .13248 0 4.5 ]
[.01131 .25025 -18 -4.5 ]
[.01131 .25025 0 4.5 ]
[.01131 .36802 -18 -4.5 ]
[.01131 .36802 0 4.5 ]
[.01131 .48579 -18 -4.5 ]
[.01131 .48579 0 4.5 ]
[.01131 .60356 -24 -4.5 ]
[.01131 .60356 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(200)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(400)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(600)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(800)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1000)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .13248 m
.03006 .13248 L
s
[(200)] .01131 .13248 1 0 Mshowa
.02381 .25025 m
.03006 .25025 L
s
[(400)] .01131 .25025 1 0 Mshowa
.02381 .36802 m
.03006 .36802 L
s
[(600)] .01131 .36802 1 0 Mshowa
.02381 .48579 m
.03006 .48579 L
s
[(800)] .01131 .48579 1 0 Mshowa
.02381 .60356 m
.03006 .60356 L
s
[(1000)] .01131 .60356 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.02381 .0736 m
.06244 .09885 L
.10458 .13602 L
.14415 .18088 L
.18221 .23234 L
.22272 .29315 L
.26171 .35308 L
.30316 .41283 L
.34309 .4625 L
.3815 .50118 L
.42237 .5326 L
.46172 .55462 L
.49955 .56974 L
.51896 .57568 L
.53984 .58096 L
.55955 .58505 L
.58106 .5887 L
.62077 .59368 L
.64045 .5955 L
.66142 .59707 L
.68139 .59829 L
.703 .59935 L
.74307 .60079 L
.76301 .60131 L
.78407 .60176 L
.82204 .60235 L
.84155 .60257 L
.86247 .60277 L
.88228 .60292 L
.90383 .60305 L
.92315 .60314 L
.94367 .60322 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0014Ool40003Ool20004Ool2000UOol30002Ool20004Ool2000ROol3
0004Ool20004Ool2000TOol20004Ool20004Ool2000POol50002Ool20004Ool20004Ool20003Ool0
04Aoo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`009Goo00@007ooOol0009oo`04001o
ogoo0002Ool00`00Oomoo`0OOol01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000ROol0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000QOol01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo0002Ool10001Ool1Ool004Eoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`008Woo1@0000Eoo`00Oomoo`00009oo`04001oogoo000QOol01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000ROol01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000Q
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool10001Ool1Ool004Ioo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol087oo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`008Goo0`000goo00@007ooOol0009oo`04001oogoo000SOol20003Ool01000
Oomoo`000Woo00@007ooOol0025oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
009oo`40005oo`5oo`00A7oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`008goo00<0
07oo00000Woo00@007ooOol0009oo`04001oogoo000ROol00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol0029oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0025oo`05001oogoo
Ool00002Ool01000Oomoo`000Woo00@007ooOol0009oo`40005oo`5oo`00AGoo0P0017oo0P0017oo
0P009Goo0P000goo0P0017oo0P008goo0`000goo0P0017oo0P0097oo0P0017oo0P0017oo0P008Goo
0P0017oo0P0017oo0P0017oo0P000goo003oOolQOol001]oo`03001oogoo0?moo`=oo`006goo00<0
07ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`005Gooo`00
1P001Woo000KOol00`00Oomoo`0^Ool00`00Oomoo`0_Ool00`00Oomoo`0^Ool00`00Oomoo`0_Ool0
0`00Oomoo`0_Ool00`00Oomoo`0:Ool001]oo`03001oogoo02ioo`03001oogoo02moo`03001oogoo
02ioo`03001oogoo02moo`03001oogoo02moo`03001oogoo00Yoo`006goo00<007ooOol0ogoo0goo
000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo
000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo
000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo
000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo
000KOol00g`OOomoo`3oOol3Ool001]oo`03001l7g`O0?moo`=oo`006goo00<007ooOol00W`Oogoo
0Goo000KOol00`00Oomoo`02Ool00g`OOomoo`3mOol001]oo`03001oogoo00=oo`9l7oeoo`006goo
00<007ooOol01Goo0W`Ongoo000KOol00`00Oomoo`07Ool00g`OOomoo`3hOol001]oo`03001oogoo
00Qoo`03O1moogoo0?Moo`006goo00<007ooOol02Goo00=l7gooOol0mWoo000KOol00`00Oomoo`0:
Ool00g`OOomoo`3eOol001]oo`03001oogoo00]oo`03O1moogoo0?Aoo`006goo00<007ooOol037oo
0W`Om7oo000KOol00`00Oomoo`0>Ool00g`OOomoo`3aOol000Moo`@000=oo`8000Aoo`8000Eoo`03
001oogoo00moo`03O1moogoo0?1oo`001goo00<007ooOol00goo00@007ooOol0009oo`04001oogoo
0004Ool00`00Oomoo`0@Ool00g`OOomoo`3_Ool000Qoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`0017oo0P004Woo00=l7gooOol0kWoo0009Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`03001oogoo009oo`03001oogoo019oo`03O1moogoo0>eoo`001goo00@007ooOol0009oo`04
001oogoo0002Ool01000Oomoo`0017oo00<007ooOol04goo00=l7gooOol0k7oo0008Ool20004Ool2
0004Ool20005Ool00`00Oomoo`0DOol00g`OOomoo`3[Ool001]oo`03001oogoo01Eoo`03O1moogoo
0>Yoo`006goo00<007ooOol05Goo00=l7gooOol0jWoo000KOol00`00Oomoo`0FOol00g`OOomoo`3Y
Ool001]oo`03001oogoo01Moo`03O1moogoo0>Qoo`006goo00<007ooOol067oo00=l7gooOol0igoo
000KOol00`00Oomoo`0IOol00g`OOomoo`3VOol001]oo`03001oogoo01Yoo`03O1moogoo0>Eoo`00
6goo00<007ooOol06Woo00=l7gooOol0iGoo000KOol00`00Oomoo`0KOol00g`OOomoo`3TOol001]o
o`03001oogoo01aoo`03O1moogoo0>=oo`006goo00<007ooOol07Goo00=l7gooOol0hWoo000KOol0
0`00Oomoo`0NOol00g`OOomoo`3QOol001]oo`03001oogoo01ioo`03O1moogoo0>5oo`006goo00<0
07ooOol07goo00=l7gooOol0h7oo000KOol00`00Oomoo`0POol00g`OOomoo`3OOol001]oo`03001o
ogoo025oo`03O1moogoo0=ioo`006goo00<007ooOol08Goo00=l7gooOol0gWoo000KOol00`00Oomo
o`0ROol00g`OOomoo`3MOol001]oo`03001oogoo02=oo`03O1moogoo0=aoo`006goo00<007ooOol0
97oo00=l7gooOol0fgoo000KOol00`00Oomoo`0TOol00g`OOomoo`3KOol001]oo`03001oogoo02Eo
o`03O1moogoo0=Yoo`006goo00<007ooOol09Woo00=l7gooOol0fGoo000KOol00`00Oomoo`0WOol0
0g`OOomoo`3HOol001]oo`03001oogoo02Moo`03O1moogoo0=Qoo`002Goo0`000Woo0P0017oo0P00
1Goo00<007ooOol0:7oo00=l7gooOol0egoo000:Ool01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo009oo`03001oogoo02Uoo`03O1moogoo0=Ioo`001goo1@0000Eoo`00Oomoo`00009oo`04
001oogoo0004Ool2000ZOol00g`OOomoo`3FOol000Moo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo02Yoo`03O1moogoo0=Eoo`0027oo00<007oo00000Woo00@007oo
Ool0009oo`04001oogoo0004Ool00`00Oomoo`0ZOol00g`OOomoo`3EOol000Uoo`8000=oo`8000Ao
o`8000Eoo`03001oogoo02]oo`03O1moogoo0=Aoo`006goo00<007ooOol0;7oo00=l7gooOol0dgoo
000KOol00`00Oomoo`0/Ool00g`OOomoo`3COol001]oo`03001oogoo02eoo`03O1moogoo0=9oo`00
6goo00<007ooOol0;Woo00=l7gooOol0dGoo000KOol00`00Oomoo`0^Ool00g`OOomoo`3AOol001]o
o`03001oogoo02moo`03O1moogoo0=1oo`006goo00<007ooOol0;goo00=l7gooOol0d7oo000KOol0
0`00Oomoo`0`Ool00g`OOomoo`3?Ool001]oo`03001oogoo035oo`03O1moogoo0<ioo`006goo00<0
07ooOol0<Goo00=l7gooOol0cWoo000KOol00`00Oomoo`0bOol00g`OOomoo`3=Ool001]oo`03001o
ogoo03=oo`03O1moogoo0<aoo`006goo00<007ooOol0=7oo00=l7gooOol0bgoo000KOol00`00Oomo
o`0dOol00g`OOomoo`3;Ool001]oo`03001oogoo03Eoo`03O1moogoo0<Yoo`006goo00<007ooOol0
=Woo00=l7gooOol0bGoo000KOol00`00Oomoo`0gOol00g`OOomoo`38Ool001]oo`03001oogoo03Mo
o`03O1moogoo0<Qoo`006goo00<007ooOol0>7oo00=l7gooOol0agoo000KOol00`00Oomoo`0iOol0
0g`OOomoo`36Ool001]oo`03001oogoo03Yoo`03O1moogoo0<Eoo`006goo00<007ooOol0>Woo00=l
7gooOol0aGoo000KOol00`00Oomoo`0kOol00g`OOomoo`34Ool001]oo`03001oogoo03aoo`03O1mo
ogoo0<=oo`001goo0`0017oo0P0017oo0P001Goo00<007ooOol0?7oo00=l7gooOol0`goo0007Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`0mOol00g`OOomoo`32
Ool000Moo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`8003moo`03O1moogoo
0<5oo`001goo0`000goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`0nOol00g`OOomo
o`31Ool000Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0?goo
00=l7gooOol0`7oo0008Ool30003Ool20004Ool20005Ool00`00Oomoo`0oOol00g`OOomoo`30Ool0
01]oo`03001oogoo041oo`03O1moogoo0;moo`006goo00<007ooOol0@Goo00=l7gooOol0_Woo000K
Ool00`00Oomoo`11Ool00g`OOomoo`2nOol001]oo`03001oogoo049oo`03O1moogoo0;eoo`006goo
00<007ooOol0@goo00=l7gooOol0_7oo000KOol00`00Oomoo`13Ool00g`OOomoo`2lOol001]oo`03
001oogoo04Aoo`03O1moogoo0;]oo`006goo00<007ooOol0A7oo00=l7gooOol0^goo000KOol00`00
Oomoo`15Ool00g`OOomoo`2jOol001]oo`03001oogoo04Ioo`03O1moogoo0;Uoo`006goo00<007oo
Ool0Agoo00=l7gooOol0^7oo000KOol00`00Oomoo`18Ool00g`OOomoo`2gOol001]oo`03001oogoo
04Qoo`03O1moogoo0;Moo`006goo00<007ooOol0BGoo00=l7gooOol0]Woo000KOol00`00Oomoo`1:
Ool00g`OOomoo`2eOol001]oo`03001oogoo04]oo`03O1moogoo0;Aoo`006goo00<007ooOol0C7oo
00=l7gooOol0/goo000KOol00`00Oomoo`1=Ool00g`OOomoo`2bOol001]oo`03001oogoo04eoo`03
O1moogoo0;9oo`006goo00<007ooOol0CWoo00=l7gooOol0/Goo000KOol00`00Oomoo`1?Ool00g`O
Oomoo`2`Ool001]oo`03001oogoo051oo`03O1moogoo0:moo`006goo00<007ooOol0DGoo00=l7goo
Ool0[Woo000KOol00`00Oomoo`1BOol00g`OOomoo`2]Ool001]oo`03001oogoo05=oo`03O1moogoo
0:aoo`0027oo0P0017oo0P0017oo0P001Goo00<007ooOol0E7oo00=l7gooOol0Zgoo0007Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`1EOol00g`OOomoo`2ZOol0
00Moo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`8005Moo`03O1moogoo0:Uo
o`0027oo0P000goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`1GOol00g`OOomoo`2X
Ool000Moo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo05Qoo`03
O1moogoo0:Moo`0027oo0P0017oo0P0017oo0P001Goo00<007ooOol0FGoo00=l7gooOol0YWoo000K
Ool00`00Oomoo`1JOol00g`OOomoo`2UOol001]oo`03001oogoo05]oo`03O1moogoo0:Aoo`006goo
00<007ooOol0G7oo0W`OY7oo000KOol00`00Oomoo`1NOol00g`OOomoo`2QOol001]oo`03001oogoo
05moo`03O1moogoo0:1oo`006goo00<007ooOol0H7oo00=l7gooOol0Wgoo000KOol00`00Oomoo`1Q
Ool2O1nOOol001]oo`03001oogoo06=oo`03O1moogoo09aoo`006goo00<007ooOol0I7oo00=l7goo
Ool0Vgoo000KOol00`00Oomoo`1UOol2O1nKOol001]oo`03001oogoo06Moo`9l7iUoo`006goo00<0
07ooOol0JGoo0W`OUgoo000KOol00`00Oomoo`1[Ool2O1nEOol001]oo`03001oogoo06eoo`9l7i=o
o`006goo00<007ooOol0Kgoo0W`OTGoo000KOol00`00Oomoo`1aOol2O1n?Ool001]oo`03001oogoo
07=oo`=l7haoo`006goo00<007ooOol0MWoo0W`ORWoo000KOol00`00Oomoo`1hOol4O1n6Ool001]o
o`03001oogoo07aoo`Al7h9oo`006goo00<007ooOol0P7oo0W`OP7oo000KOol00`00Oomoo`22Ool4
O1mlOol001]oo`03001oogoo08Ioo`Il7gIoo`006goo00<007ooOol0S7oo27`OKWoo00000goo0000
00030002Ool20004Ool20004Ool20005Ool00`00Oomoo`2DOol=O1mQOol000=oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo0:5ooa9l7dmo
o`000goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo
0P00]7oo@g`O37oo0003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOol3Ool000=oo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol0009oo`03001oogoo009oo`03001oogoo0?moo`=oo`000Woo0P0017oo0P0017oo0P00
17oo0P001Goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-110, -102, 4, 6}}],
  "  \n\t\t\t",
  Cell[BoxData[
      \(y\  = \ \(y \((t)\)\ \  = \ \ 0.01\/\(0.00001\[InvisibleSpace] + \
0.00009\ \[ExponentialE]\^\(\(-0.01\)\ t\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Logistic Differential Equation",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LogisticEquationProof.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Logistic Differential Equation",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/LogisticEquationProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Harvesting a Logistic Population",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWhen the harvesting term  ",
  StyleBox["-k",
    FontFamily->"Courier New"],
  "  is incorporated into into bounded population model we have \n\t\n\t\t\t\
",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "There are ",
  StyleBox["three",
    FontColor->RGBColor[1, 0, 1]],
  " solution forms for this differential equation, and they correspond to the \
nature of the stationary solutions  ( ",
  StyleBox["x(t) \[Congruent] c",
    FontFamily->"Courier New"],
  ").  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition(Stationary Points)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The stationary points of the D. E.  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  "  are solutions where ",
  Cell[BoxData[
      \(dx\/dt\  \[Congruent] \ 0\)]],
  " and are the roots of the characteristic equation  \n\n\t\t\t",
  Cell[BoxData[
      \(a\ x\  - \ b\ x\^2\  - \ k\  = \ 0\)]],
  ". \n\nThe roots are known to be  ",
  Cell[BoxData[
      \(x = \(a \[PlusMinus] \@\(a\^2 - 4\ b\ k\)\)\/\(2\ b\)\)]],
  ",  and the stationary solutions are  ",
  Cell[BoxData[
      \(x \((t)\) = \(a \[PlusMinus] \@\(a\^2 - 4\ b\ k\)\)\/\(2\ b\)\)]],
  ".  \n\n",
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Since  ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  "  is a real function, there are no stationary solutions when  ",
  Cell[BoxData[
      \(a\^2 - 4\ b\ k < 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Case (i)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" If   ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(a\^2 = 4\ b\ k\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  there is one stationary solution ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(\(x\_1\) \((t)\) = a\/\(2\ b\)\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWhen  ",
  Cell[BoxData[
      \(4\ b\ k = a\^2\)]],
  ",  the differential equation has the form  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ a\^2\/\(4\ b\)\)]],
  "  and the solution is  \n\n\t\t\t",
  Cell[BoxData[
      \(x \((t)\)\  = \ a\/\(2\ b\) + \(1\/b\) 1\/\(t - 4\ b\ c\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.123607 [
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(4)] -0.0125 .49443 1 0 Mshowa
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
0 .12361 m
.06085 .12361 L
.12721 .12361 L
.18954 .12361 L
.24948 .12361 L
.31328 .12361 L
.37469 .12361 L
.43997 .12361 L
.50286 .12361 L
.56336 .12361 L
.62773 .12361 L
.6897 .12361 L
.74929 .12361 L
.81275 .12361 L
.87381 .12361 L
.93874 .12361 L
s
.93874 .12361 m
1 .12361 L
s
.5 .165 .165 r
0 .09889 m
.05071 .09784 L
.10601 .09659 L
.15795 .09531 L
.2079 .09395 L
.26107 .09236 L
.31224 .09065 L
.36664 .08862 L
.41905 .08642 L
.46947 .08402 L
.5231 .08109 L
.57475 .07784 L
.62441 .07421 L
.67729 .06965 L
.72818 .06439 L
.78228 .05754 L
.8344 .04925 L
.88453 .03905 L
.93788 .0246 L
.98923 .0051 L
s
.98923 .0051 m
.99925 0 L
s
1 0 0 r
0 .07416 m
.02535 .07207 L
.05301 .06958 L
.07897 .06701 L
.10395 .0643 L
.13053 .06111 L
.15612 .0577 L
.18332 .05364 L
.20952 .04923 L
.23473 .04443 L
.26155 .03858 L
.28738 .03208 L
.31221 .02481 L
.33864 .01569 L
.36409 .00517 L
s
.36409 .00517 m
.3743 0 L
s
0 1 0 r
0 .04944 m
.0169 .04631 L
.03534 .04257 L
.05265 .03872 L
.0693 .03465 L
.08702 .02986 L
.10408 .02475 L
.12221 .01866 L
.13968 .01204 L
.15649 .00484 L
s
.15649 .00484 m
.16635 0 L
s
0 0 1 r
0 .02472 m
.01268 .02054 L
.0265 .01556 L
.03949 .01042 L
.05197 .00499 L
s
.05197 .00499 m
.06238 0 L
s
.5 .165 .165 r
0 .24721 m
.02962 .23412 L
.06085 .22302 L
.12721 .20553 L
.18715 .1943 L
.25095 .18529 L
.31237 .17856 L
.37764 .17284 L
.44053 .16836 L
.50104 .16475 L
.5654 .1615 L
.62738 .15883 L
.68697 .15659 L
.75042 .1545 L
.81149 .15272 L
.87641 .15104 L
.93896 .1496 L
.99911 .14835 L
s
.99911 .14835 m
1 .14833 L
s
1 0 0 r
0 .37082 m
.01414 .3457 L
.02962 .32346 L
.06085 .28988 L
.07745 .27625 L
.09521 .26394 L
.12721 .24613 L
.16077 .23174 L
.19249 .22094 L
.25299 .20536 L
.31736 .19346 L
.37933 .18488 L
.43892 .1784 L
.50238 .17286 L
.56344 .16849 L
.62837 .16462 L
.69091 .16148 L
.75107 .15888 L
.81508 .15648 L
.87671 .15446 L
.9422 .15256 L
s
.9422 .15256 m
1 .15108 L
s
1 .5 0 r
0 .49443 m
.01414 .44064 L
.02962 .39718 L
.04579 .36293 L
.06085 .33793 L
.09291 .29894 L
.11087 .28272 L
.12721 .27038 L
.15991 .25065 L
.1901 .23662 L
.2506 .21614 L
.2801 .20863 L
.31258 .20166 L
.37604 .19088 L
.4371 .18298 L
.50203 .1764 L
.56457 .1713 L
.62472 .16725 L
.68874 .16363 L
.75037 .16067 L
.81586 .15797 L
.87897 .15572 L
.93968 .15381 L
s
.93968 .15381 m
1 .15214 L
s
0 1 0 r
0 .61803 m
.00732 .5662 L
.01414 .52683 L
.02962 .45905 L
.04471 .41184 L
.06085 .37413 L
.07871 .34244 L
.0956 .31907 L
.12721 .28649 L
.15867 .26332 L
.18772 .24711 L
.21972 .2331 L
.24969 .22259 L
.30928 .20672 L
.37035 .195 L
.43528 .18569 L
.49782 .17876 L
.55797 .17341 L
.62199 .16875 L
.68362 .16502 L
.74911 .16168 L
.81221 .15893 L
.87293 .15664 L
.93751 .15451 L
.9997 .1527 L
s
.9997 .1527 m
1 .15269 L
s
0 0 1 r
.01264 .61803 m
.01414 .60541 L
.02225 .55134 L
.02962 .51171 L
.04471 .44988 L
.06085 .40238 L
.07721 .36653 L
.09496 .33677 L
.11031 .31637 L
.12721 .29798 L
.15846 .27185 L
.19158 .25152 L
.22215 .23715 L
.25503 .22491 L
.31996 .20713 L
.3825 .19506 L
.44265 .18633 L
.50667 .17912 L
.5683 .17359 L
.63379 .1688 L
.6969 .16498 L
.75761 .16187 L
.82219 .15904 L
.88439 .15668 L
.94419 .15469 L
s
.94419 .15469 m
1 .15305 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001>Ool5
000mOol40010Ool20011Ool30006Ool0051oo`03001oogoo03eoo`03001oogoo041oo`04001oogoo
0011Ool00`00Oomoo`05Ool0051oo`03001oogoo03ioo`03001oogoo045oo`03001oogoo03eoo`D0
00Ioo`00D7oo00<007ooOol0?goo00<007ooOol0@Goo00<007ooOol0?7oo00@007ooOol000Moo`00
D7oo00<007ooOol0?Goo00@007ooOol003moo`04001oogoo000oOol00`00Ool00007Ool004moo`80
041oo`80045oo`80045oo`8000Moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool000eooa0000807aT00083h3H0009l0:@0008lY0Qoo`003Goo00<007ooOol02goo0P0O6Goo0P?P
67oo00<007ooOol06Woo0g`08Woo00<007ooOol0@7oo00<007ooOol0>goo0cbT00=oo`00Ool01goo
000=Ool00`00Oomoo`09Ool201lIOol20n0JOol00`00Oomoo`0HOol2O00UOol00`00Oomoo`10Ool0
0`00Oomoo`0iOol2?:@4Ool00`00Oomoo`06Ool000eoo`03001oogoo00Ioo`<07aQoo`<3h3Eoo`9l
0:=oo`<lY0moo`003Goo00<007ooOol00Woo100O6Goo0P?P=Goo0g`0XWoo0cbT4Woo000=Ool00`00
Ool07`0201lJOol30n0cOol4O02SOol2?:@EOol000eoo`807aUoo`@3h3=oo`=l0:Aoo`<lY1Moo`00
3Goo00<007ooOol05Woo0P?P=7oo0g`0Xgoo13bT6Woo000=Ool00`00Oomoo`0BOol40n0cOol3O02S
Ool3?:@NOol000eoo`03001oogoo00eoo`D3h3=oo`Al0:9oo`@lY25oo`003Goo00<007ooOol02Goo
10?P=Goo0g`0XWoo13bT9Goo000=Ool00`00Oomoo`04Ool50n0eOol4O02POol5?:@YOol000eoo`03
001oo`?P00@3h3Eoo`El0:1oo`@lY2ioo`003Goo0P?P<goo1g`0Wgoo1SbT<Woo000=Ool00`00Oomo
o`0[Ool7O02OOol7?:@hOol000eoo`03001oogoo02Aoo`Ml09moo`LlY3moo`003Goo00<007ooOol0
7Goo1g`0Wgoo1cbTAWoo000=Ool00`00Oomoo`0FOol7O02KOol;?:A=Ool000eoo`03001oogoo00Qo
o`il09Qoo`XlY5Qoo`003Goo00@007ooOomoo`Ml09moo`LlY69oo`003Goo17`0W7oo2SbTJGoo000=
Ool00`00Oomoo`21OolL?:AcOol000eoo`03001oogoo07Aoo`dlY8moo`003Goo00<007ooOol0F7oo
73bTW7oo000=Ool00`00Oomoo`0lOolL?:BhOol000eoo`03001oogoo021ooa`lY=Aoo`003Goo8cbT
l7oo000=Ool00`00Oomoo`3oOolAOol000eoo`03001oogoo0?mooa5oo`003Goo00<007ooOol0ogoo
4Goo000=Ool00`00Oomoo`3oOolAOol000Eoo`D000=oo`03001oogoo0?mooa5oo`001goo00<007oo
Ool00goo00<007ooOol0ogoo4Goo0007Ool00`00Oomoo`03OoooO1l<O1l8Ool000Moo`03001oogoo
00=oo`03001oogoo0?mooa5oo`001goo00<007ooOol00goo00<007ooOol0ogoo4Goo0006Ool20005
Ool00`00Oomoo`3oOolAOol000eoo`03001oogoo0?mooa5oo`003Goo00<007ooOol0ogoo4Goo000=
Ool00`00Oomoo`3oOol9?:@8Ool000eoo`03001oogoo0=ioob4lY0Umh0Qoo`003Goo00<007ooOol0
_Goo8CbT00=l07gPON003GgP0`?P5`0O27oo000=Ool00`00Oomoo`2LOolQ?:@@O0030n0Q01lOOol0
00eoo`03001oogoo08]ooa4lY11ooa1mh0<3h1407d1oo`003Goo00<007ooOol0NWoo4CbT4Goo0g`0
37gP10?P400ODGoo000=Ool00`00Oomoo`1ZOol@?:@AOol<O004ON020n0B01mQOol000eoo`03001o
ogoo05Uooa4lY15ooa1l00=mh083h0d07g=oo`003Goo00<007ooOol0C7oo3CbT5Goo3G`017oo1ggP
0P?P200OP7oo000=Ool00`00Oomoo`14Ool8?:@JOol8O008Ool4ON060n0801n8Ool000eoo`03001o
ogoo03ioo`HlY1Yoo`Ql00Moo`9mh0T3h0P07i1oo`003Goo00<007ooOol0>7oo1SbT67oo27`01goo
17gP1P?P2@0OV7oo000=Ool00`00Oomoo`0bOol6?:@HOol6O009Ool4ON040n0801nQOol000eoo`03
001oogoo02eoo`DlY1Yoo`Al00Uoo`Emh0<3h0H07jUoo`003Goo00<007ooOol09goo1SbT6Woo1G`0
1goo1GgP0`?P1P0O[goo000=Ool00`00Oomoo`0ROol5?:@LOol4O005Ool6ON030n0601neOol000eo
o`03001oogoo01eoo`DlY1aoo`El00=oo`Imh003Ool3h0?P0083h0@07k]oo`003Goo00<007ooOol0
6Goo13bT7Goo17`017oo17gP0goo10?P100O_goo000=Ool00`00Oomoo`0DOol5?:@MOol4O005Ool3
ON03Ool40n0017oo01l07`0O`goo000=Ool00`00Oomoo`0@Ool4?:@NOol4O006Ool3ON02Ool40n02
Ool301o6Ool000eoo`03001oogoo00aoo`@lY1moo`=l00Qoo`9mh09oo`<3h09oo`@07lUoo`003Goo
00<007ooOol02Goo0cbT87oo0g`027oo0ggP0Woo0P?P0Woo0`0OcGoo000=Ool00`00Oomoo`07Ool2
?:@QOol2O008Ool3ON03Ool20n0017oo01l07`0Od7oo000=Ool00`00Oomoo`04Ool3?:@POol3O008
Ool2ON03Ool30n0301oCOol000eoo`03001oogoo009oo`8lY21oo`=l00Qoo`=mh0=oo`83h0<07mIo
o`001Goo100017oo00<007ooOol00SbT7goo0g`02Goo0WgP17oo0P?P0P0OfGoo0005Ool00`00Oomo
o`05Ool00`00?:@lY00OOol2O00:Ool2ON04Ool20n0201oKOol000Ioo`03001oogoo00Aoo`03?:@0
000001eoo`9l00Yoo`9mh0=oo`<3h0807meoo`001goo00<007ooOol00goo00<007ooOol06goo0W`0
2goo00Amh7ooOomoo`83h09oo`0301moogoo0=eoo`001Goo00@007ooOol000Aoo`03001oogoo01Uo
o`9l00]oo`9mh09oo`83h09oo`807n1oo`001Woo0P001Goo00<007ooOol05goo0W`02goo0WgP0Woo
0P?P0Woo0P0OhWoo000=Ool00`00Oomoo`0FOol00g`0Oomoo`09Ool2ON03Ool00`?POomoo`0201oT
Ool000eoo`03001oogoo01Aoo`9l00Yoo`9mh0=oo`83h003Ool07`0O0>Ioo`003Goo00<007ooOol0
4goo00=l07ooOol02Goo00=mh7ooOol00Woo00@3h7ooOol07nQoo`003Goo00<007ooOol04Woo00=l
07ooOol027oo0WgP17oo00@3h7ooOol07nUoo`003Goo00<007ooOol04Goo00=l07ooOol027oo00=m
h7ooOol00Woo0P?P0Woo00<07gooOol0j7oo000=Ool00`00Oomoo`0?Ool2O00:Ool00ggPOomoo`02
Ool00`?POomoo`0201o[Ool000eoo`03001oogoo00ioo`03O01oogoo00Uoo`03ON1oogoo009oo`04
0n1oogoo01o]Ool000eoo`03001oogoo00eoo`03O01oogoo00Uoo`03ON1oogoo009oo`040n1oogoo
01o^Ool000eoo`03001oogoo00aoo`03O01oogoo00Uoo`03ON1oogoo009oo`040n1oogoo01o_Ool0
00eoo`03001oogoo00]oo`03O01oogoo00Uoo`03ON1oogoo009oo`040n1oogoo01o`Ool000eoo`03
001oogoo00Yoo`03O01oogoo00Uoo`03ON1oogoo009oo`040n1oogoo01oaOol000eoo`03001oogoo
00Uoo`03O01oogoo00Uoo`03ON1oogoo009oo`040n1oogoo01obOol000eoo`03001oogoo00Uoo`03
O01oogoo00Qoo`03ON1oogoo009oo`040n1oogoo01ocOol000eoo`03001oogoo00Qoo`03O01oogoo
00Qoo`03ON1oogoo009oo`040n1oogoo01odOol000eoo`03001oogoo00Moo`03O01oogoo00Qoo`03
ON1oogoo009oo`040n1oogoo01oeOol000eoo`03001oogoo00Ioo`03O01oogoo00Uoo`05ON1oogoo
Ool3h002Ool00`0OOomoo`3dOol000eoo`03001oogoo00Eoo`03O01oogoo00Uoo`05ON1oogooOol3
h003Ool00`0OOomoo`3dOol000eoo`03001oogoo00Aoo`03O01oogoo00Uoo`03ON1oogoo009oo`04
0n1oogoo01ogOol000eoo`03001oogoo00Aoo`03O01oogoo00Qoo`03ON1oogoo009oo`040n1oogoo
01ohOol000eoo`03001oogoo00=oo`03O01oogoo00Qoo`03ON1oogoo009oo`050n1oogooOol07`3h
Ool000eoo`03001oogoo009oo`03O01oogoo00Qoo`03ON1oogoo00=oo`040n1oogoo01oiOol000eo
o`03001oogoo009oo`03O01oogoo00Moo`03ON1oogoo00=oo`050n1oogooOol07`3iOol000eoo`05
001oogooOoml000:Ool00ggPOomoo`02Ool01@?POomoogoo01l0nWoo000=Ool01000Oomoog`02Woo
00=mh7ooOol00goo00D3h7ooOomoo`0O0?Yoo`003Goo00@007ooOoml00Yoo`03ON1oogoo009oo`05
0n1oogooOol07`3kOol000eoo`03001oog`000Yoo`03ON1oogoo00=oo`050n1oogooOol07`3kOol0
00eoo`03001oog`000Yoo`03ON1oogoo009oo`050n1oogooOol07`3lOol000Ioo`8000Eoo`03001l
07oo00Uoo`03ON1oogoo00=oo`050n1oogooOol07`3lOol000Eoo`04001oogoo0004Ool00`00O01o
o`09Ool00ggPOomoo`02Ool01@?POomoogoo01l0oGoo0007Ool00`00Oomoo`03Ool00g`000000008
Ool00ggPOomoo`03Ool010?POomoo`0OoWoo0008Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00ggP
Oomoo`02Ool01@?POomoogoo01l0oWoo0005Ool01000Oomoo`0017oo00<007ooOol01goo00=mh7oo
Ool00goo00@3h7ooOol07omoo`001Woo0P001Goo00<007ooOol01goo00=mh7ooOol00Woo00D3h7oo
Oomoo`0O0?moo`003Goo00<007ooOol01Woo00=mh7ooOol00goo00@3h7ooOol07omoo`5oo`003Goo
00<007ooOol01Woo00=mh7ooOol00Woo00D3h7ooOomoo`0O0?moo`5oo`003Goo00<007ooOol01Goo
00=mh7ooOol00goo00@3h7ooOol07omoo`9oo`003Goo00<007ooOol01Goo00=mh7ooOol00goo00@3
h7ooOol07omoo`9oo`003Goo00<007ooOol01Goo00=mh7ooOol00Woo00@3h7ooOol07omoo`=oo`00
3Goo00<007ooOol017oo00=mh7ooOol00goo00@3h7ooOol07omoo`=oo`003Goo00<007ooOol017oo
00=mh7ooOol00Woo00@3h7ooOol07omoo`Aoo`003Goo00<007ooOol017oo00=mh7ooOol00Woo00@3
h7ooOol07omoo`Aoo`003Goo00<007ooOol00goo00=mh7ooOol00goo00@3h7ooOol07omoo`Aoo`00
3Goo00<007ooOol00goo00=mh7ooOol00Woo00@3h7ooOol07omoo`Eoo`003Goo00<007ooOol00Woo
00=mh7ooOol00goo00@3h7ooOol07omoo`Eoo`003Goo00<007ooOol00Woo00=mh7ooOol00goo00@3
h7ooOol07omoo`Eoo`003Goo00<007ooOol00Woo00=mh7ooOol00Woo00D3h7ooOomoo`0O0?moo`Eo
o`003Goo00D007ooOomooggP00Eoo`040n1oogoo01ooOol6Ool000eoo`05001oogooOommh005Ool0
10?POomoo`0Oogoo1Woo000=Ool01@00OomoogooON0017oo00D3h7ooOomoo`0O0?moo`Ioo`003Goo
00@007ooOommh0Eoo`040n1oogoo01ooOol7Ool000eoo`04001oogooON05Ool010?POomoo`0Oogoo
1goo000=Ool01000OomooggP17oo00D3h7ooOomoo`0O0?moo`Moo`003Goo00@007ooOommh0Aoo`05
0n1oogooOol07`3oOol7Ool000eoo`03001ooggP00Eoo`040n1oogoo01ooOol8Ool000eoo`03001o
oggP00Eoo`040n1oogoo01ooOol8Ool000eoo`03001ooggP00Aoo`050n1oogooOol07`3oOol8Ool0
00eoo`03001ooggP00Aoo`050n1oogooOol07`3oOol8Ool000eoo`03001mh7oo00Aoo`040n1oogoo
01ooOol9Ool000eoo`03001mh7oo00Aoo`040n1oogoo01ooOol9Ool000eoo`03001mh7oo00=oo`05
0n1oogooOol07`3oOol9Ool000Moo`<000=oo`03001mh7oo00=oo`050n1oogooOol07`3oOol9Ool0
00Qoo`03001oogoo009oo`03ON1oogoo00=oo`040n1oogoo01ooOol:Ool000Eoo`D000=oo`03ON00
000000=oo`040n1oogoo01ooOol:Ool000Eoo`04001oogoo0004Ool00`00Oomoo`03Ool010?POomo
o`0Oogoo2Woo0006Ool00`00Ool00004Ool00`00Oomoo`02Ool01@?POomoogoo01l0ogoo2Woo0007
Ool20004Ool00`00Oomoo`02Ool010?POomoo`0Oogoo2goo000=Ool00`00Oomoo`02Ool010?POomo
o`0Oogoo2goo000=Ool00`00Oomoo`02Ool010?POomoo`0Oogoo2goo000=Ool01@00Oomoogoo0n00
0goo00<07gooOol0ogoo2Goo000=Ool01@00Oomoogoo0n000Woo00<07gooOol0ogoo2Woo000=Ool0
1@00Oomoogoo0n000Woo00<07gooOol0ogoo2Woo000=Ool01@00Oomoogoo0n000Woo00<07gooOol0
ogoo2Woo000=Ool01@00Oomoogoo0n000Woo00<07gooOol0ogoo2Woo000=Ool01000Oomoo`?P0goo
00<07gooOol0ogoo2Woo000=Ool01000Oomoo`?P0goo00<07gooOol0ogoo2Woo000=Ool01000Oomo
o`?P0Woo00<07gooOol0ogoo2goo000=Ool01000Oomoo`?P0Woo00<07gooOol0ogoo2goo000=Ool0
1000Oomoo`?P0Woo00<07gooOol0ogoo2goo000=Ool01000Oomoo`?P0Woo00<07gooOol0ogoo2goo
000=Ool00`00Ool3h003Ool00`0OOomoo`3oOol;Ool000eoo`03001oo`?P00=oo`0301moogoo0?mo
o`]oo`003Goo00<007oo0n000Woo00<07gooOol0ogoo37oo000=Ool00`00Ool3h002Ool00`0OOomo
o`3oOol<Ool000eoo`03001oo`?P009oo`0301moogoo0?moo`aoo`003Goo00<007oo0n000Woo00<0
7gooOol0ogoo37oo000=Ool00`000n1oo`02Ool00`0OOomoo`3oOol<Ool000eoo`030003h7oo009o
o`0301moogoo0?moo`aoo`003Goo00<000?POol00Woo00<07gooOol0ogoo37oo000=Ool01@000n1o
ogoo01l0ogoo3goo000=Ool01@000n1oogoo01l0ogoo3goo000=Ool01@000n1oogoo01l0ogoo3goo
000=Ool01@?POomoogoo01l0ogoo3goo000=Ool01@?POomoogoo01l0ogoo3goo000=Ool010?POomo
o`0Oogoo47oo000=Ool010?POomoo`0Oogoo47oo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, 0, 0, 0}}],
  "  "
}], "Text",
  Editable->False],

Cell[TextData[{
  "The solution with the initial condition  ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  "  is \n\n\t\t\t",
  Cell[BoxData[
      \(x \((t)\)\  = \ 
        a\/\(2\ b\) + \(1\/b\) 1\/\(t - 2/\((a - 2\ b\ x\_0)\)\)\)]],
  ". \n\t\t\nIf  ",
  Cell[BoxData[
      \(x\_0 \[GreaterEqual] a\/\(2\ b\)\)]],
  "  then   ",
  Cell[BoxData[
      \(lim\+\(t \[Rule] \[Infinity]\)\ \ x \((t)\)\  = \ a\/\(2\ b\)\)]],
  ". \n\nIf  ",
  Cell[BoxData[
      \(x\_0 < a\/\(2\ b\)\)]],
  "  then function  ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  "  has a vertical asymptote at  ",
  Cell[BoxData[
      \(t\_1\  = 2\/\(a - 2\ b\ x\_0\)\)]],
  " and the population   ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  "  becomes extinct at some time  ",
  Cell[BoxData[
      \(t = t\_0\)]],
  "  (where ",
  Cell[BoxData[
      \(0 < t\_0 < t\_1\)]],
  "),  i. e.  \n\n\t\t\t",
  Cell[BoxData[
      \(x \((t\_0)\)\  = \ 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/HarvestingModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/HarvestingModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Case (ii)  If  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(a\^2 > 4\ b\ k\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" there are two stationary solutions  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(\(x\_1\) \((t)\) = \(a - \@\(a\^2 - 4\ b\ k\)\)\/\(2\ b\)\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  and  ",
  Cell[BoxData[
      \(\(x\_2\) \((t)\) = \(a + \@\(a\^2 - 4\ b\ k\)\)\/\(2\ b\)\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWhen  ",
  Cell[BoxData[
      \(a\^2 > 4\ b\ k\)]],
  ",  the differential equation has the form  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  "  and the solution is  \n\n\t\t\t",
  Cell[BoxData[
      \(x \((t)\) = 
        a\/\(2  b\)\  + \(\@\(a\^2 - 4\ b\ k\)\/\(2  b\)\) \((1 - 
                2\/\(1 + c\ \[ExponentialE]\^\(\@\(a\^2 - 4\ b\ k\)\ t\)\))\)\
\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0772542 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .07725 -6 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -6 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -6 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -6 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -6 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -6 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(1)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(2)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(3)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(4)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(5)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(6)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(7)] -0.0125 .54078 1 0 Mshowa
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.56 .37 .6 r
.5 Mabswid
0 .07725 m
.08113 .07725 L
.16962 .07725 L
.25272 .07725 L
.33264 .07725 L
.41771 .07725 L
.49959 .07725 L
.58663 .07725 L
.67048 .07725 L
.75115 .07725 L
.83697 .07725 L
.9196 .07725 L
.99906 .07725 L
s
.99906 .07725 m
1 .07725 L
s
1 0 1 r
0 .23176 m
.08113 .23176 L
.16962 .23176 L
.25272 .23176 L
.33264 .23176 L
.41771 .23176 L
.49959 .23176 L
.58663 .23176 L
.67048 .23176 L
.75115 .23176 L
.83697 .23176 L
.9196 .23176 L
.99906 .23176 L
s
.99906 .23176 m
1 .23176 L
s
1 0 0 r
0 .01545 m
.02541 .01084 L
.05312 .0053 L
s
.05312 .0053 m
.07698 0 L
s
1 .5 0 r
0 .0309 m
.02974 .02714 L
.06218 .02259 L
.09264 .01784 L
.12194 .01276 L
.15312 .00671 L
.18314 .00017 L
s
.18314 .00017 m
.18382 0 L
s
0 1 0 r
0 .04635 m
.03634 .04351 L
.07598 .04006 L
.1132 .03643 L
.149 .03252 L
.18711 .02784 L
.22379 .02276 L
.26277 .0166 L
.30033 .0098 L
.33647 .0023 L
s
.33647 .0023 m
.346 0 L
s
0 0 1 r
0 .0618 m
.04864 .06005 L
.10168 .05788 L
.1515 .05557 L
.19941 .05305 L
.2504 .04999 L
.29949 .04662 L
.35167 .04249 L
.40193 .03787 L
.45029 .03272 L
.50174 .02631 L
.55128 .019 L
.59891 .01067 L
.64963 0 L
s
.64963 0 m
.64964 0 L
s
1 0 1 r
0 .23176 m
.04057 .23176 L
.08481 .23176 L
.12636 .23176 L
.16632 .23176 L
.20885 .23176 L
.2498 .23176 L
.29331 .23176 L
.33524 .23176 L
.37557 .23176 L
.41848 .23176 L
.4598 .23176 L
.49953 .23176 L
.54183 .23176 L
.58254 .23176 L
.62583 .23176 L
.66752 .23176 L
.70762 .23176 L
.7503 .23176 L
.79139 .23176 L
.83505 .23176 L
.87712 .23176 L
.9176 .23176 L
.96065 .23176 L
1 .23176 L
s
.5 .165 .165 r
0 .30902 m
.04057 .30033 L
.08481 .29225 L
.12636 .28574 L
.16632 .28029 L
.20885 .27522 L
.2498 .27094 L
.29331 .26693 L
.33524 .26352 L
.37557 .2606 L
.41848 .25783 L
.4598 .25544 L
.49953 .25338 L
.54183 .2514 L
.58254 .24969 L
.62583 .24805 L
.66752 .24662 L
.70762 .24537 L
.7503 .24417 L
.79139 .24312 L
.83505 .24211 L
.87712 .24122 L
.9176 .24044 L
.96065 .23969 L
1 .23906 L
s
1 0 0 r
0 .38627 m
.04057 .36393 L
.08481 .34457 L
.12636 .32986 L
.16632 .31812 L
.20885 .30762 L
.2498 .29905 L
.29331 .29128 L
.33524 .28485 L
.37557 .27947 L
.41848 .27446 L
.4598 .27023 L
.49953 .26663 L
.54183 .26322 L
.58254 .26031 L
.62583 .25755 L
.66752 .25517 L
.70762 .25312 L
.7503 .25115 L
.79139 .24945 L
.83505 .24781 L
.87712 .2464 L
.9176 .24516 L
.96065 .24397 L
1 .24298 L
s
1 .5 0 r
0 .46353 m
.04057 .4231 L
.08481 .39027 L
.12636 .3666 L
.16632 .34843 L
.20885 .3327 L
.2498 .32022 L
.29331 .30915 L
.33524 .30017 L
.37557 .29278 L
.41848 .286 L
.4598 .28034 L
.49953 .27558 L
.54183 .27112 L
.58254 .26733 L
.62583 .26377 L
.66752 .26073 L
.70762 .25812 L
.7503 .25563 L
.79139 .25348 L
.83505 .25143 L
.87712 .24966 L
.9176 .24812 L
.96065 .24664 L
1 .24542 L
s
0 1 0 r
0 .54078 m
.01975 .50746 L
.04057 .47828 L
.08481 .43054 L
.12477 .39877 L
.1673 .37273 L
.20824 .35295 L
.25176 .33603 L
.29369 .32271 L
.33402 .312 L
.37693 .30239 L
.41825 .29451 L
.45798 .28797 L
.50028 .28193 L
.54099 .27686 L
.58428 .27215 L
.62597 .26815 L
.66607 .26475 L
.70875 .26153 L
.74984 .25877 L
.7935 .25616 L
.83557 .25391 L
.87605 .25196 L
.9191 .2501 L
.96056 .24848 L
1 .24709 L
s
0 0 1 r
0 .61803 m
.01975 .5703 L
.04057 .52986 L
.08481 .4663 L
.12477 .42567 L
.1673 .39332 L
.20824 .36931 L
.25176 .34914 L
.29369 .33348 L
.33402 .32104 L
.37693 .30998 L
.41825 .301 L
.45798 .2936 L
.50028 .28679 L
.54099 .28111 L
.58428 .27585 L
.62597 .27142 L
.66607 .26765 L
.70875 .2641 L
.74984 .26107 L
.7935 .2582 L
.83557 .25573 L
.87605 .25361 L
.9191 .25157 L
.96056 .24981 L
1 .2483 L
s
1 0 1 r
0 .23176 m
.08113 .23176 L
.16962 .23176 L
.25272 .23176 L
.33264 .23176 L
.41771 .23176 L
.49959 .23176 L
.58663 .23176 L
.67048 .23176 L
.75115 .23176 L
.83697 .23176 L
.9196 .23176 L
.99906 .23176 L
s
.99906 .23176 m
1 .23176 L
s
0 0 1 r
0 .10301 m
.08113 .10668 L
.16962 .11113 L
.25272 .11573 L
.33264 .12053 L
.41771 .12602 L
.49959 .13164 L
.58663 .13792 L
.67048 .1442 L
.75115 .15037 L
.83697 .157 L
.9196 .16335 L
.99906 .16934 L
s
.99906 .16934 m
1 .1694 L
s
0 1 0 r
0 .12876 m
.08113 .13447 L
.16962 .14098 L
.25272 .14728 L
.33264 .15343 L
.41771 .15999 L
.49959 .16624 L
.58663 .17271 L
.67048 .17869 L
.75115 .18416 L
.83697 .18962 L
.9196 .19449 L
.99906 .1988 L
s
.99906 .1988 m
1 .19885 L
s
1 .5 0 r
0 .15451 m
.08113 .16076 L
.16962 .16749 L
.25272 .17363 L
.33264 .1793 L
.41771 .18502 L
.49959 .19018 L
.58663 .19526 L
.67048 .19972 L
.75115 .20363 L
.83697 .20737 L
.9196 .21057 L
.99906 .21331 L
s
.99906 .21331 m
1 .21334 L
s
1 0 0 r
0 .18026 m
.08113 .18567 L
.16962 .19119 L
.25272 .19596 L
.33264 .20017 L
.41771 .20423 L
.49959 .20774 L
.58663 .21106 L
.67048 .21389 L
.75115 .21629 L
.83697 .21852 L
.9196 .22039 L
.99906 .22195 L
s
.99906 .22195 m
1 .22197 L
s
.5 .165 .165 r
0 .20601 m
.08113 .20931 L
.16962 .2125 L
.25272 .21513 L
.33264 .21736 L
.41771 .21943 L
.49959 .22117 L
.58663 .22276 L
.67048 .22408 L
.75115 .22518 L
.83697 .22618 L
.9196 .227 L
.99906 .22768 L
s
.99906 .22768 m
1 .22769 L
s
.628 .126 .941 r
0 .10301 m
.08113 .10668 L
.16962 .11113 L
.25272 .11573 L
.33264 .12053 L
.41771 .12602 L
.49959 .13164 L
.58663 .13792 L
.67048 .1442 L
.75115 .15037 L
.83697 .157 L
.9196 .16335 L
.99906 .16934 L
s
.99906 .16934 m
1 .1694 L
s
1 0 1 r
0 .12876 m
.08113 .13447 L
.16962 .14098 L
.25272 .14728 L
.33264 .15343 L
.41771 .15999 L
.49959 .16624 L
.58663 .17271 L
.67048 .17869 L
.75115 .18416 L
.83697 .18962 L
.9196 .19449 L
.99906 .1988 L
s
.99906 .1988 m
1 .19885 L
s
0 0 1 r
0 .15451 m
.08113 .16076 L
.16962 .16749 L
.25272 .17363 L
.33264 .1793 L
.41771 .18502 L
.49959 .19018 L
.58663 .19526 L
.67048 .19972 L
.75115 .20363 L
.83697 .20737 L
.9196 .21057 L
.99906 .21331 L
s
.99906 .21331 m
1 .21334 L
s
0 1 0 r
0 .18026 m
.08113 .18567 L
.16962 .19119 L
.25272 .19596 L
.33264 .20017 L
.41771 .20423 L
.49959 .20774 L
.58663 .21106 L
.67048 .21389 L
.75115 .21629 L
.83697 .21852 L
.9196 .22039 L
.99906 .22195 L
s
.99906 .22195 m
1 .22197 L
s
1 .5 0 r
0 .20601 m
.08113 .20931 L
.16962 .2125 L
.25272 .21513 L
.33264 .21736 L
.41771 .21943 L
.49959 .22117 L
.58663 .22276 L
.67048 .22408 L
.75115 .22518 L
.83697 .22618 L
.9196 .227 L
.99906 .22768 L
s
.99906 .22768 m
1 .22769 L
s
1 0 0 r
0 .10301 m
.08113 .10668 L
.16962 .11113 L
.25272 .11573 L
.33264 .12053 L
.41771 .12602 L
.49959 .13164 L
.58663 .13792 L
.67048 .1442 L
.75115 .15037 L
.83697 .157 L
.9196 .16335 L
.99906 .16934 L
s
.99906 .16934 m
1 .1694 L
s
.5 .165 .165 r
0 .12876 m
.08113 .13447 L
.16962 .14098 L
.25272 .14728 L
.33264 .15343 L
.41771 .15999 L
.49959 .16624 L
.58663 .17271 L
.67048 .17869 L
.75115 .18416 L
.83697 .18962 L
.9196 .19449 L
.99906 .1988 L
s
.99906 .1988 m
1 .19885 L
s
.628 .126 .941 r
0 .15451 m
.08113 .16076 L
.16962 .16749 L
.25272 .17363 L
.33264 .1793 L
.41771 .18502 L
.49959 .19018 L
.58663 .19526 L
.67048 .19972 L
.75115 .20363 L
.83697 .20737 L
.9196 .21057 L
.99906 .21331 L
s
.99906 .21331 m
1 .21334 L
s
1 0 1 r
0 .18026 m
.08113 .18567 L
.16962 .19119 L
.25272 .19596 L
.33264 .20017 L
.41771 .20423 L
.49959 .20774 L
.58663 .21106 L
.67048 .21389 L
.75115 .21629 L
.83697 .21852 L
.9196 .22039 L
.99906 .22195 L
s
.99906 .22195 m
1 .22197 L
s
0 0 1 r
0 .20601 m
.08113 .20931 L
.16962 .2125 L
.25272 .21513 L
.33264 .21736 L
.41771 .21943 L
.49959 .22117 L
.58663 .22276 L
.67048 .22408 L
.75115 .22518 L
.83697 .22618 L
.9196 .227 L
.99906 .22768 L
s
.99906 .22768 m
1 .22769 L
s
0 1 0 r
0 .10301 m
.08113 .10668 L
.16962 .11113 L
.25272 .11573 L
.33264 .12053 L
.41771 .12602 L
.49959 .13164 L
.58663 .13792 L
.67048 .1442 L
.75115 .15037 L
.83697 .157 L
.9196 .16335 L
.99906 .16934 L
s
.99906 .16934 m
1 .1694 L
s
1 .5 0 r
0 .12876 m
.08113 .13447 L
.16962 .14098 L
.25272 .14728 L
.33264 .15343 L
.41771 .15999 L
.49959 .16624 L
.58663 .17271 L
.67048 .17869 L
.75115 .18416 L
.83697 .18962 L
.9196 .19449 L
.99906 .1988 L
s
.99906 .1988 m
1 .19885 L
s
1 0 0 r
0 .15451 m
.08113 .16076 L
.16962 .16749 L
.25272 .17363 L
.33264 .1793 L
.41771 .18502 L
.49959 .19018 L
.58663 .19526 L
.67048 .19972 L
.75115 .20363 L
.83697 .20737 L
.9196 .21057 L
.99906 .21331 L
s
.99906 .21331 m
1 .21334 L
s
.5 .165 .165 r
0 .18026 m
.08113 .18567 L
.16962 .19119 L
.25272 .19596 L
.33264 .20017 L
.41771 .20423 L
.49959 .20774 L
.58663 .21106 L
.67048 .21389 L
.75115 .21629 L
.83697 .21852 L
.9196 .22039 L
.99906 .22195 L
s
.99906 .22195 m
1 .22197 L
s
.628 .126 .941 r
0 .20601 m
.08113 .20931 L
.16962 .2125 L
.25272 .21513 L
.33264 .21736 L
.41771 .21943 L
.49959 .22117 L
.58663 .22276 L
.67048 .22408 L
.75115 .22518 L
.83697 .22618 L
.9196 .227 L
.99906 .22768 L
s
.99906 .22768 m
1 .22769 L
s
1 0 1 r
0 .10301 m
.08113 .10668 L
.16962 .11113 L
.25272 .11573 L
.33264 .12053 L
.41771 .12602 L
.49959 .13164 L
.58663 .13792 L
.67048 .1442 L
.75115 .15037 L
.83697 .157 L
.9196 .16335 L
.99906 .16934 L
s
.99906 .16934 m
1 .1694 L
s
0 0 1 r
0 .12876 m
.08113 .13447 L
.16962 .14098 L
.25272 .14728 L
.33264 .15343 L
.41771 .15999 L
.49959 .16624 L
.58663 .17271 L
.67048 .17869 L
.75115 .18416 L
.83697 .18962 L
.9196 .19449 L
.99906 .1988 L
s
.99906 .1988 m
1 .19885 L
s
0 1 0 r
0 .15451 m
.08113 .16076 L
.16962 .16749 L
.25272 .17363 L
.33264 .1793 L
.41771 .18502 L
.49959 .19018 L
.58663 .19526 L
.67048 .19972 L
.75115 .20363 L
.83697 .20737 L
.9196 .21057 L
.99906 .21331 L
s
.99906 .21331 m
1 .21334 L
s
1 .5 0 r
0 .18026 m
.08113 .18567 L
.16962 .19119 L
.25272 .19596 L
.33264 .20017 L
.41771 .20423 L
.49959 .20774 L
.58663 .21106 L
.67048 .21389 L
.75115 .21629 L
.83697 .21852 L
.9196 .22039 L
.99906 .22195 L
s
.99906 .22195 m
1 .22197 L
s
1 0 0 r
0 .20601 m
.08113 .20931 L
.16962 .2125 L
.25272 .21513 L
.33264 .21736 L
.41771 .21943 L
.49959 .22117 L
.58663 .22276 L
.67048 .22408 L
.75115 .22518 L
.83697 .22618 L
.9196 .227 L
.99906 .22768 L
s
.99906 .22768 m
1 .22769 L
s
.5 .165 .165 r
0 .07725 m
.08113 .07725 L
.16962 .07725 L
.25272 .07725 L
.33264 .07725 L
.41771 .07725 L
.49959 .07725 L
.58663 .07725 L
.67048 .07725 L
.75115 .07725 L
.83697 .07725 L
.9196 .07725 L
.99906 .07725 L
s
.99906 .07725 m
1 .07725 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000kOol2
0004Ool20003Ool4000WOol20004Ool20005Ool3000UOol20004Ool20003Ool3000WOol20004Ool2
0004Ool2000/Ool50006Ool003Yoo`04001oogoo0008Ool00`00Oomoo`0WOol01000Oomoo`002goo
00<007ooOol08goo00@007ooOol000Qoo`04001oogoo000UOol01000Oomoo`0027oo00@007ooOol0
02eoo`03001oogoo00Ioo`00>Woo00@007ooOol000Uoo`03001oogoo02Ioo`04001oogoo0008Ool5
000TOol01000Oomoo`0027oo00@007ooOol002Eoo`04001oogoo0008Ool01000Oomoo`00;Goo00<0
07ooOol01Woo000jOol01000Oomoo`002Woo00<007ooOol09Goo00@007ooOol000Qoo`04001oogoo
000UOol01000Oomoo`0027oo0`009Woo00@007ooOol000Uoo`8002ioo`03001oogoo00Ioo`00>Woo
00@007ooOol000Qoo`04001oogoo000VOol01000Oomoo`002Goo00<007oo00009Goo00@007ooOol0
00Uoo`03001oogoo02Eoo`04001oogoo0008Ool01000Oomoo`00;Goo00<007ooOol01Woo000kOol2
000:Ool2000XOol2000;Ool2000VOol2000:Ool3000VOol2000:Ool2000]Ool20008Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000=OolA0004O00J0003ON0Y00020n1>0003
01mM0008Ool000eoo`03001oogoo00Yoo`Al01Yoo`Amh0Ioo`03001oogoo021oo`<3h11oo`03001o
ogoo039oo`03001oogoo00Aoo`@07bYoo`03001oogoo039oo`03001oogoo00Ioo`003Goo00<007oo
Ool01Woo17`067oo1WgP2Woo00<007ooOol06goo1@?P4goo00<007ooOol0<Woo00<007ooOol0100O
;Woo00<007ooOol0<Woo00<007ooOol01Woo000=Ool01000Oomoogoo1G`05Woo1WgP9Woo20?PBWoo
1P0OL7oo000=Ool4O00GOol4ON0UOol70n1<Ool601mfOol000eoo`03001oogoo019oo`Imh2Aoo`D3
h4aoo`L07gaoo`003Goo00<007ooOol02Woo27gP8Woo20?PBgoo1P0OPgoo000=Ool01000Oomoogoo
2GgP8goo1`?PC7oo1`0ORGoo000=Ool4ON0WOol50n1<Ool701n@Ool000eoo`03001oogoo021oo`P3
h4Moo`X07iMoo`003Goo00<007ooOol05Woo2P?P@Woo3@0OXGoo000=Ool00`00Oomoo`02OolD0n0n
Ool>01n^Ool000eoo`D3h4Eoo`d07kaoo`003Goo00<007ooOol0>Goo3P0ObGoo000=Ool00`00Oomo
o`0/Ool=01oGOol000eoo`03001oogoo015ooa/07nAoo`003Goo500Oogoo000=Ool00`00Oomoo`3o
OolAOol000Eoo`D000=oo`03001oogoo0?mooa5oo`001goo00<007ooOol00goo00<007ooOol0ogoo
4Goo0007Ool00`00Oomoo`03Oooo?:@<?:@8Ool000Moo`03001oogoo00=oo`03001oogoo0?mooa5o
o`001goo00<007ooOol00goo00<007ooOol0ogoo4Goo0006Ool20005Ool00`00Oomoo`3oOolAOol0
00eoo`03001oogoo0?mooa5oo`003Goo00<007ooOol0ogoo4Goo000=Ool00`00Oomoo`3oOolAOol0
00eoo`al7omoo`Qoo`003Goo00<007ooOol02Goo5W`OlGoo000=Ool00`00Oomoo`0OOolAO1oPOol0
00eoo`03001oogoo031oo`]l7mEoo`003Goo00<007ooOol0>goo4G`Oa7oo000=Ool00`00Oomoo`1<
OolFO1n^Ool000eoo`03001oogoo069ooa1l7iioo`003Goo1P0OKgoo2g`OTgoo000=Ool00`00Oomo
o`03Ool;01m_Ool;O1n8Ool000eoo`03001oogoo00iooa407fUoo`al7gaoo`003Goo00<007ooOol0
7goo4@0OI7oo4G`OJgoo000=Ool00`00Oomoo`0`Ool;01mZOolAO1mJOol000Eoo`@000Aoo`03001o
ogoo03]oo`/07g1oo`Yl7e1oo`001Goo00<007ooOol01Goo00<007ooOol0AWoo2`0OKgoo2g`OAGoo
0006Ool00`00Oomoo`04Ool60n1>Ool;01m_Ool<O1liOol000Moo`03001oogoo00=oo`03001oogoo
00=oo`/3h4ioo`/07g1ooa5l7bQoo`001Goo00@007ooOol000Aoo`03001oogoo00ioo`/3h4iooa40
7g1ooa1l7aQoo`001Woo0P001Goo00<007ooOol06Goo30?PDgoo400OL7oo2W`O3Woo000=Ool00`00
Oomoo`0UOolA0n1BOol<01m^Ool6O1l8Ool000eoo`03001oogoo03Iooa03h4iooa407f]oo`003Goo
00<007ooOol0AWoo2`?PE7oo4@0OFWoo000=Ool<ON18OolA0n1DOol:01m@Ool000eoo`03001oogoo
00Uooa1mh4Uooa03h4iooa407cmoo`003Goo00<007ooOol06Goo37gPCGoo2`?PE7oo4@0O;Woo000=
Ool00`00Oomoo`0UOolAON17OolA0n1DOol;01lSOol000eoo`03001oogoo03IooaImh49ooaL3h4Qo
oa007a=oo`003Goo00<007ooOol0C7oo5WgP@goo5P?P@Woo2`0O27oo000=Ool00`00Oomoo`1ROolF
ON13OolF0n0oOol000eoo`al06mooaImh4=ooaL3h2Qoo`003Goo00<007ooOol02Goo;G`0F7oo5ggP
@goo5@?P4goo000=Ool00`00Oomoo`0fOolFO01IOol/ON0/Ool;0n08Ool000eoo`03001oogoo04ao
obal05UooaMmh2Qoo`003Goo00<007ooOol0N7oo;G`0@goo87gP27oo0006Ool20005Ool00`00Oomo
o`2UOomHO00COol000Eoo`04001oogoo0004Ool00`00Oomoo`3mOol;O008Ool000Moo`03001oogoo
00=oooml7`al7`Qoo`0027oo00<007ooOol00Woo00<007ooOol0ogoo4Goo0005Ool01000Oomoo`00
17oo00<007ooOol0eWoo<SbT27oo0006Ool20005Ool00`00Oomoo`2dOolR?:@FOolFO006ON08Ool0
00eoo`03001oogoo09=oob4lY1MooaIl01Mmh1007`Qoo`003Goo00<007ooOol0OGoo5SbT8Goo5g`0
5WgP5`0O67oo000=Ool00`00Oomoo`1bOol;?:@QOolFO00;Ool<ON0;0n0;01l_Ool000eoo`03001o
ogoo05aooaHlY25oo`]l00aooaEmh003Ool07`0O01@07cYoo`003Goo00<007ooOol0DGoo2cbT;7oo
2g`02goo2ggP2`?P300OD7oo000=Ool00`00Oomoo`16Ool;?:@/Ool;O00;Ool;ON000goo0n03h008
0n0;01mLOol000eoo`03001oogoo03]oo`/lY2aoo`]l00]oo`]mh0=oo`T3h0X07fMoo`003Goo00<0
07ooOol0<Woo2CbT;7oo2g`03Woo27gP27oo1P?P2@0OLGoo000=Ool00`00Oomoo`0/Ool6?:@]Ool8
O00COol6ON08Ool80n0601mjOol000eoo`03001oogoo02Aoo`PlY2eoo`Il01=oo`Qmh0Ioo`P3h0P0
7h1oo`003Goo00<007ooOol07Goo1cbT;Goo27`04Goo27gP27oo1P?P200OR7oo000=Ool00`00Oomo
o`0GOol6?:@]Ool7O00COol6ON08Ool80n0601n@Ool000eoo`03001oogoo015oo`HlY2moo`Al01Eo
o`Emh0Ioo`P3h0=oo`D07iIoo`003Goo00<007ooOol02goo1SbT<Goo17`04goo1WgP1Goo1P?P1Goo
1P0OVgoo0007Ool30003Ool00`00Oomoo`06Ool5?:@cOol4O00BOol5ON07Ool40n06Ool501nQOol0
00Qoo`03001oogoo009oo`03001oogoo00HlY39oo`Il011oo`Imh0Qoo`@3h0Aoo`H07jIoo`001Goo
1@000goo0cbT<goo1G`04Woo17gP2Woo10?P17oo100O[7oo0005Ool01000Oomoo`0017oo00<007oo
Ool0;goo17`04goo17gP2goo0`?P17oo100O/7oo0006Ool00`00Ool00004Ool00`00Oomoo`0[Ool4
O00COol4ON0;Ool40n03Ool401ndOol000Moo`8000Aoo`03001oogoo02Qoo`=l01Aoo`=mh0]oo`@3
h0Aoo`<07kQoo`003Goo00<007ooOol097oo17`057oo0ggP2goo0`?P1Goo0`0O^goo000=Ool00`00
Oomoo`0QOol3O00FOol2ON0:Ool40n06Ool201nnOol000eoo`03001oogoo01ioo`=l01Ioo`=mh0Qo
o`@3h0Moo`<07l1oo`003Goo00<007ooOol06goo0g`05Woo0ggP27oo0`?P27oo0`0O`goo000=Ool0
0`00Oomoo`0IOol2O00FOol3ON09Ool20n08Ool301o6Ool000eoo`03001oogoo01Ioo`=l01Eoo`=m
h0Uoo`<3h0Qoo`807lUoo`003Goo00<007ooOol04goo0g`05Goo0ggP2Woo0P?P27oo0`0Obgoo000=
Ool00`00Oomoo`0AOol2O00EOol3ON0;Ool20n07Ool301o>Ool000eoo`03001oogoo00ioo`=l01Eo
o`9mh0]oo`<3h0Moo`807m5oo`003Goo00<007ooOol037oo0W`05Woo0WgP2goo0P?P1goo0`0Odgoo
000=Ool00`00Oomoo`0:Ool2O00FOol2ON0;Ool20n07Ool201oFOol000eoo`03001oogoo00Qoo`9l
01Ioo`9mh0]oo`83h0Moo`807mQoo`003Goo00<007ooOol01Woo0W`05goo00=mh7ooOol02Goo0P?P
1goo0P0OfWoo000=Ool00`00Oomoo`04Ool2O00GOol2ON0;Ool00`?POomoo`05Ool201oLOol000eo
o`03001oogoo009oo`9l01Moo`9mh0]oo`83h0Moo`0301moogoo0=aoo`001Woo0P001Goo00<007oo
Ool00W`05goo0WgP2goo0P?P1goo0P0Oggoo0005Ool01000Oomoo`0017oo00<007`0O0005goo0WgP
2goo0P?P27oo00<07gooOol0ggoo0008Ool00`00Oomoo`02Ool00g`00000000EOol2ON0<Ool00`?P
Oomoo`07Ool00`0OOomoo`3POol000Ioo`8000Eoo`03001oogoo01Aoo`03ON1oogoo00Yoo`83h0Qo
o`807n=oo`001Woo00<007ooOol017oo00<007ooOol04Woo0WgP2goo0P?P2Goo00<07gooOol0hgoo
0006Ool30004Ool00`00Oomoo`0AOol00ggPOomoo`0:Ool00`?POomoo`07Ool201oVOol000eoo`03
001oogoo011oo`03ON1oogoo00Yoo`030n1oogoo00Moo`0301moogoo0>Ioo`003Goo00<007ooOol0
3Woo0WgP37oo00<3h7ooOol01Woo0P0OjGoo000=Ool00`00Oomoo`0=Ool00ggPOomoo`0;Ool00`?P
Oomoo`06Ool00`0OOomoo`3YOol000eoo`03001oogoo00aoo`03ON1oogoo00Yoo`83h0Moo`807nao
o`003Goo00<007ooOol02Woo0WgP37oo00<3h7ooOol01Woo00<07gooOol0k7oo000=Ool00`00Oomo
o`09Ool00ggPOomoo`0;Ool00`?POomoo`05Ool201o_Ool000eoo`03001oogoo00Qoo`03ON1oogoo
00]oo`030n1oogoo00Eoo`0301moogoo0>moo`003Goo00<007ooOol01goo00=mh7ooOol02goo00<3
h7ooOol01Goo00<07gooOol0l7oo000=Ool00`00Oomoo`06Ool00ggPOomoo`0;Ool00`?POomoo`05
Ool00`0OOomoo`3aOol000eoo`03001oogoo00Eoo`03ON1oogoo00]oo`030n1oogoo00Eoo`0301mo
ogoo0?9oo`003Goo00<007ooOol017oo00=mh7ooOol02goo00<3h7ooOol01Goo00<07gooOol0lgoo
000=Ool00`00Oomoo`02Ool2ON0=Ool00`?POomoo`05Ool00`0OOomoo`3dOol000eoo`05001oogoo
Oommh00>Ool00`?POomoo`06Ool00`0OOomoo`3dOol000eoo`04001oogooON0>Ool00`?POomoo`06
Ool00`0OOomoo`3eOol000Eoo`<000Eoo`03001ooggP00ioo`030n1oogoo00Ioo`0301moogoo0?Io
o`001Goo00@007ooOol000Aoo`03001mh7oo00eoo`030n1oogoo00Ioo`0301moogoo0?Moo`001Goo
00@007ooOol000Aoo`03ON00000000aoo`030n1oogoo00Ioo`0301moogoo0?Qoo`001Goo0`001Goo
00<007ooOol02goo00<3h7ooOol01Woo00<07gooOol0nGoo0006Ool00`00Oomoo`04Ool00`00Oomo
o`0:Ool00`?POomoo`06Ool00`0OOomoo`3jOol000Ioo`<000Aoo`03001oogoo00Uoo`030n1oogoo
00Moo`0301moogoo0?Yoo`003Goo00<007ooOol027oo00<3h7ooOol01goo00<07gooOol0ngoo000=
Ool00`00Oomoo`07Ool00`?POomoo`07Ool00`0OOomoo`3lOol000eoo`03001oogoo00Moo`030n1o
ogoo00Ioo`0301moogoo0?eoo`003Goo00<007ooOol01Woo00<3h7ooOol01goo00<07gooOol0oGoo
000=Ool00`00Oomoo`05Ool00`?POomoo`07Ool00`0OOomoo`3nOol000eoo`03001oogoo00Aoo`03
0n1oogoo00Moo`0301moogoo0?moo`003Goo00<007ooOol017oo00<3h7ooOol01goo00<07gooOol0
ogoo000=Ool00`00Oomoo`03Ool00`?POomoo`07Ool00`0OOomoo`3oOol1Ool000eoo`03001oogoo
009oo`030n1oogoo00Moo`0301moogoo0?moo`9oo`003Goo00D007ooOomoo`?P00Yoo`0301moogoo
0?moo`9oo`003Goo00D007ooOomoo`?P00Uoo`0301moogoo0?moo`=oo`003Goo00@007ooOol3h0Uo
o`0301moogoo0?moo`Aoo`003Goo00@007ooOol3h0Qoo`0301moogoo0?moo`Eoo`003Goo00<007oo
0n002Goo00<07gooOol0ogoo1Goo000=Ool00`00Ool3h008Ool00`0OOomoo`3oOol6Ool000Moo`03
001oogoo00=oo`030003h7oo00Moo`0301moogoo0?moo`Moo`001goo00<007ooOol00goo00<000?P
Ool01goo00<07gooOol0ogoo1goo0007Ool00`00Oomoo`03Ool00`?P00000006Ool00`0OOomoo`3o
Ool8Ool000Qoo`03001oogoo009oo`03001oogoo00Ioo`0301moogoo0?moo`Qoo`001Goo00@007oo
Ool000Aoo`03001oogoo00Eoo`0301moogoo0?moo`Uoo`001Goo100017oo00<007ooOol01Goo00<0
7gooOol0ogoo2Goo000=Ool00`00Oomoo`04Ool00`0OOomoo`3oOol:Ool000eoo`03001oogoo00Ao
o`0301moogoo0?moo`Yoo`003Goo00<007ooOol00goo00<07gooOol0ogoo2goo000=Ool00`00Oomo
o`03Ool00`0OOomoo`3oOol;Ool000eoo`03001oogoo009oo`0301moogoo0?moo`aoo`003Goo00<0
07ooOol00Woo00<07gooOol0ogoo37oo000=Ool01@00Oomoogoo01l0ogoo3goo000=Ool01@00Oomo
ogoo01l0ogoo3goo000=Ool01000Oomoo`0Oogoo47oo000=Ool01000Oomoo`0Oogoo47oo000=Ool0
1000Oomoo`0Oogoo47oo000=Ool00`00Ool07`3oOolAOol000eoo`03001oo`0O0?mooa5oo`003Goo
00<0000OOol0ogoo4Goo000=Ool00`0001moo`3oOolAOol000eoo`0301moogoo0?mooa5oo`003Goo
00<07gooOol0ogoo4Goo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, 0, 0, 0}}],
  "  "
}], "Text",
  Editable->False],

Cell[TextData[{
  "The two real roots of the characteristic equation  ",
  Cell[BoxData[
      \(a\ r - b\ r\^2 - k = 0\)]],
  ",  are  ",
  Cell[BoxData[
      \(r\_1 = \(\(a\  - \ \@\(a\^2\  - \ 4\ b\ k\)\)\/\(2\ \
b\)\ \ \ and\ \ \ r\_2 = \(a\  + \ \@\(a\^2\  - \ 4\ b\ k\)\)\/\(2\ \
b\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The solution with the initial condition  ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  "  is \n\n\t",
  Cell[BoxData[
      \(x \((t)\)\  = \ 
        a\/\(2  b\) + \@\(a\^2 - 4\ b\ k\)\/\(2\ b\)\  - \(\(a + \@\(a\^2 - 4\
\ b\ k\) - 
                  2\ b\ x\_0\)\/\(2\ b\)\) \(2 \((\@\(a\^2 - 4\ b\ k\))\)\)\/\
\(\((\@\(a\^2 - 4\ b\ k\) + a - 2\ b\ x\_0)\) + \ \((\@\(a\^2 - 4\ b\ k\) - a \
+ 2\ b\ x\_0)\) \[ExponentialE]\^\(\@\(a\^2 - 4\ b\ k\)\ t\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "If   ",
  Cell[BoxData[
      \(r\_1\  < \ x\_0\)]],
  "   then   ",
  Cell[BoxData[
      \(lim\+\(t \[Rule] \[Infinity]\)\ \ x \((t)\)\  = \ \(r\_2\  = \ \(a\  \
+ \ \@\(a\^2\  - \ 4\ b\ k\)\)\/\(2\ b\)\)\)]],
  ".  \n\t\nIf   ",
  Cell[BoxData[
      \(0\  < \ x\_0 < r\_1\)]],
  "   then the population   ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  "  becomes extinct at some time  ",
  Cell[BoxData[
      \(t = t\_0\)]],
  ",  i. e.   ",
  Cell[BoxData[
      \(x \((t\_0)\)\  = \ 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/HarvestingModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/HarvestingModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Case (iii)  If  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(a\^2 < 4\ b\ k\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  StyleBox[" there are no stationary solutions.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n"
}], "Text"],

Cell[TextData[{
  "When  ",
  Cell[BoxData[
      \(4\ b\ k > a\^2\)]],
  ",  the differential equation has the form  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  "  and the solution is  \n\n\t\t\t",
  Cell[BoxData[
      \(x \((t)\)\  = \ 
        a\/\(2  b\)\  - \(\@\(4\ b\ k - a\^2\)\/\(2  b\)\) 
            Tan[t\/2\ \@\(4\ b\ k - a\^2\) - c]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 1.33333 0 0.154508 [
[.33333 -0.0125 -12 -9 ]
[.33333 -0.0125 12 0 ]
[.66667 -0.0125 -9 -9 ]
[.66667 -0.0125 9 0 ]
[1 -0.0125 -12 -9 ]
[1 -0.0125 12 0 ]
[-0.0125 .15451 -6 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46353 -6 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.33333 0 m
.33333 .00625 L
s
[(0.25)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(0.5)] .66667 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(0.75)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .15451 m
.00625 .15451 L
s
[(1)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(2)] -0.0125 .30902 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(3)] -0.0125 .46353 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(4)] -0.0125 .61803 1 0 Mshowa
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
0 .15451 m
.04327 .14013 L
.09046 .12569 L
.13478 .11299 L
.17741 .10131 L
.22278 .08926 L
.26645 .07784 L
.31287 .06571 L
.35759 .05385 L
.40061 .04209 L
.44638 .02899 L
.49046 .01555 L
.53283 .00159 L
s
.53283 .00159 m
.5372 0 L
s
.5 .165 .165 r
0 .30902 m
.04327 .26956 L
.09046 .23616 L
.13478 .21084 L
.17741 .19031 L
.22278 .1714 L
.26645 .1553 L
.31287 .13985 L
.35759 .12616 L
.40061 .11379 L
.44638 .10124 L
.49046 .08953 L
.53283 .07845 L
.57795 .06666 L
.62138 .05517 L
.66755 .04258 L
.71202 .02989 L
.7548 .01693 L
.80032 .00201 L
s
.80032 .00201 m
.80588 0 L
s
1 0 0 r
0 .46353 m
.02106 .41767 L
.04327 .37868 L
.09046 .31661 L
.13309 .2759 L
.17846 .24232 L
.22213 .21627 L
.26855 .19321 L
.31327 .17418 L
.35629 .15802 L
.40206 .14253 L
.44614 .12885 L
.48851 .11652 L
.53363 .10403 L
.57706 .09242 L
.62323 .08032 L
.6677 .06871 L
.71048 .05743 L
.756 .04511 L
.79983 .03274 L
.8464 .01879 L
.89127 .00426 L
s
.89127 .00426 m
.90327 0 L
s
1 .5 0 r
0 .61803 m
.02106 .53634 L
.04327 .47192 L
.06579 .42146 L
.09046 .37783 L
.13583 .31803 L
.1795 .27609 L
.22592 .24178 L
.27065 .21527 L
.31367 .19391 L
.35944 .17437 L
.40351 .15782 L
.44589 .14345 L
.49101 .12938 L
.53443 .11673 L
.58061 .10395 L
.62508 .09206 L
.66786 .08085 L
.71338 .06897 L
.7572 .05741 L
.80378 .0448 L
.84865 .03211 L
.89183 .01917 L
.93775 .00432 L
s
.93775 .00432 m
.9499 0 L
s
0 1 0 r
.02766 .61803 m
.04327 .55252 L
.0677 .47828 L
.09046 .42596 L
.13413 .3532 L
.158 .32336 L
.18055 .2995 L
.22358 .26241 L
.26935 .23138 L
.31342 .20699 L
.3558 .1871 L
.40092 .16869 L
.44434 .15295 L
.49051 .13779 L
.53499 .12432 L
.57776 .11212 L
.62329 .09969 L
.66711 .08808 L
.71368 .07592 L
.75856 .06418 L
.80174 .05269 L
.84766 .04007 L
.89189 .02731 L
.93441 .01425 L
s
.93441 .01425 m
.97716 0 L
s
0 0 1 r
.04442 .61803 m
.05508 .57327 L
.0677 .52878 L
.09046 .46481 L
.11432 .4133 L
.13688 .37457 L
.17991 .31832 L
.22568 .27456 L
.26975 .24212 L
.31212 .21681 L
.35725 .19426 L
.40067 .17562 L
.44684 .15818 L
.49132 .14309 L
.53409 .12976 L
.57961 .11649 L
.62344 .10435 L
.67001 .09191 L
.71489 .08015 L
.75806 .06888 L
.80399 .05676 L
.84821 .04477 L
.89074 .03276 L
.93602 .01921 L
.97959 .00516 L
s
.97959 .00516 m
.99415 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001HOol2
0004Ool20003Ool40003Ool20016Ool20004Ool20004Ool20015Ool20004Ool20005Ool00`00Oomo
o`02Ool20007Ool005Moo`04001oogoo0008Ool00`00Oomoo`03Ool01000Oomoo`00A7oo00@007oo
Ool000Qoo`04001oogoo0013Ool01000Oomoo`002Woo00D007ooOomoo`00009oo`03001oogoo00Ao
o`00Egoo00@007ooOol000Uoo`03001oogoo00Eoo`03001oogoo049oo`04001oogoo000;Ool00`00
Oomoo`11Ool01000Oomoo`002Woo00<007ooOol017oo00<007ooOol017oo001GOol01000Oomoo`00
2Woo00<007ooOol00Woo0P00AGoo00@007ooOol000Uoo`8004Aoo`04001oogoo000;Ool01000Oomo
ogoo0P001goo001GOol01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo04Aoo`04001oogoo
0009Ool00`00Oomoo`13Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Ioo`00F7oo
0P002Woo0P0017oo0`00AGoo0P002Woo0`00A7oo0P002Goo10000goo0`001Woo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`0037ooR@000g`O@P0013bT5`000W`02P000WgP1@00
0P?P0P000`0O00<007ooOol03Woo000<Ool00`00Oomoo`1COol00`00Oomoo`0]Ool3O1lTOol00`00
Oomoo`0KOol3?:@HOol3O009Ool3ON03Ool40n0017oo01l07`0O0goo00<007ooOol03Woo000<Ool0
0`00Oomoo`21Ool2O1m3Ool2?:@HOol3O009Ool3ON02Ool40n02Ool301lGOol000aoo`03001oogoo
07ioo`=l7d9oo`<lY1Moo`=l00Uoo`=mh09oo`<3h0Aoo`807aYoo`0037oo00<007ooOol0Ngoo0g`O
@Woo0cbT5goo0g`02Goo0ggP0Woo0`?P17oo0`0O77oo000<Ool00`00Oomoo`1gOol4O1m2Ool3?:@F
Ool4O009Ool3ON03Ool20n03Ool401lOOol000aoo`03001oogoo07=oo`Al7dAoo`8lY1Eoo`Al00Uo
o`Amh0=oo`<3h003Ool07`0O00807b=oo`0037oo00<007ooOol0L7oo0g`OAGoo0cbT4goo17`02Goo
17gP17oo0`?P100O9goo000<Ool00`00Oomoo`1]Ool3O1m4Ool4?:@COol3O009Ool4ON04Ool40n03
01l[Ool000aoo`03001oogoo06Yoo`=l7d=oo`@lY1=oo`Al00Qoo`Amh0Aoo`@3h0@07bioo`0037oo
00<007ooOol0Igoo0g`O@Woo13bT4goo17`027oo17gP17oo10?P100O<Woo000<Ool00`00Oomoo`1T
Ool3O1m1Ool4?:@DOol3O009Ool3ON04Ool40n0017oo01l07`0O=Woo000<Ool00`00Oomoo`1POol4
O1m0Ool4?:@EOol3O009Ool3ON03Ool40n02Ool301liOol000aoo`03001oogoo05aoo`Al7d1oo`@l
Y1Ioo`=l00Uoo`=mh0=oo`<3h0=oo`<07caoo`0037oo00<007ooOol0F7oo17`O@Goo0cbT5goo0g`0
2Goo0ggP0Woo10?P0goo0`0O?goo000<Ool00`00Oomoo`1DOol4O1m1Ool4?:@GOol3O009Ool3ON00
0goo0n03h0020n04Ool301m2Ool000aoo`03001oogoo051oo`Al7d5oo`@lY1Moo`Al00Qoo`Amh0@3
h0Aoo`@07dEoo`0037oo00<007ooOol0C7oo17`O@Goo13bT5goo17`027oo17gP10?P17oo100OBGoo
000<Ool00`00Oomoo`18Ool4O1m1Ool4?:@HOol3O008Ool4ON040n04Ool401m=Ool000aoo`03001o
ogoo04Aoo`Al7d5oo`@lY1Qoo`Al00Moo`Amh004Ool3h0?P0n04Ool401mAOol000aoo`03001oogoo
045oo`=l7d9oo`<lY1Qoo`Al00Moo`Amh09oo`<3h0=oo`@07eEoo`0037oo00<007ooOol0?Goo17`O
@Goo13bT5goo17`027oo0ggP0goo0`?P0goo0`0OFGoo000<Ool00`00Oomoo`0iOol4O1m1Ool4?:@G
Ool4O008Ool4ON03Ool30n02Ool401mLOol000aoo`03001oogoo03Eoo`Al7d9oo`<lY1Moo`Al00Qo
o`Amh0Aoo`<3h003Ool07`0O00807f1oo`0037oo00<007ooOol0<Goo17`O@Woo13bT5Woo17`02Goo
0ggP17oo10?P100OI7oo000<Ool00`00Oomoo`0]Ool4O1m2Ool4?:@FOol4O009Ool4ON03Ool40n04
01mXOol000aoo`03001oogoo02Yoo`=l7d9oo`@lY1Ioo`Al00Uoo`Amh0=oo`@3h0@07faoo`0037oo
00<007ooOol09Woo17`O@Goo13bT5goo0g`02Goo17gP0goo10?P100OL7oo000<Ool00`00Oomoo`0R
Ool4O1m1Ool4?:@GOol4O008Ool4ON03Ool40n0401mdOol000aoo`03001oogoo01ioo`Al7d9oo`<l
Y1Moo`Al00Qoo`Amh0Aoo`<3h0@07gQoo`0037oo00<007ooOol06Woo17`O@goo0cbT5goo0g`027oo
17gP17oo0`?P100OO7oo000<Ool00`00Oomoo`0FOol4O1m5Ool2?:@FOol4O007Ool4ON04Ool30n04
01n0Ool000aoo`03001oogoo01=oo`=l7dIoo`<lY1Aoo`Al00Moo`Amh0Eoo`83h0@07hAoo`0037oo
00<007ooOol047oo0g`OAGoo13bT57oo0g`027oo0ggP1Woo0P?P0`0OR7oo000<Ool00`00Oomoo`0=
Ool3O1m4Ool4?:@EOol3O008Ool3ON06Ool20n0301n;Ool000aoo`03001oogoo00Yoo`=l7d=oo`@l
Y1Ioo`=l00Uoo`9mh0Ioo`<3h0807hioo`0037oo00<007ooOol01goo0g`O@goo0cbT5goo0g`02Goo
0ggP17oo10?P0`0OT7oo000<Ool00`00Oomoo`04Ool3O1m3Ool3?:@GOol3O009Ool3ON03Ool40n00
17oo01l07`0OTgoo0004Ool50003Ool00`00Oomoo`02Ool2O1m3Ool3?:@GOol3O009Ool3ON02Ool4
0n02Ool301nFOol000Ioo`03001oogoo00=oo`03001oog`O009l7d9oo`<lY1Moo`=l00Yoo`9mh09o
o`<3h0Aoo`807iUoo`001Woo00<007ooOol00goo0W`O00<007ooOol0?goo0cbT5goo0g`02Woo0ggP
0Woo0P?P17oo0`0OVgoo0006Ool00`00Oomoo`03Ool00`00Oomoo`0nOol3?:@GOol3O00:Ool3ON03
Ool20n03Ool301nNOol000Ioo`03001oogoo00=oo`03001oogoo03aoo`8lY1Moo`=l00Yoo`=mh0Ao
o`83h09oo`<07j5oo`001Goo0P001Goo00<007ooOol0>Goo0cbT5goo0W`02Woo0ggP1Goo0P?P00Ao
o`0O01l07jAoo`0037oo00<007ooOol0=Woo0cbT5goo0g`02Goo0ggP1Goo0`?P0`0OYgoo000<Ool0
0`00Oomoo`0dOol2?:@GOol3O009Ool3ON05Ool30n0301nZOol000aoo`03001oogoo035oo`<lY1Mo
o`9l00Yoo`9mh0Eoo`<3h003Ool07`0O0:eoo`0037oo00<007ooOol0;goo0SbT67oo0W`02Goo0ggP
17oo0`?P0Woo0P0O[goo000<Ool00`00Oomoo`0]Ool2?:@HOol2O009Ool2ON04Ool30n03Ool201na
Ool000aoo`03001oogoo02Yoo`<lY1Qoo`9l00Uoo`9mh0Aoo`83h0Aoo`807k=oo`0037oo00<007oo
Ool0:7oo0SbT67oo0g`02Goo0WgP17oo0P?P0goo0`0O]Goo000<Ool00`00Oomoo`0VOol2?:@HOol2
O00:Ool2ON04Ool20n03Ool201nhOol000aoo`03001oogoo02Aoo`8lY1Qoo`9l00Yoo`9mh0Aoo`83
h0=oo`807kYoo`0037oo00<007ooOol08Woo0SbT67oo0W`02Woo0WgP17oo0P?P0goo0P0O_7oo000<
Ool00`00Oomoo`0POol2?:@HOol2O00:Ool2ON04Ool20n03Ool201nnOol000aoo`03001oogoo01io
o`8lY1Qoo`9l00Yoo`9mh0Eoo`040n1oogooOol201o0Ool000aoo`03001oogoo01aoo`8lY1Uoo`03
O01oogoo00Uoo`03ON1oogoo00=oo`83h0=oo`0301moogoo0<1oo`0037oo00<007ooOol06Woo0SbT
6Goo0W`02Woo0WgP17oo0P?P0goo0P0O`goo000<Ool00`00Oomoo`0IOol00cbTOomoo`0GOol2O00:
Ool2ON05Ool00`?POomoo`02Ool00`0OOomoo`33Ool000aoo`03001oogoo01Moo`8lY1Qoo`9l00Yo
o`9mh0Eoo`83h0=oo`807lIoo`0037oo00<007ooOol05Goo0SbT6Goo00=l07ooOol027oo0WgP1Woo
00@3h7ooOomoo`807lQoo`0037oo00<007ooOol057oo00<lY7ooOol05goo0W`02Goo0WgP1Woo0P?P
0goo00<07gooOol0b7oo000<Ool00`00Oomoo`0BOol2?:@HOol2O00:Ool00ggPOomoo`05Ool010?P
Oomoogoo0P0Obgoo000<Ool00`00Oomoo`0AOol00cbTOomoo`0GOol00g`0Oomoo`08Ool2ON06Ool2
0n03Ool00`0OOomoo`3;Ool000aoo`03001oogoo011oo`03?:Aoogoo01Ioo`9l00Yoo`03ON1oogoo
00Eoo`040n1oogooOol201o>Ool000aoo`03001oogoo00ioo`8lY1Qoo`03O01oogoo00Uoo`03ON1o
ogoo00Aoo`83h0=oo`0301moogoo0<ioo`0037oo00<007ooOol03Goo00<lY7ooOol05goo00=l07oo
Ool027oo0WgP1Woo00<3h7ooOol00Woo00<07gooOol0cgoo000<Ool00`00Oomoo`0<Ool00cbTOomo
o`0FOol2O00:Ool00ggPOomoo`04Ool20n03Ool201oBOol000aoo`03001oogoo00Yoo`8lY1Qoo`03
O01oogoo00Uoo`03ON1oogoo00Aoo`030n1oogoo009oo`0301moogoo0=9oo`0037oo00<007ooOol0
2Goo00<lY7ooOol05goo00=l07ooOol027oo0WgP1Woo00<3h7ooOol00Woo00<07gooOol0dgoo000<
Ool00`00Oomoo`08Ool00cbTOomoo`0FOol2O00:Ool00ggPOomoo`04Ool20n03Ool201oFOol000ao
o`03001oogoo00Moo`03?:Aoogoo01Ioo`03O01oogoo00Uoo`03ON1oogoo00Aoo`030n1oogoo009o
o`0301moogoo0=Ioo`0037oo00<007ooOol01Woo00<lY7ooOol05Woo00=l07ooOol02Goo00=mh7oo
Ool017oo00<3h7ooOol00Woo00<07gooOol0egoo000<Ool00`00Oomoo`05Ool00cbTOomoo`0FOol0
0g`0Oomoo`09Ool00ggPOomoo`04Ool00`?POomoo`02Ool00`0OOomoo`3HOol000aoo`03001oogoo
00Aoo`03?:Aoogoo01Ioo`03O01oogoo00Uoo`03ON1oogoo00Aoo`030n1oogoo009oo`0301moogoo
0=Uoo`0037oo00<007ooOol00Woo0SbT67oo00=l07ooOol02Goo00=mh7ooOol00goo0P?P17oo00<0
7gooOol0fWoo000<Ool01@00Oomoogoo?:@067oo0W`02Woo0WgP1Goo00<3h7ooOol00Woo0P0OgGoo
000<Ool01000OomoocbT67oo00=l07ooOol02Goo00=mh7ooOol017oo00<3h7ooOol00Woo00<07goo
Ool0gGoo0004Ool40004Ool00`00OollY00HOol00g`0Oomoo`09Ool00ggPOomoo`04Ool00`?POomo
o`02Ool00`0OOomoo`3NOol000Aoo`03001oogoo00Eoo`03000lY7oo01Moo`03O01oogoo00Uoo`03
ON1oogoo00Aoo`030n1oogoo009oo`0301moogoo0=moo`001Goo00<007ooOol017oo00<lY0000000
5Woo00=l07ooOol02Goo00=mh7ooOol017oo00<3h7ooOol00Woo00<07gooOol0h7oo0006Ool00`00
Oomoo`03Ool00`00Oomoo`0EOol00g`0Oomoo`09Ool00ggPOomoo`05Ool01@?POomoogoo01l0hgoo
0004Ool01000Oomoo`0017oo00<007ooOol057oo00=l07ooOol02Goo00=mh7ooOol01Goo00D3h7oo
Oomoo`0O0>Aoo`001Goo0P001Goo00<007ooOol04goo00=l07ooOol02Goo00=mh7ooOol01Goo00D3
h7ooOomoo`0O0>Eoo`0037oo00<007ooOol04goo00=l07ooOol02Goo00=mh7ooOol017oo00D3h7oo
Oomoo`0O0>Ioo`0037oo00<007ooOol04Woo00=l07ooOol02Goo00=mh7ooOol017oo00<3h7ooOol0
0Woo00<07gooOol0i7oo000<Ool00`00Oomoo`0AOol00g`0Oomoo`09Ool00ggPOomoo`04Ool00`?P
Oomoo`02Ool00`0OOomoo`3UOol000aoo`03001oogoo011oo`03O01oogoo00Uoo`03ON1oogoo00Ao
o`030n1oogoo009oo`0301moogoo0>Ioo`0037oo00<007ooOol047oo00=l07ooOol02Goo00=mh7oo
Ool017oo00D3h7ooOomoo`0O0>Uoo`0037oo00<007ooOol03goo00=l07ooOol02Goo00=mh7ooOol0
17oo00D3h7ooOomoo`0O0>Yoo`0037oo00<007ooOol03Woo00=l07ooOol02Goo00=mh7ooOol017oo
00<3h7ooOol00Woo00<07gooOol0j7oo000<Ool00`00Oomoo`0=Ool00g`0Oomoo`09Ool00ggPOomo
o`04Ool00`?POomoo`02Ool00`0OOomoo`3YOol000aoo`03001oogoo00eoo`03O01oogoo00Uoo`03
ON1oogoo00=oo`030n1oogoo009oo`0301moogoo0>Yoo`0037oo00<007ooOol037oo00=l07ooOol0
2Goo00=mh7ooOol017oo00D3h7ooOomoo`0O0>eoo`0037oo00<007ooOol02goo00=l07ooOol02Goo
00=mh7ooOol017oo00D3h7ooOomoo`0O0>ioo`0037oo00<007ooOol02Woo00=l07ooOol02Goo00=m
h7ooOol017oo00<3h7ooOol00Woo00<07gooOol0k7oo000<Ool00`00Oomoo`0:Ool00g`0Oomoo`09
Ool00ggPOomoo`04Ool01@?POomoogoo01l0kgoo000<Ool00`00Oomoo`09Ool00g`0Oomoo`09Ool0
0ggPOomoo`04Ool01@?POomoogoo01l0l7oo000<Ool00`00Oomoo`08Ool00g`0Oomoo`09Ool00ggP
Oomoo`05Ool01@?POomoogoo01l0l7oo000<Ool00`00Oomoo`07Ool00g`0Oomoo`09Ool00ggPOomo
o`05Ool01@?POomoogoo01l0lGoo000<Ool00`00Oomoo`07Ool00g`0Oomoo`09Ool00ggPOomoo`04
Ool00`?POomoo`02Ool00`0OOomoo`3_Ool000aoo`03001oogoo00Ioo`03O01oogoo00Uoo`03ON1o
ogoo00Eoo`050n1oogooOol07`3bOol000aoo`03001oogoo00Ioo`03O01oogoo00Uoo`03ON1oogoo
00Aoo`030n1oogoo009oo`0301moogoo0?1oo`0037oo00<007ooOol01Goo00=l07ooOol02Goo00=m
h7ooOol017oo00<3h7ooOol00Woo00<07gooOol0lGoo000<Ool00`00Oomoo`04Ool00g`0Oomoo`0:
Ool00ggPOomoo`04Ool00`?POomoo`02Ool00`0OOomoo`3aOol000aoo`03001oogoo00Aoo`03O01o
ogoo00Uoo`03ON1oogoo00Aoo`030n1oogoo009oo`0301moogoo0?9oo`0037oo00<007ooOol00goo
00=l07ooOol02Woo00=mh7ooOol017oo00<3h7ooOol00Woo00<07gooOol0lWoo000<Ool00`00Oomo
o`03Ool00g`0Oomoo`09Ool00ggPOomoo`04Ool00`?POomoo`02Ool00`0OOomoo`3cOol000aoo`03
001oogoo009oo`03O01oogoo00Yoo`03ON1oogoo00=oo`030n1oogoo009oo`0301moogoo0?Aoo`00
37oo00<007ooOol00Woo00=l07ooOol02Goo00=mh7ooOol017oo00<3h7ooOol00Woo00<07gooOol0
m7oo000<Ool01@00OomoogooO00037oo00=mh7ooOol00goo00<3h7ooOol00Woo00<07gooOol0mGoo
000<Ool01@00OomoogooO0002goo00=mh7ooOol017oo00<3h7ooOol00Woo00<07gooOol0mGoo000<
Ool01000Oomoog`037oo00=mh7ooOol00goo00<3h7ooOol00Woo00<07gooOol0mWoo000<Ool01000
Oomoog`02goo00=mh7ooOol017oo00<3h7ooOol00Woo00<07gooOol0mWoo000<Ool01000Oomoog`0
2goo00=mh7ooOol017oo00D3h7ooOomoo`0O0?Uoo`0037oo00<007ooO0002goo00=mh7ooOol017oo
00<3h7ooOol00Woo00<07gooOol0mgoo000<Ool00`00Ooml000;Ool00ggPOomoo`04Ool01@?POomo
ogoo01l0nWoo000<Ool00`00O01oo`0:Ool00ggPOomoo`05Ool01@?POomoogoo01l0nWoo0005Ool2
0005Ool00`00O01oo`0:Ool00ggPOomoo`04Ool01@?POomoogoo01l0ngoo0004Ool01000Oomoo`00
17oo00=l07ooOol02Goo00=mh7ooOol01Goo00D3h7ooOomoo`0O0?]oo`001Woo00<007ooOol00goo
00=l000000002Goo00=mh7ooOol017oo00D3h7ooOomoo`0O0?aoo`001goo00<007ooOol00Woo00<0
07ooOol027oo00=mh7ooOol01Goo00D3h7ooOomoo`0O0?aoo`0017oo00@007ooOol000Aoo`03001o
ogoo00Qoo`03ON1oogoo00Eoo`040n1oogoo01omOol000Eoo`8000Eoo`03001oogoo00Qoo`03ON1o
ogoo00Aoo`050n1oogooOol07`3mOol000aoo`03001oogoo00Moo`03ON1oogoo00Eoo`050n1oogoo
Ool07`3mOol000aoo`03001oogoo00Moo`03ON1oogoo00Eoo`050n1oogooOol07`3mOol000aoo`03
001oogoo00Moo`03ON1oogoo00Aoo`050n1oogooOol07`3nOol000aoo`03001oogoo00Ioo`03ON1o
ogoo00Eoo`050n1oogooOol07`3nOol000aoo`03001oogoo00Ioo`03ON1oogoo00Eoo`050n1oogoo
Ool07`3nOol000aoo`03001oogoo00Ioo`03ON1oogoo00Aoo`050n1oogooOol07`3oOol000aoo`03
001oogoo00Eoo`03ON1oogoo00Eoo`050n1oogooOol07`3oOol000aoo`03001oogoo00Eoo`03ON1o
ogoo00Aoo`030n1oogoo009oo`0301moogoo0?eoo`0037oo00<007ooOol017oo00=mh7ooOol01Goo
00D3h7ooOomoo`0O0?moo`5oo`0037oo00<007ooOol017oo00=mh7ooOol01Goo00D3h7ooOomoo`0O
0?moo`5oo`0037oo00<007ooOol017oo00=mh7ooOol017oo00<3h7ooOol00Woo00<07gooOol0oWoo
000<Ool00`00Oomoo`03Ool00ggPOomoo`05Ool00`?POomoo`02Ool00`0OOomoo`3nOol000aoo`03
001oogoo00=oo`03ON1oogoo00Eoo`050n1oogooOol07`3oOol2Ool000aoo`03001oogoo00=oo`03
ON1oogoo00Aoo`030n1oogoo009oo`0301moogoo0?moo`0037oo00<007ooOol00Woo00=mh7ooOol0
1Goo00<3h7ooOol00Woo00<07gooOol0ogoo000<Ool00`00Oomoo`02Ool00ggPOomoo`04Ool00`?P
Oomoo`02Ool00`0OOomoo`3oOol1Ool000aoo`03001oogoo009oo`03ON1oogoo00Aoo`030n1oogoo
009oo`0301moogoo0?moo`5oo`0037oo00<007ooOol00Woo00=mh7ooOol017oo00<3h7ooOol00Woo
00<07gooOol0ogoo0Goo000<Ool01@00OomoogooON001Woo00<3h7ooOol00Woo00<07gooOol0ogoo
0Woo000<Ool01@00OomoogooON001Woo00<3h7ooOol00Woo00<07gooOol0ogoo0Woo000<Ool01@00
OomoogooON001Woo00D3h7ooOomoo`0O0?moo`Eoo`0037oo00D007ooOomooggP00Ioo`050n1oogoo
Ool07`3oOol5Ool000aoo`04001oogooON06Ool00`?POomoo`02Ool00`0OOomoo`3oOol3Ool000ao
o`04001oogooON06Ool01@?POomoogoo01l0ogoo1Woo000<Ool01000OomooggP1Woo00D3h7ooOomo
o`0O0?moo`Ioo`0037oo00@007ooOommh0Ioo`050n1oogooOol07`3oOol6Ool000aoo`03001ooggP
00Ioo`030n1oogoo009oo`0301moogoo0?moo`Aoo`0037oo00<007ooON001Woo00<3h7ooOol00Woo
00<07gooOol0ogoo17oo000<Ool00`00Oommh006Ool01@?POomoogoo01l0ogoo1goo000<Ool00`00
Oommh006Ool01@?POomoogoo01l0ogoo1goo000<Ool00`00ON1oo`05Ool00`?POomoo`02Ool00`0O
Oomoo`3oOol5Ool000aoo`03001mh7oo00Eoo`030n1oogoo009oo`0301moogoo0?moo`Eoo`0037oo
00<007gPOol01Goo00<3h7ooOol00Woo00<07gooOol0ogoo1Goo000<Ool00`00ON1oo`05Ool00`?P
Oomoo`02Ool00`0OOomoo`3oOol5Ool000Ioo`<000=oo`03ON1oogoo00Aoo`030n1oogoo009oo`03
01moogoo0?moo`Ioo`001goo00<007ooOol00Woo00=mh7ooOol017oo00<3h7ooOol00Woo00<07goo
Ool0ogoo1Woo0004Ool50003Ool00ggP00000004Ool00`?POomoo`02Ool00`0OOomoo`3oOol6Ool0
00Aoo`04001oogoo003oOolIOol000Eoo`03001oo`000?mooaUoo`001Woo0P00ogoo6Goo003oOolQ
Ool00001\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, 0, 0, 0}}],
  "  "
}], "Text",
  Editable->False],

Cell[TextData[{
  "The solution with the initial condition  ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  "  is \n\n\t\t\t",
  Cell[BoxData[
      \(x \((t)\)\  = \ 
        a\/\(2\ b\) - \@\(4\ b\ k - a\^2\)\/\(2\ b\)\ Tan[
              t\/2\ \@\(4\ b\ k - a\^2\) - 
                ArcTan[\(2\ b\ x\_0 - a\)\/\@\(4\ b\ k - a\^2\)]]\)]],
  ".\n"
}], "Text"],

Cell[TextData[{
  "The function  ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  "  has a vertical asymptote at  ",
  Cell[BoxData[
      \(t\_1\  = \ \(2\ \((\[Pi]\/2 - c)\)\)\/\@\(4\ b\ k - a\^2\)\)]],
  " so the population   ",
  StyleBox["x(t)",
    FontFamily->"Courier New"],
  "  becomes extinct at some time  ",
  Cell[BoxData[
      \(t = t\_0\)]],
  "  (where ",
  Cell[BoxData[
      \(0 < t\_0 < t\_1\)]],
  ".), i.e.  \n\n\t\t\t",
  Cell[BoxData[
      \(x \((t\_0)\)\  = \ 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/HarvestingModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/HarvestingModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Solutions",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIf only the graph of the solution is required, and the formula is \
not needed, then an efficient way to solve the differential equation is with \
a numerical method such as Modified Euler's method or the Runge-Kutta method. \
 The choice of method depends on the accuracy required.  If an accurate table \
of numerical values is required then the Runge-Kutta method should be used.  \
"
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/HarvestingModelProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/HarvestingModelProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Program ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" (Modified Euler's Method)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To compute a numerical approximation for the solution of the \
initial value problem ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y'\  = \ f \((t, y)\)\)]],
  StyleBox[" with ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(y \((a)\) = \[Alpha]\)]],
  " over",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  " at a discrete set of points using the formula ",
  Cell[BoxData[
      \(y\_\(k + 1\)\  = \ 
        y\_k\  + \ 
          h\ f \((t\_k + h\/2, y\_k\  + \ h\/2\ f \((t\_k, y\_k)\))\)\)]],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(\(MEuler[a0_, b0_, \[Alpha]_, 
        m0_]\)\(:=\)\(\ \)\(\[IndentingNewLine]\)\(Module[{a = a0, b = b0, j, 
          m = m0}, \[IndentingNewLine]h\  = \ \(b - a\)\/m; \ \
\[IndentingNewLine]T\  = \ 
          Table[\ a + \((j - 1)\) h, {j, 1, 
              m + 1}]; \ \[IndentingNewLine]Y = \ 
          Table[\ \[Alpha], {j, 1, m + 1}]; \ \ \[IndentingNewLine]For[\ 
          j = 1, j \[LessEqual] 
            m, \(j++\), \[IndentingNewLine]\(Y\_\(\(\[LeftDoubleBracket]\)\(j \
+ 1\)\(\[RightDoubleBracket]\)\) = 
              Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\) + 
                h\ \ f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\) + h\/2, 
                    Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\
\)\) + \(h\/2\) 
                        f[T\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\), 
                          Y\_\(\(\[LeftDoubleBracket]\)\(j\)\(\
\[RightDoubleBracket]\)\)]];\)\ ]; \ \[IndentingNewLine]Return[
          Transpose[{T, Y}]];\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to solve the D. E.  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, k, x, t];\)\ \), "\[IndentingNewLine]", 
    \(\(de = \(x'\)[t] \[Equal] 
          a\ x[t] - b\ x[t]\^2 - k;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the D. E.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \)}], "Input"],

Cell[TextData[{
  "Use the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s procedure  ",
  StyleBox["DSolve",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(solset = DSolve[\ de, \ x[t], \ t\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(f[t_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The solution is\>", "\<\n\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", f[t]];\)\), "\[IndentingNewLine]", 
    \(\(f[t_] = \ FullSimplify[f[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", f[t]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  The general solution found by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (and Maple too) is for case (iii) only.  Is this a surprise ?  It is up \
to the reader to find proof for the formulas in cases (i) and (ii)."
}], "Text"],

Cell[TextData[{
  StyleBox["Warning.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  This illustrates what happens when we use a computer symbolic algebra \
system such as Derive, Maple, Matlab, MACSYMA or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is used to find the \"general solution.\"  Only one solution is found.  \
Furthermore, it might be the \"least significant\" of the three forms of the \
solution that exist.  However, luck is with us.  When numbers are used for \
the arbitrary constants, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will find the correct solution.  This \"confusion\" must be understood if \
a practicing mathematician is planning on using computer symbolic algebra \
systems such as Derive, Maple, Matlab, MACSYMA or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the roots of  ",
  Cell[BoxData[
      \(a\ r\  - \ b\ r\^2\  - \ k\  = \ 0\)]],
  ",  and equilibrium solutions of the D. E.  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(ceqn\  = \ 
        a\ r\  - \ b\ r\^2 - \ 
            k\  \[Equal] \ \ 0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation  \>", ceqn];\)\)}], "Input"],

Cell[TextData[{
  "Use the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s procedure  ",
  StyleBox["Solve",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(\(Solve[\ ceqn, r\ ]\)\(\ \)\)\)], "Input"],

Cell["\<\
There are two \"constant\" or stationary solutions to the D. E.\
\>", "Text"],

Cell[BoxData[{
    \(\(x\_1[
          t_] = \(a - \@\(a\^2 - 4\ b\ k\)\)\/\(2\ b\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(x\_1\)[t] = \>\"", 
        x\_1[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)'[t] = \>\"", \(x\_1'\)[
          t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a \!\(x\_1\)[t]- b \!\(\((x\_1[t])\)\^2\) - k = \>\"", 
        a\ x\_1[t] - \ b\ \((x\_1[t])\)\^2\  - \ 
          k\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a \!\(x\_1\)[t]- b \!\(\((x\_1[t])\)\^2\) - k = \>\"", 
        MapAll[Expand, 
          a\ x\_1[t] - \ b\ \((x\_1[t])\)\^2\  - \ 
            k]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)'[t] = a \!\(x\_1\)[t]- b \!\(\((x\_1[t])\)\^2\
\) - k\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        MapAll[Expand, \(x\_1'\)[t]\  \[Equal] \ 
            a\ x\_1[t] - \ b\ \((x\_1[t])\)\^2\  - \ k]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(x\_2[
          t_] = \(a + \@\(a\^2 - 4\ b\ k\)\)\/\(2\ b\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(x\_2\)[t] = \>\"", 
        x\_2[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)'[t] = \>\"", \(x\_2'\)[
          t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a \!\(x\_2\)[t]- b \!\(\((x\_2[t])\)\^2\) - k = \>\"", 
        a\ x\_2[t] - \ b\ \((x\_2[t])\)\^2\  - \ 
          k\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<a \!\(x\_2\)[t]- b \!\(\((x\_2[t])\)\^2\) - k = \>\"", 
        MapAll[Expand, 
          a\ x\_2[t] - \ b\ \((x\_2[t])\)\^2\  - \ 
            k]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)'[t] = a \!\(x\_2\)[t]- b \!\(\((x\_2[t])\)\^2\
\) - k\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        MapAll[Expand, \(x\_2'\)[t]\  \[Equal] \ 
            a\ x\_2[t] - \ b\ \((x\_2[t])\)\^2\  - \ k]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Caveat.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  The stationary solutions found are for case (ii).  Substituting  ",
  Cell[BoxData[
      \(k = a\^2\/\(4\ b\)\)]],
  " must be done prior to solving if the solution for case (i) is to be \
obtained."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Case (i)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" If   ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(a\^2 = 4\ b\ k\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  there is one stationary solution ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(\(x\_1\) \((t)\) = a\/\(2\ b\)\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " Solve the population model with harvesting  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  ", \nusing the constants  ",
  StyleBox["a = 2",
    FontFamily->"Courier New"],
  ",  ",
  StyleBox["b = 1",
    FontFamily->"Courier New"],
  ",  and  ",
  StyleBox["k = 1",
    FontFamily->"Courier New"],
  ",  and explore this situation."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, k, x, t];\)\ \), "\[IndentingNewLine]", 
    \(\(de = \(x'\)[t] \[Equal] 
          a\ x[t] - b\ x[t]\^2 - k;\)\ \), "\[IndentingNewLine]", 
    \(\(de1 = 
        ReplaceAll[\ 
          de, \ {a \[Rule] 2, b \[Rule] 1, 
            k \[Rule] 1}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Replace  {a\[Rule]2, b\[Rule]1, k\[Rule]1}\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de1];\)\ \ \)}], "Input"],

Cell["Construct the general solution. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<Solve\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de1];\)\ \), "\[IndentingNewLine]", 
    \(\(sol1 = DSolve[de1\ , x[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[sol1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(x[t_] = \ 
      sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\[RightDoubleBracket]\)\); \
\ Print["\<x[t] = \>", x[t]\ ];\ \)}], "Input"],

Cell["Construct the constant solution.  ", "Text"],

Cell[BoxData[{
    \(\(ceqn = 
        a\ X[t] - b\ X[t]\^2 - k\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(ceqn1 = 
        ReplaceAll[
          ceqn, \ {a \[Rule] 2, b \[Rule] 1, 
            k \[Rule] 1}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(csolset = Solve[\ ceqn1, \ X[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(x\_1[t_] = \ 
        csolset\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\[RightDoubleBracket]\
\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[ceqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Replace {a\[Rule]2, b\[Rule]1, k\[Rule]1}\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Solve\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[ceqn1];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<Get\>"]; \ 
    Print[\*"\"\<\!\(x\_1\)[t] = \>\"", x\_1[t]\ ];\ \)}], "Input"],

Cell[TextData[{
  "Find the limit as ",
  Cell[BoxData[
      \(t \[Rule] \[Infinity]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(lim = 
        Limit[\ x[t], 
          t \[Rule] \[Infinity]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\< x[t] = \
\>", \*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\< \>", 
        x[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\< x[t] = \
\>", lim];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<\>"]; \ 
    Print[\*"\"\<\!\(x\_1\)[t] = \>\"", x\_1[t]\ ];\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Plot the solutions to the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 2\ x[t] - x[t]\^2 - 1\)]],
  "  in Example 3\nthat have the following initial conditions  ",
  StyleBox["x[0] = 2",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["3",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["4",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["5",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["6",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Use the general solution that was constructed in example 4.", "Text"],

Cell[BoxData[
    \(x[t_]\  = \ \(1 + t - C[1]\)\/\(t - C[1]\)\)], "Input"],

Cell[TextData[{
  "Solve for the constant ",
  StyleBox["C[1]",
    FontFamily->"Courier New"],
  " to make the initial conditions  ",
  StyleBox["x[0] = 2",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["3",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["4",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["5",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["6",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(\(Table[\ 
      Solve[\ x[0] == c, C[1]\ ], \ {c, 2, 6}]\)\(\ \)\)\)], "Input"],

Cell["\<\
The solution functions corresponding to the above list of constants is: \
\>", "Text"],

Cell[BoxData[
    \(\(\(fun1\)\(\ \)\(=\)\(\ \)\(ReplaceAll[\ x[t]\ , 
        C[1]\  \[Rule] \ Table[\(-1\)\/j, {j, 1, 5}]\ ]\)\(\ \)\)\)], "Input"],

Cell["Make them look nicer.  ", "Text"],

Cell[BoxData[
    \(\(\(fun1\)\(=\)\(Together[fun1]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Plot these functions, since a \"table of functions\" is being sent to the \
plot subroutine, the command ",
  StyleBox["Evaluate",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " is necessary.   "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph1 = \ 
        Plot[\ Evaluate[fun1], {t, 0, 6}, PlotRange \[Rule] {{0, 2}, {0, 6}}, 
          PlotStyle \[Rule] {Brown, Red, Orange, Green, 
              Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", fun1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", ReplaceAll[fun1, t \[Rule] 0]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Plot some more solutions to the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 2\ x[t] - x[t]\^2 - 1\)]],
  "  in Example 3\nPlot those that have the following initial conditions  ",
  Cell[BoxData[
      RowBox[{\(x[0] = 1\/5\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(2\/5\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(3\/5\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(4\/5\)}]]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Use the general solution that was constructed in example 4.", "Text"],

Cell[BoxData[
    \(x[t_]\  = \ \(1 + t - C[1]\)\/\(t - C[1]\)\)], "Input"],

Cell[TextData[{
  "Solve for the constant ",
  StyleBox["C[1]",
    FontFamily->"Courier New"],
  " to make the initial conditions",
  "  ",
  Cell[BoxData[
      RowBox[{\(x[0] = 1\/5\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(2\/5\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(3\/5\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(4\/5\)}]]],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(\(Table[\ 
      Solve[\ x[0] \[Equal] j\/5, C[1]\ ], \ {j, 1, 4}]\)\(\ \)\)\)], "Input"],

Cell["\<\
The solution functions corresponding to the above list of constants is: \
\>", "Text"],

Cell[BoxData[
    \(\(\(fun2\)\(\ \)\(=\)\(\ \)\(ReplaceAll[\ x[t], \ 
        C[1]\  \[Rule] \ Table[5\/j, {j, 1, 4}]\ ]\)\(\ \)\)\)], "Input"],

Cell["Make them look nicer.  ", "Text"],

Cell[BoxData[
    \(\(\(fun2\)\(=\)\(Simplify[fun2]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Plot these functions, since a \"table of functions\" is being sent to the \
plot subroutine, the command ",
  StyleBox["Evaluate",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " is necessary.   "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = \ 
        Plot[Evaluate[fun2], {t, 0, 6}, PlotRange \[Rule] {{0, 6}, {0, 6}}, 
          PlotStyle \[Rule] {Brown, Red, Green, 
              Blue}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", fun2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", ReplaceAll[fun2, t \[Rule] 0]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Discuss the graphs in the plot in Example 5.\nWhat are the vertical lines \
?\nWhat are the curves that lie below ",
  StyleBox["x=1",
    FontFamily->"Courier New"],
  ".\nWhat are the curves that lie above ",
  StyleBox["x=1",
    FontFamily->"Courier New"],
  " ?  What use are they ?\n\nIn order to clear things up, it is necessary to \
specify the individual domain, for each of the solutions, then plot all the \
curves on the same graph."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Recall from example 4 that the constant solution is  ",
  Cell[BoxData[
      \(x\_1[t] = 1\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_] = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t] = \>\"", x\_1[t]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x\_1[t_] = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(g0 = \ 
        Plot[x\_1[t], {t, 0, 6}, PlotRange \[Rule] {{0, 2}, {0, 1}}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = \ 
        Plot[Evaluate[fun2], {t, 0, 6}, PlotRange \[Rule] {{0, 6}, {0, 6}}, 
          PlotStyle \[Rule] {Brown, Red, Green, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g0, gr2, PlotRange \[Rule] {{0, 6}, {0, 6}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", fun2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", 
        ReplaceAll[fun2, t \[Rule] 0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<And the `constant` solution\>"];\)\), "\[IndentingNewLine]", \

    \(\(Print[\*"\"\<\!\(x\_1\)[t] = \>\"", x\_1[t]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "The vertical lines are asymptotes of the solutions ",
  Cell[BoxData[
      \(x[
          t]\  = {\(\(-4\) + t\)\/\(\(-5\) + t\), \(3 - 2\ t\)\/\(5 - 2\ t\), \
\(2 - 3\ t\)\/\(5 - 3\ t\), \(1 - 4\ t\)\/\(5 - 4\ t\)}\)]],
  ".  \n\nThe curves that lie below ",
  Cell[BoxData[
      \(x\_1[t] = 1\)]],
  " are the solutions with the initial conditions we wanted.\n\nThe curves \
that lie above ",
  Cell[BoxData[
      \(x\_1[t] = 1\)]],
  " are extraneous portions of the solution functions.   \nThey are not \
useful for our purposes.  In order to get rid of them it will take some \
effort."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g0 = \ 
        Plot[x\_1[t], {t, 0, 6}, PlotRange \[Rule] {{0, 2}, {0, 1}}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(g1\  = \ 
        Plot[\(\(-4\) + t\)\/\(\(-5\) + t\), {t, 0, 5}, 
          PlotRange \[Rule] {{0, 2}, {0, 1}}, PlotStyle \[Rule] Brown, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(g2\  = \ 
        Plot[\(3 - 2\ t\)\/\(5 - 2\ t\), {t, 0, 5/2}, 
          PlotRange \[Rule] {{0, 2}, {0, 1}}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(g3\  = \ 
        Plot[\(2 - 3\ t\)\/\(5 - 3\ t\), {t, 0, 5/3}, 
          PlotRange \[Rule] {{0, 2}, {0, 1}}, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(g4 = \ 
        Plot[\(1 - 4\ t\)\/\(5 - 4\ t\), {t, 0, 5/4}, 
          PlotRange \[Rule] {{0, 2}, {0, 1}}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g0, g1, g2, g3, g4, PlotRange \[Rule] {{0, 6}, {0, 6}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Show[g0, g1, g2, g3, g4, PlotRange \[Rule] {{0, 4}, {0, 6}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t] = \>\"", 
        x\_1[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", fun2];\)\)}], "Input"],

Cell["Now form a composite graph of all the functions.", "Text"],

Cell[BoxData[{
    \(\(Show[g0, g1, g2, g3, g4, graph1, PlotRange \[Rule] {{0, 4}, {0, 6}}, 
        Ticks \[Rule] {Range[0, 6, 1], Range[0, 6, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", fun1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", 
        ReplaceAll[fun1, t \[Rule] 0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t] = \>\"", 
        x\_1[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", fun2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", ReplaceAll[fun2, t \[Rule] 0]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Observe.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solutions with initial conditions  ",
  StyleBox["x[0] > 0",
    FontFamily->"Courier New"],
  "  tend to  ",
  Cell[BoxData[
      \(x\_1[t] = 1\)]],
  " as ",
  Cell[BoxData[
      \(t \[Rule] \[Infinity]\)]],
  ". \nThe solutions with initial conditions  ",
  StyleBox["0 < x [0] < 1",
    FontFamily->"Courier New"],
  "  go to zero at some finite value of ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " and  ",
  StyleBox["x[t]",
    FontFamily->"Courier New"],
  "  becomes extinct. \nThe constant function   ",
  Cell[BoxData[
      \(x\_1[t] = 1\)]],
  " is the dividing line for these two cases. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the ",
  " D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 2\ x[t] - x[t]\^2 - 1\)]],
  "  using the formula with the initial condition  ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, verify that the formula for the general solution is correct.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, t, x];\)\), "\[IndentingNewLine]", 
    \(\(de = \(x'\)[t] \[Equal] 
          2\ x[t] - \ x[t]\^2 - 1;\)\), "\[IndentingNewLine]", 
    \(solset\  = MapAll[Simplify, DSolve[de, x[t], t]]\)}], "Input"],

Cell[BoxData[{
    \(sol = 
      Together[ReplaceAll[
          a\/\(2\ b\) + \(1\/b\) 1\/\(t - 4\ b\ c\), {a \[Rule] 2, 
            b \[Rule] 1, 
            k \[Rule] a\^2/\((4\ b)\)}]]\), "\[IndentingNewLine]", 
    \(sol = ReplaceAll[sol, c \[Rule] c/4]\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<The general solution to\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", sol];\)\)}], "Input"],

Cell[TextData[{
  "First, verify that the formula for the solution with the initial condition \
 ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  "  is correct. "
}], "Text"],

Cell[BoxData[{
    \(\(ic = x[0] \[Equal] 2;\)\), "\[IndentingNewLine]", 
    \(solset = DSolve[{de, ic}, x[t], t]\)}], "Input"],

Cell[BoxData[
    \(sol = 
      Together[ReplaceAll[
          a\/\(2\ b\) + \(1\/b\) 
              1\/\(t - 2/\((a - 2\ b\ x\_0)\)\), {a \[Rule] 2, b \[Rule] 1, 
            k \[Rule] a\^2/\((4\ b)\), x\_0 \[Rule] 2}]]\)], "Input"],

Cell[BoxData[{
    \(\(Print["\<The solution to\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[ic];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", sol];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Use the Modified Euler Method to find numerical solutions to",
  " the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 2\ x[t] - x[t]\^2 - 1\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The solution curves with the initial conditions  ",
  Cell[BoxData[
      \(x \((0)\) = 6, 5, 4, 3, 2, 1, 4\/5\)]],
  "  can all be computed over the interval  ",
  Cell[BoxData[
      \(\([a, b]\) = \([0, 4]\)\)]],
  ".  \nHowever the solution curves with the initial conditions   ",
  Cell[BoxData[
      \(x \((0)\) = 3\/5, 2\/5, 1\/5\)]],
  "   must be computed over smaller intervals, \nfor instance the intervals   \
",
  Cell[BoxData[
      \(\([a, b]\) = \([0, 1.5]\), \([0, 1.0]\), \ \([0, 0.5]\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, t, y];\)\), "\[IndentingNewLine]", 
    \(\(f[t_, y_]\  = \ 2\ y - y\^2 - 1;\)\ \), "\[IndentingNewLine]", 
    \(\(p0 = {6, 5, 4, 3, 2, 1, 4\/5};\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\), "\[IndentingNewLine]", 
    \(\(b = 4.0;\)\ \), "\[IndentingNewLine]", 
    \(\(MEuler[\ a\ , b, p0\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 
        Table[0, {i, 
            Length[Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)]}];\)\), "\[IndentingNewLine]", 
    \(\(graphs = Z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(colors = {Blue, Green, Orange, Red, Brown, \ Magenta, Brown, Red, 
          Green, Blue, Black, Black};\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
], \(i++\), \[IndentingNewLine]Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
          Transpose[{T, 
              Y\_\(\(\[LeftDoubleBracket]\)\(All, \
i\)\(\[RightDoubleBracket]\)\)}]; \[IndentingNewLine]graphs\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\) = 
          ListPlot[
            Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
            PlotJoined \[Rule] True, 
            PlotStyle \[Rule] 
              colors\_\(\(\[LeftDoubleBracket]\)\(Mod[i, 11]\)\(\
\[RightDoubleBracket]\)\), 
            DisplayFunction \[Rule] 
              Identity];\ ];\)\), "\[IndentingNewLine]", 
    \(\(Show[graphs, PlotRange \[Rule] {{a, b}, {0, 5}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(W = MEuler[0.0\ , 1.5, 3\/5\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(graph1 = 
        ListPlot[W, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, PlotRange \[Rule] {{0, 4}, {0, 5}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(W = MEuler[0.0\ , 1.0, 2\/5\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ListPlot[W, PlotJoined \[Rule] True, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph2, PlotRange \[Rule] {{0, 4}, {0, 5}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(W = MEuler[0.0\ , 0.5, 1\/5\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ListPlot[W, PlotJoined \[Rule] True, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph3, PlotRange \[Rule] {{0, 4}, {0, 5}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell["Now all the solution curves can be shown on one graph. ", "Text"],

Cell[BoxData[
    \(\(Show[graphs, graph1, graph2, graph3, 
        PlotRange \[Rule] {{a, b}, {0, 6}}, 
        Ticks \[Rule] {Range[0, 4, 1], Range[0, 6, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell["\<\
This is the same as the graph that was obtained in Example 6.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Case (ii)  If  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(a\^2 > 4\ b\ k\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" there are two stationary solutions  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(\(x\_1\) \((t)\) = \(a - \@\(a\^2 - 4\ b\ k\)\)\/\(2\ b\)\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  and  ",
  Cell[BoxData[
      \(\(x\_2\) \((t)\) = \(a + \@\(a\^2 - 4\ b\ k\)\)\/\(2\ b\)\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " Solve the population model with harvesting  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  ",  \nusing the constants  ",
  StyleBox["a = 4",
    FontFamily->"Courier New"],
  ",  ",
  StyleBox["b = 1",
    FontFamily->"Courier New"],
  ",  and  ",
  StyleBox["k = 3",
    FontFamily->"Courier New"],
  ",  and explore this situation."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, k, x, t];\)\ \), "\[IndentingNewLine]", 
    \(\(de = \(x'\)[t] \[Equal] 
          a\ x[t] - b\ x[t]\^2 - k;\)\ \), "\[IndentingNewLine]", 
    \(\(de1 = 
        ReplaceAll[\ 
          de, \ {a \[Rule] 4, b \[Rule] 1, 
            k \[Rule] 3}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Replace  {a\[Rule]4, b\[Rule]1, k\[Rule]3}\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de1];\)\ \ \)}], "Input"],

Cell["Construct the general solution. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<Solve\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de1];\)\ \), "\[IndentingNewLine]", 
    \(\(sol1 = DSolve[de1\ , x[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[sol1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[t_] = \ 
        sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]\ ];\)\ \)}], "Input"],

Cell["Construct the constant solutions.  ", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, k, X, t];\)\ \), "\[IndentingNewLine]", 
    \(\(ceqn = 
        a\ X[t] - b\ X[t]\^2 - k\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(ceqn1 = 
        ReplaceAll[
          ceqn, \ {a \[Rule] 4, b \[Rule] 1, 
            k \[Rule] 3}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(csolset = Solve[\ ceqn1, \ X[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(x\_1[t_] = \ 
        csolset\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\[RightDoubleBracket]\
\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(x\_2[t_] = \ 
        csolset\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\[RightDoubleBracket]\
\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[ceqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Replace {a\[Rule]4, b\[Rule]1, k\[Rule]3}\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Solve\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[ceqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[csolset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t] = \>\"", 
        x\_1[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t] = \>\"", x\_2[t]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Find  ",
  Cell[BoxData[
      \(lim\+\(t \[Rule] \[Infinity]\)\ x[t]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(lim = 
        Limit[\ x[t], 
          t \[Rule] \[Infinity]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\< x[t] = \
\>", \*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\< \>", 
        x[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(t \[Rule] \[Infinity]\)\)\>\"", "\< x[t] = \
\>", lim];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<\>"]; \ 
    Print[\*"\"\<\!\(x\_2\)[t] = \>\"", x\_2[t]\ ];\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Notice that  ",
  Cell[BoxData[
      \(lim\+\(t \[Rule] \[Infinity]\)\ x[t]\)]],
  "  tends to the second constant function  ",
  Cell[BoxData[
      \(x\_2[t] = 3\)]],
  "  as ",
  Cell[BoxData[
      \(t \[Rule] \[Infinity]\)]],
  ".  \nIt will take more investigation to see what is happening.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Plot the solutions to the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 4\ x[t] - x[t]\^2 - 3\)]],
  "  in Example 9\nthat have the following initial conditions  ",
  StyleBox["x[0] = 4",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["5",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["6",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["7",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["8",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We shall use the technique where we solve  ",
  Cell[BoxData[
      \(x[
          0] = \(\(3\ \[ExponentialE]\^0 - \[ExponentialE]\^\(2\ C[1]\)\)\/\(\
\[ExponentialE]\^0 - \[ExponentialE]\^\(2\ C[1]\)\) = c\)\)]],
  "  for  ",
  Cell[BoxData[
      \(c = 4\/3, 5\/3, 6\/3, 7\/3, 8\/3\)]],
  ". \nYou will get some warning messages from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", ignore them.  Hang in there ! "
}], "Text"],

Cell[BoxData[{
    \(\(x[
          t_] = \(3\ \[ExponentialE]\^\(2\ t\) - \[ExponentialE]\^\(2\ C[1]\)\
\)\/\(\[ExponentialE]\^\(2\ t\) - \[ExponentialE]\^\(2\ C[1]\)\);\)\ \), "\
\[IndentingNewLine]", 
    \(Table[\ Solve[\ x[0] \[Equal] c, C[1]\ ], \ {c, 4, 8}]\ \)}], "Input"],

Cell[TextData[{
  "Replace the values  ",
  Cell[BoxData[
      \({\(-\(Log[3]\/2\)\), \(-\(Log[2]\/2\)\), \(-\(1\/2\)\)\ Log[
            5\/3], \(-\(1\/2\)\)\ Log[3\/2], \(-\(1\/2\)\)\ Log[7\/5]}\)]],
  "  for the constant ",
  StyleBox["c[1]",
    FontFamily->"Courier New"],
  ",\nand ",
  "form the functions",
  " we wish to plot. "
}], "Text"],

Cell[BoxData[
    \(\(\(fun1\)\(\ \)\(=\)\(\ \)\(ReplaceAll[\ 
        x[t], \ \ C[1]\  \[Rule] \ 
          Table[\(-\(1\/2\)\)\ Log[\(j + 2\)\/j], {j, 1, 
              5}]\ ]\)\(\ \)\)\)], "Input"],

Cell["Make them look nicer.  ", "Text"],

Cell[BoxData[
    \(\(\(fun1\)\(\ \)\(=\)\(\ \)\(Simplify[fun1]\)\(\ \)\)\)], "Input"],

Cell["Graph these solutions. ", "Text"],

Cell[BoxData[{
    \(\(HDE\  = \ \*"\"\<x'[t] = 4 x[t] - x[t\!\(\(]\^2\)\) - 3\>\"";\)\ \), \
"\[IndentingNewLine]", 
    \(\(x\_2[t_] = \ 3;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = \ 
        Plot[Evaluate[{x\_2[t], fun1}], {t, 0, 1}, 
          PlotRange \[Rule] {{0, 1}, {0, 8}}, 
          PlotStyle \[Rule] {Magenta, Brown, Red, Orange, Green, 
              Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[HDE];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[t] = \>", fun1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[0] = \>", 
        ReplaceAll[fun1, t \[Rule] 0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t] = \>\"", x\_2[t]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Observe.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The family of functions ",
  Cell[BoxData[
      \(x[
          t]\  = {\(1 - 9\ \[ExponentialE]\^\(2\ t\)\)\/\(1 - 3\ \
\[ExponentialE]\^\(2\ t\)\), \(1 - 6\ \[ExponentialE]\^\(2\ t\)\)\/\(1 - 2\ \
\[ExponentialE]\^\(2\ t\)\), \(3 - 15\ \[ExponentialE]\^\(2\ t\)\)\/\(3 - 5\ \
\[ExponentialE]\^\(2\ t\)\), \(2 - 9\ \[ExponentialE]\^\(2\ t\)\)\/\(2 - 3\ \
\[ExponentialE]\^\(2\ t\)\), \(5 - 21\ \[ExponentialE]\^\(2\ t\)\)\/\(5 - 7\ \
\[ExponentialE]\^\(2\ t\)\)}\)]],
  " \ntend to the constant function  ",
  Cell[BoxData[
      \(x\_2[t] = \ 3\)]],
  "  as  ",
  Cell[BoxData[
      \(t \[Rule] \[Infinity]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Plot the solutions to the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 4\ x[t] - x[t]\^2 - 3\)]],
  "  in Example 9\nthat have the following initial conditions  ",
  Cell[BoxData[
      \(x[0] = 4\/3, 5\/3, 6\/3, 7\/3, 8\/3\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We could try the above technique where we solve  ",
  Cell[BoxData[
      \(x[
          0] = \(\(3\ \[ExponentialE]\^0 - \[ExponentialE]\^\(2\ C[1]\)\)\/\(\
\[ExponentialE]\^0 - \[ExponentialE]\^\(2\ C[1]\)\) = c\)\)]],
  "  for  ",
  Cell[BoxData[
      \(c = 4\/3, 5\/3, 6\/3, 7\/3, 8\/3\)]],
  ". \nBut it will involve complex numbers.  Hang in there ! "
}], "Text"],

Cell[BoxData[{
    \(\(x[
          t_] = \(3\ \[ExponentialE]\^\(2\ t\) - \[ExponentialE]\^\(2\ C[1]\)\
\)\/\(\[ExponentialE]\^\(2\ t\) - \[ExponentialE]\^\(2\ C[1]\)\);\)\), "\
\[IndentingNewLine]", 
    \(Table[\ 
      Solve[\ x[0] \[Equal] c, C[1]\ ], \ {c, 4\/3, 8\/3, 
        1\/3}]\ \)}], "Input"],

Cell[TextData[{
  "Notice that there are multiple solutions for some of these values. \n\
Special care and attention must be given to locate the ones to use, they are:\
\n",
  Cell[BoxData[
      \({Log[\[ImaginaryI]\ \@5], 
        Log[\[ImaginaryI]\ \@2], \(\[ImaginaryI]\ \[Pi]\)\/2, 
        1\/2\ \((\[ImaginaryI]\ \[Pi] - 
              Log[2])\), \ \(1\/2\) \((\[ImaginaryI]\ \[Pi] - Log[5])\)}\)]],
  "\nNow replace these constants."
}], "Text"],

Cell[BoxData[
    \(\(\(fun2\)\(\ \)\(=\)\(\ \)\(ReplaceAll[\ 
        x[t], \ \ C[1]\  \[Rule] {Log[\[ImaginaryI]\ \@5], 
            Log[\[ImaginaryI]\ \@2], \(\[ImaginaryI]\ \[Pi]\)\/2, 
            1\/2\ \((\[ImaginaryI]\ \[Pi] - Log[2])\), 
            1\/2\ \((\[ImaginaryI]\ \[Pi] - 
                  Log[5])\)}\ ]\)\(\ \)\)\)], "Input"],

Cell["Make them look nicer.  ", "Text"],

Cell[BoxData[
    \(\(\(fun2\)\(\ \)\(=\)\(\ \)\(Simplify[fun2]\)\(\ \)\)\)], "Input"],

Cell["\<\
It might be better to just solve the D.E. with the required initial \
conditions.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[x, t];\)\ \), "\[IndentingNewLine]", 
    \(\(de\  = \ \(x'\)[t] \[Equal] \(-3\) + 4\ x[t] - 
            x[t]\^2;\)\ \), "\[IndentingNewLine]", 
    \(sol = \ DSolve[{de, x[0] \[Equal] 1 + j\/3}\ , x[t], t]\ \)}], "Input"],

Cell["Then form the construction with the following two steps.", "Text"],

Cell[BoxData[
    \(\(\(fun2\)\(=\)\(sol\_\(\(\[LeftDoubleBracket]\)\(1, 1, 
          2\)\(\[RightDoubleBracket]\)\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(fun2\)\(=\)\(Table[fun2, {j, 1, 5}]\)\(\ \)\)\)], "Input"],

Cell["\<\
This is the same list that was obtained using those pesky complex numbers. \
\>", "Text"],

Cell["Graph these solutions. ", "Text"],

Cell[BoxData[{
    \(\(HDE\  = \ \*"\"\<x'[t] = 4 x[t] - x[t\!\(\(]\^2\)\) - 3\>\"";\)\ \), \
"\[IndentingNewLine]", 
    \(\(x\_1[t_] = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(x\_2[t_] = \ 3;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = \ 
        Plot[Evaluate[{x\_2[t], fun2, x\_1[t]}], {t, 0, 2}, 
          PlotRange \[Rule] {{0, 2}, {0, 3.5}}, 
          PlotStyle \[Rule] {Magenta, Blue, Green, Orange, Red, Brown, 
              Purple}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[HDE];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", fun2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", 
        ReplaceAll[fun2, t \[Rule] 0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t] = \>\"", 
        x\_2[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t] = \>\"", x\_1[t]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Observe.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The family of functions ",
  Cell[BoxData[
      \(x[
          t]\  = {\(5 + 3\ \[ExponentialE]\^\(2\ t\)\)\/\(5 + \[ExponentialE]\
\^\(2\ t\)\), \(4 + 6\ \[ExponentialE]\^\(2\ t\)\)\/\(4 + 2\ \
\[ExponentialE]\^\(2\ t\)\), \(3 + 9\ \[ExponentialE]\^\(2\ t\)\)\/\(3 + 3\ \
\[ExponentialE]\^\(2\ t\)\), \(2 + 12\ \[ExponentialE]\^\(2\ t\)\)\/\(2 + 4\ \
\[ExponentialE]\^\(2\ t\)\), \(1 + 15\ \[ExponentialE]\^\(2\ t\)\)\/\(1 + 5\ \
\[ExponentialE]\^\(2\ t\)\)}\)]],
  " \ntend to the constant function  ",
  Cell[BoxData[
      \(x\_2[t] = \ 3\)]],
  "  as  ",
  Cell[BoxData[
      \(t \[Rule] \[Infinity]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Plot the solutions to the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 4\ x[t] - x[t]\^2 - 3\)]],
  "  in Example 9\nthat have the following initial conditions  ",
  Cell[BoxData[
      \(x[0] = 1\/5, 2\/5, 3\/5, 4\/5\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We could try the above technique where we solve  ",
  Cell[BoxData[
      \(x[
          0] = \(\(3\ \[ExponentialE]\^0 - \[ExponentialE]\^\(2\ C[1]\)\)\/\(\
\[ExponentialE]\^0 - \[ExponentialE]\^\(2\ C[1]\)\) = c\)\)]],
  "  for  ",
  Cell[BoxData[
      \(c = 1\/5, 2\/5, 3\/5, 4\/5\)]],
  ". \nBut it will involve complex numbers.  Hang in there ! "
}], "Text"],

Cell[BoxData[{
    \(\(x[
          t_] = \(3\ \[ExponentialE]\^\(2\ t\) - \[ExponentialE]\^\(2\ C[1]\)\
\)\/\(\[ExponentialE]\^\(2\ t\) - \[ExponentialE]\^\(2\ C[1]\)\);\)\), "\
\[IndentingNewLine]", 
    \(Table[\ 
      Solve[\ x[0] \[Equal] c, C[1]\ ], \ {c, 1\/5, 4\/5, 
        1\/5}]\ \)}], "Input"],

Cell[TextData[{
  "Notice that there are multiple solutions for some of these values. \n\
Special care and attention must be given to locate the ones to use, they are:\
\n",
  Cell[BoxData[
      \({1\/2\ Log[7\/2], 1\/2\ Log[13\/3], Log[6]\/2, Log[11]\/2}\)]],
  "\nNow replace these constants."
}], "Text"],

Cell[BoxData[
    \(\(\(fun3\)\(\ \)\(=\)\(\ \)\(ReplaceAll[\ 
        x[t], \ \ C[1]\  \[Rule] {1\/2\ Log[7\/2], 1\/2\ Log[13\/3], 
            Log[6]\/2, Log[11]\/2}\ ]\)\(\ \)\)\)], "Input"],

Cell["Make them look nicer.  ", "Text"],

Cell[BoxData[
    \(\(\(fun3\)\(\ \)\(=\)\(\ \)\(Simplify[fun3]\)\(\ \)\)\)], "Input"],

Cell["\<\
It might be better to just solve the D.E. with the required initial \
conditions.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[x, t];\)\ \), "\[IndentingNewLine]", 
    \(\(de\  = \ \(x'\)[t] \[Equal] \(-3\) + 4\ x[t] - 
            x[t]\^2;\)\ \), "\[IndentingNewLine]", 
    \(sol = \ DSolve[{de, x[0] \[Equal] j\/5}\ , x[t], t]\ \)}], "Input"],

Cell["Then form the construction with the following two steps.", "Text"],

Cell[BoxData[
    \(\(\(fun3\)\(=\)\(sol\_\(\(\[LeftDoubleBracket]\)\(1, 1, 
          2\)\(\[RightDoubleBracket]\)\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(fun3\)\(=\)\(Table[fun3, {j, 1, 4}]\)\(\ \)\)\)], "Input"],

Cell["\<\
They is algebraically the same as the list that was obtained using those \
pesky complex numbers. \
\>", "Text"],

Cell["Graph these solutions. ", "Text"],

Cell[BoxData[{
    \(\(HDE\  = \ \*"\"\<x'[t] = 4 x[t] - x[t\!\(\(]\^2\)\) - 3\>\"";\)\ \), \
"\[IndentingNewLine]", 
    \(\(x\_1[t_] = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(x\_2[t_] = \ 3;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr3 = \ 
        Plot[Evaluate[{x\_2[t], fun3, x\_1[t]}], {t, 0, 2}, 
          PlotRange \[Rule] {{0, 2}, {0, 8}}, 
          PlotStyle \[Rule] {Magenta, Red, Orange, Green, Blue, 
              Violet}];\)\), "\[IndentingNewLine]", 
    \(\(Print[HDE];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t] = \>\"", 
        x\_2[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", fun3];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", 
        ReplaceAll[fun3, t \[Rule] 0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t] = \>\"", x\_1[t]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Discuss the graphs in the plot in Example 12.\nWhat are the vertical lines \
?\nWhat are the curves that lie below ",
  StyleBox["x=1",
    FontFamily->"Courier New"],
  ".\nWhat are the curves that lie above ",
  StyleBox["x=3",
    FontFamily->"Courier New"],
  " ?  What use are they ?"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
In order to clear things up, it is necessary to specify the individual \
domain, for each of the solutions, then plot all the curves on the same \
graph.\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x\_1[t_] = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(x\_2[t_] = \ 3;\)\ \), "\[IndentingNewLine]", 
    \(\(g0\  = \ 
        Plot[x\_1[t], {t, 0, 2}, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
          PlotStyle \[Rule] Violet, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(g1\  = \ 
        Plot[x\_2[t], {t, 0, 2}, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(g2\  = \ 
        Plot[\(\(-7\) + 6\ E\^\(2\ t\)\)\/\(\(-7\) + 2\ E\^\(2\ t\)\), {t, 0, 
            1\/2\ Log[7\/2]}, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(g3\  = \ 
        Plot[\(\(-13\) + 9\ E\^\(2\ t\)\)\/\(\(-13\) + 3\ E\^\(2\ t\)\), {t, 
            0, 1\/2\ Log[13\/3]}, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
          PlotStyle \[Rule] Orange, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(g4\  = \ 
        Plot[\(3\ \((\(-2\) + E\^\(2\ t\))\)\)\/\(\(-6\) + E\^\(2\ t\)\), {t, 
            0, \(1\/2\) Log[6]}, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
          PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(g5 = \ 
        Plot[\(\(-11\) + 3\ E\^\(2\ t\)\)\/\(\(-11\) + E\^\(2\ t\)\), {t, 
            0, \(1\/2\) Log[11]}, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g0, g1, g2, g3, g4, g5, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell["Now form a composite graph of all the functions.", "Text"],

Cell[BoxData[{
    \(\(Show[g0, g1, g2, g3, g4, g5, gr1, gr2, 
        Ticks \[Rule] {Range[0, 1, 0.2], Range[0, 8, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< x[t] = \>", fun1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[0] = \>", 
        ReplaceAll[fun1, t \[Rule] 0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t] = \>\"", 
        x\_2[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[t] = \>", fun2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[0] = \>", 
        ReplaceAll[fun2, t \[Rule] 0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t] = \>\"", 
        x\_1[t]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[t] = \>", fun3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[0] = \>", ReplaceAll[fun3, t \[Rule] 0]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Observe.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The solutions with initial conditions  ",
  StyleBox["x[0] > 3",
    FontFamily->"Courier New"],
  "  tend to  ",
  Cell[BoxData[
      \(x\_2[t] = 3\)]],
  " as ",
  Cell[BoxData[
      \(t \[Rule] \[Infinity]\)]],
  ". \nThe solutions with initial conditions  ",
  StyleBox["1 < x[0] < 3",
    FontFamily->"Courier New"],
  "  tend to  ",
  Cell[BoxData[
      \(x\_2[t] = 3\)]],
  " as ",
  Cell[BoxData[
      \(t \[Rule] \[Infinity]\)]],
  ". \nThe solutions with initial conditions  ",
  StyleBox["0 < x[0] < 1",
    FontFamily->"Courier New"],
  "  go to zero at some finite value of  ",
  StyleBox["t",
    FontFamily->"Courier New"],
  "  and  ",
  StyleBox["x[t]",
    FontFamily->"Courier New"],
  "  becomes extinct. \nThe constant functions   ",
  Cell[BoxData[
      \(x\_1[t] = 1\)]],
  " and   ",
  Cell[BoxData[
      \(x\_2[t] = 3\)]],
  " are the dividing lines for these three cases. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the ",
  " D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 4\ x[t] - x[t]\^2 - 3\)]],
  "  using the formula with the initial condition  ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, verify that the formula for the general solution is correct.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, c, k, t, x];\)\), "\[IndentingNewLine]", 
    \(\(de = \(x'\)[t] \[Equal] 
          4\ x[t] - \ x[t]\^2 - 3;\)\), "\[IndentingNewLine]", 
    \(solset = DSolve[de, x[t], t]\ \)}], "Input"],

Cell[BoxData[{
    \(sol = 
      TrigToExp[
        Simplify[
          ReplaceAll[
            a\/\(2  b\) - \(\@\(a\^2 - 4\ b\ k\)\/\(2\ b\)\) \(c + \ \
\[ExponentialE]\^\(\@\(a\^2 - 4\ b\ k\)\ t\)\)\/\(c - \ \[ExponentialE]\^\(\@\
\(a\^2 - 4\ b\ k\)\ t\)\), {a \[Rule] 4, b \[Rule] 1, 
              k \[Rule] 3}]]]\), "\[IndentingNewLine]", 
    \(sol = Together[sol]\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<The general solution to\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", sol];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  You may need to identify the relationship between the arbitrary \
constants, i. e.  ",
  Cell[BoxData[
      \(c\  = \ \[ExponentialE]\^\(2\ C[1]\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "First, verify that the formula for the solution with the initial condition \
 ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  "  is correct. "
}], "Text"],

Cell[BoxData[{
    \(\(ic = x[0] \[Equal] 4;\)\), "\[IndentingNewLine]", 
    \(solset = DSolve[{de, ic}, x[t], t]\ \)}], "Input"],

Cell[BoxData[{
    \(sol = 
      TrigToExp[
        Simplify[
          ReplaceAll[
            a\/\(2  b\) + \@\(a\^2 - 4\ b\ k\)\/\(2\ b\)\  - \(\(a + \@\(a\^2 \
- 4\ b\ k\) - 
                      2\ b\ x\_0\)\/\(2\ b\)\) \(2 \((\@\(a\^2 - 4\ b\ k\))\)\
\)\/\(\((\@\(a\^2 - 4\ b\ k\) + a - 2\ b\ x\_0)\) + \ \((\@\(a\^2 - 4\ b\ k\) \
- a + 2\ b\ x\_0)\) \[ExponentialE]\^\(\@\(a\^2 - 4\ b\ k\)\ t\)\), {a \
\[Rule] 4, b \[Rule] 1, k \[Rule] 3, 
              x\_0 \[Rule] 4}]]]\), "\[IndentingNewLine]", 
    \(sol = Together[sol]\)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<The solution to\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[ic];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", sol];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Use the Modified Euler Method to find numerical solutions to",
  " the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 4\ x[t] - x[t]\^2 - 3\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The solution curves with the initial conditions  ",
  Cell[BoxData[
      \(x \((0)\) = 8, 7, 6, 5, 4, 3, 8\/3, 7\/3, 6\/3, 5\/3, 4\/3, 1, 
      4\/5\)]],
  "  can all be computed over the interval  ",
  Cell[BoxData[
      \(\([a, b]\) = \([0, 1]\)\)]],
  ".  \nHowever the solution curves with the initial conditions   ",
  Cell[BoxData[
      \(x \((0)\) = 3\/5, 2\/5, 1\/5\)]],
  "   must be computed over smaller intervals, \nfor instance the intervals   \
",
  Cell[BoxData[
      \(\([a, b]\) = \([0, 0.7]\), \([0, 0.4]\), \ \([0, 0.2]\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, t, y];\)\), "\[IndentingNewLine]", 
    \(\(f[t_, y_]\  = \ 4\ y - y\^2 - 3;\)\ \), "\[IndentingNewLine]", 
    \(\(p0 = {8, 7, 6, 5, 4, 3, 8\/3, 7\/3, 6\/3, 5\/3, 4\/3, 1, 
          4\/5};\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0.0;\)\), "\[IndentingNewLine]", 
    \(\(b = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(MEuler[\ a\ , b, p0\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 
        Table[0, {i, 
            Length[Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)]}];\)\), "\[IndentingNewLine]", 
    \(\(graphs = Z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(colors = {Blue, Green, Orange, Red, Brown, \ Magenta, Red, Orange, 
          Green, Blue, Magenta, Brown, Blue, Black, 
          Black};\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
], \(i++\), \[IndentingNewLine]Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
          Transpose[{T, 
              Y\_\(\(\[LeftDoubleBracket]\)\(All, \
i\)\(\[RightDoubleBracket]\)\)}]; \[IndentingNewLine]graphs\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\) = 
          ListPlot[
            Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
            PlotJoined \[Rule] True, 
            PlotStyle \[Rule] 
              colors\_\(\(\[LeftDoubleBracket]\)\(Mod[i, 14]\)\(\
\[RightDoubleBracket]\)\), 
            DisplayFunction \[Rule] 
              Identity];\ ];\)\), "\[IndentingNewLine]", 
    \(\(Show[graphs, PlotRange \[Rule] {{a, b}, {0, 8}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(W = MEuler[0.0\ , 0.7, 3\/5\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(graph1 = 
        ListPlot[W, PlotJoined \[Rule] True, PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(W = MEuler[0.0\ , 0.4, 2\/5\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ListPlot[W, PlotJoined \[Rule] True, PlotStyle \[Rule] Orange, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph2, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(W = MEuler[0.0\ , 0.2, 1\/5\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ListPlot[W, PlotJoined \[Rule] True, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph3, PlotRange \[Rule] {{0, 1}, {0, 8}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell["Now all the solution curves can be shown on one graph. ", "Text"],

Cell[BoxData[
    \(\(Show[graphs, graph1, graph2, graph3, 
        PlotRange \[Rule] {{a, b}, {0, 8}}, 
        Ticks \[Rule] {Range[0, 1, 0.2], Range[0, 8, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell["\<\
This is the same as the graph that was obtained in Example 13.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Case (iii)  If  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(a\^2 < 4\ b\ k\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  StyleBox[" there are no stationary solutions.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solve the population model with harvesting  ",
  Cell[BoxData[
      \(dx\/dt\  = \ a\ x\  - \ b\ x\^2\  - \ k\)]],
  ",  \nusing the constants  ",
  StyleBox["a = 3",
    FontFamily->"Courier New"],
  ",  ",
  StyleBox["b = 3",
    FontFamily->"Courier New"],
  ",  and  ",
  StyleBox["k = 3",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, k, x, t];\)\ \), "\[IndentingNewLine]", 
    \(\(de = \(x'\)[t] \[Equal] 
          a\ x[t] - b\ x[t]\^2 - k;\)\ \), "\[IndentingNewLine]", 
    \(\(de1 = 
        ReplaceAll[\ 
          de, \ {a \[Rule] 3, b \[Rule] 3, 
            k \[Rule] 3}\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<Replace  {a\[Rule]3, b\[Rule]3, k\[Rule]3}\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de1];\)\ \ \)}], "Input"],

Cell["Construct the general solution. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<Solve\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de1];\)\ \), "\[IndentingNewLine]", 
    \(\(sol1 = DSolve[de1\ , x[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[sol1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(x[t_] = \ 
        sol1\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Plot the solutions to the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 3\ x[t] - 3  x[t]\^2 - 3\)]],
  "  in Example 17\nthat have the following initial conditions  ",
  StyleBox["x[0] = 1",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["2",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["3",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["4",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["5",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["6",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We shall use the technique where we solve  ",
  Cell[BoxData[
      \(x[
          0] = \(\(3\ \[ExponentialE]\^0 - \[ExponentialE]\^\(2\ C[1]\)\)\/\(\
\[ExponentialE]\^0 - \[ExponentialE]\^\(2\ C[1]\)\) = c\)\)]],
  "  for  ",
  Cell[BoxData[
      \(c = 4\/3, 5\/3, 6\/3, 7\/3, 8\/3\)]],
  ". \nYou will get some warning messages from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", ignore them.  Hang in there ! "
}], "Text"],

Cell[BoxData[{
    \(\(x[
          t_] = \[InvisibleSpace]1\/2\ \((1 + \@3\ Tan[
                  1\/2\ \((\(-3\)\ \@3\ t + \@3\ C[
                            1])\)])\);\)\ \), "\[IndentingNewLine]", 
    \(Table[\ Solve[\ x[0] \[Equal] c, C[1]\ ], \ {c, 1, 6}]\ \)}], "Input"],

Cell[BoxData[
    \(\(\(Table[\(2\ ArcTan[\(2  j - 1\)\/\@3]\)\/\@3, {j, 1, 
        6}]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Replace the values  ",
  Cell[BoxData[
      \({\(-\(Log[3]\/2\)\), \(-\(Log[2]\/2\)\), \(-\(1\/2\)\)\ Log[
            5\/3], \(-\(1\/2\)\)\ Log[3\/2], \(-\(1\/2\)\)\ Log[7\/5]}\)]],
  "  for the constant ",
  StyleBox["c[1]",
    FontFamily->"Courier New"],
  ",\nand ",
  "form the functions",
  " we wish to plot. "
}], "Text"],

Cell[BoxData[
    \(fun1\  = 
      Simplify[\ 
        ReplaceAll[\ 
          x[t], \ \ C[
              1]\  \[Rule] \ \ Table[\(2\ ArcTan[\(2  j - 1\)\/\@3]\)\/\@3, \
{j, 1, 6}]\ ]\ ]\)], "Input"],

Cell["Graph these solutions. ", "Text"],

Cell[BoxData[{
    \(\(HDE\  = \ \*"\"\<x'[t] = 3 x[t] - 2 x[t\!\(\(]\^2\)\) - 2\>\"";\)\ \
\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = \ 
        Plot[Evaluate[{fun1}], {t, 0, 0.8}, 
          PlotRange \[Rule] {{0, 0.75}, {0, 6}}, 
          Ticks \[Rule] {Range[0, 0.75, 0.25], Range[0, 6, 1]}, 
          PlotStyle \[Rule] {Magenta, Brown, Red, Orange, Green, 
              Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[HDE];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[t] = \>", fun1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< x[0] = \>", ReplaceAll[fun1, t \[Rule] 0]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Observe.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The each population curve becomes extinct.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Solve the ",
  " D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 3\ x[t] - 3  x[t]\^2 - 3\)]],
  "  using the formula with the initial condition  ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, verify that the formula for the general solution is correct. \
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, c, k, t, x];\)\), "\[IndentingNewLine]", 
    \(\(de = \(x'\)[t] \[Equal] 
          3  x[t] - 3  x[t]\^2 - 3;\)\), "\[IndentingNewLine]", 
    \(solset = DSolve[de, x[t], t]\)}], "Input"],

Cell[BoxData[
    \(sol = 
      Simplify[ReplaceAll[
          a\/\(2  b\)\  - \(\@\(4\ b\ k - a\^2\)\/\(2  b\)\) 
              Tan[t\/2\ \@\(4\ b\ k - a\^2\) - c], {a \[Rule] 3, b \[Rule] 3, 
            k \[Rule] 3}]]\)], "Input"],

Cell[BoxData[{
    \(\(Print["\<The general solution to\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", sol];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  You may need to identify the relationship between the arbitrary \
constants, i. e.  ",
  Cell[BoxData[
      \(C[1] \[Rule] \(2\/\@3\) c\)]],
  ". "
}], "Text"],

Cell[BoxData[
    \(Expand[
      ReplaceAll[1\/2\ \((\(-3\)\ \@3\ t + \@3\ C[1])\), 
        C[1] \[Rule] \(2\/\@3\) c]]\)], "Input"],

Cell[TextData[{
  "First, verify that the formula for the solution with the initial condition \
 ",
  Cell[BoxData[
      \(x \((0)\) = x\_0\)]],
  "  is correct. "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(ic = x[0] \[Equal] 1;\)\), "\[IndentingNewLine]", 
    \(solset = DSolve[{de, ic}, x[t], t]\)}], "Input"],

Cell[BoxData[
    \(sol = 
      Simplify[ReplaceAll[
          a\/\(2\ b\) - \@\(4\ b\ k - a\^2\)\/\(2\ b\)\ Tan[
                t\/2\ \@\(4\ b\ k - a\^2\) - 
                  ArcTan[\(2\ b\ x\_0 - a\)\/\@\(4\ b\ k - a\^2\)]], {a \
\[Rule] 3, b \[Rule] 3, k \[Rule] 3, x\_0 \[Rule] 1}]]\)], "Input"],

Cell[BoxData[{
    \(\(Print["\<The solution to\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<with the initial condition\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[ic];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", sol];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Use the Modified Euler Method to find numerical solutions to",
  " the D. E.  ",
  Cell[BoxData[
      \(\(x'\)[t] = 3\ x[t] - 3  x[t]\^2 - 3\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The solution curves with the initial conditions  ",
  Cell[BoxData[
      \(x \((0)\) = 6, 5, 4, 3, 2, 1\)]],
  "  can all be computed over the interval  ",
  Cell[BoxData[
      \(\([a, b]\) = \([0, 0.75]\)\)]],
  ".  \nHowever the solution curves with the initial conditions do have \
vertical asymptotes so be careful how large an interval you use."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, t, y];\)\), "\[IndentingNewLine]", 
    \(\(f[t_, y_]\  = \ 3\ y - 3  y\^2 - 3;\)\ \), "\[IndentingNewLine]", 
    \(\(p0 = {6, 5, 4, 3, 2, 1};\)\ \), "\[IndentingNewLine]", 
    \(\(a = 0;\)\), "\[IndentingNewLine]", 
    \(\(b = 0.75;\)\ \), "\[IndentingNewLine]", 
    \(\(MEuler[\ a\ , b, p0\ , 110\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = 
        Table[0, {i, 
            Length[Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)]}];\)\), "\[IndentingNewLine]", 
    \(\(graphs = Z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(colors = {\ Blue, \ Green, \ Orange, Red, Brown, \ Magenta, \ 
          Violet};\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          Length[Y\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
], \(i++\), \[IndentingNewLine]Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\)\  = \ 
          Transpose[{T, 
              Y\_\(\(\[LeftDoubleBracket]\)\(All, \
i\)\(\[RightDoubleBracket]\)\)}]; \[IndentingNewLine]graphs\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\) = 
          ListPlot[
            Z\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), 
            PlotJoined \[Rule] True, 
            PlotStyle \[Rule] 
              colors\_\(\(\[LeftDoubleBracket]\)\(Mod[i, 7]\)\(\
\[RightDoubleBracket]\)\), 
            DisplayFunction \[Rule] 
              Identity];\ ];\)\), "\[IndentingNewLine]", 
    \(\(Show[graphs, PlotRange \[Rule] {{a, b}, {0, 6}}, 
        Ticks \[Rule] {Range[0, 0.75, 0.25], Range[0, 6, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \)}], "Input"],

Cell["\<\
This is the same as the graph that was obtained in Example 17.\
\>", "Text"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["The Logistic Curve",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/LogisticEquationBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["The Logistic Curve",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/LogisticEquationBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/HarvestingModelBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Harvesting Model",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/HarvestingModelBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 173, 4, 35, "Text"],
Cell[1952, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3431, 111, 1287, 38, 369, "Text"],
Cell[4721, 151, 11844, 268, 258, "Text"],
Cell[16568, 421, 658, 22, 33, "Text"],
Cell[17229, 445, 378, 12, 112, "Text"],
Cell[17610, 459, 294, 9, 33, "Text"],
Cell[17907, 470, 997, 30, 160, "Text"],
Cell[18907, 502, 1022, 35, 122, "Text"],
Cell[19932, 539, 14180, 448, 197, "Text"],
Cell[34115, 989, 974, 36, 201, "Text"],
Cell[35092, 1027, 596, 22, 33, "Text"],
Cell[35691, 1051, 1173, 38, 141, "Text"],
Cell[36867, 1091, 21465, 984, 197, "Text"],
Cell[58335, 2077, 317, 10, 43, "Text"],
Cell[58655, 2089, 502, 13, 102, "Text"],
Cell[59160, 2104, 544, 21, 81, "Text"],
Cell[59707, 2127, 596, 22, 33, "Text"],
Cell[60306, 2151, 342, 13, 52, "Text"],
Cell[60651, 2166, 402, 13, 84, "Text"],
Cell[61056, 2181, 16823, 416, 197, "Text"],
Cell[77882, 2599, 364, 11, 106, "Text"],
Cell[78249, 2612, 520, 20, 86, "Text"],
Cell[78772, 2634, 596, 22, 33, "Text"],
Cell[79371, 2658, 517, 10, 109, "Text"],
Cell[79891, 2670, 613, 21, 33, "Text"],
Cell[80507, 2693, 870, 28, 55, "Text"],
Cell[81380, 2723, 1091, 20, 201, "Input"],
Cell[82474, 2745, 279, 11, 36, "Text"],

Cell[CellGroupData[{
Cell[82778, 2760, 101, 2, 33, "Text"],
Cell[82882, 2764, 281, 5, 90, "Input"],
Cell[83166, 2771, 197, 9, 34, "Text"],
Cell[83366, 2782, 536, 9, 150, "Input"],
Cell[83905, 2793, 345, 9, 33, "Text"],
Cell[84253, 2804, 886, 20, 71, "Text"]
}, Closed]],
Cell[85154, 2827, 327, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[85506, 2842, 101, 2, 33, "Text"],
Cell[85610, 2846, 194, 4, 50, "Input"],
Cell[85807, 2852, 196, 9, 34, "Text"],
Cell[86006, 2863, 65, 1, 30, "Input"],
Cell[86074, 2866, 87, 2, 33, "Text"],
Cell[86164, 2870, 1018, 20, 194, "Input"],
Cell[87185, 2892, 1018, 20, 194, "Input"],
Cell[88206, 2914, 314, 9, 37, "Text"]
}, Closed]],
Cell[88535, 2926, 694, 25, 34, "Text"],
Cell[89232, 2953, 517, 19, 55, "Text"],

Cell[CellGroupData[{
Cell[89774, 2976, 101, 2, 33, "Text"],
Cell[89878, 2980, 565, 12, 150, "Input"],
Cell[90446, 2994, 48, 0, 33, "Text"],
Cell[90497, 2996, 448, 8, 130, "Input"],
Cell[90948, 3006, 50, 0, 33, "Text"],
Cell[91001, 3008, 833, 18, 210, "Input"],
Cell[91837, 3028, 110, 5, 33, "Text"],
Cell[91950, 3035, 643, 12, 166, "Input"]
}, Closed]],
Cell[92608, 3050, 607, 25, 49, "Text"],

Cell[CellGroupData[{
Cell[93240, 3079, 101, 2, 33, "Text"],
Cell[93344, 3083, 75, 0, 33, "Text"],
Cell[93422, 3085, 75, 1, 44, "Input"],
Cell[93500, 3088, 432, 20, 33, "Text"],
Cell[93935, 3110, 102, 2, 30, "Input"],
Cell[94040, 3114, 96, 2, 33, "Text"],
Cell[94139, 3118, 149, 2, 44, "Input"],
Cell[94291, 3122, 39, 0, 33, "Text"],
Cell[94333, 3124, 74, 1, 30, "Input"],
Cell[94410, 3127, 239, 7, 34, "Text"],
Cell[94652, 3136, 437, 7, 90, "Input"]
}, Closed]],
Cell[95104, 3146, 1227, 37, 52, "Text"],

Cell[CellGroupData[{
Cell[96356, 3187, 101, 2, 33, "Text"],
Cell[96460, 3191, 75, 0, 33, "Text"],
Cell[96538, 3193, 75, 1, 44, "Input"],
Cell[96616, 3196, 1041, 33, 36, "Text"],
Cell[97660, 3231, 111, 2, 42, "Input"],
Cell[97774, 3235, 96, 2, 33, "Text"],
Cell[97873, 3239, 144, 2, 44, "Input"],
Cell[98020, 3243, 39, 0, 33, "Text"],
Cell[98062, 3245, 74, 1, 30, "Input"],
Cell[98139, 3248, 239, 7, 34, "Text"],
Cell[98381, 3257, 422, 7, 90, "Input"]
}, Closed]],
Cell[98818, 3267, 602, 16, 125, "Text"],

Cell[CellGroupData[{
Cell[99445, 3287, 101, 2, 33, "Text"],
Cell[99549, 3291, 135, 5, 33, "Text"],
Cell[99687, 3298, 143, 2, 50, "Input"],
Cell[99833, 3302, 1029, 19, 190, "Input"],
Cell[100865, 3323, 625, 16, 132, "Text"],
Cell[101493, 3341, 1576, 30, 266, "Input"],
Cell[103072, 3373, 64, 0, 33, "Text"],
Cell[103139, 3375, 639, 11, 130, "Input"],
Cell[103781, 3388, 733, 26, 71, "Text"]
}, Closed]],
Cell[104529, 3417, 315, 12, 30, "Text"],

Cell[CellGroupData[{
Cell[104869, 3433, 101, 2, 33, "Text"],
Cell[104973, 3437, 91, 2, 33, "Text"],
Cell[105067, 3441, 236, 4, 70, "Input"],
Cell[105306, 3447, 273, 6, 63, "Input"],
Cell[105582, 3455, 386, 7, 110, "Input"],
Cell[105971, 3464, 176, 6, 33, "Text"],
Cell[106150, 3472, 128, 2, 50, "Input"],
Cell[106281, 3476, 234, 5, 44, "Input"],
Cell[106518, 3483, 504, 9, 150, "Input"]
}, Closed]],
Cell[107037, 3495, 269, 9, 30, "Text"],

Cell[CellGroupData[{
Cell[107331, 3508, 101, 2, 33, "Text"],
Cell[107435, 3512, 547, 15, 77, "Text"],
Cell[107985, 3529, 1699, 33, 305, "Input"],
Cell[109687, 3564, 382, 6, 83, "Input"],
Cell[110072, 3572, 384, 6, 83, "Input"],
Cell[110459, 3580, 383, 6, 83, "Input"],
Cell[110845, 3588, 71, 0, 33, "Text"],
Cell[110919, 3590, 227, 4, 30, "Input"],
Cell[111149, 3596, 85, 2, 33, "Text"]
}, Closed]],
Cell[111249, 3601, 757, 25, 40, "Text"],
Cell[112009, 3628, 518, 19, 55, "Text"],

Cell[CellGroupData[{
Cell[112552, 3651, 101, 2, 33, "Text"],
Cell[112656, 3655, 565, 12, 150, "Input"],
Cell[113224, 3669, 48, 0, 33, "Text"],
Cell[113275, 3671, 491, 9, 150, "Input"],
Cell[113769, 3682, 51, 0, 33, "Text"],
Cell[113823, 3684, 1219, 25, 290, "Input"],
Cell[115045, 3711, 113, 5, 33, "Text"],
Cell[115161, 3718, 643, 12, 166, "Input"],
Cell[115807, 3732, 414, 14, 52, "Text"]
}, Closed]],
Cell[116236, 3749, 608, 25, 49, "Text"],

Cell[CellGroupData[{
Cell[116869, 3778, 102, 2, 33, "Text"],
Cell[116974, 3782, 459, 13, 56, "Text"],
Cell[117436, 3797, 280, 5, 66, "Input"],
Cell[117719, 3804, 350, 11, 55, "Text"],
Cell[118072, 3817, 200, 4, 44, "Input"],
Cell[118275, 3823, 39, 0, 33, "Text"],
Cell[118317, 3825, 86, 1, 30, "Input"],
Cell[118406, 3828, 39, 0, 33, "Text"],
Cell[118448, 3830, 772, 14, 170, "Input"],
Cell[119223, 3846, 737, 20, 56, "Text"]
}, Closed]],
Cell[119975, 3869, 394, 13, 52, "Text"],

Cell[CellGroupData[{
Cell[120394, 3886, 102, 2, 33, "Text"],
Cell[120499, 3890, 389, 10, 56, "Text"],
Cell[120891, 3902, 306, 7, 79, "Input"],
Cell[121200, 3911, 453, 10, 92, "Text"],
Cell[121656, 3923, 345, 6, 43, "Input"],
Cell[122004, 3931, 39, 0, 33, "Text"],
Cell[122046, 3933, 86, 1, 30, "Input"],
Cell[122135, 3936, 105, 3, 33, "Text"],
Cell[122243, 3941, 252, 4, 83, "Input"],
Cell[122498, 3947, 72, 0, 33, "Text"],
Cell[122573, 3949, 140, 2, 30, "Input"],
Cell[122716, 3953, 82, 1, 30, "Input"],
Cell[122801, 3956, 99, 2, 33, "Text"],
Cell[122903, 3960, 39, 0, 33, "Text"],
Cell[122945, 3962, 938, 17, 210, "Input"],
Cell[123886, 3981, 734, 20, 57, "Text"]
}, Closed]],
Cell[124635, 4004, 388, 13, 52, "Text"],

Cell[CellGroupData[{
Cell[125048, 4021, 102, 2, 33, "Text"],
Cell[125153, 4025, 383, 10, 56, "Text"],
Cell[125539, 4037, 306, 7, 79, "Input"],
Cell[125848, 4046, 308, 7, 91, "Text"],
Cell[126159, 4055, 193, 3, 42, "Input"],
Cell[126355, 4060, 39, 0, 33, "Text"],
Cell[126397, 4062, 86, 1, 30, "Input"],
Cell[126486, 4065, 105, 3, 33, "Text"],
Cell[126594, 4070, 248, 4, 83, "Input"],
Cell[126845, 4076, 72, 0, 33, "Text"],
Cell[126920, 4078, 140, 2, 30, "Input"],
Cell[127063, 4082, 82, 1, 30, "Input"],
Cell[127148, 4085, 122, 3, 33, "Text"],
Cell[127273, 4090, 39, 0, 33, "Text"],
Cell[127315, 4092, 927, 17, 210, "Input"]
}, Closed]],
Cell[128257, 4112, 447, 14, 87, "Text"],

Cell[CellGroupData[{
Cell[128729, 4130, 102, 2, 33, "Text"],
Cell[128834, 4134, 177, 4, 33, "Text"],
Cell[129014, 4140, 1725, 33, 278, "Input"],
Cell[130742, 4175, 64, 0, 33, "Text"],
Cell[130809, 4177, 885, 16, 190, "Input"],
Cell[131697, 4195, 1020, 38, 90, "Text"]
}, Closed]],
Cell[132732, 4236, 316, 12, 30, "Text"],

Cell[CellGroupData[{
Cell[133073, 4252, 102, 2, 33, "Text"],
Cell[133178, 4256, 91, 2, 33, "Text"],
Cell[133272, 4260, 224, 4, 70, "Input"],
Cell[133499, 4266, 386, 9, 83, "Input"],
Cell[133888, 4277, 386, 7, 110, "Input"],
Cell[134277, 4286, 272, 9, 33, "Text"],
Cell[134552, 4297, 176, 6, 33, "Text"],
Cell[134731, 4305, 130, 2, 50, "Input"],
Cell[134864, 4309, 549, 12, 140, "Input"],
Cell[135416, 4323, 504, 9, 150, "Input"]
}, Closed]],
Cell[135935, 4335, 270, 9, 30, "Text"],

Cell[CellGroupData[{
Cell[136230, 4348, 102, 2, 33, "Text"],
Cell[136335, 4352, 587, 16, 77, "Text"],
Cell[136925, 4370, 1777, 35, 305, "Input"],
Cell[138705, 4407, 384, 6, 83, "Input"],
Cell[139092, 4415, 385, 6, 83, "Input"],
Cell[139480, 4423, 382, 6, 83, "Input"],
Cell[139865, 4431, 71, 0, 33, "Text"],
Cell[139939, 4433, 229, 4, 30, "Input"],
Cell[140171, 4439, 86, 2, 33, "Text"]
}, Closed]],
Cell[140272, 4444, 334, 12, 30, "Text"],
Cell[140609, 4458, 450, 17, 55, "Text"],

Cell[CellGroupData[{
Cell[141084, 4479, 102, 2, 33, "Text"],
Cell[141189, 4483, 565, 12, 150, "Input"],
Cell[141757, 4497, 48, 0, 33, "Text"],
Cell[141808, 4499, 491, 9, 150, "Input"]
}, Closed]],
Cell[142314, 4511, 668, 28, 49, "Text"],

Cell[CellGroupData[{
Cell[143007, 4543, 102, 2, 33, "Text"],
Cell[143112, 4547, 459, 13, 56, "Text"],
Cell[143574, 4562, 280, 5, 63, "Input"],
Cell[143857, 4569, 111, 2, 59, "Input"],
Cell[143971, 4573, 350, 11, 55, "Text"],
Cell[144324, 4586, 200, 6, 59, "Input"],
Cell[144527, 4594, 39, 0, 33, "Text"],
Cell[144569, 4596, 684, 12, 150, "Input"],
Cell[145256, 4610, 160, 5, 33, "Text"]
}, Closed]],
Cell[145431, 4618, 319, 12, 30, "Text"],

Cell[CellGroupData[{
Cell[145775, 4634, 102, 2, 33, "Text"],
Cell[145880, 4638, 92, 2, 33, "Text"],
Cell[145975, 4642, 223, 4, 70, "Input"],
Cell[146201, 4648, 234, 5, 48, "Input"],
Cell[146438, 4655, 386, 7, 110, "Input"],
Cell[146827, 4664, 261, 9, 43, "Text"],
Cell[147091, 4675, 134, 3, 48, "Input"],
Cell[147228, 4680, 176, 6, 33, "Text"],
Cell[147407, 4688, 147, 2, 70, "Input"],
Cell[147557, 4692, 302, 6, 54, "Input"],
Cell[147862, 4700, 504, 9, 150, "Input"]
}, Closed]],
Cell[148381, 4712, 273, 9, 30, "Text"],

Cell[CellGroupData[{
Cell[148679, 4725, 102, 2, 33, "Text"],
Cell[148784, 4729, 383, 9, 52, "Text"],
Cell[149170, 4740, 1734, 34, 291, "Input"],
Cell[150907, 4776, 86, 2, 33, "Text"]
}, Closed]],
Cell[151008, 4781, 158, 3, 32, "Text"],
Cell[151169, 4786, 582, 18, 33, "Text"],
Cell[151754, 4806, 557, 16, 33, "Text"],
Cell[152314, 4824, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

