(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    142837,       3767]*)
(*NotebookOutlinePosition[    143503,       3790]*)
(*  CellTagsIndexPosition[    143459,       3786]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Frobenius Series Solution of a \
Differential Equation",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tConsider the second order linear differential equation\n\t\n(1)\t\t\
",
  Cell[BoxData[
      \(P \((x)\) y'' \((x)\)\  + \ Q \((x)\) y' \((x)\)\  + \ 
          R \((x)\) y \((x)\)\  = \ 0\)]],
  ". \n\nRewrite this equation in the form   ",
  Cell[BoxData[
      \(y'' \((x)\)\  + \ \(\(Q \((x)\)\)\/\(P \((x)\)\)\) 
            y' \((x)\)\  + \ \(\(R \((x)\)\)\/\(P \((x)\)\)\) y \((x)\)\  = \ 
        0\)]],
  ",  then use the substitutions  ",
  Cell[BoxData[
      \(\(f\_1\) \((x)\) = \(Q \((x)\)\)\/\(P \((x)\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(f\_2\) \((x)\) = \(R \((x)\)\)\/\(P \((x)\)\)\)]],
  "  and rewrite the differential equation (1) in the form  \n\n(2)\t\t",
  Cell[BoxData[
      \(y'' \((x)\)\  + \ \(f\_1\) \((x)\) y' \((x)\)\  + \ \(f\_2\) \((x)\) 
            y \((x)\)\  = \ 0\)]],
  ".\n"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Analytic",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/AnalyticFunction.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The functions ",
  Cell[BoxData[
      \(\(f\_1\) \((x)\)\)]],
  " and ",
  Cell[BoxData[
      \(\(f\_2\) \((x)\)\)]],
  " are analytic at ",
  Cell[BoxData[
      \(x = x\_0\)]],
  " if they have ",
  StyleBox[ButtonBox["Taylor series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/TaylorSeries.html"], None},
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[0, 0, 1]],
  " expansions with radius of convergence ",
  Cell[BoxData[
      \(r\_1 > 0\)]],
  " and  ",
  Cell[BoxData[
      \(r\_2 > 0\)]],
  ", respectively.  That is  \n\n\t\t",
  Cell[BoxData[
      \(\(f\_1\) \((x)\) = \(\(Q \((x)\)\)\/\(P \((x)\)\)\  = \ \[Sum]\+\(n = \
0\)\%\[Infinity]\( p\_n\) \((x - x\_0)\)\^n\)\)]],
  "  which converges for  ",
  Cell[BoxData[
      \(\(\(|\)\(x - x\_0\)\(|\)\(\(<\)\(\ \)\(r\_1\)\)\)\)]],
  " \n\tand\n\t\t",
  Cell[BoxData[
      \(\(f\_2\) \((x)\) = \(\(R \((x)\)\)\/\(P \((x)\)\)\  = \ \[Sum]\+\(n = \
0\)\%\[Infinity]\( q\_n\) \((x - x\_0)\)\^n\)\)]],
  "  which converges for  ",
  Cell[BoxData[
      \(\(\(|\)\(x - x\_0\)\(|\)\(\(<\)\(\ \)\(r\_2\)\)\)\)]],
  " "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Ordinary Point",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RegularSingularPoint.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If the functions ",
  Cell[BoxData[
      \(\(f\_1\) \((x)\) = \(Q \((x)\)\)\/\(P \((x)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(\(f\_2\) \((x)\) = \(R \((x)\)\)\/\(P \((x)\)\)\)]],
  " are analytic at ",
  Cell[BoxData[
      \(x = x\_0\)]],
  ", then the point ",
  Cell[BoxData[
      \(x = x\_0\)]],
  " is called an ",
  ButtonBox["ordinary point",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RegularSingularPoint.html"], None},
    ButtonStyle->"Hyperlink"],
  " of the differential equation  \n\n\t\t",
  Cell[BoxData[
      \(y'' \((x)\)\  + \ \(f\_1\) \((x)\) y' \((x)\)\  + \ \(f\_2\) \((x)\) 
            y \((x)\)\  = \ 0\)]],
  ". \n\nOtherwise, the point ",
  Cell[BoxData[
      \(x = x\_0\)]],
  " is called a ",
  ButtonBox["singular point",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RegularSingularPoint.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Regular Singular Point)",
    ButtonData:>{
      URL[ 
      "http://mathworld.wolfram.com/Second-OrderOrdinaryDifferentialEquation.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[".",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  " is a singular point of (1) and that  ",
  Cell[BoxData[
      \(\(\[Phi]\_1\) \((x)\) = \ x \( Q \((x)\)\)\/\(P \((x)\)\)\)]],
  " and  ",
  Cell[BoxData[
      \(\(\[Phi]\_2\) \((x)\) = \ \(x\^2\) \(R \((x)\)\)\/\(P \((x)\)\)\)]],
  " are analytic at ",
  Cell[BoxData[
      \(x = 0\)]],
  ".\n\nThey will have Maclaurin series expansions with radius of convergence \
",
  Cell[BoxData[
      \(r\_1 > 0\)]],
  " and  ",
  Cell[BoxData[
      \(r\_2 > 0\)]],
  ", respectively.  That is  \n\n\t\t",
  Cell[BoxData[
      \(\(\[Phi]\_1\) \((x)\) = \ \ \(x \( Q \((x)\)\)\/\(P \((x)\)\)\  = \ \
\[Sum]\+\(n = 0\)\%\[Infinity]\( p\_n\) x\^n\)\)]],
  "  which converges for  ",
  Cell[BoxData[
      \(\(\(|\)\(x\)\(|\)\(\(<\)\(\ \)\(r\_1\)\)\)\)]],
  " \n\tand\n\t\t",
  Cell[BoxData[
      \(\(\[Phi]\_2\) \((x)\) = \ \(\(x\^2\) \(R \((x)\)\)\/\(P \((x)\)\)\  = \
\ \[Sum]\+\(n = 0\)\%\[Infinity]\( q\_n\) x\^n\)\)]],
  "  which converges for  ",
  Cell[BoxData[
      \(\(\(|\)\(x\)\(|\)\(\(<\)\(\ \)\(r\_2\)\)\)\)]],
  " \n\nThen the point  ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  " is called a ",
  StyleBox["regular singular point",
    FontColor->RGBColor[1, 0, 1]],
  " of the differential equation (1). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method of Frobenius.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThis method is attributed to the german ",
  "mathematician",
  " ",
  ButtonBox["Ferdinand Georg Frobenius",
    ButtonData:>{
      URL[ 
      "http://www-gap.dcs.st-and.ac.uk/~history/Mathematicians/Frobenius.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " (1849-1917 ).  Assume that ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  "  is regular singular point of the differential equation \n\n\t",
  Cell[BoxData[
      \(P \((x)\) y'' \((x)\)\  + \ Q \((x)\) y' \((x)\)\  + \ 
          R \((x)\) y \((x)\)\  = \ 0\)]],
  ".  \n\t\nA ",
  ButtonBox["Frobenius series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FrobeniusMethod.html"], None},
    ButtonStyle->"Hyperlink"],
  " (generalized Laurent series) of the form  \n\n\t\t",
  Cell[BoxData[
      \(y \((x)\)\ \  = \ \ \(\(x\^r\) \(\[Sum]\+\(n = 0\)\%\[Infinity]\( 
                    c\_n\) x\^n\)\ \  = \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
                  c\_n\) x\^\(n + r\)\)\)]],
  "  \n\ncan be used to solve the differential equation.  The parameter ",
  Cell[BoxData[
      \(r\)]],
  " must be chosen so that when the series is substituted into the D.E. the \
coefficient of the smallest power of  ",
  Cell[BoxData[
      \(x\)]],
  " is zero.  This is called the indicial equation.  Next, a recursive \
equation for the coefficients is obtained by setting the coefficient of  ",
  Cell[BoxData[
      \(x\^\(n + r\)\)]],
  "  equal to zero.  Caveat: There are some instances when only one Frobenius \
solution can be constructed. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Indicial Equation",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/IndicialEquation.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The parameter ",
  Cell[BoxData[
      \(r\)]],
  " in the Frobenius series is a root of the indicial equation\n\n\t\t",
  Cell[BoxData[
      \(r \((r - 1)\) + \(p\_0\) r\  + \ q\_0\  = \ 0\)]],
  ".\n\n\tAssuming that the singular point is  ",
  Cell[BoxData[
      \(x\_0\)]],
  ", we can calculate ",
  Cell[BoxData[
      \(p\_0\ and\ \ q\_0\)]],
  " as follows: \n\n\t\t",
  Cell[BoxData[
      \(p\_0\  = \ 
        lim\+\(x \[Rule] x\_0\)\ \ x \( Q \((x)\)\)\/\(P \((x)\)\)\)]],
  " \nand\n\t\t",
  Cell[BoxData[
      \(q\_0\  = \ 
        lim\+\(x \[Rule] x\_0\)\ \ \(x\^2\) \(R \((x)\)\)\/\(P \((x)\)\)\)]],
  " "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Frobenius Series Method",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/FrobeniusSeriesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Frobenius Series Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/FrobeniusSeriesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition of  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      StyleBox[\(F \((r)\)\),
        FontWeight->"Bold",
        FontColor->RGBColor[0, 0, 1]]]],
  "  We state the following definition of  ",
  Cell[BoxData[
      \(F \((r)\)\)]],
  " "
}], "Text"],

Cell[BoxData[
    \(\(\(\t\t\)\(F \((r)\)\  \[Equal] \ \ r \((r - 1)\)\  + \ \(p\_0\) 
          r\  + \ q\_0\)\)\)], "Input",
  Evaluatable->False],

Cell[TextData[{
  "The exponents of the singularity are the roots  ",
  Cell[BoxData[
      \(r\  = r\_1, r\_2\)]],
  "  of  ",
  Cell[BoxData[
      \(F \((r)\)\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  StyleBox["The Recursive Formulas.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  \n\n\tWe are now in a position to state the recursive formula for the \
sequence of coefficients  ",
  Cell[BoxData[
      \({c\_n}\_\(n = 0\)\%\[Infinity]\)]],
  "  for the Frobenius series solution "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\t\t\)\(y \((x)\)\ \  \[Equal] \ \ \[Sum]\+\(n = 0\)\%\[Infinity]\( 
              c\_n\) x\^\(n + r\)\)\)\)], "Input",
  Evaluatable->False],

Cell[TextData[{
  "The recursive formula for computing  ",
  Cell[BoxData[
      \(c\_n\)]],
  "  is "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\t\t\)\(c\_n\ \  \[Equal] \ \ \(-1\)\/\(F \((n + r)\)\)\ \(\[Sum]\+\
\(k = 0\)\%\(n - 1\)\(c\_k\) \((\((k + r)\) p\_\(n - k\) + 
                q\_\(n - k\))\)\)\)\)\)], "Input",
  Evaluatable->False],

Cell["where", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\t\t\)\(F \((r)\)\ \  \[Equal] \ \ r \((r - 1)\)\  + \ \(p\_0\) 
          r\  + \ q\_0\)\)\)], "Input",
  Evaluatable->False],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Frobenius Series Method",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/FrobeniusSeriesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Frobenius Series Method",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/FrobeniusSeriesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Frobenius series to solve the D. E.   \n\n\t\t",
  Cell[BoxData[
      \(x\^2\ \(\(y'\)'\)[x] + \ \ x\ \(y'\)[
              x] + \((x\^2\  - \((1\/2)\)\^2)\) y[x]\  = \ 0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Determine the nature of the singularity at ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^2;\)\), "\[IndentingNewLine]", 
    \(\(Q[x_] = x;\)\), "\[IndentingNewLine]", 
    \(\(R[x_] = x\^2\  - \((1\/2)\)\^2;\)\), "\[IndentingNewLine]", 
    \(\(f\_1[x_] = Q[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(f\_2[x_] = R[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(de = 
        P[x]\ \(y''\)[x] + \ \ Q[x]\ \(y'\)[x] + R[x] y[x]\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(If[
        P[X\_0] \[Equal] 0, \[IndentingNewLine]Print["\<P[x] = \>", 
          P[x]]; \ \[IndentingNewLine]Print["\<P[\>", X\_0, "\<] = \>", 
          P[X\_0]]; \[IndentingNewLine]Print[\*"\"\<The point \!\(x\_0\) = \>\
\"", X\_0, "\< is a singular point of the D. E.\>"]; \
\[IndentingNewLine]Print["\<Proceed with a Frobenius solution.\>"];, \
\[IndentingNewLine]Print[\*"\"\<The point \!\(x\_0\) = \>\"", 
          X\_0, "\< is NOT singular point.\>"]; \
\[IndentingNewLine]Print["\<Use the power series method for an ordinary point \
of the D. E.\>"]; \[IndentingNewLine]Print[\*"\"\<y''[x] + \!\(f\_1\)[x]y'[x] \
+ \!\(f\_2\)[x]y[x] = 0\>\""]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_1\)[x]=\
\!\(Q[x]\/P[x]\) = \>\"", Together[Q[x]\/P[x]], "\< = \>", 
          Series[f\_1[x], {x, X\_0, 
              3}]]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_2\)[x]=\!\(R[x]\/P[\
x]\) = \>\"", Together[R[x]\/P[x]], "\< = \>", 
          Series[f\_2[x], {x, X\_0, 3}]]; \[IndentingNewLine]If[
          X\_0 \[Equal] 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\!\(x\^n\)\>\"", "\<, etc.\>"]]; \ \
\[IndentingNewLine]If[X\_0 > 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x-\>", 
            X\_0, \*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]]; \
\[IndentingNewLine]If[X\_0 < 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x+\>", \(-X\_0\), \
\*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]];\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Construct the Indicial Equation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi]\_1[x_] = \ \ x  Q[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi]\_2[x_] = \ \ \(x\^2\) 
          R[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(p\_0\  = \ 
        Limit[x  Q[x]\/P[x], x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(q\_0\  = \ 
        Limit[\(x\^2\) R[x]\/P[x], 
          x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[r];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = 
        r \((r - 1)\) + \(p\_0\) r\  + \ q\_0\  \[Equal] \ 
          0;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[x] = \>", P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Q[x] = \>", Q[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<R[x] = \>", R[x], "\<\n\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_1\)[x_] =   x\!\(Q[x]\/P[x]\) = \>\"", 
        x  Q[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< x\!\(Q[x]\/P[x]\) = \>\"", p\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_2\)[x_] =  \!\(x\^2\)\!\(R[x]\/P[x]\) = \
\>\"", \(x\^2\) R[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< \!\(x\^2\)\!\(R[x]\/P[x]\) = \>\"", q\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The indicial equation is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", \*"\"\<r(r-1) + \!\(p\_0\) r + \!\(q\_0\) \[Equal] \
0\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = MapAll[Expand, ieqn];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \)}], "Input"],

Cell[TextData[StyleBox["Find the Roots of the Indicial Equation. ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print["\<The indicial equation is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[ieqn, r];\)\ \), "\[IndentingNewLine]", 
    \(\(r\_1\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(r\_2\  = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", 
        r\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_2\) = \>\"", r\_2];\)\ \)}], "Input"],

Cell[TextData[{
  "Form the first Frobenius solution corresponding to the larger root  ",
  Cell[BoxData[
      \(r\_1 = 1\/2\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, s, x];\)\ \), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r = 1\/2;\)\ \), "\n", 
    \(\(n = 9;\)\ \), "\n", 
    \(\(s[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%n c\_k\ x\^k)\) + \(x\^r\) 
              O[x]\^\(n + 1\)];\)\ \), "\n", 
    \(\(coeff = Table[c\_k, {k, 1, n}];\)\ \), "\n", 
    \(\(Print["\<  s[x] = \>", s[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< s'[x] = \>", \(s'\)[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<s''[x] = \>", \(s''\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Substitute into\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\^2\) s''[x]+ x \
s'[x]+(\!\(x\^2\)-(\!\(1\/2\)\!\(\()\^2\)\))s[x] \[Equal] 0\>\""];\)\ \), "\n\
", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(deqn = 
        Expand[x\^2\ \(\(s'\)'\)[x] + \ \ x\ \(s'\)[
                  x] + \((x\^2\  - \((1\/2)\)\^2)\) s[x]\ ] \[Equal] 
          0;\)\), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\ \)}], "Input"],

Cell["Form the set of equations to solve and do it. ", "Text"],

Cell[BoxData[{
    \(\(eqns = LogicalExpand[deqn];\)\ \), "\n", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[ReplaceAll[eqns, And \[Rule] List]]\ ];\)\ \), "\n", 
    \(\(solset = Solve[eqns, coeff];\)\ \), "\n", 
    \(\(Print[
        TableForm[
          Sort[solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]]\ ];\)\ \), "\n", 
    \(\(s[x_] = 
        ReplaceAll[s[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print["\<y = \>", s[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", 
        Normal[s[x]], "\< + ...\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y = \[InvisibleSpace]\!\(c\_0\)\>\"", \((\
\[InvisibleSpace]x\^r)\), "\<(\>", 
        Normal[\(1\/\(\(\[InvisibleSpace]\)\(c\_0\)\)\) \(x\^\(-r\)\) 
            s[x]], "\< + ...)\>"];\)\)}], "Input"],

Cell["The first Frobenius solution is: ", "Text"],

Cell[BoxData[{
    \(\(s1[x_] = ReplaceAll[s[x], c\_0 \[Rule] 1];\)\ \), "\n", 
    \(\(Print["\<f1[x] = \>", s1[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", 
        Normal[s1[x]], "\< + ...\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \[InvisibleSpace]\>", \((\[InvisibleSpace]x\^r)\), "\
\<(\>", Normal[\(x\^\(-r\)\) s1[x]], "\< + ...)\>"];\)\)}], "Input"],

Cell[TextData[{
  "Form the second Frobenius solution corresponding to the smaller root  ",
  Cell[BoxData[
      \(r\_2 = \(-1\)\/2\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, s, x];\)\ \), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r = \(-1\)\/2;\)\ \), "\n", 
    \(\(n = 11;\)\ \), "\n", 
    \(\(s[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%n c\_k\ x\^k)\) + \(x\^r\) 
              O[x]\^\(n + 1\)];\)\ \), "\n", 
    \(\(coeff = Table[c\_k, {k, 2, n}];\)\ \), "\n", 
    \(\(Print["\<  s[x] = \>", s[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< s'[x] = \>", \(s'\)[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<s''[x] = \>", \(s''\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Substitute into\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\^2\) s''[x]+ x \
s'[x]+(\!\(x\^2\)-(\!\(1\/2\)\!\(\()\^2\)\))s[x] \[Equal] 0\>\""];\)\ \), "\n\
", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(deqn = 
        Expand[x\^2\ \(\(s'\)'\)[x] + \ \ x\ \(s'\)[
                  x] + \((x\^2\  - \((1\/2)\)\^2)\) s[x]] \[Equal] 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\)}], "Input"],

Cell["Form the set of equations to solve and do it.  ", "Text"],

Cell[BoxData[{
    \(\(eqns = LogicalExpand[deqn];\)\ \), "\n", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[ReplaceAll[eqns, And \[Rule] List]]\ ];\)\ \), "\n", 
    \(\(solset = Solve[eqns, coeff];\)\ \), "\n", 
    \(\(Print[
        TableForm[
          Sort[solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]]\ ];\)\ \), "\n", 
    \(\(s[x_] = 
        ReplaceAll[s[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print["\<y = \>", s[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", 
        Normal[s[x]], "\< + ...\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<y = \[InvisibleSpace]\!\(c\_0\)\>\"", \((\
\[InvisibleSpace]x\^r)\), "\<(\>", 
        Normal[\(1\/\(\(\[InvisibleSpace]\)\(c\_0\)\)\) \(x\^\(-r\)\) 
            s[x]], "\< + ...)\>"];\)\)}], "Input"],

Cell["The second Frobenius solution is: ", "Text"],

Cell[BoxData[{
    \(\(s2[x_] = ReplaceAll[s[x], c\_0 \[Rule] 1];\)\ \), "\n", 
    \(\(Print["\<f2[x] = \>", s2[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", Normal[s2[x]], "\< + ...\>"\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Observe that the coefficients that involve ",
  Cell[BoxData[
      \(c\_1\)]],
  " are that multiple of the first Frobenius solution.  Hence we can set  ",
  Cell[BoxData[
      \(c\_1 = 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(s2[x_] = ReplaceAll[s2[x], c\_1 \[Rule] 0];\)\ \), "\n", 
    \(\(Print["\<f2[x] = \>", s2[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", 
        Normal[s2[x]], "\< + ...\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \[InvisibleSpace]\>", \((\[InvisibleSpace]x\^r)\), \
"\<(\>", Normal[\(x\^\(-r\)\) s2[x]], "\< + ...)\>"];\)\)}], "Input"],

Cell[TextData[{
  "After you are done, use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s DSolve subroutine to get the answer and check out its series expansion. \
 "
}], "Text"],

Cell[BoxData[{
    \(c = 0; \ x = 0; \ y = 0; \ Remove[c, x, y];\), "\[IndentingNewLine]", 
    \(\(de = 
        x\^2\ \(\(y'\)'\)[x] + \ \ x\ \(y'\)[
                x] + \((x\^2\  - \((1\/2)\)\^2)\) y[x] \[Equal] 
          0;\)\), "\n", 
    \(\(solset = DSolve[de, y[x], x];\)\), "\n", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\), "\[IndentingNewLine]", 
    \(\(sol1 = 
        ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), {\[ExponentialE]\^\(\[ImaginaryI]\ x\) \
\[Rule] \((\ Cos[x] + \[ImaginaryI]\ Sin[
                      x])\), \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ x\) \
\[Rule] \ Cos[\(-x\)] + \[ImaginaryI]\ Sin[\(-x\)]}];\)\), "\n", 
    \(\(sol1 = 
        ReplaceAll[
          sol1, {C[1] \[Rule] \(1\/2\) c\_1 + \(1\/2\) \[ImaginaryI]\ c\_2, 
            C[2] \[Rule] c\_2 + \[ImaginaryI]\ c\_1}];\)\), "\n", 
    \(\(sol1 = Expand[sol1];\)\), "\[IndentingNewLine]", 
    \(\(f[x_] = sol1;\)\), "\[IndentingNewLine]", 
    \(\(Print["\< y[x] = \>", f[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Two linearly independent solutions are\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(g1[x_] = 
        ReplaceAll[f[x], {c\_1 \[Rule] 0, c\_2 \[Rule] 1}];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\), "\n", 
    \(\(g2[x_] = 
        ReplaceAll[f[x], {c\_1 \[Rule] 1, c\_2 \[Rule] 0}];\)\), "\n", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\)}], "Input"],

Cell["\<\
Now we plot the series approximations and the analytic solutions. \
\>", "Text"],

Cell[BoxData[{
    \(\(S1[x_] = Normal[s1[x]\ ];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], g1[x]}, {x, 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{0, 2  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle\  \[Rule] {Cyan, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S2[x_] = Normal[s2[x]\ ];\)\), "\n", 
    \(\(Plot[{S2[x], g2[x]}, {x, 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{0, 2  \[Pi]}, {\(-1\), 3}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S2[x] = \>", S2[x]\ ];\)\), "\n", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["The recursive formula for the coefficients.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nIf we look at the series in more depth we will be able to obtain the \
analytic solutions as infinite sums.  First find the recursive formula for \
the coefficients of  ",
  Cell[BoxData[
      \(x\^\(r + n\)\)]],
  ".  If you try this be sure to use the  \" := \"  replacement delayed \
structure to avoid an infinite recursion.  For this example the trial term  \
",
  Cell[BoxData[
      \(t[x] = \[Sum]\+\(k = n - 2\)\%n c\_k\ x\^\(r + k\)\)]],
  " works with the replacements ",
  Cell[BoxData[
      \({x\^\(n + r\) \[Rule] 1, x\^\(\(-1\) + n + r\) \[Rule] 0, 
        x\^\(\(-2\) + n + r\) \[Rule] 0, x\^\(1 + n + r\) \[Rule] 0, 
        x\^\(2 + n + r\) \[Rule] 0}\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, t, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(t[x_] := \[Sum]\+\(k = n - 2\)\%n c\_k\ x\^\(r + k\)\ ;\)\ \), "\n", 
    \(\(nterm = 
        x\^2\ \(\(t'\)'\)[x] + \ \ x\ \(t'\)[
                x] + \((x\^2\  - \((1\/2)\)\^2)\) t[x] \[Equal] 
          0;\)\ \), "\n", 
    \(\(nterm = ExpandAll[nterm];\)\ \), "\n", 
    \(\(Print["\<The general term in the sum is\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(nterm = 
        ReplaceAll[
          nterm, {x\^\(n + r\) \[Rule] 1, x\^\(\(-1\) + n + r\) \[Rule] 0, 
            x\^\(\(-2\) + n + r\) \[Rule] 0, x\^\(1 + n + r\) \[Rule] 0, 
            x\^\(2 + n + r\) \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Simplify it.\>", "\<\n\>"];\)\ \), "\n", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(solset = \ Solve[nterm, c\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Solve it for the recursive formula.\>", "\<\n\>"];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\)\ \)}], "Input"],

Cell["\<\
If you can't get the above computation to work, then just type in the \
recursive formula. \
\>", "Text"],

Cell[BoxData[
    \(c\_n_ := \(-\(\(4  c\_\(n - 2\)\)\/\(\(-1\) + 4\ n\^2 + 8\ n\ r + 
              4\ r\^2\)\)\)\)], "Input"],

Cell[TextData[{
  "Now look at each series individually.  The first Frobenius series \
corresponds to  ",
  Cell[BoxData[
      \(r\_1 = 1\/2\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r\  = \ 1\/2\ ;\)\), "\n", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_1 = 0;\)\), "\n", 
    \(\(c\_n_ := \(-\(\(4\ c\_\(n - 2\)\)\/\(\(-1\) + 4\ n\^2 + 8\ n\ r + 
                4\ r\^2\)\)\)\ ;\)\), "\n", 
    \(\(s1[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%11\( c\_k\) 
                  x\^k)\)]\ ;\)\ \), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<c\>"\_i, "\< = \>", c\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        Simplify[\(-\(\(4\ \*"\"\<\!\(c\_\(n - 2\)\)\>\""\)\/\(\(-1\) + 
                  4\ n\^2 + 8\ n\ r + 
                  4\ r\^2\)\)\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<s1[x] = \>", s1[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Now look at the second Frobenius series which corresponds to  ",
  Cell[BoxData[
      \(r\_2 = \(-1\)\/2\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r\  = \(-1\)\/2\ ;\)\), "\n", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_1 = 0;\)\), "\[IndentingNewLine]", 
    \(\(c\_n_ := \(-\(\(4\ c\_\(n - 2\)\)\/\(\(-1\) + 4\ n\^2 + 8\ n\ r + 
                4\ r\^2\)\)\)\ ;\)\), "\[IndentingNewLine]", 
    \(\(s2[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%11\( c\_k\) 
                  x\^k)\)\ ];\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<c\>"\_i, "\< = \>", c\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        Simplify[\(-\(\(4\ \*"\"\<\!\(c\_\(n - 2\)\)\>\""\)\/\(\(-1\) + 
                  4\ n\^2 + 8\ n\ r + 
                  4\ r\^2\)\)\)]];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<s2[x] = \>", s2[x]\ ]\)}], "Input"],

Cell["\<\
When the explicit formulas for the coefficients of the first Frobenius are \
used we get: \
\>", "Text"],

Cell[BoxData[{
    \(\(a\_k_ := \((\(-1\))\)\^k\/\(\((2  k + 1)\)!\);\)\ \), "\n", 
    \(\(r = 1\/2;\)\ \), "\n", 
    \(\(f1[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%\[Infinity]\( a\_k\) 
                  x\^\(2  k\))\)\ ]\ ;\)\ \), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<a\>"\_i, "\< = \>", a\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(a\_k\) = \>\"", \((\(-1\))\)\^k\/\(\((2  k + \
1)\)!\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", \(x\^r\) \((\[Sum]\+\(k = 0\)\%10\( a\_k\) 
                x\^\(2  k\))\), "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(f1[x_] = PowerExpand[f1[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{s1[x], f1[x]}, {x, 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{0, 2  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle\  \[Rule] {Cyan, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<s1[x] = \>", s1[x]\ ];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell["\<\
When the explicit formulas for the coefficients of the second Frobenius are \
used we get: \
\>", "Text"],

Cell[BoxData[{
    \(\(b\_k_ := \((\(-1\))\)\^k\/\(\((2  k)\)!\);\)\ \), "\n", 
    \(\(r = \(-1\)\/2;\)\ \), "\n", 
    \(\(f2[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%\[Infinity]\( b\_k\) 
                  x\^\(2  k\))\)\ ];\)\ \), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<b\>"\_i, "\< = \>", b\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(b\_k\) = \>\"", \((\(-1\))\)\^k\/\(\((2  k)\)!\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", 
        x\^r, "\<(\>", \((\[Sum]\+\(k = 0\)\%10\( b\_k\) 
              x\^\(2  k\))\), "\< + ... )\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", f2[x]\ ];\)\ \), "\n", 
    \(\(f2[x_] = PowerExpand[f2[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", f2[x]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[{s2[x], g2[x]}, {x, 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{0, 2  \[Pi]}, {\(-1\), 3}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<s2[x] = \>", s2[x]\ ];\)\), "\n", 
    \(\(Print["\<f2[x] = \>", f2[x]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Frobenius series to solve the D. E.   \n\n\t\t",
  Cell[BoxData[
      \(2  x\ \(\(y'\)'\)[x] + \ \ 3\ \(y'\)[x] - \ y[x]\  = \ 0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Determine the nature of the singularity at ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = 2  x;\)\), "\[IndentingNewLine]", 
    \(\(Q[x_] = 3;\)\), "\[IndentingNewLine]", 
    \(\(R[x_] = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(f\_1[x_] = Q[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(f\_2[x_] = R[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(de = 
        P[x]\ \(y''\)[x] + \ \ Q[x]\ \(y'\)[x] + R[x] y[x]\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(If[
        P[X\_0] \[Equal] 0, \[IndentingNewLine]Print["\<P[x] = \>", 
          P[x]]; \ \[IndentingNewLine]Print["\<P[\>", X\_0, "\<] = \>", 
          P[X\_0]]; \[IndentingNewLine]Print[\*"\"\<The point \!\(x\_0\) = \>\
\"", X\_0, "\< is a singular point.\>"]; \[IndentingNewLine]Print["\<Proceed \
with a Frobenius solution.\>"];, \[IndentingNewLine]Print[\*"\"\<The point \!\
\(x\_0\) = \>\"", 
          X\_0, "\< is NOT singular point.\>"]; \
\[IndentingNewLine]Print["\<Use the power series method for an ordinary \
point.\>"]; \[IndentingNewLine]Print[\*"\"\<y''[x] + \!\(f\_1\)[x]y'[x] + \
\!\(f\_2\)[x]y[x] = 0\>\""]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_1\)[x]=\!\
\(Q[x]\/P[x]\) = \>\"", Together[Q[x]\/P[x]], "\< = \>", 
          Series[f\_1[x], {x, X\_0, 
              3}]]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_2\)[x]=\!\(R[x]\/P[\
x]\) = \>\"", Together[R[x]\/P[x]], "\< = \>", 
          Series[f\_2[x], {x, X\_0, 3}]]; \[IndentingNewLine]If[
          X\_0 \[Equal] 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\!\(x\^n\)\>\"", "\<, etc.\>"]]; \ \
\[IndentingNewLine]If[X\_0 > 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x-\>", 
            X\_0, \*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]]; \
\[IndentingNewLine]If[X\_0 < 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x+\>", \(-X\_0\), \
\*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]];\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Construct the Indicial Equation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi]\_1[x_] = \ \ x  Q[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi]\_2[x_] = \ \ \(x\^2\) 
          R[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(p\_0\  = \ 
        Limit[x  Q[x]\/P[x], x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(q\_0\  = \ 
        Limit[\(x\^2\) R[x]\/P[x], 
          x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[r];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = 
        r \((r - 1)\) + \(p\_0\) r\  + \ q\_0\  \[Equal] \ 
          0;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[x] = \>", P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Q[x] = \>", Q[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<R[x] = \>", R[x], "\<\n\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_1\)[x_] =   x\!\(Q[x]\/P[x]\) = \>\"", 
        x  Q[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< x\!\(Q[x]\/P[x]\) = \>\"", p\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_2\)[x_] =  \!\(x\^2\)\!\(R[x]\/P[x]\) = \
\>\"", \(x\^2\) R[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< \!\(x\^2\)\!\(R[x]\/P[x]\) = \>\"", q\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The indicial equation is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", \*"\"\<r(r-1) + \!\(p\_0\) r + \!\(q\_0\) \[Equal] \
0\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = MapAll[Expand, ieqn];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \)}], "Input"],

Cell[TextData[StyleBox["Find the Roots of the Indicial Equation. ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print["\<The indicial equation is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[ieqn, r];\)\ \), "\[IndentingNewLine]", 
    \(\(r\_1\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(r\_2\  = 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", 
        r\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_2\) = \>\"", r\_2];\)\ \)}], "Input"],

Cell[TextData[{
  "Form the first Frobenius solution corresponding to the root  ",
  Cell[BoxData[
      \(r\_1 = \(-1\)\/2\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, s, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r = \(-1\)\/2;\)\), "\n", 
    \(\(n = 7;\)\), "\n", 
    \(\(s[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%n c\_k\ x\^k)\) + \(x\^r\) 
              O[x]\^\(n + 1\)]\ ;\)\), "\n", 
    \(\(coeff = Table[c\_k, {k, 1, n}];\)\), "\n", 
    \(\(Print["\<  s[x] = \>", s[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< s'[x] = \>", \(s'\)[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<s''[x] = \>", \(s''\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Substitute into\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<2 x s''[x] + 3 s'[x] - s[x] \[Equal] 0\>"];\)\), "\n", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(deqn = 
        Expand[2  x\ \(\(s'\)'\)[x] + \ \ 3\ \(s'\)[x] - \ s[x]\ ] \[Equal] 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\)}], "Input"],

Cell["Form the set of equations to solve and do it. ", "Text"],

Cell[BoxData[{
    \(\(eqns = LogicalExpand[deqn];\)\), "\n", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[ReplaceAll[eqns, And \[Rule] List]]\ ];\)\ \), "\n", 
    \(\(solset = Solve[eqns, coeff];\)\), "\n", 
    \(\(Print[
        TableForm[
          Sort[solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]]\ ];\)\ \), "\n", 
    \(\(s[x_] = 
        ReplaceAll[s[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\), "\n", 
    \(\(Print["\<y = \>", s[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", Normal[s[x]], "\< + ...\>"\ ];\)\)}], "Input"],

Cell["The first Frobenius solution is: ", "Text"],

Cell[BoxData[{
    \(\(s1[x_] = ReplaceAll[s[x], c\_0 \[Rule] 1];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", s1[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", 
        Normal[s1[x]], "\< + ...\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \[InvisibleSpace]\>", \((\[InvisibleSpace]x\^r)\), "\
\<(\>", Normal[\(x\^\(-r\)\) s1[x]], "\< + ...)\>"];\)\)}], "Input"],

Cell[TextData[{
  "Form the second Frobenius solution corresponding to the root  ",
  Cell[BoxData[
      \(r\_2 = 0\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, s, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r = 0;\)\), "\n", 
    \(\(n = 7;\)\), "\n", 
    \(\(s[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%n c\_k\ x\^k)\) + \(x\^r\) 
              O[x]\^\(n + 1\)]\ ;\)\), "\n", 
    \(\(coeff = Table[c\_k, {k, 1, n}];\)\ \), "\n", 
    \(\(deqn = 
        Expand[2  x\ \(\(s'\)'\)[x] + \ \ 3\ \(s'\)[x] - \ s[x]\ ] \[Equal] 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  s[x] = \>", s[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< s'[x] = \>", \(s'\)[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<s''[x] = \>", \(s''\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Substitute into\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<2 x s''[x] + 3 s'[x] - s[x] \[Equal] 0\>"];\)\), "\n", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\ \)}], "Input"],

Cell["Form the set of equations to solve and do it. ", "Text"],

Cell[BoxData[{
    \(\(eqns = LogicalExpand[deqn];\)\), "\n", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[ReplaceAll[eqns, And \[Rule] List]]\ ];\)\ \), "\n", 
    \(\(solset = Solve[eqns, coeff];\)\), "\n", 
    \(\(Print[
        TableForm[
          Sort[solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]]\ ];\)\ \), "\n", 
    \(\(s[x_] = 
        ReplaceAll[s[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\), "\n", 
    \(\(Print["\<y = \>", s[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", Normal[s[x]], "\<+ ...\>"\ ];\)\)}], "Input"],

Cell["The second Frobenius solution is: ", "Text"],

Cell[BoxData[{
    \(\(s2[x_] = ReplaceAll[s[x], c\_0 \[Rule] 1];\)\), "\n", 
    \(\(Print["\<f2[x] = \>", s2[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", Normal[s2[x]], "\< + ...\>"\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "After you are done, use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s DSolve subroutine to get the answer and check out its series expansion. \
\nThis will require slight fussing around with the appropriate multiple of  \
\"",
  StyleBox["Sinh",
    FontFamily->"Courier New"],
  "\". "
}], "Text"],

Cell[BoxData[{
    \(x = 0; \ y = 0; \ Remove[x, y];\), "\[IndentingNewLine]", 
    \(\(de = 
        2  x\ \(\(y'\)'\)[x] + \ \ 3\ \(y'\)[x] - \ y[x] \[Equal] 
          0;\)\), "\n", 
    \(\(sol1 = 
        DSolve[2  x\ \(\(y'\)'\)[x] + \ \ 3\ \(y'\)[x] - \ y[x] \[Equal] 0, 
          y[x], x];\)\), "\n", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print[sol1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Two linearly independent solutions are\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(g1[x_] = Cosh[\@2\ \@x]\/\@x;\)\), "\n", 
    \(\(sol11 = 
        ReplaceAll[
          sol1, {C[1] \[Rule] 1\/2, 
            C[2] \[Rule] \ \(-\(\@2\/2\)\)}];\)\), "\n", 
    \(\(g1[x_] = 
        Expand[sol11\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(g1[x_] = 
        FullSimplify[g1[x], Trig \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\), "\n", 
    \(\(sol22 = 
        ReplaceAll[
          sol1, {C[1] \[Rule] 1\/\(2 \@ 2\), 
            C[2] \[Rule] \ 1\/2}];\)\), "\n", 
    \(\(g2[x_] = 
        Expand[sol22\_\(\(\[LeftDoubleBracket]\)\(1, 1, 2\)\(\
\[RightDoubleBracket]\)\)];\)\), "\[IndentingNewLine]", 
    \(\(g2[x_] = 
        FullSimplify[g2[x], Trig \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\)}], "Input"],

Cell["\<\
At this time we could plot the series approximations and the analytic \
solutions. To see the difference in the graphs we will reduce the number of \
terms in the series.\
\>", "Text"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]\ ], 4];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], g1[x]}, {x, 0, 9}, PlotRange \[Rule] {{0, 9}, {0, 10}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S2[x_] = Take[Normal[s2[x]], 4];\)\), "\n", 
    \(\(Plot[{S2[x], g2[x]}, {x, 0, 10}, 
        PlotRange \[Rule] {{0, 10}, {0, 10}}, 
        PlotStyle\  \[Rule] {Cyan, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S2[x] = \>", S2[x]\ ];\)\), "\n", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["The recursive formula for the coefficients.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIf we look at the series in more depth we will be able to obtain the \
analytic solutions as infinite sums.  First find the recursive formula for \
the coefficients of  ",
  Cell[BoxData[
      \(x\^\(r + n\)\)]],
  ".  If you try this be sure to use the  \" := \"  replacement delayed \
structure to avoid an infinite recursion.  For this example the trial term  \
",
  Cell[BoxData[
      \(t[x] = \[Sum]\+\(k = n - 1\)\%n c\_k\ x\^\(r + k\)\)]],
  " works with the replacements ",
  Cell[BoxData[
      \({x\^\(n + r\) \[Rule] 0, x\^\(\(-1\) + n + r\) \[Rule] 1, 
        x\^\(\(-2\) + n + r\) \[Rule] 0, x\^\(1 + n + r\) \[Rule] 0, 
        x\^\(2 + n + r\) \[Rule] 0}\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, t, x];\)\ \), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(t[x_] := \[Sum]\+\(k = n - 1\)\%n c\_k\ x\^\(r + k\);\)\), "\n", 
    \(\(nterm = 
        2  x\ \(\(t'\)'\)[x] + \ \ 3\ \(t'\)[x] - \ t[x] \[Equal] 
          0\ ;\)\), "\n", 
    \(\(nterm = ExpandAll[nterm];\)\ \), "\n", 
    \(\(Print["\<The general term in the sum is\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Simplify it.\>", "\<\n\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(nterm = 
        ReplaceAll[
          nterm, {x\^\(n + r\) \[Rule] 0, x\^\(\(-1\) + n + r\) \[Rule] 1, 
            x\^\(\(-2\) + n + r\) \[Rule] 0, x\^\(1 + n + r\) \[Rule] 0, 
            x\^\(2 + n + r\) \[Rule] 0}];\)\ \), "\n", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[nterm, c\_n];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Solve it for the recursive formula.\>", "\<\n\>"];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\)\ \)}], "Input"],

Cell["\<\
If you can't get the above computation to work, then just type in the \
recursive formula. \
\>", "Text"],

Cell[BoxData[
    \(\(\(c\_n_ := 
        c\_\(n - 1\)\/\(n + 2\ n\^2 + r + 4\ n\ r + 2\ r\^2\);\)\(\ \)\)\)], \
"Input"],

Cell[TextData[{
  "Now look at each series individually.  The first Frobenius corresponds to  \
",
  Cell[BoxData[
      \(r\_1 = \(-1\)\/2\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, x];\)\ \), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r\  = \ \(-1\)\/2\ ;\)\), "\n", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_n_ := 
        c\_\(n - 1\)\/\(n + 2\ n\^2 + r + 4\ n\ r + 2\ r\^2\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(s1[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%11\( c\_k\) 
                  x\^k)\)]\ ;\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<c\>"\_i, "\< = \>", c\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        Simplify[\*"\"\<\!\(c\_\(n - 1\)\)\>\""\/\(n + 2\ n\^2 + r + 4\ n\ r \
+ 2\ r\^2\)]];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<s1[x] = \>", s1[x]\ ]\)}], "Input"],

Cell[TextData[{
  "Now look at the second Frobenius series corresponding to  ",
  Cell[BoxData[
      \(r\_2 = 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r\  = 0\ ;\)\), "\n", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_n_ := 
        c\_\(n - 1\)\/\(n + 2\ n\^2 + r + 4\ n\ r + 2\ r\^2\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(s2[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%11\( c\_k\) 
                  x\^k)\)\ ];\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<c\>"\_i, "\< = \>", c\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        Simplify[\*"\"\<\!\(c\_\(n - 1\)\)\>\""\/\(n + 2\ n\^2 + r + 4\ n\ r \
+ 2\ r\^2\)]];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<s2[x] = \>", s2[x]\ ]\)}], "Input"],

Cell["\<\
The explicit formulas for the coefficients for the first Frobenius series \
are: \
\>", "Text"],

Cell[BoxData[{
    \(\(a\_k_ := 1\/\(\(k!\)\ \(\((2  k - 1)\)!!\)\);\)\), "\n", 
    \(\(r = \(-\(1\/2\)\);\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<a\>"\_i, "\< = \>", a\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(a\_k\) = \>\"", 
        1\/\(\(k!\)\ \(\((2  k - 1)\)!!\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", 
        x\^r, "\<(\>", \((\[Sum]\+\(k = 0\)\%11\( a\_k\) 
              x\^k)\)\ , "\< + ... )\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(f1[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%11\( a\_k\) 
                  x\^k)\)\ ];\)\), "\n", 
    \(\(Print["\<s1[x] = \>", f1[x]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]\ ], 4];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], f1[x]}, {x, 0, 9}, PlotRange \[Rule] {{0, 9}, {0, 10}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(b\_k_ := 1\/\(\(k!\)\ \(\((2  k + 1)\)!!\)\);\)\), "\n", 
    \(\(r = 0;\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<b\>"\_i, "\< = \>", b\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(b\_k\) = \>\"", 
        1\/\(\(k!\)\ \(\((2  k + 1)\)!!\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", 
        x\^r, "\<(\>", \((\[Sum]\+\(k = 0\)\%11\( b\_k\) 
              x\^k)\), "\< + ... )\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(f2[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%11\( b\_k\) 
                  x\^k)\)\ ];\)\), "\n", 
    \(\(Print["\<s2[x] = \>", f2[x]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(S2[x_] = Take[Normal[s2[x]], 4];\)\), "\n", 
    \(\(Plot[{S2[x], f2[x]}, {x, 0, 10}, 
        PlotRange \[Rule] {{0, 10}, {0, 10}}, 
        PlotStyle\  \[Rule] {Cyan, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S2[x] = \>", S2[x]\ ];\)\), "\n", 
    \(\(Print["\<f2[x] = \>", f2[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We cannot add up the infinite number of terms in this sequence because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not know this formula yet. "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " However, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can treat infinite series \"like a function.\" "
}], "Text"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]\ ], 4];\)\), "\n", 
    \(\(f1[x_] = 
        Expand[\(x\^\(-\(1\/2\)\)\) \((\[Sum]\+\(k = 0\)\%\[Infinity]\( 
                      1\/\(\(k!\)\ \(\((2  k - 1)\)!!\)\)\) 
                  x\^k)\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], f1[x]}, {x, 0, 9}, PlotRange \[Rule] {{0, 9}, {0, 10}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S2[x_] = Take[Normal[s2[x]], 4];\)\), "\n", 
    \(\(f2[x_] = 
        Expand[\(x\^0\) \((\[Sum]\+\(k = 0\)\%\[Infinity]\( 
                      1\/\(\(k!\)\ \(\((2  k + 1)\)!!\)\)\) 
                  x\^k)\)\ ];\)\), "\[IndentingNewLine]", 
    \(\(Plot[{S2[x], f2[x]}, {x, 0, 10}, 
        PlotRange \[Rule] {{0, 10}, {0, 10}}, 
        PlotStyle\  \[Rule] {Cyan, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S2[x] = \>", S2[x]\ ];\)\), "\n", 
    \(\(Print["\<f2[x] = \>", f2[x]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Frobenius series to solve the D. E.   \n\n\t\t",
  Cell[BoxData[
      \(2  x\^2\ \(\(y'\)'\)[x] + 
          3\ x\ \ \(y'\)[x] - \((\ x\^2 + 1)\)\ y[x]\  = \ 0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Determine the nature of the singularity at ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = 2  x\^2;\)\), "\[IndentingNewLine]", 
    \(\(Q[x_] = 3\ x;\)\), "\[IndentingNewLine]", 
    \(\(R[x_] = \(-\((\ x\^2 + 1)\)\);\)\), "\[IndentingNewLine]", 
    \(\(f\_1[x_] = Q[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(f\_2[x_] = R[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(de = 
        P[x]\ \(y''\)[x] + \ \ Q[x]\ \(y'\)[x] + R[x] y[x]\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(If[
        P[X\_0] \[Equal] 0, \[IndentingNewLine]Print["\<P[x] = \>", 
          P[x]]; \ \[IndentingNewLine]Print["\<P[\>", X\_0, "\<] = \>", 
          P[X\_0]]; \[IndentingNewLine]Print[\*"\"\<The point \!\(x\_0\) = \>\
\"", X\_0, "\< is a singular point.\>"]; \[IndentingNewLine]Print["\<Proceed \
with a Frobenius solution.\>"];, \[IndentingNewLine]Print[\*"\"\<The point \!\
\(x\_0\) = \>\"", 
          X\_0, "\< is NOT singular point.\>"]; \
\[IndentingNewLine]Print["\<Use the power series method for an ordinary \
point.\>"]; \[IndentingNewLine]Print[\*"\"\<y''[x] + \!\(f\_1\)[x]y'[x] + \
\!\(f\_2\)[x]y[x] = 0\>\""]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_1\)[x]=\!\
\(Q[x]\/P[x]\) = \>\"", Together[Q[x]\/P[x]], "\< = \>", 
          Series[f\_1[x], {x, X\_0, 
              3}]]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_2\)[x]=\!\(R[x]\/P[\
x]\) = \>\"", Together[R[x]\/P[x]], "\< = \>", 
          Series[f\_2[x], {x, X\_0, 3}]]; \[IndentingNewLine]If[
          X\_0 \[Equal] 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\!\(x\^n\)\>\"", "\<, etc.\>"]]; \ \
\[IndentingNewLine]If[X\_0 > 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x-\>", 
            X\_0, \*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]]; \
\[IndentingNewLine]If[X\_0 < 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x+\>", \(-X\_0\), \
\*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]];\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Construct the Indicial Equation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi]\_1[x_] = \ \ x  Q[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi]\_2[x_] = \ \ \(x\^2\) 
          R[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(p\_0\  = \ 
        Limit[x  Q[x]\/P[x], x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(q\_0\  = \ 
        Limit[\(x\^2\) R[x]\/P[x], 
          x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[r];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = 
        r \((r - 1)\) + \(p\_0\) r\  + \ q\_0\  \[Equal] \ 
          0;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[x] = \>", P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Q[x] = \>", Q[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<R[x] = \>", R[x], "\<\n\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_1\)[x_] =   x\!\(Q[x]\/P[x]\) = \>\"", 
        x  Q[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< x\!\(Q[x]\/P[x]\) = \>\"", p\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_2\)[x_] =  \!\(x\^2\)\!\(R[x]\/P[x]\) = \
\>\"", \(x\^2\) R[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< \!\(x\^2\)\!\(R[x]\/P[x]\) = \>\"", q\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The indicial equation is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", \*"\"\<r(r-1) + \!\(p\_0\) r + \!\(q\_0\) \[Equal] \
0\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = MapAll[Expand, ieqn];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \)}], "Input"],

Cell[TextData[StyleBox["Find the Roots of the Indicial Equation. ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print["\<The indicial equation is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[ieqn, r];\)\ \), "\[IndentingNewLine]", 
    \(\(r\_1\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(r\_2\  = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", 
        r\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_2\) = \>\"", r\_2];\)\ \)}], "Input"],

Cell[TextData[{
  "Form the first Frobenius solution corresponding to the root  ",
  Cell[BoxData[
      \(r\_1 = 1\/2\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, s, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r = 1\/2;\)\), "\n", 
    \(\(n = 10;\)\), "\n", 
    \(\(s[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%n c\_k\ x\^k)\) + 
            O[x]\^\(n + 1\)];\)\), "\n", 
    \(\(coeff = Table[c\_k, {k, 1, n}];\)\), "\n", 
    \(\(Print["\<  s[x] = \>", s[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< s'[x] = \>", \(s'\)[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<s''[x] = \>", \(s''\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Substitute into\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<2 \!\(x\^2\) s''[x] + 3 x s'[x] - (\!\(x\^2\)+1) s[x] \
\[Equal] 0\>\""];\)\), "\n", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(deqn = 
        Expand[2 
                 x\^2\ \(\(s'\)'\)[x] + \ \ 3\ x\ \ \(s'\)[x] - \((\ 
                  x\^2\  + 1)\)\ s[x]] \[Equal] 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\)}], "Input"],

Cell["Form the set of equations to solve and do it. ", "Text"],

Cell[BoxData[{
    \(\(eqns = LogicalExpand[deqn];\)\), "\n", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[ReplaceAll[eqns, And \[Rule] List]]\ ];\)\ \), "\n", 
    \(\(solset = Solve[eqns, coeff];\)\), "\n", 
    \(\(Print[
        TableForm[
          Sort[solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]]\ ];\)\ \), "\n", 
    \(\(s[x_] = 
        ReplaceAll[s[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\), "\n", 
    \(\(Print["\<y = \>", s[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", Normal[s[x]], "\< + ...\>"\ ];\)\)}], "Input"],

Cell["The first Frobenius solution is: ", "Text"],

Cell[BoxData[{
    \(\(s1[x_] = ReplaceAll[s[x], c\_0 \[Rule] 1];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", s1[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", 
        Normal[s1[x]], "\< + ...\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \[InvisibleSpace]\>", \((\[InvisibleSpace]x\^r)\), \
"\<(\>", Normal[\(x\^\(-r\)\) s1[x]], "\< + ...)\>"];\)\)}], "Input"],

Cell[TextData[{
  "Form the second ",
  "Frobenius solution corresponding to the root  ",
  Cell[BoxData[
      \(r\_2 = \(-1\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, s, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r = \(-1\);\)\), "\n", 
    \(\(n = 10;\)\), "\n", 
    \(\(s[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%n c\_k\ x\^k)\) + 
            O[x]\^\(n + 1\)]\ ;\)\), "\n", 
    \(\(coeff = Table[c\_k, {k, 1, n}];\)\), "\n", 
    \(\(Print["\<  s[x] = \>", s[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< s'[x] = \>", \(s'\)[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<s''[x] = \>", \(s''\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Substitute into\>"];\)\), "\n", 
    \(\(Print[\*"\"\<2 \!\(x\^2\) s''[x] + 3 x s'[x] - (\!\(x\^2\)+1) s[x] \
\[Equal] 0\>\""];\)\), "\n", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(deqn = 
      Expand[2  x\^2\ \(\(s'\)'\)[x] + \ \ 3\ x\ \ \(s'\)[x] - \((\ 
                x\^2\  + 1)\)\ s[x]] \[Equal] 0\)}], "Input"],

Cell["Form the set of equations to solve and do it. ", "Text"],

Cell[BoxData[{
    \(\(eqns = LogicalExpand[deqn];\)\), "\n", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[ReplaceAll[eqns, And \[Rule] List]]\ ];\)\ \), "\n", 
    \(\(solset = Solve[eqns, coeff];\)\), "\n", 
    \(\(Print[
        TableForm[
          Sort[solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]]\ ];\)\ \), "\n", 
    \(\(s[x_] = 
        ReplaceAll[s[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\), "\n", 
    \(\(Print["\<y = \>", s[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", Normal[s[x]], "\< + ...\>"\ ];\)\ \)}], "Input"],

Cell["The second Frobenius solution is: ", "Text"],

Cell[BoxData[{
    \(\(s2[x_] = ReplaceAll[s[x], c\_0 \[Rule] 1];\)\), "\n", 
    \(\(Print["\<f2[x] = \>", s2[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", Normal[s2[x]], "\< + ...\>"\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "After you are done, use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s DSolve subroutine to get the answer and check out its series expansion. \
\nThis will require some fussing around with the appropriate multiple of the \
Bessel function. "
}], "Text"],

Cell[BoxData[{
    \(x = 0; \ y = 0; \ Remove[x, y];\), "\[IndentingNewLine]", 
    \(\(de = 
        2  x\^2\ \(\(y'\)'\)[x] + \ \ 3\ x\ \ \(y'\)[x] - \((\ 
                x\^2\  + 1)\)\ y[x] \[Equal] 0;\)\), "\n", 
    \(\(sol1 = DSolve[de, y[x], x];\)\), "\n", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print[sol1];\)\), "\[IndentingNewLine]", 
    \(\(Print[FunctionExpand[sol1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Two linearly independent solutions are\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(g1[x_] = 
        2\ 2\^\(1/8\)\ Gamma[7\/4] 
          BesselI[3\/4, x\/\@2]\/x\^\(1/4\);\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\), "\n", 
    \(\(g1[x_] = FullSimplify[g1[x]\ ];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\), "\n", 
    \(\(g2[x_] = \(Gamma[1\/4]\/\(2\ 2\^\(\(1/8\)\(\ \)\)\)\) 
          BesselI[\(-\(3\/4\)\), x\/\@2]\/x\^\(1/4\);\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\), "\n", 
    \(\(g2[x_] = FullSimplify[g2[x]\ ];\)\), "\n", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\)}], "Input"],

Cell["\<\
At this time we could plot the series approximations and the analytic \
solutions. To see the difference in the graphs we will reduce the number of \
terms in the series. \
\>", "Text"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]], 3];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], g1[x]}, {x, 0, 5}, PlotRange \[Rule] {{0, 5}, {0, 10}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S2[x_] = Take[Normal[s2[x]], 3];\)\), "\n", 
    \(\(Plot[{S2[x], g2[x]}, {x, 0, 5}, PlotRange \[Rule] {{0, 5}, {0, 10}}, 
        PlotStyle\  \[Rule] {Cyan, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S2[x] = \>", S2[x]\ ];\)\), "\n", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["The recursive formula for the coefficients.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nIf we look at the series in more depth we will be able to obtain the \
analytic solutions as infinite sums.  First find the recursive formula for \
the coefficients of  ",
  Cell[BoxData[
      \(x\^\(r + n\)\)]],
  ".  If you try this be sure to use the  \" := \"  replacement delayed \
structure to avoid an infinite recursion.  Also, include the semicolon at the \
end of the lines. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, t, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(t[x_] := \[Sum]\+\(k = n - 2\)\%n c\_k\ x\^\(r + k\)\ ;\)\), "\n", 
    \(\(nterm = 
        2 \( x\^2\) \(\(t'\)'\)[x] + 
            3  x\ \(t'\)[x] - \((\ x\^2\  + 1)\)\ t[x] \[Equal] 
          0;\)\), "\n", 
    \(\(nterm = ExpandAll[nterm];\)\ \), "\n", 
    \(\(Print["\<The general term in the sum is\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Simplify it.\>", "\<\n\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(nterm = 
        ReplaceAll[
          nterm, {x\^\(n + r\) \[Rule] 1, x\^\(\(-1\) + n + r\) \[Rule] 0, 
            x\^\(\(-2\) + n + r\) \[Rule] 0, x\^\(1 + n + r\) \[Rule] 0, 
            x\^\(2 + n + r\) \[Rule] 0}];\)\ \), "\n", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve it.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[nterm, c\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Solve it for the recursive formula.\>", "\<\n\>"];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\)\ \)}], "Input"],

Cell["\<\
If you can't get the above computation to work, then just type in the \
recursive formula. \
\>", "Text"],

Cell[BoxData[
    \(\(c\_n_ := 
        c\_\(n - 2\)\/\(2\ \((n + r)\)\^2 + n + \ r - 1\);\)\)], "Input"],

Cell[TextData[{
  "Now look at each series individually.  The first Frobenius series \
corresponding to  ",
  Cell[BoxData[
      \(r\_1 = 1\/2\)]],
  "  is: "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\), "\[IndentingNewLine]", 
    \(\(r\  = \ 1\/2\ ;\)\), "\n", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_1 = 0\ ;\)\), "\n", 
    \(\(c\_n_ := 
        c\_\(n - 2\)\/\(2\ \((n + r)\)\^2 + n + \ r - 1\);\)\), "\
\[IndentingNewLine]", 
    \(\(f1[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%13\( c\_k\) 
                  x\^k)\)]\ ;\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<c\>"\_i, "\< = \>", c\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        Simplify[\*"\"\<\!\(c\_\(n - 2\)\)\>\""\/\(2\ \((n + r)\)\^2 + n + \ \
r - 1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]], 3];\)\), "\n", 
    \(\(Plot[{S1[x], f1[x]}, {x, 0, 5}, PlotRange \[Rule] {{0, 5}, {0, 10}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "Now look at the second Frobenius series corresponds to  ",
  Cell[BoxData[
      \(r\_2 = \(-1\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\), "\[IndentingNewLine]", 
    \(\(r\  = \(-1\)\ ;\)\), "\n", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_1 = 0\ ;\)\), "\n", 
    \(\(c\_n_ := 
        c\_\(n - 2\)\/\(2\ \((n + r)\)\^2 + n + \ r - 1\);\)\), "\
\[IndentingNewLine]", 
    \(\(f2[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%15\( c\_k\) 
                  x\^k)\)\ ];\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<c\>"\_i, "\< = \>", c\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        Simplify[\*"\"\<\!\(c\_\(n - 2\)\)\>\""\/\(2\ \((n + r)\)\^2 + n + \ \
r - 1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f2[x] = \>", f2[x]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S2[x_] = Take[Normal[s2[x]], 3];\)\), "\n", 
    \(\(Plot[{S2[x], f2[x]}, {x, 0, 5}, PlotRange \[Rule] {{0, 5}, {0, 10}}, 
        PlotStyle\  \[Rule] {Cyan, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S2[x] = \>", S2[x]\ ];\)\), "\n", 
    \(\(Print["\<f2[x] = \>", f2[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We cannot add up an infinite number of terms in this sequence because we \
do not have a closed formula for the coefficients c[k], it is a recursive \
formula and will exceed the finite recursion depth of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We would like to have a explicit formula for  ",
  Cell[BoxData[
      \(c\_n\)]],
  "  instead of the recursive formula for  ",
  Cell[BoxData[
      \(c\_n\)]],
  ". \nSuch formulas need to be discovered.  How can we do in.  For this \
example, we can resort to \"picking\" ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s mind. \nThat is to say, we can look at the way ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " solves it and reverse engineer the solution. "
}], "Text"],

Cell[BoxData[
    \(Series[\(Gamma[1\/4]\/\(2\ 2\^\(\(1/8\)\(\ \)\)\)\) 
        BesselI[\(-\(3\/4\)\), x\/\@2]\/x\^\(1/4\), {x, 0, 7}]\)], "Input"],

Cell[TextData[{
  "Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " thinks that the Gamma function is used, we will discover \"how to do \
it.\" "
}], "Text"],

Cell[BoxData[{
    \(\(r\  = \ 1\/2\ ;\)\), "\[IndentingNewLine]", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_1 = 0\ ;\)\), "\[IndentingNewLine]", 
    \(\(c\_n_ := 
        c\_\(n - 2\)\/\(2\ \((n + r)\)\^2 + n + \ r - 1\);\)\), "\
\[IndentingNewLine]", 
    \(\*"\"\<\!\(c\_n\)\>\"" == 
      ExpandDenominator[\*"\"\<\!\(c\_\(n - 2\)\)\>\""\/\(2\ \((n + \
1\/2)\)\^2 + n + 1\/2 - 1\)]\), "\[IndentingNewLine]", 
    \(\*"\"\<\!\(c\_n\)\>\"" == \*"\"\<\!\(c\_\(n - 2\)\)\>\""\/Factor[3\ n + \
2\ n\^2]\)}], "Input"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(c\_2\) = \>\"", 
        c\_2, "\< = \>", \(\(\(1\)\(\ \)\)\/\((2)\)\) \(\(1\)\(\ \)\)\/\((4 + \
3)\), "\< = \>", \(\(\(1\)\(\ \)\)\/\((2)\)\) \(\(\(1\)\(\ \)\)\/4\) \
\(\(1\)\(\ \)\)\/\((1 + 3\/4)\), "\< = \>", 
        FullSimplify[
          Gamma[7\/4]\/\(\(\((2*1)\)!!\) \(4\^1\) Gamma[\(4*1 + \
7\)\/4]\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(c\_4\) = \>\"", 
        c\_4, "\< = \>", \(\(\(1\)\(\ \)\)\/\(\((2)\) \((4)\)\)\) \(\(1\)\(\ \
\)\)\/\(\((4 + 3)\) \((8 + 3)\)\), "\< = \>", \(\(\(1\)\(\ \)\)\/\(\((2)\) \
\((4)\)\)\) \(1\/4\^2\) \(\(1\)\(\ \)\)\/\(\((1 + 3\/4)\) \((2 + 3\/4)\)\), "\
\< = \>", 
        FullSimplify[
          Gamma[7\/4]\/\(\(\((2*2)\)!!\) \(\(4\^2\) Gamma[\(4*2 + \
7\)\/4]\)\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(c\_6\) = \>\"", 
        c\_6, "\< = \>", \(\(\(1\)\(\ \)\)\/\(\((2)\) \((4)\) \((6)\)\)\) \
\(\(1\)\(\ \)\)\/\(\((4 + 3)\) \((8 + 3)\) \((12 + 3)\)\), "\< = \>", 
        FullSimplify[
          Gamma[7\/4]\/\(\(\((2*3)\)!!\) \(\(4\^3\) Gamma[\(4*3 + \
7\)\/4]\)\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(c\_8\) = \>\"", 
        c\_8, "\< = \>", \(\(\(1\)\(\ \)\)\/\(\((2)\) \((4)\) \((6)\) \((8)\)\
\)\) \(\(1\)\(\ \)\)\/\(\((4 + 3)\) \((8 + 3)\) \((12 + 3)\) \((16 + 3)\)\), \
"\< = \>", 
        FullSimplify[
          Gamma[7\/4]\/\(\(\((2*4)\)!!\) \(\(4\^4\) Gamma[\(4*4 + \
7\)\/4]\)\)]];\)\)], "Input"],

Cell[TextData[{
  "We now see the pattern and define the coefficient  ",
  Cell[BoxData[
      \(a\_n = c\_\(2  n\)\)]],
  " \n\n\t",
  Cell[BoxData[
      \(a\_n\  = \ \(c\_\(2  n\)\  = \ 
          Gamma[7\/4]\/\(\(\((2  n)\)!!\) \(4\^n\) Gamma[\(4  n + 7\)\/4]\)\)\
\)]]
}], "Text"],

Cell[BoxData[{
    \(\(Clear[n];\)\), "\[IndentingNewLine]", 
    \(a\_n_\  := 
      FullSimplify[
        Gamma[7\/4]\/\(\(\((2  n)\)!!\) \(4\^n\) Gamma[\(4  n + \
7\)\/4]\)]\)}], "Input"],

Cell[TextData[{
  "Compare the coefficients  ",
  Cell[BoxData[
      \(a\_n\)]],
  "  with  ",
  Cell[BoxData[
      \(c\_\(2  n\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(FullSimplify[Table[a\_n, {n, 0, 5}]]\)], "Input"],

Cell[BoxData[
    \(FullSimplify[Table[c\_\(2  n\), {n, 0, 5}]]\)], "Input"],

Cell["\<\
Now sum the series to get the first few terms in the solution. \
\>", "Text"],

Cell[BoxData[{
    \(\(g1[x_] = 
        2\ 2\^\(1/8\)\ Gamma[7\/4] 
          BesselI[3\/4, x\/\@2]\/x\^\(1/4\);\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\), "\n", 
    \(\(g1[x_] = FullSimplify[g1[x]\ ];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g1[x] = \>", Series[g1[x], {x, 0, 11}]\ ];\)\)}], "Input"],

Cell[BoxData[
    \(\(Print["\<g1[x] = \>", \[Sum]\+\(n = 0\)\%5 a\_n\ x\^\(\((4*n + 1)\)/2\
\), "\< + ...\>"\ ];\)\)], "Input"],

Cell[TextData[{
  "Can ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the sum of the series ? "
}], "Text"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%\[Infinity] Gamma[7\/4]\/\(\(\((2  n)\)!!\) \(4\^n\) \
Gamma[\(4  n + 7\)\/4]\)\ x\^\(\((4  n + 1)\)/2\)\)], "Input"],

Cell[TextData[{
  "Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " cannot sum the series ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] Gamma[7\/4]\/\(\(\((2  n)\)!!\) \(4\^n\
\) Gamma[\(4  n + 7\)\/4]\)\ x\^\(\((4  n + 1)\)/2\)\)]],
  ", \nwe have at least found the formula for the coefficients. "
}], "Text"],

Cell[BoxData[
    \(Series[Hypergeometric0F1[1\/4, x\^2\/8]\/x, {x, 0, 11}]\)], "Input"],

Cell["\<\
Similarly, we can find a formula for the coefficients of the second solution. \
\
\>", "Text"],

Cell[BoxData[{
    \(\(g2[x_] = \(Gamma[1\/4]\/\(2\ 2\^\(\(1/8\)\(\ \)\)\)\) 
          BesselI[\(-\(3\/4\)\), x\/\@2]\/x\^\(1/4\);\)\), "\n", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\), "\n", 
    \(\(g2[x_] = FullSimplify[g2[x]\ ];\)\), "\n", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g2[x] = \>", 
        Series[\(Gamma[1\/4]\/\(2\ 2\^\(\(1/8\)\(\ \)\)\)\) 
            BesselI[\(-\(3\/4\)\), x\/\@2]\/x\^\(1/4\), {x, 0, 
            11}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g2[x] = \>", Series[g2[x], {x, 0, 11}]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[n];\)\), "\[IndentingNewLine]", 
    \(b\_n_\  := 
      FullSimplify[
        Gamma[1\/4]\/\(\(\((2  n)\)!!\) \(4\^n\) Gamma[\(4  n + \
1\)\/4]\)]\)}], "Input"],

Cell[BoxData[
    \(FullSimplify[Table[b\_n, {n, 0, 5}]]\)], "Input"],

Cell[BoxData[{
    \(\(Print["\<g2[x] = \>", 
        Series[g2[x], {x, 0, 11}]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g2[x] = \>", \[Sum]\+\(n = 0\)\%6 b\_n\ x\^\((2  n - 1)\), "\
\< + ...\>"\ ];\)\)}], "Input"],

Cell[TextData[{
  "Can ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the sum of the series ? "
}], "Text"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%\[Infinity] Gamma[1\/4]\/\(\(\((2  n)\)!!\) \(4\^n\) \
Gamma[\(4  n + 1\)\/4]\)\ x\^\((2  n - 1)\)\)], "Input"],

Cell[TextData[{
  "Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " cannot sum the series  ",
  Cell[BoxData[
      \(\[Sum]\+\(n = 0\)\%\[Infinity] Gamma[1\/4]\/\(\(\((2  n)\)!!\) \(4\^n\
\) Gamma[\(4  n + 1\)\/4]\)\ x\^\((2  n - 1)\)\)]],
  ", \nwe have at least found the formula for the coefficients. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Frobenius series to solve the D. E.   \n\n\t\t",
  Cell[BoxData[
      \(x\^2\ \(\(y'\)'\)[x] + x\ \ \(y'\)[x] + \ x\^2\ y[x]\  = \ 0\)]],
  ".  \n\t\t\nA solution is known to be the celebrated ",
  ButtonBox["Bessel function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BesselFunctionoftheFirstKind.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  "  ",
  Cell[BoxData[
      \(\(J\_0\) \((x)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Determine the nature of the singularity at ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^2;\)\), "\[IndentingNewLine]", 
    \(\(Q[x_] = \ x;\)\), "\[IndentingNewLine]", 
    \(\(R[x_] = x\^2;\)\), "\[IndentingNewLine]", 
    \(\(f\_1[x_] = Q[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(f\_2[x_] = R[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(de = 
        P[x]\ \(y''\)[x] + \ \ Q[x]\ \(y'\)[x] + R[x] y[x]\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(If[
        P[X\_0] \[Equal] 0, \[IndentingNewLine]Print["\<P[x] = \>", 
          P[x]]; \ \[IndentingNewLine]Print["\<P[\>", X\_0, "\<] = \>", 
          P[X\_0]]; \[IndentingNewLine]Print[\*"\"\<The point \!\(x\_0\) = \>\
\"", X\_0, "\< is a singular point.\>"]; \[IndentingNewLine]Print["\<Proceed \
with a Frobenius solution.\>"];, \[IndentingNewLine]Print[\*"\"\<The point \!\
\(x\_0\) = \>\"", 
          X\_0, "\< is NOT singular point.\>"]; \
\[IndentingNewLine]Print["\<Use the power series method for an ordinary \
point.\>"]; \[IndentingNewLine]Print[\*"\"\<y''[x] + \!\(f\_1\)[x]y'[x] + \
\!\(f\_2\)[x]y[x] = 0\>\""]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_1\)[x]=\!\
\(Q[x]\/P[x]\) = \>\"", Together[Q[x]\/P[x]], "\< = \>", 
          Series[f\_1[x], {x, X\_0, 
              3}]]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_2\)[x]=\!\(R[x]\/P[\
x]\) = \>\"", Together[R[x]\/P[x]], "\< = \>", 
          Series[f\_2[x], {x, X\_0, 3}]]; \[IndentingNewLine]If[
          X\_0 \[Equal] 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\!\(x\^n\)\>\"", "\<, etc.\>"]]; \ \
\[IndentingNewLine]If[X\_0 > 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x-\>", 
            X\_0, \*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]]; \
\[IndentingNewLine]If[X\_0 < 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x+\>", \(-X\_0\), \
\*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]];\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Construct the Indicial Equation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi]\_1[x_] = \ \ x  Q[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi]\_2[x_] = \ \ \(x\^2\) 
          R[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(p\_0\  = \ 
        Limit[x  Q[x]\/P[x], x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(q\_0\  = \ 
        Limit[\(x\^2\) R[x]\/P[x], 
          x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[r];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = 
        r \((r - 1)\) + \(p\_0\) r\  + \ q\_0\  \[Equal] \ 
          0;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[x] = \>", P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Q[x] = \>", Q[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<R[x] = \>", R[x], "\<\n\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_1\)[x_] =   x\!\(Q[x]\/P[x]\) = \>\"", 
        x  Q[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< x\!\(Q[x]\/P[x]\) = \>\"", p\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_2\)[x_] =  \!\(x\^2\)\!\(R[x]\/P[x]\) = \
\>\"", \(x\^2\) R[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< \!\(x\^2\)\!\(R[x]\/P[x]\) = \>\"", q\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The indicial equation is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", \*"\"\<r(r-1) + \!\(p\_0\) r + \!\(q\_0\) \[Equal] \
0\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = MapAll[Expand, ieqn];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \)}], "Input"],

Cell[TextData[StyleBox["Find the Roots of the Indicial Equation. ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print["\<The indicial equation is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[ieqn, r];\)\ \), "\[IndentingNewLine]", 
    \(\(r\_1\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(r\_2\  = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", 
        r\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_2\) = \>\"", r\_2];\)\ \)}], "Input"],

Cell[TextData[{
  "Form the first Frobenius solution corresponding to the root  ",
  Cell[BoxData[
      \(r\_1 = 0\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, s, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r = 0;\)\), "\n", 
    \(\(n = 10;\)\), "\n", 
    \(\(s[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%n c\_k\ x\^k)\) + 
            O[x]\^\(n + 1\)];\)\), "\n", 
    \(\(coeff = Table[c\_k, {k, 1, n}];\)\), "\n", 
    \(\(Print["\<  s[x] = \>", s[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< s'[x] = \>", \(s'\)[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<s''[x] = \>", \(s''\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Substitute into\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\^2\) s''[x] + x s'[x] + \!\(x\^2\) s[x] \[Equal] 0\
\>\""];\)\), "\n", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(deqn = 
        Expand[x\^2\ \(\(s'\)'\)[x] + \ \ x\ \ \(s'\)[x] + 
              x\^2\ s[x]] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\)}], "Input"],

Cell["Form the set of equations to solve and do it. ", "Text"],

Cell[BoxData[{
    \(\(eqns = LogicalExpand[deqn];\)\), "\n", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[ReplaceAll[eqns, And \[Rule] List]]\ ];\)\ \), "\n", 
    \(\(solset = Solve[eqns, coeff];\)\), "\n", 
    \(\(Print[
        TableForm[
          Sort[solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]]\ ];\)\ \), "\n", 
    \(\(s[x_] = 
        ReplaceAll[s[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\), "\n", 
    \(\(Print["\<y = \>", s[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", Normal[s[x]], "\< + ...\>"\ ];\)\)}], "Input"],

Cell["The first Frobenius solution is: ", "Text"],

Cell[BoxData[{
    \(\(s1[x_] = ReplaceAll[s[x], c\_0 \[Rule] 1];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", s1[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", 
        Normal[s1[x]], "\< + ...\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \[InvisibleSpace]\>", \((\[InvisibleSpace]x\^r)\), \
"\<(\>", Normal[\(x\^\(-r\)\) s1[x]], "\< + ...)\>"];\)\)}], "Input"],

Cell[TextData[{
  "This first Frobenius series solution is a ",
  ButtonBox["Bessel Function of the First Kind",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BesselFunctionoftheFirstKind.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  ", and it is defined at the origin  ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(x = 0; \ y = 0; \ Remove[x, y];\), "\[IndentingNewLine]", 
    \(\(de = 
        x\^2\ \(\(y'\)'\)[x] + \ \ x\ \ \(y'\)[x] + \ x\^2\ y[x] \[Equal] 
          0;\)\), "\n", 
    \(\(sol1 = DSolve[de, y[x], x];\)\), "\n", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print[sol1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Two linearly independent solutions are\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(g1[x_] = BesselJ[0, x];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\), "\n", 
    \(\(g2[x_] = BesselY[0, x];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The second solution to the differential equation is a ",
  ButtonBox["Bessel Function of the Second Kind",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BesselFunctionoftheSecondKind.html"],
       None},
    ButtonStyle->"Hyperlink"],
  ".  It is not a simple Frobenius series and will be discussed in another \
module."
}], "Text"],

Cell["\<\
At this time we could plot the series approximations and the analytic \
solutions. To see the difference in the graphs we will reduce the number of \
terms in the series. \
\>", "Text"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]], 5];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], g1[x]}, {x, 0, 5}, 
        PlotRange \[Rule] {{0, 5}, {\(-0.5\), 1}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", \ g1[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["The recursive formula for the coefficients.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nIf we look at the series in more depth we will be able to obtain the \
analytic solutions as infinite sums.  First find the recursive formula for \
the coefficients of  ",
  Cell[BoxData[
      \(x\^\(r + n\)\)]],
  ".  If you try this be sure to use the  \" := \"  replacement delayed \
structure to avoid an infinite recursion.  Also, include the semicolon at the \
end of the lines. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, t, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(t[x_] := \[Sum]\+\(k = n - 2\)\%n c\_k\ x\^\(r + k\)\ ;\)\), "\n", 
    \(\(nterm = \(x\^2\) \(\(t'\)'\)[x] + x\ \(t'\)[x] + x\^2\ t[x] \[Equal] 
          0;\)\), "\n", 
    \(\(nterm = ExpandAll[nterm];\)\ \), "\n", 
    \(\(Print["\<The general term in the sum is\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Simplify it.\>", "\<\n\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(nterm = 
        ReplaceAll[
          nterm, {x\^\(n + r\) \[Rule] 1, x\^\(\(-1\) + n + r\) \[Rule] 0, 
            x\^\(\(-2\) + n + r\) \[Rule] 0, x\^\(1 + n + r\) \[Rule] 0, 
            x\^\(2 + n + r\) \[Rule] 0}];\)\ \), "\n", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve it.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[nterm, c\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Solve it for the recursive formula.\>", "\<\n\>"];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\)\ \)}], "Input"],

Cell["\<\
If you can't get the above computation to work, then just type in the \
recursive formula. \
\>", "Text"],

Cell[BoxData[
    \(\(c\_n_ := \(-\(c\_\(n - 2\)\/\(n\^2 + 2\ n\ r + 
                r\^2\)\)\);\)\)], "Input"],

Cell[TextData[{
  "Now look at each series individually.  The first Frobenius series \
corresponding to  ",
  Cell[BoxData[
      \(r\_1 = 1\)]],
  "  is: "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\), "\[IndentingNewLine]", 
    \(\(r\  = \ 0\ ;\)\), "\n", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_1 = 0\ ;\)\), "\n", 
    \(\(c\_n_ := \(-\(c\_\(n - 2\)\/\(n\^2 + 2\ n\ r + 
                r\^2\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(f1[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%13\( c\_k\) 
                  x\^k)\)]\ ;\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<c\>"\_i, "\< = \>", c\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        Simplify[\(-\(\*"\"\<\!\(c\_\(n - 2\)\)\>\""\/\(n\^2 + 2\ n\ r + 
                  r\^2\)\)\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The coefficient  ",
  Cell[BoxData[
      \(c\_n\)]],
  "  can be expressed in closed form    ",
  Cell[BoxData[
      \(c\_n\  = \((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 2\)\) \((\(n!\))\) \
\(\((n - 1)\)!\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(Table[\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 2\)\) \((\(n!\))\) \
\(\((n - 1)\)!\)\), {n, 1, 7}]\)], "Input"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]], 3];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], f1[x]}, {x, 0, 5}, 
        PlotRange \[Rule] {{0, 5}, {\(-1\), 4}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The the first Frobenius series solution is twice the Bessel function  ",
  Cell[BoxData[
      \(\(J\_0\) \((x)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(J\_0[
          x_]\  = \ \[Sum]\+\(n = \
0\)\%\[Infinity]\(\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\) 
            x\^\(2  n\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)[x] = \!\(\[Sum]\+\(n = 0\)\%6\)\!\(\((\(-1\))\
\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\)\!\(x\^\(2  n\)\)\>\"", "\< + ...\
\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)[x] = \>\"", \ \[Sum]\+\(n = \
0\)\%6\(\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\) 
            x\^\(2  n\), "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)[x] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\
\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\)\!\(x\^\(2  \
n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)[x] = \>\"", \[Sum]\+\(n = \
0\)\%\[Infinity]\(\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\) 
            x\^\(2  n\)];\)\ \)}], "Input"],

Cell[TextData[{
  "The first Frobenius series solution agrees with the series expansion of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s function  ",
  StyleBox["BesselJ[1,x]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[
    \(Series[BesselJ[0, x], {x, 0, 13}]\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Frobenius series to solve the D. E.   \n\n\t\t",
  Cell[BoxData[
      \(x\^2\ \(\(y'\)'\)[x] + x\ \ \(y'\)[x] + \((\ x\^2 - 1)\)\ y[x]\  = \ 
        0\)]],
  ".  \n\nA solution is known to be the celebrated ",
  ButtonBox["Bessel function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BesselFunctionoftheFirstKind.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  "  ",
  Cell[BoxData[
      \(\(J\_1\) \((x)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Determine the nature of the singularity at ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(X\_0 = 0;\)\ \), "\[IndentingNewLine]", 
    \(\(P[x_] = x\^2;\)\), "\[IndentingNewLine]", 
    \(\(Q[x_] = \ x;\)\), "\[IndentingNewLine]", 
    \(\(R[x_] = \((\ x\^2 - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(f\_1[x_] = Q[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(f\_2[x_] = R[x]\/P[x];\)\), "\[IndentingNewLine]", 
    \(\(de = 
        P[x]\ \(y''\)[x] + \ \ Q[x]\ \(y'\)[x] + R[x] y[x]\  \[Equal] \ 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(If[
        P[X\_0] \[Equal] 0, \[IndentingNewLine]Print["\<P[x] = \>", 
          P[x]]; \ \[IndentingNewLine]Print["\<P[\>", X\_0, "\<] = \>", 
          P[X\_0]]; \[IndentingNewLine]Print[\*"\"\<The point \!\(x\_0\) = \>\
\"", X\_0, "\< is a singular point.\>"]; \[IndentingNewLine]Print["\<Proceed \
with a Frobenius solution.\>"];, \[IndentingNewLine]Print[\*"\"\<The point \!\
\(x\_0\) = \>\"", 
          X\_0, "\< is NOT singular point.\>"]; \
\[IndentingNewLine]Print["\<Use the power series method for an ordinary \
point.\>"]; \[IndentingNewLine]Print[\*"\"\<y''[x] + \!\(f\_1\)[x]y'[x] + \
\!\(f\_2\)[x]y[x] = 0\>\""]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_1\)[x]=\!\
\(Q[x]\/P[x]\) = \>\"", Together[Q[x]\/P[x]], "\< = \>", 
          Series[f\_1[x], {x, X\_0, 
              3}]]; \[IndentingNewLine]Print[\*"\"\<\!\(f\_2\)[x]=\!\(R[x]\/P[\
x]\) = \>\"", Together[R[x]\/P[x]], "\< = \>", 
          Series[f\_2[x], {x, X\_0, 3}]]; \[IndentingNewLine]If[
          X\_0 \[Equal] 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\!\(x\^n\)\>\"", "\<, etc.\>"]]; \ \
\[IndentingNewLine]If[X\_0 > 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x-\>", 
            X\_0, \*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]]; \
\[IndentingNewLine]If[X\_0 < 0, 
          Print[\*"\"\<y[x] = \!\(\[Sum]\+\(n = \
0\)\%\[Infinity]\)\!\(a\_n\)\>\"", "\<(x+\>", \(-X\_0\), \
\*"\"\<\!\(\()\^n\)\)\>\"", "\<, etc.\>"]];\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Construct the Indicial Equation.",
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi]\_1[x_] = \ \ x  Q[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi]\_2[x_] = \ \ \(x\^2\) 
          R[x]\/P[x];\)\ \), "\[IndentingNewLine]", 
    \(\(p\_0\  = \ 
        Limit[x  Q[x]\/P[x], x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(q\_0\  = \ 
        Limit[\(x\^2\) R[x]\/P[x], 
          x \[Rule] X\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[r];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = 
        r \((r - 1)\) + \(p\_0\) r\  + \ q\_0\  \[Equal] \ 
          0;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<P[x] = \>", P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Q[x] = \>", Q[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<R[x] = \>", R[x], "\<\n\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_1\)[x_] =   x\!\(Q[x]\/P[x]\) = \>\"", 
        x  Q[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< x\!\(Q[x]\/P[x]\) = \>\"", p\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[Phi]\_2\)[x_] =  \!\(x\^2\)\!\(R[x]\/P[x]\) = \
\>\"", \(x\^2\) R[x]\/P[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(q\_0\) = \>\"", "\<lim\>"\+\(x \[Rule] X\_0\), \ \*"\
\"\< \!\(x\^2\)\!\(R[x]\/P[x]\) = \>\"", q\_0];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The indicial equation is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", \*"\"\<r(r-1) + \!\(p\_0\) r + \!\(q\_0\) \[Equal] \
0\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(ieqn = MapAll[Expand, ieqn];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \)}], "Input"],

Cell[TextData[StyleBox["Find the Roots of the Indicial Equation. ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Print["\<The indicial equation is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[ieqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[ieqn, r];\)\ \), "\[IndentingNewLine]", 
    \(\(r\_1\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(r\_2\  = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", 
        r\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_2\) = \>\"", r\_2];\)\ \)}], "Input"],

Cell[TextData[{
  "Form the first Frobenius solution corresponding to the root  ",
  Cell[BoxData[
      \(r\_1 = 1\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, s, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(r = 1;\)\), "\n", 
    \(\(n = 10;\)\), "\n", 
    \(\(s[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%n c\_k\ x\^k)\) + 
            O[x]\^\(n + 1\)];\)\), "\n", 
    \(\(coeff = Table[c\_k, {k, 1, n}];\)\), "\n", 
    \(\(Print["\<  s[x] = \>", s[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< s'[x] = \>", \(s'\)[x]\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<s''[x] = \>", \(s''\)[x]\ ];\)\ \ \), "\n", 
    \(\(Print["\<Substitute into\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\^2\) s''[x] + x s'[x] + (\!\(x\^2\)-1) s[x] \
\[Equal] 0\>\""];\)\), "\n", 
    \(\(Print["\<Get\>"];\)\), "\[IndentingNewLine]", 
    \(\(deqn = 
        Expand[x\^2\ \(\(s'\)'\)[x] + \ \ x\ \ \(s'\)[x] + \((\ 
                  x\^2 - 1)\)\ s[x]] \[Equal] 
          0;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\)}], "Input"],

Cell["Form the set of equations to solve and do it. ", "Text"],

Cell[BoxData[{
    \(\(eqns = LogicalExpand[deqn];\)\), "\n", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[ReplaceAll[eqns, And \[Rule] List]]\ ];\)\ \), "\n", 
    \(\(solset = Solve[eqns, coeff];\)\), "\n", 
    \(\(Print[
        TableForm[
          Sort[solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)]]\ ];\)\ \), "\n", 
    \(\(s[x_] = 
        ReplaceAll[s[x], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\), "\n", 
    \(\(Print["\<y = \>", s[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y = \>", Normal[s[x]], "\< + ...\>"\ ];\)\)}], "Input"],

Cell["The first Frobenius solution is: ", "Text"],

Cell[BoxData[{
    \(\(s1[x_] = ReplaceAll[s[x], c\_0 \[Rule] 1];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", s1[x]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", 
        Normal[s1[x]], "\< + ...\>"\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = \[InvisibleSpace]\>", \((\[InvisibleSpace]x\^r)\), \
"\<(\>", Normal[\(x\^\(-r\)\) s1[x]], "\< + ...)\>"];\)\)}], "Input"],

Cell[TextData[{
  "This first Frobenius series solution is a ",
  ButtonBox["Bessel Function of the First Kind",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BesselFunctionoftheFirstKind.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  ", and it is defined at the origin  ",
  Cell[BoxData[
      \(x\_0 = 0\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(x = 0; \ y = 0; \ Remove[x, y];\), "\[IndentingNewLine]", 
    \(\(de = 
        x\^2\ \(\(y'\)'\)[x] + \ \ x\ \ \(y'\)[x] + \((\ x\^2 - 1)\)\ y[
                x] \[Equal] 0;\)\), "\n", 
    \(\(sol1 = DSolve[de, y[x], x];\)\), "\n", 
    \(\(Print[de];\)\), "\[IndentingNewLine]", 
    \(\(Print[sol1];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Two linearly independent solutions are\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(g1[x_] = BesselJ[1, x];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", g1[x]\ ];\)\), "\n", 
    \(\(g2[x_] = BesselY[1, x];\)\), "\n", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<g2[x] = \>", g2[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The second solution to the differential equation is a ",
  ButtonBox["Bessel Function of the Second Kind",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/BesselFunctionoftheSecondKind.html"],
       None},
    ButtonStyle->"Hyperlink"],
  ".  It is not a simple Frobenius series and will be discussed in another \
module."
}], "Text"],

Cell["\<\
At this time we could plot the series approximations and the analytic \
solutions. To see the difference in the graphs we will reduce the number of \
terms in the series. \
\>", "Text"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]], 3];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], 2\ g1[x]}, {x, 0, 5}, 
        PlotRange \[Rule] {{0, 5}, {\(-1\), 3}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<g1[x] = \>", 2\ g1[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["The recursive formula for the coefficients.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\nIf we look at the series in more depth we will be able to obtain the \
analytic solutions as infinite sums.  First find the recursive formula for \
the coefficients of  ",
  Cell[BoxData[
      \(x\^\(r + n\)\)]],
  ".  If you try this be sure to use the  \" := \"  replacement delayed \
structure to avoid an infinite recursion.  Also, include the semicolon at the \
end of the lines. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, r, t, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\ \), "\[IndentingNewLine]", 
    \(\(t[x_] := \[Sum]\+\(k = n - 2\)\%n c\_k\ x\^\(r + k\)\ ;\)\), "\n", 
    \(\(nterm = \(x\^2\) \(\(t'\)'\)[x] + 
            x\ \(t'\)[x] + \((x\^2 - 1)\)\ t[x] \[Equal] 0;\)\), "\n", 
    \(\(nterm = ExpandAll[nterm];\)\ \), "\n", 
    \(\(Print["\<The general term in the sum is\>", "\<\n\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Simplify it.\>", "\<\n\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(nterm = 
        ReplaceAll[
          nterm, {x\^\(n + r\) \[Rule] 1, x\^\(\(-1\) + n + r\) \[Rule] 0, 
            x\^\(\(-2\) + n + r\) \[Rule] 0, x\^\(1 + n + r\) \[Rule] 0, 
            x\^\(2 + n + r\) \[Rule] 0}];\)\ \), "\n", 
    \(\(Print[nterm];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve it.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[nterm, c\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<Solve it for the recursive formula.\>", "\<\n\>"];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1, \
1\)\(\[RightDoubleBracket]\)\)];\)\ \)}], "Input"],

Cell["\<\
If you can't get the above computation to work, then just type in the \
recursive formula. \
\>", "Text"],

Cell[BoxData[
    \(\(c\_n_ := \(-\(c\_\(n - 2\)\/\(\(-1\) + n\^2 + 2\ n\ r + 
                r\^2\)\)\);\)\)], "Input"],

Cell[TextData[{
  "Now look at each series individually.  The first Frobenius series \
corresponding to  ",
  Cell[BoxData[
      \(r\_1 = 1\)]],
  "  is: "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[c, k, n, x];\)\), "\n", 
    \(c = 0; \ Remove[c];\), "\[IndentingNewLine]", 
    \(\(r\  = \ 1\ ;\)\), "\n", 
    \(\(c\_0 = 1\ ;\)\), "\n", 
    \(\(c\_1 = 0\ ;\)\), "\n", 
    \(\(c\_n_ := \(-\(c\_\(n - 2\)\/\(\(-1\) + n\^2 + 2\ n\ r + 
                r\^2\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(f1[x_] = 
        Expand[\(x\^r\) \((\[Sum]\+\(k = 0\)\%13\( c\_k\) 
                  x\^k)\)]\ ;\)\), "\n", 
    \(\(For[i = 0, i \[LessEqual] 10, \(i++\), 
        Print["\<c\>"\_i, "\< = \>", c\_i]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_n\) = \>\"", 
        Simplify[\(-\(\*"\"\<\!\(c\_\(n - 2\)\)\>\""\/\(\(-1\) + n\^2 + 
                  2\ n\ r + r\^2\)\)\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The coefficient  ",
  Cell[BoxData[
      \(c\_n\)]],
  "  can be expressed in closed form    ",
  Cell[BoxData[
      \(c\_n\  = \((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 2\)\) \((\(n!\))\) \
\(\((n - 1)\)!\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(Table[\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 2\)\) \((\(n!\))\) \
\(\((n - 1)\)!\)\), {n, 1, 7}]\)], "Input"],

Cell[BoxData[{
    \(\(S1[x_] = Take[\ Normal[s1[x]], 3];\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S1[x], f1[x]}, {x, 0, 5}, 
        PlotRange \[Rule] {{0, 5}, {\(-1\), 3}}, 
        PlotStyle\  \[Rule] {Green, Red}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S1[x] = \>", S1[x]\ ];\)\), "\n", 
    \(\(Print["\<f1[x] = \>", f1[x]\ ];\)\)}], "Input"],

Cell[TextData[{
  "The the first Frobenius series solution is twice the Bessel function  ",
  Cell[BoxData[
      \(\(J\_1\) \((x)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(J\_1[
          x_]\  = \ \[Sum]\+\(n = 1\)\%\[Infinity]\(\((\(-1\))\)\^\(n - 1\)\/\
\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - 1)\)!\)\)\) 
            x\^\(2  n - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_1\)[x] = \!\(\[Sum]\+\(n = 1\)\%7\)\!\(\((\(-1\))\
\)\^\(n - 1\)\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - 1)\)!\)\)\)\!\(x\^\
\(2  n - 1\)\)\>\"", "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_1\)[x] = \>\"", \ \[Sum]\+\(n = \
1\)\%7\(\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - 
                        1)\)!\)\)\) 
            x\^\(2  n - 1\), "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_1\)[x] = \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\
\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - \
1)\)!\)\)\)\!\(x\^\(2  n - 1\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_1\)[x] = \>\"", \[Sum]\+\(n = \
1\)\%\[Infinity]\(\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 
                        1\)\) \((\(n!\))\) \(\((n - 1)\)!\)\)\) 
            x\^\(2  n - 1\)];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  \n\nThe Frobenius series solution  ",
  StyleBox["s(x)",
    FontFamily->"Courier New"],
  "  will have the initial conditions   ",
  StyleBox["s(0) = 0",
    FontFamily->"Courier New"],
  "  will   ",
  Cell[BoxData[
      StyleBox[\(s' \((0)\) = 1\/2\),
        FontFamily->"Courier New"]]],
  ", whereas the the built in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function  ",
  StyleBox["BesselJ[1,x]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  does not have the initial value 0 because it is the negative of the \
derivative of  ",
  StyleBox["BesselJ[0,x]",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = BesselJ[1, x];\)\), "\[IndentingNewLine]", 
    \(Print[\*"\"\<\!\(\[PartialD]\_x\) BesselJ[0,x] = \>\"", \[PartialD]\_x\ 
        BesselJ[0, x], "\<\n\>"]\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[0] = \>", f[0]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<and\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[x] = \!\(\[PartialD]\_x\) BesselJ[1,x]\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<f'[x] = \>", \(f'\)[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[0] = \>", \(f'\)[0]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Maclaurin series and verify the identity  ",
  Cell[BoxData[
      \(\(J\_0\%'\) \((x)\)\  = \ \(-\ J\_1\) \((x)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Using the results of Examples 4 and 5 we have the series representations \
for  ",
  Cell[BoxData[
      \(\(J\_0\) \((x)\)\)]],
  " and   ",
  Cell[BoxData[
      \(\(J\_1\) \((x)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Enter the Maclaurin series expansion for   ",
  Cell[BoxData[
      \(\(J\_0\) \((x)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(J\_0[
          x_]\  = \ \[Sum]\+\(n = \
0\)\%\[Infinity]\(\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\) 
            x\^\(2  n\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)[x] = \!\(\[Sum]\+\(n = 0\)\%\[Infinity]\)\!\(\
\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\)\!\(x\^\(2  \
n\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)[x] = \>\"", \[Sum]\+\(n = \
0\)\%\[Infinity]\(\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\) 
            x\^\(2  n\)];\)\ \)}], "Input"],

Cell[TextData[{
  "Differentiate the Maclaurin series expansion for   ",
  Cell[BoxData[
      \(\(J\_0\) \((x)\)\)]],
  " term by term.  "
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(J\_0\)'[x] = \!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \
\((\(n!\))\)\^2\)\)(2n)\!\(x\^\(2  n - 1\)\)\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)'[x] = \!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\) \((\(n!\
\))\)\)\)(2n)\!\(x\^\(2  n - 1\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)'[x] = \!\(\[Sum]\+\(n = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^n\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \
\(\((n - 1)\)!\)\)\)\!\(x\^\(2  n - 1\)\)\>\""];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_0\)'[x] = \>\"", \ \[Sum]\+\(n = 1\)\%\[Infinity]\
\(\((\(-1\))\)\^n\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - 1)\)!\)\)\) 
            x\^\(2  n - 1\)];\)\ \)}], "Input"],

Cell[TextData[{
  "Enter the Maclaurin series expansion for  ",
  Cell[BoxData[
      \(\(J\_1\) \((x)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(J\_1[
          x_]\  = \ \[Sum]\+\(n = 1\)\%\[Infinity]\(\((\(-1\))\)\^\(n - 1\)\/\
\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - 1)\)!\)\)\) 
            x\^\(2  n - 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_1\)[x] = \!\(\[Sum]\+\(n = 1\)\%\[Infinity]\)\!\(\
\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - \
1)\)!\)\)\)\!\(x\^\(2  n - 1\)\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_1\)[x] = \>\"", \[Sum]\+\(n = \
1\)\%\[Infinity]\(\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 
                        1\)\) \((\(n!\))\) \(\((n - 1)\)!\)\)\) 
            x\^\(2  n - 1\)];\)\ \)}], "Input"],

Cell[TextData[{
  "Compare the series for  ",
  Cell[BoxData[
      RowBox[{\(J\_0\%'\), \((x)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", \(J\_1\), \((x)\)}]]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\< \!\(J\_0\)'[x] = \>\"", \ \[Sum]\+\(n = \
1\)\%\[Infinity]\(\((\(-1\))\)\^n\/\(\(2\^\(2  n - 
                        1\)\) \((\(n!\))\) \(\((n - 1)\)!\)\)\) 
            x\^\(2  n - 1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<- \!\(J\_1\)[x] = \>\"", \[Sum]\+\(n = \
1\)\%\[Infinity]\(\((\(-1\))\)\^n\/\(\(2\^\(2  n - 
                        1\)\) \((\(n!\))\) \(\((n - 1)\)!\)\)\) 
            x\^\(2  n - 1\)];\)\ \)}], "Input"],

Cell["\<\
It always helps to look at a few of the terms of the series to see what is \
happening.  \
\>", "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(J\_0\)[x] = \>\"", \[Sum]\+\(n = \
0\)\%6\(\((\(-1\))\)\^n\/\(\(2\^\(2  n\)\) \((\(n!\))\)\^2\)\) 
            x\^\(2  n\), "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_1\)[x] = \>\"", \[Sum]\+\(n = \
1\)\%6\(\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - 
                        1)\)!\)\)\) 
            x\^\(2  n - 1\), "\< + ...\>"];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(J\_0\)'[x] = \>\"", \ \[Sum]\+\(n = \
1\)\%6\(\((\(-1\))\)\^n\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - 
                        1)\)!\)\)\) 
            x\^\(2  n - 1\), "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(J\_1\)[x]  =  \>\"", \[Sum]\+\(n = \
1\)\%6\(\((\(-1\))\)\^\(n - 1\)\/\(\(2\^\(2  n - 1\)\) \((\(n!\))\) \(\((n - 
                        1)\)!\)\)\) 
            x\^\(2  n - 1\), "\< + ...\>"];\)\ \)}], "Input"],

Cell[TextData[{
  "It is now easy to see that    ",
  Cell[BoxData[
      \(\(J\_0\%'\) \((x)\)\  = \ \(-\ J\_1\) \((x)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We are done. \n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We could have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " compute some terms in the Maclaurin series expansions of    ",
  Cell[BoxData[
      \(\(J\_0\) \((x)\)\)]],
  " and   ",
  Cell[BoxData[
      \(\(J\_1\) \((x)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(s0[x_] = 
        Series[BesselJ[0, x], {x, 0, 12}];\)\ \), "\[IndentingNewLine]", 
    \(\(s1[x_] = 
        Series[BesselJ[1, x], {x, 0, 12}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<BesselJ[0,x] = \>", 
        s0[x], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<BesselJ[1,x] = \>", s1[x], "\< + ...\>"];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<BesselJ'[0,x] = \>", \(s0'\)[
          x], "\< + ...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<BesselJ[1,x]  =  \>", s1[x], "\< + ...\>"];\)\ \)}], "Input"],

Cell[TextData[{
  "Again, it is now easy to see that    ",
  Cell[BoxData[
      \(\(J\_0\%'\) \((x)\)\  = \ \(-\ J\_1\) \((x)\)\)]],
  ". "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Application of the Vibrating Drum",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe two dimensional wave equation is   ",
  Cell[BoxData[
      \(\[PartialD]\_\(t, t\)u = \(a\^2\) \[Del]\^2 u\)]],
  ",  \n\nin rectangular coordinates it is   ",
  Cell[BoxData[
      \(\[PartialD]\_\(t, t\)u = \(a\^2\) \((\[PartialD]\_\(x, x\)u + \
\[PartialD]\_\(y, y\)u)\)\)]],
  ",  \n\nand in polar coordinates it is   ",
  Cell[BoxData[
      \(\[PartialD]\_\(t, t\)u = \(a\^2\) \((\[PartialD]\_\(r, r\)u + \
\(1\/r\) \[PartialD]\_r\ u + 
              1\/r\^2\ \[PartialD]\_\(\[Theta], \[Theta]\)u)\)\)]],
  ".\n\n     Consider a drum head that a flexible circular membrane of radius \
",
  Cell[BoxData[
      \(c\)]],
  ".  Assume that it is struck in the center and this produces radial \
vibrations only where the displacement depends only on time ",
  Cell[BoxData[
      \(t\)]],
  " and distance ",
  Cell[BoxData[
      \(r\)]],
  " from the center.  Then  ",
  Cell[BoxData[
      \(u[t, r]\)]],
  " satisfies the D.E. \n      \n\t",
  Cell[BoxData[
      \(\[PartialD]\_\(t, t\)u = \(a\^2\) \((\[PartialD]\_\(r, r\)u + \
\(1\/r\) \[PartialD]\_r\ u)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Proof ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  " ",
  StyleBox[ButtonBox["Vibrating Drum",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/VibratingDrumProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Vibrating Drum",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/VibratingDrumProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider a drum head of radius ",
  Cell[BoxData[
      \(c = 1\)]],
  ". For convenience, choose the parameter  ",
  Cell[BoxData[
      \(a = 1\)]],
  ". The method of separation of variables permits us to use the substitution \
 ",
  Cell[BoxData[
      \(u[t, r]\  = \ R[r] Cos[\[Omega]\ t]\)]],
  ".  Use this substitution and obtain the D.E. \n\n\t",
  Cell[BoxData[
      \(0\  = \ 
        r\^2\ \[Omega]\^2\ R[r] + r\ \(R'\)[r] + r\^2\ \(R''\)[r]\)]],
  ".  \n\t\nSolve this D.E. and plot the solution over the interval  ",
  Cell[BoxData[
      \(\(-15\) \[LessEqual] r \[LessEqual] 15\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[r, R, t, u, \[Omega]];\)\ \), "\[IndentingNewLine]", 
    \(\(u[t_, r_]\  = \ R[r]\ \ Cos[\[Omega]\ t];\)\ \), "\n", 
    \(\(deqn = \[PartialD]\_\(t, t\)u[t, 
              r] \[Equal] \((\[PartialD]\_\(r, r\)u[t, 
                  r] + \(1\/r\) \[PartialD]\_r\ 
                  u[t, r])\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<   u[t,r] = \>", u[t, r]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(\[PartialD]\_t\)u[t,r] = \>\"", \[PartialD]\_t u[
            t, r]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_\(t, t\)\)u[t,r] = \>\"", \[PartialD]\_\
\(t, t\)u[t, r]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(\[PartialD]\_r\)u[t,r] = \>\"", \[PartialD]\_r u[
            t, r]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_\(r, r\)\)u[t,r] = \>\"", \[PartialD]\_\
\(r, r\)u[t, r]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute into the D.E.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_\(t, t\)\)u[t,r] \[Equal] (\!\(\
\[PartialD]\_\(r, r\)\)u[t,r] + \!\(1\/r\)\!\(\[PartialD]\_r\) u[t,r])\>\""];\
\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(deqn = Simplify[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(deqn = 
        Thread[deqn/Cos[t\ \[Omega]], Equal];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(deqn = Thread[r\^2\ deqn, Equal];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", deqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve this Bessesl equation and get\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(solset = DSolve[deqn, R[r], r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", solset];\)\ \)}], "Input"],

Cell[TextData[{
  "The solution we require is the one involving the function  ",
  Cell[BoxData[
      \(BesselJ[0, r\ \[Omega]]\)]],
  ". \nFor illustration, set  ",
  Cell[BoxData[
      \(\[Omega] = 1\)]],
  "  and graph  ",
  Cell[BoxData[
      \(y\  = \ BesselJ[0, r]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(f[r_] = BesselJ[0, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[r], {r, \(-15\), 15}, 
        PlotRange \[Rule] {{\(-15\), 15}, {\(-0.5\), 1}}, 
        PlotStyle \[Rule] Blue, 
        Ticks \[Rule] {Range[\(-15\), 15, 5], 
            Range[\(-0.5\), 1, 0.5]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The function  ",
  Cell[BoxData[
      \(BesselY[0, r\ \[Omega]]\)]],
  " is not the one we use because it has goes to ",
  Cell[BoxData[
      InterpretationBox[\(-\[Infinity]\),
        DirectedInfinity[ -1]]]],
  " when  ",
  Cell[BoxData[
      \(r \[Rule] 0\)]],
  "  \nFor illustration, set  ",
  Cell[BoxData[
      \(\[Omega] = 1\)]],
  "  and graph  ",
  Cell[BoxData[
      \(y\  = \ BesselJ[0, r]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(f[r_] = BesselY[0, r];\)\ \), "\[IndentingNewLine]", 
    \(\(lim = 
        Limit[BesselY[0, r], r \[Rule] 0];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[r], {r, 0.01, 15}, PlotRange \[Rule] {{0, 15}, {\(-3\), 1}}, 
        PlotStyle \[Rule] Orange, 
        Ticks \[Rule] {Range[0, 15, 5], Range[\(-5\), 1, 1]}, 
        AxesLabel \[Rule] {"\<r\>", "\<y\>"}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[r] = \>", f[r]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(lim\+\(r \[Rule] 0\)\)\>\"", "\< f[r] = \>", 
        lim];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  In Example 7, the boundary condition for the D.E. is  ",
  Cell[BoxData[
      \(R[1] = 0\)]],
  ",  i.e. the drum head has radius  ",
  Cell[BoxData[
      \(c = 1\)]],
  ". \nThus the parameter  ",
  Cell[BoxData[
      \(\[Omega]\)]],
  "  must be chosen to be a root of the Bessel function. \nThe zeros do not \
have a simple formula. However it is known that they are \"close to\" \
multiples of  ",
  Cell[BoxData[
      \(\[Pi]\)]],
  ".  \nVerify this and find the first five zeros. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Multiples of  ",
  Cell[BoxData[
      \(\[Pi]\)]],
  "  will be sufficiently close to be starting values for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  ",
  StyleBox["FindRoot",
    FontFamily->"Courier New"],
  "  subroutine. \nThe first root is"
}], "Text"],

Cell[BoxData[{
    \(\(f[r_] = BesselJ[0, r];\)\ \), "\[IndentingNewLine]", 
    \(\(sol = 
        FindRoot[
          BesselJ[0, x] \[Equal] 
            0, {x, \[Pi]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[r], {r, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-0.5\), 1}}, 
        PlotStyle \[Rule] Cyan, 
        Ticks \[Rule] {Range[0, 5\ \[Pi], \[Pi]], 
            Range[\(-0.5\), 1, 0.5]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve \>", f[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[sol];\)\ \)}], "Input"],

Cell["\<\
We can put all five of them in an array called \"roots.\"  Then redraw the \
graph with horizontal axis ticks at the integers.\
\>", "Text"],

Cell[BoxData[{
    \(\(f[x_] = BesselJ[0, x];\)\ \), "\[IndentingNewLine]", 
    \(\(eqn\  = \ f[x] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = \ 
        Table[FindRoot[eqn, {x, k\ \ \[Pi]}], {k, 1, 5}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[f[r], {r, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-0.5\), 1}}, 
        PlotStyle \[Rule] Cyan, 
        Ticks \[Rule] {Range[0, 5\ \[Pi], \[Pi]], 
            Range[\(-0.5\), 1, 0.5]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y = f[x] = \>", f[x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve \>", f[x], "\< = 0\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(All, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Surface equation for the vibrating drum.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe solution we are seeking in Example 7 is  ",
  Cell[BoxData[
      \(u[t, r]\  = \ R[r] Cos[\[Omega]\ t]\)]],
  " where the boundary condition  ",
  Cell[BoxData[
      \(R[1] = 0\)]],
  " requires that  ",
  Cell[BoxData[
      \(\[Omega] = \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\)]],
  ",  hence  ",
  Cell[BoxData[
      \(R[r] = 
        BesselJ[0, \(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\) r]\)]],
  ". Therefore the fundamental solutions to the wave equation for the drum \
head is  \n\n\t",
  Cell[BoxData[
      \(z\  = \ \(u[t, r, \[Theta]]\  = \ 
          BesselJ[0, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\ r] 
            Cos[\(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\) t]\)\)]],
  ",  for  ",
  StyleBox["n = 1,2,3",
    FontFamily->"Courier New"],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Plot the functions  ",
  Cell[BoxData[
      RowBox[{\(f[n, x]\), "=", 
        RowBox[{\(BesselJ[
            0, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\ x]\), "  ", 
          StyleBox["where",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          "  ", \(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\)}]}]]],
  " is the n-th root of  ",
  Cell[BoxData[
      \(f[x]\  = \ BesselJ[0, x]\)]],
  ". \nSince we will be considering a drum of unit radius, plot  ",
  Cell[BoxData[
      \(y\  = \ \(f[n, x] = 
          BesselJ[0, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\ x]\)\)]],
  " over the interval  ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] x \[LessEqual] 1\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = BesselJ[0, x];\)\ \), "\[IndentingNewLine]", 
    \(\(eqn\  = \ f[x] \[Equal] 0;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = \ 
        Table[FindRoot[eqn, {x, k\ \ \[Pi]}], {k, 1, 
            5}];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Lambda] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(All, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(f[n_, x_] := 
      BesselJ[0, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\ x\ ]\ \), "\[IndentingNewLine]", 
    \(\(For[n = 1, 
        n \[LessEqual] 
          5, \(n++\), \[IndentingNewLine]Plot[{\(f[n, x] + Abs[f[n, x]]\)\/2, \
\(f[n, x] - Abs[f[n, x]]\)\/2, 0}, {x, \(-1\), 1}, 
          PlotRange \[Rule] {{\(-1\), 1}, {\(-0.45\), 1}}, 
          PlotStyle \[Rule] {Pink, Cyan, Black}, 
          Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
              Range[0, 1, 0.5]}]; \ \[IndentingNewLine]\ 
        Print["\<f[\>", n, "\<,x] = \>", f[n, x]\ ];];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The initial displacement for a fundamental solution is  ",
  Cell[BoxData[
      \(u[0, r, \[Theta]] = 
        BesselJ[0, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\ r]\)]],
  ".  \nPlot the functions for  ",
  StyleBox["n = 1,2,3",
    FontFamily->"Courier New"],
  ".  \n\nThe first fundamental solution vibrates up and down throughout the \
entire disk of radius 1. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The first fundamental solution has a circle of radius  ",
  Cell[BoxData[
      \(r = 1\)]],
  " as a node where there is no vibration and it moves up and down inside \
this circle."
}], "Text"],

Cell[BoxData[{
    \(\(n = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(u[r_, \[Theta]_]\  = \ 
        BesselJ[0, \(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\) r\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[{r\ \ Cos[\[Theta]], r\ \ Sin[\[Theta]], 
          u[r, \[Theta]]}, {r, 0, 1}, {\[Theta], 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}, {\(-0.45\), 1}}, 
        ViewPoint -> {5, 3, 1}, 
        BoxRatios \[Rule] {1, 1, 0.3}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<When n = \>", 
        n, "\< we have \>", "\<\[Lambda]\>"\_n, "\< = \>", \[Lambda]\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z = u[r,\[Theta]] = \>", u[r, \[Theta]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "The second fundamental solution has a circle of radius  ",
  Cell[BoxData[
      \(R = \(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\) = \(2.404826\/5.520078 = 0.435651\)\)\)]],
  " as a node where there is no vibration and it moves up and down in \
opposite directions on the inside and outside of this circle."
}], "Text"],

Cell[BoxData[{
    \(\(R = \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\
\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\
\ \), "\[IndentingNewLine]", 
    \(\(disk1 = Disk[{0, 0}, 1];\)\ \), "\n", 
    \(\(disk2 = Disk[{0, 0}, R];\)\ \), "\n", 
    \(\(circle1 = Circle[{0, 0}, 1];\)\ \), "\n", 
    \(\(circle2 = Circle[{0, 0}, R];\)\ \), "\n", 
    \(\(Show[Graphics[{{Cyan, disk1, Pink, disk2}, circle1, circle2}], 
        PlotRange -> {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}}, Axes \[Rule] True, 
        AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<r = \>", R];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(f[n_, x_] := 
        BesselJ[0, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\ x\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{\(f[n, x] + Abs[f[n, x]]\)\/2, \(f[n, x] - Abs[f[n, x]]\)\/2, 
          0}, {x, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-0.45\), 1}}, 
        PlotStyle \[Rule] {Pink, Cyan, Black}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[0.5, 1, 0.5]}];\)\ \), "\[IndentingNewLine]", 
    \(\ \(Print["\<f[\>", n, "\<,x] = \>", 
        f[n, x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<r = \>", R];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(u[r_, \[Theta]_]\  = \ 
        BesselJ[0, \(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\) r\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[{r\ \ Cos[\[Theta]], r\ \ Sin[\[Theta]], 
          u[r, \[Theta]]}, {r, 0, 1}, {\[Theta], 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}, {\(-0.45\), 1}}, 
        ViewPoint -> {5, 3, 1}, 
        BoxRatios \[Rule] {1, 1, 0.3}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<When n = \>", 
        n, "\< we have \>", "\<\[Lambda]\>"\_n, "\< = \>", \[Lambda]\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z = u[r,\[Theta]] = \>", u[r, \[Theta]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "The third fundamental solution has a two circular nodes of radius  ",
  Cell[BoxData[
      \(R\_1 = \(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\) = \(2.404826\/8.653728 = 0.277895\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(\(\ \)\(R\_2 = \(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\) = \(5.520078\/8.653728 = 0.637884\)\)\)\)\)]],
  "  where there is no vibration and it moves up and down in opposite \
directions between circles."
}], "Text"],

Cell[BoxData[{
    \(\(R\_1 = \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(R\_2 = \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(disk1 = Disk[{0, 0}, 1];\)\ \), "\n", 
    \(\(disk2 = 
        Disk[{0, 
            0}, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(disk3 = 
        Disk[{0, 
            0}, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(circle1 = Circle[{0, 0}, 1];\)\ \), "\n", 
    \(\(circle2 = 
        Circle[{0, 
            0}, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(circle3 = 
        Circle[{0, 
            0}, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\/\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Show[
        Graphics[{{Pink, disk1, Cyan, disk2, Pink, disk3}, circle1, circle2, 
            circle3}], PlotRange -> {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}}, 
        Axes \[Rule] True, AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", 
        R\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_2\) = \>\"", R\_2];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(f[n_, x_] := 
        BesselJ[0, \[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\ x\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{\(f[n, x] + Abs[f[n, x]]\)\/2, \(f[n, x] - Abs[f[n, x]]\)\/2, 
          0}, {x, \(-1\), 1}, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-0.45\), 1}}, 
        PlotStyle \[Rule] {Pink, Cyan, Black}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], 
            Range[0, 1, 0.5]}];\)\ \), "\[IndentingNewLine]", 
    \(\ \(Print["\<f[\>", n, "\<,x] = \>", 
        f[n, x]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_1\) = \>\"", 
        R\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(r\_2\) = \>\"", R\_2];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(n = 3;\)\ \), "\[IndentingNewLine]", 
    \(\(u[r_, \[Theta]_]\  = \ 
        BesselJ[0, \(\[Lambda]\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\) r\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot3D[{r\ \ Cos[\[Theta]], r\ \ Sin[\[Theta]], 
          u[r, \[Theta]]}, {r, 0, 1}, {\[Theta], 0, 2  \[Pi]}, 
        PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}, {\(-0.45\), 1}}, 
        ViewPoint -> {5, 3, 1}, 
        BoxRatios \[Rule] {1, 1, 0.3}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<When n = \>", 
        n, "\< we have \>", "\<\[Lambda]\>"\_n, "\< = \>", \[Lambda]\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<z = u[r,\[Theta]] = \>", u[r, \[Theta]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Frobenius Series Solution of O.D.E.'s",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/N310/projects3/e22.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Frobenius Series Solution of O.D.E.'s",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/N310/projects3/e22.htm"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Bessel Functions and Vibrating Drum",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/N310/projects3/p23.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Bessel Functions and Vibrating Drum",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/N310/projects3/p23.htm"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Series Solutions and Frobenius Method",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/FrobeniusSeriesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Series Solutions and Frobenius Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/FrobeniusSeriesBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  " Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Vibrating Drum",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/VibratingDrumBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Vibrating Drum",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/VibratingDrumBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 211, 5, 35, "Text"],
Cell[1990, 60, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3469, 112, 997, 27, 225, "Text",
  Evaluatable->False],
Cell[4469, 141, 1557, 51, 119, "Text",
  Evaluatable->False],
Cell[6029, 194, 1377, 45, 114, "Text",
  Evaluatable->False],
Cell[7409, 241, 1775, 57, 200, "Text",
  Evaluatable->False],
Cell[9187, 300, 1702, 45, 261, "Text",
  Evaluatable->False],
Cell[10892, 347, 1090, 36, 195, "Text",
  Evaluatable->False],
Cell[11985, 385, 676, 23, 33, "Text"],
Cell[12664, 410, 322, 12, 33, "Text"],
Cell[12989, 424, 148, 3, 30, "Input",
  Evaluatable->False],
Cell[13140, 429, 187, 8, 33, "Text"],
Cell[13330, 439, 379, 11, 71, "Text",
  Evaluatable->False],
Cell[13712, 452, 165, 3, 49, "Input",
  Evaluatable->False],
Cell[13880, 457, 162, 7, 33, "Text",
  Evaluatable->False],
Cell[14045, 466, 225, 4, 51, "Input",
  Evaluatable->False],
Cell[14273, 472, 69, 2, 33, "Text",
  Evaluatable->False],
Cell[14345, 476, 150, 3, 30, "Input",
  Evaluatable->False],
Cell[14498, 481, 676, 23, 33, "Text"],
Cell[15177, 506, 305, 9, 74, "Text"],

Cell[CellGroupData[{
Cell[15507, 519, 101, 2, 33, "Text"],
Cell[15611, 523, 122, 5, 33, "Text"],
Cell[15736, 530, 2074, 37, 577, "Input"],
Cell[17813, 569, 221, 7, 33, "Text"],
Cell[18037, 578, 1748, 31, 517, "Input"],
Cell[19788, 611, 131, 2, 33, "Text"],
Cell[19922, 615, 693, 13, 170, "Input"],
Cell[20618, 630, 149, 5, 36, "Text"],
Cell[20770, 637, 1050, 21, 358, "Input"],
Cell[21823, 660, 62, 0, 33, "Text"],
Cell[21888, 662, 906, 19, 205, "Input"],
Cell[22797, 683, 49, 0, 33, "Text"],
Cell[22849, 685, 400, 6, 90, "Input"],
Cell[23252, 693, 156, 5, 36, "Text"],
Cell[23411, 700, 1054, 21, 358, "Input"],
Cell[24468, 723, 63, 0, 33, "Text"],
Cell[24534, 725, 906, 19, 205, "Input"],
Cell[25443, 746, 50, 0, 33, "Text"],
Cell[25496, 748, 230, 3, 70, "Input"],
Cell[25729, 753, 233, 8, 33, "Text"],
Cell[25965, 763, 397, 6, 90, "Input"],
Cell[26365, 771, 192, 6, 33, "Text"],
Cell[26560, 779, 1483, 30, 342, "Input"],
Cell[28046, 811, 90, 2, 33, "Text"],
Cell[28139, 815, 414, 7, 110, "Input"],
Cell[28556, 824, 345, 6, 90, "Input"],
Cell[28904, 832, 837, 20, 92, "Text"],
Cell[29744, 854, 1220, 24, 310, "Input"],
Cell[30967, 880, 115, 3, 33, "Text"],
Cell[31085, 885, 127, 2, 42, "Input"],
Cell[31215, 889, 165, 6, 36, "Text"],
Cell[31383, 897, 847, 17, 278, "Input"],
Cell[32233, 916, 148, 5, 36, "Text"],
Cell[32384, 923, 877, 17, 278, "Input"],
Cell[33264, 942, 114, 3, 33, "Text"],
Cell[33381, 947, 838, 14, 292, "Input"],
Cell[34222, 963, 368, 6, 90, "Input"],
Cell[34593, 971, 115, 3, 33, "Text"],
Cell[34711, 976, 833, 15, 292, "Input"],
Cell[35547, 993, 299, 5, 70, "Input"]
}, Closed]],
Cell[35861, 1001, 263, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[36149, 1013, 101, 2, 33, "Text"],
Cell[36253, 1017, 122, 5, 33, "Text"],
Cell[36378, 1024, 2034, 37, 562, "Input"],
Cell[38415, 1063, 221, 7, 33, "Text"],
Cell[38639, 1072, 1748, 31, 517, "Input"],
Cell[40390, 1105, 131, 2, 33, "Text"],
Cell[40524, 1109, 693, 13, 170, "Input"],
Cell[41220, 1124, 147, 5, 36, "Text"],
Cell[41370, 1131, 947, 18, 328, "Input"],
Cell[42320, 1151, 62, 0, 33, "Text"],
Cell[42385, 1153, 652, 14, 170, "Input"],
Cell[43040, 1169, 49, 0, 33, "Text"],
Cell[43092, 1171, 396, 6, 90, "Input"],
Cell[43491, 1179, 140, 5, 33, "Text"],
Cell[43634, 1186, 943, 18, 314, "Input"],
Cell[44580, 1206, 62, 0, 33, "Text"],
Cell[44645, 1208, 651, 14, 170, "Input"],
Cell[45299, 1224, 50, 0, 33, "Text"],
Cell[45352, 1226, 228, 3, 70, "Input"],
Cell[45583, 1231, 332, 10, 52, "Text"],
Cell[45918, 1243, 1398, 32, 386, "Input"],
Cell[47319, 1277, 194, 4, 33, "Text"],
Cell[47516, 1283, 399, 6, 110, "Input"],
Cell[47918, 1291, 335, 6, 90, "Input"],
Cell[48256, 1299, 839, 20, 92, "Text"],
Cell[49098, 1321, 1178, 24, 294, "Input"],
Cell[50279, 1347, 115, 3, 33, "Text"],
Cell[50397, 1352, 121, 3, 40, "Input"],
Cell[50521, 1357, 164, 6, 36, "Text"],
Cell[50688, 1365, 758, 16, 256, "Input"],
Cell[51449, 1383, 137, 5, 33, "Text"],
Cell[51589, 1390, 746, 16, 242, "Input"],
Cell[52338, 1408, 105, 3, 33, "Text"],
Cell[52446, 1413, 701, 13, 247, "Input"],
Cell[53150, 1428, 399, 6, 110, "Input"],
Cell[53552, 1436, 687, 13, 233, "Input"],
Cell[54242, 1451, 335, 6, 90, "Input"],
Cell[54580, 1459, 274, 8, 33, "Text"],
Cell[54857, 1469, 229, 8, 33, "Text"],
Cell[55089, 1479, 540, 9, 134, "Input"],
Cell[55632, 1490, 534, 10, 134, "Input"]
}, Closed]],
Cell[56181, 1503, 294, 9, 68, "Text"],

Cell[CellGroupData[{
Cell[56500, 1516, 101, 2, 33, "Text"],
Cell[56604, 1520, 122, 5, 33, "Text"],
Cell[56729, 1527, 2055, 37, 563, "Input"],
Cell[58787, 1566, 221, 7, 33, "Text"],
Cell[59011, 1575, 1748, 31, 517, "Input"],
Cell[60762, 1608, 131, 2, 33, "Text"],
Cell[60896, 1612, 693, 13, 170, "Input"],
Cell[61592, 1627, 142, 5, 36, "Text"],
Cell[61737, 1634, 1024, 21, 330, "Input"],
Cell[62764, 1657, 62, 0, 33, "Text"],
Cell[62829, 1659, 652, 14, 170, "Input"],
Cell[63484, 1675, 49, 0, 33, "Text"],
Cell[63536, 1677, 392, 6, 90, "Input"],
Cell[63931, 1685, 151, 6, 33, "Text"],
Cell[64085, 1693, 922, 18, 296, "Input"],
Cell[65010, 1713, 62, 0, 33, "Text"],
Cell[65075, 1715, 656, 14, 170, "Input"],
Cell[65734, 1731, 50, 0, 33, "Text"],
Cell[65787, 1733, 226, 3, 70, "Input"],
Cell[66016, 1738, 287, 7, 52, "Text"],
Cell[66306, 1747, 1139, 22, 385, "Input"],
Cell[67448, 1771, 195, 4, 33, "Text"],
Cell[67646, 1777, 397, 6, 110, "Input"],
Cell[68046, 1785, 324, 5, 90, "Input"],
Cell[68373, 1792, 539, 12, 90, "Text"],
Cell[68915, 1806, 1273, 26, 315, "Input"],
Cell[70191, 1834, 115, 3, 33, "Text"],
Cell[70309, 1839, 105, 2, 42, "Input"],
Cell[70417, 1843, 171, 6, 36, "Text"],
Cell[70591, 1851, 776, 17, 280, "Input"],
Cell[71370, 1870, 327, 5, 90, "Input"],
Cell[71700, 1877, 139, 5, 33, "Text"],
Cell[71842, 1884, 776, 17, 266, "Input"],
Cell[72621, 1903, 324, 5, 90, "Input"],
Cell[72948, 1910, 377, 10, 33, "Text"],
Cell[73328, 1922, 602, 18, 71, "Text"],
Cell[73933, 1942, 148, 2, 52, "Input"],
Cell[74084, 1946, 174, 6, 33, "Text"],
Cell[74261, 1954, 518, 11, 198, "Input"],
Cell[74782, 1967, 367, 7, 59, "Input"],
Cell[75152, 1976, 421, 8, 59, "Input"],
Cell[75576, 1986, 322, 6, 59, "Input"],
Cell[75901, 1994, 345, 7, 59, "Input"],
Cell[76249, 2003, 285, 9, 87, "Text"],
Cell[76537, 2014, 190, 5, 82, "Input"],
Cell[76730, 2021, 156, 8, 33, "Text"],
Cell[76889, 2031, 69, 1, 30, "Input"],
Cell[76961, 2034, 76, 1, 30, "Input"],
Cell[77040, 2037, 87, 2, 33, "Text"],
Cell[77130, 2041, 374, 7, 134, "Input"],
Cell[77507, 2050, 128, 2, 51, "Input"],
Cell[77638, 2054, 124, 5, 33, "Text"],
Cell[77765, 2061, 156, 2, 60, "Input"],
Cell[77924, 2065, 342, 9, 68, "Text"],
Cell[78269, 2076, 88, 1, 53, "Input"],
Cell[78360, 2079, 104, 3, 33, "Text"],
Cell[78467, 2084, 598, 10, 181, "Input"],
Cell[79068, 2096, 190, 5, 82, "Input"],
Cell[79261, 2103, 69, 1, 30, "Input"],
Cell[79333, 2106, 223, 4, 73, "Input"],
Cell[79559, 2112, 124, 5, 33, "Text"],
Cell[79686, 2119, 150, 2, 60, "Input"],
Cell[79839, 2123, 337, 9, 68, "Text"]
}, Closed]],
Cell[80191, 2135, 550, 17, 106, "Text"],

Cell[CellGroupData[{
Cell[80766, 2156, 101, 2, 33, "Text"],
Cell[80870, 2160, 122, 5, 33, "Text"],
Cell[80995, 2167, 2034, 37, 562, "Input"],
Cell[83032, 2206, 221, 7, 33, "Text"],
Cell[83256, 2215, 1748, 31, 517, "Input"],
Cell[85007, 2248, 131, 2, 33, "Text"],
Cell[85141, 2252, 693, 13, 170, "Input"],
Cell[85837, 2267, 139, 5, 33, "Text"],
Cell[85979, 2274, 961, 19, 316, "Input"],
Cell[86943, 2295, 62, 0, 33, "Text"],
Cell[87008, 2297, 652, 14, 170, "Input"],
Cell[87663, 2313, 49, 0, 33, "Text"],
Cell[87715, 2315, 392, 6, 90, "Input"],
Cell[88110, 2323, 350, 11, 33, "Text"],
Cell[88463, 2336, 689, 14, 230, "Input"],
Cell[89155, 2352, 365, 9, 33, "Text"],
Cell[89523, 2363, 195, 4, 33, "Text"],
Cell[89721, 2369, 414, 7, 110, "Input"],
Cell[90138, 2378, 539, 12, 90, "Text"],
Cell[90680, 2392, 1231, 24, 314, "Input"],
Cell[91914, 2418, 115, 3, 33, "Text"],
Cell[92032, 2423, 112, 2, 40, "Input"],
Cell[92147, 2427, 168, 6, 33, "Text"],
Cell[92318, 2435, 794, 16, 262, "Input"],
Cell[93115, 2453, 254, 9, 40, "Text"],
Cell[93372, 2464, 131, 2, 47, "Input"],
Cell[93506, 2468, 410, 7, 110, "Input"],
Cell[93919, 2477, 157, 5, 33, "Text"],
Cell[94079, 2484, 955, 16, 225, "Input"],
Cell[95037, 2502, 267, 9, 34, "Text"],
Cell[95307, 2513, 66, 1, 30, "Input"]
}, Closed]],
Cell[95388, 2517, 565, 18, 106, "Text"],

Cell[CellGroupData[{
Cell[95978, 2539, 101, 2, 33, "Text"],
Cell[96082, 2543, 122, 5, 33, "Text"],
Cell[96207, 2550, 2046, 37, 563, "Input"],
Cell[98256, 2589, 221, 7, 33, "Text"],
Cell[98480, 2598, 1748, 31, 517, "Input"],
Cell[100231, 2631, 131, 2, 33, "Text"],
Cell[100365, 2635, 693, 13, 170, "Input"],
Cell[101061, 2650, 139, 5, 33, "Text"],
Cell[101203, 2657, 992, 20, 316, "Input"],
Cell[102198, 2679, 62, 0, 33, "Text"],
Cell[102263, 2681, 652, 14, 170, "Input"],
Cell[102918, 2697, 49, 0, 33, "Text"],
Cell[102970, 2699, 392, 6, 90, "Input"],
Cell[103365, 2707, 350, 11, 33, "Text"],
Cell[103718, 2720, 705, 14, 231, "Input"],
Cell[104426, 2736, 365, 9, 33, "Text"],
Cell[104794, 2747, 195, 4, 33, "Text"],
Cell[104992, 2753, 416, 7, 110, "Input"],
Cell[105411, 2762, 539, 12, 90, "Text"],
Cell[105953, 2776, 1243, 24, 315, "Input"],
Cell[107199, 2802, 115, 3, 33, "Text"],
Cell[107317, 2807, 121, 2, 40, "Input"],
Cell[107441, 2811, 168, 6, 33, "Text"],
Cell[107612, 2819, 812, 16, 262, "Input"],
Cell[108427, 2837, 254, 9, 40, "Text"],
Cell[108684, 2848, 131, 2, 47, "Input"],
Cell[108818, 2852, 410, 7, 110, "Input"],
Cell[109231, 2861, 157, 5, 33, "Text"],
Cell[109391, 2868, 1155, 18, 261, "Input"],
Cell[110549, 2888, 774, 27, 94, "Text"],
Cell[111326, 2917, 628, 10, 170, "Input"]
}, Closed]],
Cell[111969, 2930, 239, 7, 30, "Text"],

Cell[CellGroupData[{
Cell[112233, 2941, 101, 2, 33, "Text"],
Cell[112337, 2945, 226, 9, 33, "Text"],
Cell[112566, 2956, 130, 5, 33, "Text"],
Cell[112699, 2963, 563, 10, 135, "Input"],
Cell[113265, 2975, 151, 5, 33, "Text"],
Cell[113419, 2982, 845, 14, 178, "Input"],
Cell[114267, 2998, 129, 5, 33, "Text"],
Cell[114399, 3005, 678, 11, 158, "Input"],
Cell[115080, 3018, 420, 13, 33, "Text"],
Cell[115503, 3033, 483, 8, 92, "Input"],
Cell[115989, 3043, 113, 3, 33, "Text"],
Cell[116105, 3048, 446, 7, 108, "Input"],
Cell[116554, 3057, 498, 8, 108, "Input"],
Cell[117055, 3067, 145, 5, 33, "Text"],
Cell[117203, 3074, 384, 15, 71, "Text"],
Cell[117590, 3091, 374, 7, 90, "Input"],
Cell[117967, 3100, 200, 3, 50, "Input"],
Cell[118170, 3105, 152, 5, 33, "Text"]
}, Closed]],
Cell[118337, 3113, 1273, 37, 245, "Text",
  Evaluatable->False],
Cell[119613, 3152, 612, 21, 33, "Text"],
Cell[120228, 3175, 724, 22, 128, "Text"],

Cell[CellGroupData[{
Cell[120977, 3201, 101, 2, 33, "Text"],
Cell[121081, 3205, 1927, 32, 459, "Input"],
Cell[123011, 3239, 297, 11, 52, "Text"],
Cell[123311, 3252, 453, 8, 90, "Input"],
Cell[123767, 3262, 531, 21, 52, "Text"],
Cell[124301, 3285, 664, 11, 138, "Input"]
}, Closed]],
Cell[124980, 3299, 609, 19, 87, "Text"],

Cell[CellGroupData[{
Cell[125614, 3322, 101, 2, 33, "Text"],
Cell[125718, 3326, 298, 11, 52, "Text"],
Cell[126019, 3339, 712, 14, 150, "Input"],
Cell[126734, 3355, 150, 3, 33, "Text"],
Cell[126887, 3360, 826, 15, 170, "Input"]
}, Closed]],
Cell[127728, 3378, 1055, 31, 125, "Text"],
Cell[128786, 3411, 1100, 32, 52, "Text"],

Cell[CellGroupData[{
Cell[129911, 3447, 101, 2, 33, "Text"],
Cell[130015, 3451, 995, 20, 207, "Input"]
}, Closed]],
Cell[131025, 3474, 518, 14, 87, "Text"],

Cell[CellGroupData[{
Cell[131568, 3492, 102, 2, 33, "Text"],
Cell[131673, 3496, 213, 6, 33, "Text"],
Cell[131889, 3504, 807, 14, 110, "Input"],
Cell[132699, 3520, 442, 8, 42, "Text"],
Cell[133144, 3530, 692, 12, 169, "Input"],
Cell[133839, 3544, 680, 13, 145, "Input"],
Cell[134522, 3559, 807, 14, 110, "Input"],
Cell[135332, 3575, 670, 13, 61, "Text"],
Cell[136005, 3590, 1786, 36, 374, "Input"],
Cell[137794, 3628, 784, 15, 165, "Input"],
Cell[138581, 3645, 807, 14, 110, "Input"]
}, Closed]],
Cell[139403, 3662, 865, 24, 30, "Text"],
Cell[140271, 3688, 745, 21, 33, "Text"],
Cell[141019, 3711, 158, 3, 35, "Text"],
Cell[141180, 3716, 805, 23, 35, "Text"],
Cell[141988, 3741, 549, 16, 33, "Text"],
Cell[142540, 3759, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

