(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    253586,       7973]*)
(*NotebookOutlinePosition[    254252,       7996]*)
(*  CellTagsIndexPosition[    254208,       7992]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Study of Spring-Mass Systems",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods and Differential Equations",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews, 2005",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tConsider the system of two masses  ",
  Cell[BoxData[
      RowBox[{\(m\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(m\_2\)}]]],
  "  and two springs with no external force.  Visualize a wall on the left \
and to the right a spring , a mass, a spring and another mass.  Assume that \
the spring constants are  ",
  Cell[BoxData[
      RowBox[{\(k\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(k\_2\)}]]],
  ".   See Figure 1 below.  \n\n\t  ",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-017 0.2 0.0333333 0.0416667 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .03333 m
1 .03333 L
s
0 0 m
0 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
.5 Mabswid
.23416 .09583 m
.23375 .10045 L
.23318 .10533 L
.23183 .11374 L
.23081 .1185 L
.22972 .12264 L
.22738 .12925 L
.22606 .13196 L
.22459 .13428 L
.22329 .13578 L
.22253 .13643 L
.22182 .1369 L
.22142 .1371 L
.22099 .13728 L
.2202 .13746 L
.21943 .13749 L
.21871 .13738 L
.21827 .13724 L
.21786 .13707 L
.2171 .13663 L
.21629 .13599 L
.21542 .1351 L
.21387 .13296 L
.21249 .1304 L
.21107 .12699 L
.20966 .12274 L
.20836 .11769 L
.20728 .11245 L
.20647 .10746 L
.20575 .10182 L
.20527 .09685 L
.20507 .09402 L
.20491 .09136 L
.20484 .09001 L
.20479 .08859 L
.20471 .08608 L
.20468 .0847 L
.20467 .08343 L
.20466 .08204 L
.20467 .08058 L
.2047 .0782 L
.20474 .07689 L
.20478 .0757 L
.20488 .07358 L
.20501 .07141 L
.20532 .06789 L
.20553 .06603 L
.20575 .06439 L
.20631 .06117 L
.20691 .05868 L
Mistroke
.20763 .05654 L
.20806 .05564 L
.20846 .055 L
.20885 .05456 L
.20922 .0543 L
.20962 .05417 L
.20982 .05417 L
.21005 .05422 L
.21042 .05442 L
.21081 .05479 L
.21118 .0553 L
.21151 .05588 L
.21219 .05754 L
.21277 .05955 L
.21334 .06224 L
.21386 .06561 L
.21423 .06892 L
.21449 .07233 L
.21461 .07439 L
.21469 .07634 L
.21475 .07855 L
.21478 .08094 L
.21478 .08335 L
.21476 .08473 L
.21474 .08602 L
.21467 .0884 L
.21456 .09095 L
.21443 .09326 L
.21428 .09542 L
.21385 .10032 L
.21324 .10555 L
.21255 .11018 L
.2116 .11535 L
.21058 .11981 L
.20846 .12677 L
.20721 .12984 L
.2058 .13258 L
.20453 .13449 L
.20329 .13587 L
.20257 .13647 L
.2019 .13691 L
.20116 .13725 L
.20038 .13745 L
.19961 .1375 L
.19917 .13745 L
.19877 .13737 L
.19804 .13711 L
.19726 .13668 L
.19658 .13616 L
.19594 .13557 L
Mistroke
.19452 .13382 L
.19306 .13135 L
.19178 .12859 L
.1904 .12481 L
.18923 .12083 L
.18745 .11285 L
.18668 .10827 L
.186 .1032 L
.18549 .09825 L
.18528 .09581 L
.18513 .09356 L
.18501 .09156 L
.18491 .08937 L
.18483 .0872 L
.18478 .08492 L
.18475 .08235 L
.18476 .08002 L
.18478 .07882 L
.18481 .07752 L
.18485 .07619 L
.1849 .07496 L
.18502 .07278 L
.18515 .07085 L
.18553 .06682 L
.18594 .06378 L
.18646 .06089 L
.18709 .05838 L
.18772 .05655 L
.18811 .05573 L
.18831 .05537 L
.18853 .05504 L
.18873 .05479 L
.18894 .05457 L
.18933 .05429 L
.1897 .05417 L
.1901 .05421 L
.19048 .0544 L
.19083 .0547 L
.19103 .05495 L
.19125 .05525 L
.19163 .05593 L
.19206 .05694 L
.19244 .05805 L
.19313 .06074 L
.1937 .06384 L
.19415 .06726 L
.19448 .07081 L
.19463 .073 L
.19473 .07507 L
.19478 .07625 L
Mistroke
.19482 .07755 L
.19486 .07997 L
.19488 .08236 L
.19487 .08375 L
.19485 .08506 L
.19482 .08645 L
.19478 .08773 L
.19466 .09065 L
.19453 .09314 L
.19434 .09588 L
.19389 .10085 L
.1933 .10578 L
.19266 .11013 L
.19184 .11462 L
.19082 .11919 L
.18977 .12309 L
.18871 .12635 L
.1864 .13167 L
.18499 .13399 L
.18366 .1356 L
.1829 .13629 L
.1825 .13659 L
.18207 .13686 L
.18128 .13724 L
.18054 .13744 L
.17987 .1375 L
.17915 .13743 L
.17846 .13725 L
.17784 .13697 L
.17715 .13654 L
.17641 .13594 L
.17494 .13428 L
.17338 .13179 L
.17203 .12896 L
.17058 .12509 L
.16934 .1209 L
.16746 .11241 L
.16661 .10718 L
.16597 .10217 L
.16549 .09717 L
.16516 .09257 L
.16503 .09005 L
.16498 .08873 L
.16493 .08732 L
.16487 .08478 L
.16485 .08247 L
.16486 .08019 L
.1649 .07779 L
.16497 .07559 L
.16506 .07363 L
Mistroke
.16516 .07191 L
.1653 .0701 L
.16564 .06667 L
.16589 .0647 L
.16616 .06297 L
.16673 .06011 L
.16742 .05761 L
.16784 .05649 L
.16824 .05565 L
.1686 .05507 L
.16894 .05466 L
.16932 .05435 L
.16973 .05418 L
.17014 .05419 L
.17034 .05427 L
.17057 .05439 L
.17096 .05475 L
.17132 .05522 L
.1717 .05589 L
.17209 .05678 L
.17275 .0588 L
.1734 .06157 L
.17372 .0634 L
.174 .06527 L
.17423 .06713 L
.17442 .06901 L
.17457 .0708 L
.17471 .07278 L
.17482 .07502 L
.1749 .07717 L
.17495 .07956 L
.17497 .08095 L
.17497 .08227 L
.17495 .0844 L
.1749 .08677 L
.17482 .08928 L
.17471 .09164 L
.17443 .0959 L
.17403 .10045 L
.1734 .10572 L
.17268 .11056 L
.17097 .11897 L
.16992 .12289 L
.16885 .12621 L
.16747 .12969 L
.16612 .13235 L
.16464 .13458 L
.16394 .1354 L
.16319 .13613 L
.16237 .13674 L
Mistroke
.16161 .13714 L
.16114 .13732 L
.1607 .13743 L
.15987 .1375 L
.1592 .13743 L
.15847 .13721 L
.1577 .13684 L
.157 .13636 L
.15575 .13517 L
.15445 .13344 L
.15299 .13086 L
.15169 .12789 L
.14949 .12111 L
.14849 .11706 L
.14766 .113 L
.14681 .1079 L
.14617 .10305 L
.14566 .09812 L
.14527 .09291 L
.14513 .09021 L
.14503 .08772 L
.14499 .0863 L
.14497 .08502 L
.14495 .08356 L
.14494 .08219 L
.14495 .08014 L
.14499 .07793 L
.14506 .07569 L
.14515 .07366 L
.14526 .07183 L
.14538 .07021 L
.14572 .0668 L
.14616 .06352 L
.14674 .06046 L
.14736 .05808 L
.14799 .05636 L
.14837 .05559 L
.14878 .05495 L
.14914 .05456 L
.14953 .05428 L
.14976 .0542 L
.14997 .05417 L
.1502 .05419 L
.15043 .05426 L
.15082 .05452 L
.15104 .05474 L
.15125 .05499 L
.1516 .05554 L
.15193 .05619 L
.15231 .05711 L
Mistroke
.15264 .0581 L
.15328 .06054 L
.15387 .06375 L
.15431 .06708 L
.15464 .07052 L
.15479 .07263 L
.1549 .07463 L
.15495 .07577 L
.15499 .07703 L
.15504 .07936 L
.15506 .08145 L
.15505 .0838 L
.15501 .0863 L
.15493 .08867 L
.15484 .09091 L
.15472 .09297 L
.15438 .09761 L
.15392 .10228 L
.15327 .10735 L
.1525 .11212 L
.15152 .11699 L
.15049 .1212 L
.14944 .12473 L
.14715 .13058 L
.14574 .13315 L
.14437 .13503 L
.14356 .13588 L
.14281 .1365 L
.1424 .13678 L
.14195 .13703 L
.14152 .13722 L
.14112 .13735 L
.14032 .13749 L
.13958 .13747 L
.13876 .13728 L
.1383 .1371 L
.13789 .13689 L
.13706 .13633 L
.13616 .13551 L
.13458 .13349 L
.13313 .13094 L
.13165 .12755 L
.13044 .12407 L
.12928 .11996 L
.12833 .11589 L
.12742 .11114 L
.12672 .10663 L
.12617 .10223 L
.12588 .09955 L
.12562 .09661 L
Mistroke
.12544 .09416 L
.12528 .09146 L
.12515 .08858 L
.1251 .08701 L
.12507 .08555 L
.12503 .08298 L
.12503 .08156 L
.12504 .08027 L
.12508 .07796 L
.12514 .07588 L
.12524 .07366 L
.12539 .07139 L
.12557 .06911 L
.12578 .06708 L
.12624 .06362 L
.12678 .06072 L
.12734 .05845 L
.12802 .05649 L
.12843 .05565 L
.12881 .05504 L
.12921 .05458 L
.12959 .0543 L
.1298 .05421 L
.13 .05417 L
.13023 .05418 L
.13045 .05423 L
.13084 .05446 L
.1312 .05481 L
.13158 .05534 L
.13198 .05608 L
.1326 .05768 L
.13322 .05988 L
.13374 .06241 L
.13416 .06507 L
.13456 .06858 L
.13475 .07074 L
.13489 .07282 L
.13499 .07471 L
.13508 .07687 L
.13513 .07919 L
.13515 .08143 L
.13514 .08386 L
.13512 .08524 L
.13509 .08651 L
.13501 .08899 L
.13491 .09136 L
.13474 .09414 L
.13455 .09671 L
.13399 .10249 L
.1334 .10709 L
Mistroke
.13262 .11197 L
.13165 .11686 L
.13064 .121 L
.12841 .12788 L
.12705 .13097 L
.12568 .13338 L
.12436 .13514 L
.12311 .13634 L
.12245 .1368 L
.12171 .13718 L
.12094 .13742 L
.12021 .1375 L
.11947 .13744 L
.11869 .13723 L
.11795 .13688 L
.11729 .13643 L
.11651 .13577 L
.11568 .13487 L
.11422 .13278 L
.11276 .12998 L
.11131 .1264 L
.11016 .12284 L
.10903 .1186 L
.1081 .11434 L
.10736 .11023 L
.10671 .10588 L
.1062 .10173 L
.10574 .09685 L
.10554 .09426 L
.10538 .09151 L
.10526 .0889 L
.10518 .08647 L
.10514 .08432 L
.10512 .08203 L
.10514 .07964 L
.10518 .07751 L
.10527 .07512 L
.10538 .07295 L
.10551 .07101 L
.10565 .06929 L
.10604 .06568 L
.10653 .06248 L
.10716 .05949 L
.1075 .05822 L
.1079 .05704 L
.10829 .05611 L
.10866 .05541 L
.10903 .05487 L
.10924 .05463 L
.10944 .05446 L
Mistroke
.10965 .05431 L
.10989 .05421 L
.11011 .05417 L
.11031 .05418 L
.11072 .05432 L
.11095 .05448 L
.11117 .05467 L
.11159 .05522 L
.11204 .05602 L
.11241 .05689 L
.1128 .05802 L
.11346 .06053 L
.11402 .06353 L
.11446 .06674 L
.11465 .06852 L
.11483 .0705 L
.11495 .07228 L
.11506 .07426 L
.11516 .07648 L
.11521 .0786 L
.11523 .07993 L
.11524 .0812 L
.11524 .08362 L
.1152 .0858 L
.11514 .08813 L
.11506 .09014 L
.11494 .09237 L
.11459 .09737 L
.11413 .10203 L
.11345 .10738 L
.11266 .11228 L
.1108 .12073 L
.10958 .12488 L
.10834 .12828 L
.10688 .13147 L
.10611 .13285 L
.10523 .13417 L
.10448 .13511 L
.10367 .13595 L
.10279 .13664 L
.1024 .13689 L
.10197 .13711 L
.10154 .13728 L
.10114 .13739 L
.10035 .1375 L
.09964 .13745 L
.09888 .13726 L
.09806 .13689 L
.09761 .1366 L
.09719 .13629 L
Mistroke
.09564 .1347 L
.09484 .13361 L
.09398 .13221 L
.09234 .12881 L
.09099 .1252 L
.08987 .12149 L
.08877 .11708 L
.08774 .11191 L
.08693 .10684 L
.08633 .102 L
.08587 .0973 L
.08551 .0923 L
.08539 .08982 L
.08529 .08714 L
.08524 .08464 L
.08522 .08237 L
.08523 .08015 L
.08526 .07819 L
.08532 .07599 L
.08541 .07398 L
.08554 .07185 L
.0857 .0697 L
.08607 .06613 L
.08657 .06274 L
.08722 .05961 L
.08785 .05743 L
.08848 .05591 L
.08884 .05527 L
.08924 .05474 L
.08962 .05439 L
.08998 .05421 L
.09031 .05417 L
.09061 .05423 L
.09095 .0544 L
.09131 .05473 L
.09168 .05521 L
.09203 .05581 L
.09265 .05729 L
.09299 .05833 L
.09334 .05962 L
.09392 .06236 L
.0944 .0655 L
.09477 .06876 L
.09494 .07072 L
.09507 .07264 L
.09518 .07483 L
.09524 .0761 L
.09527 .07727 L
.09532 .07969 L
.09534 .08109 L
Mistroke
.09534 .0824 L
.09532 .08484 L
.09525 .08748 L
.09517 .08977 L
.09506 .09189 L
.09474 .09671 L
.09434 .10094 L
.09383 .10535 L
.09237 .11427 L
.09135 .11893 L
.09028 .12292 L
.0891 .12655 L
.08774 .1299 L
.08615 .13293 L
.08541 .13404 L
.08461 .13507 L
.08384 .13588 L
.08312 .13648 L
.0824 .13694 L
.0817 .13725 L
.0809 .13746 L
.08014 .1375 L
.07932 .13737 L
.07886 .13722 L
.07845 .13704 L
.07773 .13662 L
.07697 .13602 L
.07564 .13459 L
.07426 .13253 L
.07281 .12969 L
.07164 .12678 L
.07046 .12324 L
.06861 .11591 L
.06772 .11125 L
.0669 .10592 L
.06628 .10072 L
.06584 .09583 L
Mfstroke
.23416 .09583 m
.25 .09583 L
s
.06584 .09583 m
.05 .09583 L
s
.58416 .09583 m
.58375 .10045 L
.58318 .10533 L
.58183 .11374 L
.58081 .1185 L
.57972 .12264 L
.57738 .12925 L
.57606 .13196 L
.57459 .13428 L
.57329 .13578 L
.57253 .13643 L
.57182 .1369 L
.57142 .1371 L
.57099 .13728 L
.5702 .13746 L
.56943 .13749 L
.56871 .13738 L
.56827 .13724 L
.56786 .13707 L
.5671 .13663 L
.56629 .13599 L
.56542 .1351 L
.56387 .13296 L
.56249 .1304 L
.56107 .12699 L
.55966 .12274 L
.55836 .11769 L
.55728 .11245 L
.55647 .10746 L
.55575 .10182 L
.55527 .09685 L
.55507 .09402 L
.55491 .09136 L
.55484 .09001 L
.55479 .08859 L
.55471 .08608 L
.55468 .0847 L
.55467 .08343 L
.55466 .08204 L
.55467 .08058 L
.5547 .0782 L
.55474 .07689 L
.55478 .0757 L
.55488 .07358 L
.55501 .07141 L
.55532 .06789 L
.55553 .06603 L
.55575 .06439 L
.55631 .06117 L
.55691 .05868 L
Mistroke
.55763 .05654 L
.55806 .05564 L
.55846 .055 L
.55885 .05456 L
.55922 .0543 L
.55962 .05417 L
.55982 .05417 L
.56005 .05422 L
.56042 .05442 L
.56081 .05479 L
.56118 .0553 L
.56151 .05588 L
.56219 .05754 L
.56277 .05955 L
.56334 .06224 L
.56386 .06561 L
.56423 .06892 L
.56449 .07233 L
.56461 .07439 L
.56469 .07634 L
.56475 .07855 L
.56478 .08094 L
.56478 .08335 L
.56476 .08473 L
.56474 .08602 L
.56467 .0884 L
.56456 .09095 L
.56443 .09326 L
.56428 .09542 L
.56385 .10032 L
.56324 .10555 L
.56255 .11018 L
.5616 .11535 L
.56058 .11981 L
.55846 .12677 L
.55721 .12984 L
.5558 .13258 L
.55453 .13449 L
.55329 .13587 L
.55257 .13647 L
.5519 .13691 L
.55116 .13725 L
.55038 .13745 L
.54961 .1375 L
.54917 .13745 L
.54877 .13737 L
.54804 .13711 L
.54726 .13668 L
.54658 .13616 L
.54594 .13557 L
Mistroke
.54452 .13382 L
.54306 .13135 L
.54178 .12859 L
.5404 .12481 L
.53923 .12083 L
.53745 .11285 L
.53668 .10827 L
.536 .1032 L
.53549 .09825 L
.53528 .09581 L
.53513 .09356 L
.53501 .09156 L
.53491 .08937 L
.53483 .0872 L
.53478 .08492 L
.53475 .08235 L
.53476 .08002 L
.53478 .07882 L
.53481 .07752 L
.53485 .07619 L
.5349 .07496 L
.53502 .07278 L
.53515 .07085 L
.53553 .06682 L
.53594 .06378 L
.53646 .06089 L
.53709 .05838 L
.53772 .05655 L
.53811 .05573 L
.53831 .05537 L
.53853 .05504 L
.53873 .05479 L
.53894 .05457 L
.53933 .05429 L
.5397 .05417 L
.5401 .05421 L
.54048 .0544 L
.54083 .0547 L
.54103 .05495 L
.54125 .05525 L
.54163 .05593 L
.54206 .05694 L
.54244 .05805 L
.54313 .06074 L
.5437 .06384 L
.54415 .06726 L
.54448 .07081 L
.54463 .073 L
.54473 .07507 L
.54478 .07625 L
Mistroke
.54482 .07755 L
.54486 .07997 L
.54488 .08236 L
.54487 .08375 L
.54485 .08506 L
.54482 .08645 L
.54478 .08773 L
.54466 .09065 L
.54453 .09314 L
.54434 .09588 L
.54389 .10085 L
.5433 .10578 L
.54266 .11013 L
.54184 .11462 L
.54082 .11919 L
.53977 .12309 L
.53871 .12635 L
.5364 .13167 L
.53499 .13399 L
.53366 .1356 L
.5329 .13629 L
.5325 .13659 L
.53207 .13686 L
.53128 .13724 L
.53054 .13744 L
.52987 .1375 L
.52915 .13743 L
.52846 .13725 L
.52784 .13697 L
.52715 .13654 L
.52641 .13594 L
.52494 .13428 L
.52338 .13179 L
.52203 .12896 L
.52058 .12509 L
.51934 .1209 L
.51746 .11241 L
.51661 .10718 L
.51597 .10217 L
.51549 .09717 L
.51516 .09257 L
.51503 .09005 L
.51498 .08873 L
.51493 .08732 L
.51487 .08478 L
.51485 .08247 L
.51486 .08019 L
.5149 .07779 L
.51497 .07559 L
.51506 .07363 L
Mistroke
.51516 .07191 L
.5153 .0701 L
.51564 .06667 L
.51589 .0647 L
.51616 .06297 L
.51673 .06011 L
.51742 .05761 L
.51784 .05649 L
.51824 .05565 L
.5186 .05507 L
.51894 .05466 L
.51932 .05435 L
.51973 .05418 L
.52014 .05419 L
.52034 .05427 L
.52057 .05439 L
.52096 .05475 L
.52132 .05522 L
.5217 .05589 L
.52209 .05678 L
.52275 .0588 L
.5234 .06157 L
.52372 .0634 L
.524 .06527 L
.52423 .06713 L
.52442 .06901 L
.52457 .0708 L
.52471 .07278 L
.52482 .07502 L
.5249 .07717 L
.52495 .07956 L
.52497 .08095 L
.52497 .08227 L
.52495 .0844 L
.5249 .08677 L
.52482 .08928 L
.52471 .09164 L
.52443 .0959 L
.52403 .10045 L
.5234 .10572 L
.52268 .11056 L
.52097 .11897 L
.51992 .12289 L
.51885 .12621 L
.51747 .12969 L
.51612 .13235 L
.51464 .13458 L
.51394 .1354 L
.51319 .13613 L
.51237 .13674 L
Mistroke
.51161 .13714 L
.51114 .13732 L
.5107 .13743 L
.50987 .1375 L
.5092 .13743 L
.50847 .13721 L
.5077 .13684 L
.507 .13636 L
.50575 .13517 L
.50445 .13344 L
.50299 .13086 L
.50169 .12789 L
.49949 .12111 L
.49849 .11706 L
.49766 .113 L
.49681 .1079 L
.49617 .10305 L
.49566 .09812 L
.49527 .09291 L
.49513 .09021 L
.49503 .08772 L
.49499 .0863 L
.49497 .08502 L
.49495 .08356 L
.49494 .08219 L
.49495 .08014 L
.49499 .07793 L
.49506 .07569 L
.49515 .07366 L
.49526 .07183 L
.49538 .07021 L
.49572 .0668 L
.49616 .06352 L
.49674 .06046 L
.49736 .05808 L
.49799 .05636 L
.49837 .05559 L
.49878 .05495 L
.49914 .05456 L
.49953 .05428 L
.49976 .0542 L
.49997 .05417 L
.5002 .05419 L
.50043 .05426 L
.50082 .05452 L
.50104 .05474 L
.50125 .05499 L
.5016 .05554 L
.50193 .05619 L
.50231 .05711 L
Mistroke
.50264 .0581 L
.50328 .06054 L
.50387 .06375 L
.50431 .06708 L
.50464 .07052 L
.50479 .07263 L
.5049 .07463 L
.50495 .07577 L
.50499 .07703 L
.50504 .07936 L
.50506 .08145 L
.50505 .0838 L
.50501 .0863 L
.50493 .08867 L
.50484 .09091 L
.50472 .09297 L
.50438 .09761 L
.50392 .10228 L
.50327 .10735 L
.5025 .11212 L
.50152 .11699 L
.50049 .1212 L
.49944 .12473 L
.49715 .13058 L
.49574 .13315 L
.49437 .13503 L
.49356 .13588 L
.49281 .1365 L
.4924 .13678 L
.49195 .13703 L
.49152 .13722 L
.49112 .13735 L
.49032 .13749 L
.48958 .13747 L
.48876 .13728 L
.4883 .1371 L
.48789 .13689 L
.48706 .13633 L
.48616 .13551 L
.48458 .13349 L
.48313 .13094 L
.48165 .12755 L
.48044 .12407 L
.47928 .11996 L
.47833 .11589 L
.47742 .11114 L
.47672 .10663 L
.47617 .10223 L
.47588 .09955 L
.47562 .09661 L
Mistroke
.47544 .09416 L
.47528 .09146 L
.47515 .08858 L
.4751 .08701 L
.47507 .08555 L
.47503 .08298 L
.47503 .08156 L
.47504 .08027 L
.47508 .07796 L
.47514 .07588 L
.47524 .07366 L
.47539 .07139 L
.47557 .06911 L
.47578 .06708 L
.47624 .06362 L
.47678 .06072 L
.47734 .05845 L
.47802 .05649 L
.47843 .05565 L
.47881 .05504 L
.47921 .05458 L
.47959 .0543 L
.4798 .05421 L
.48 .05417 L
.48023 .05418 L
.48045 .05423 L
.48084 .05446 L
.4812 .05481 L
.48158 .05534 L
.48198 .05608 L
.4826 .05768 L
.48322 .05988 L
.48374 .06241 L
.48416 .06507 L
.48456 .06858 L
.48475 .07074 L
.48489 .07282 L
.48499 .07471 L
.48508 .07687 L
.48513 .07919 L
.48515 .08143 L
.48514 .08386 L
.48512 .08524 L
.48509 .08651 L
.48501 .08899 L
.48491 .09136 L
.48474 .09414 L
.48455 .09671 L
.48399 .10249 L
.4834 .10709 L
Mistroke
.48262 .11197 L
.48165 .11686 L
.48064 .121 L
.47841 .12788 L
.47705 .13097 L
.47568 .13338 L
.47436 .13514 L
.47311 .13634 L
.47245 .1368 L
.47171 .13718 L
.47094 .13742 L
.47021 .1375 L
.46947 .13744 L
.46869 .13723 L
.46795 .13688 L
.46729 .13643 L
.46651 .13577 L
.46568 .13487 L
.46422 .13278 L
.46276 .12998 L
.46131 .1264 L
.46016 .12284 L
.45903 .1186 L
.4581 .11434 L
.45736 .11023 L
.45671 .10588 L
.4562 .10173 L
.45574 .09685 L
.45554 .09426 L
.45538 .09151 L
.45526 .0889 L
.45518 .08647 L
.45514 .08432 L
.45512 .08203 L
.45514 .07964 L
.45518 .07751 L
.45527 .07512 L
.45538 .07295 L
.45551 .07101 L
.45565 .06929 L
.45604 .06568 L
.45653 .06248 L
.45716 .05949 L
.4575 .05822 L
.4579 .05704 L
.45829 .05611 L
.45866 .05541 L
.45903 .05487 L
.45924 .05463 L
.45944 .05446 L
Mistroke
.45965 .05431 L
.45989 .05421 L
.46011 .05417 L
.46031 .05418 L
.46072 .05432 L
.46095 .05448 L
.46117 .05467 L
.46159 .05522 L
.46204 .05602 L
.46241 .05689 L
.4628 .05802 L
.46346 .06053 L
.46402 .06353 L
.46446 .06674 L
.46465 .06852 L
.46483 .0705 L
.46495 .07228 L
.46506 .07426 L
.46516 .07648 L
.46521 .0786 L
.46523 .07993 L
.46524 .0812 L
.46524 .08362 L
.4652 .0858 L
.46514 .08813 L
.46506 .09014 L
.46494 .09237 L
.46459 .09737 L
.46413 .10203 L
.46345 .10738 L
.46266 .11228 L
.4608 .12073 L
.45958 .12488 L
.45834 .12828 L
.45688 .13147 L
.45611 .13285 L
.45523 .13417 L
.45448 .13511 L
.45367 .13595 L
.45279 .13664 L
.4524 .13689 L
.45197 .13711 L
.45154 .13728 L
.45114 .13739 L
.45035 .1375 L
.44964 .13745 L
.44888 .13726 L
.44806 .13689 L
.44761 .1366 L
.44719 .13629 L
Mistroke
.44564 .1347 L
.44484 .13361 L
.44398 .13221 L
.44234 .12881 L
.44099 .1252 L
.43987 .12149 L
.43877 .11708 L
.43774 .11191 L
.43693 .10684 L
.43633 .102 L
.43587 .0973 L
.43551 .0923 L
.43539 .08982 L
.43529 .08714 L
.43524 .08464 L
.43522 .08237 L
.43523 .08015 L
.43526 .07819 L
.43532 .07599 L
.43541 .07398 L
.43554 .07185 L
.4357 .0697 L
.43607 .06613 L
.43657 .06274 L
.43722 .05961 L
.43785 .05743 L
.43848 .05591 L
.43884 .05527 L
.43924 .05474 L
.43962 .05439 L
.43998 .05421 L
.44031 .05417 L
.44061 .05423 L
.44095 .0544 L
.44131 .05473 L
.44168 .05521 L
.44203 .05581 L
.44265 .05729 L
.44299 .05833 L
.44334 .05962 L
.44392 .06236 L
.4444 .0655 L
.44477 .06876 L
.44494 .07072 L
.44507 .07264 L
.44518 .07483 L
.44524 .0761 L
.44527 .07727 L
.44532 .07969 L
.44534 .08109 L
Mistroke
.44534 .0824 L
.44532 .08484 L
.44525 .08748 L
.44517 .08977 L
.44506 .09189 L
.44474 .09671 L
.44434 .10094 L
.44383 .10535 L
.44237 .11427 L
.44135 .11893 L
.44028 .12292 L
.4391 .12655 L
.43774 .1299 L
.43615 .13293 L
.43541 .13404 L
.43461 .13507 L
.43384 .13588 L
.43312 .13648 L
.4324 .13694 L
.4317 .13725 L
.4309 .13746 L
.43014 .1375 L
.42932 .13737 L
.42886 .13722 L
.42845 .13704 L
.42773 .13662 L
.42697 .13602 L
.42564 .13459 L
.42426 .13253 L
.42281 .12969 L
.42164 .12678 L
.42046 .12324 L
.41861 .11591 L
.41772 .11125 L
.4169 .10592 L
.41628 .10072 L
.41584 .09583 L
Mfstroke
.58416 .09583 m
.6 .09583 L
s
.41584 .09583 m
.4 .09583 L
s
1 .753 .796 r
0 .03333 m
0 .22083 L
.05 .22083 L
.05 .03333 L
F
1 0 0 r
.25 .03333 m
.25 .15833 L
.4 .15833 L
.4 .03333 L
F
0 0 1 r
.6 .03333 m
.6 .15833 L
.75 .15833 L
.75 .03333 L
F
0 g
gsave
.15 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.325 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.675 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.15 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.325 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.675 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 57.5625},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000>B000`400?l00000o`00003o0P3oool0
0`000000oooo0?ooo`0X0?ooo`D00000;@3oool5000002`0oooo1000000]0?ooo`@00000F`3oool0
0080oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1L0?ooo`000P3oool00`000000
oooo0?ooo`0Q0?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`0V0?ooo`80
000000@0oooo0000003oool000000`3oool00`000000oooo0?ooo`0U0?ooo`80000000<0oooo0000
000000000`3oool00`000000oooo0?ooo`0V0?ooo`80000000@0oooo0000003oool000000P3oool0
0`000000oooo0?ooo`1K0?ooo`000P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool09`3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo000000050?ooo`030000003oool0oooo02H0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo05X0oooo00020?ooo`030000003oool0
oooo0280oooo0`0000050?ooo`030000003oool0oooo02L0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo02H0oooo0`0000030?ooo`040000003oool0oooo000002L0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0F@3oool00080
oooo00<000000?ooo`3oool08P3oool010000000oooo0000000000030?ooo`800000:03oool30000
00030?ooo`000000oooo0080oooo0P00000X0?ooo`040000003oool00000000000<0oooo0P00000W
0?ooo`<0000000<0oooo0000003oool00P3oool2000005`0oooo00020?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`2C0?ooo`000P3oool00`000000
oooo0?ooo`0Q0?ooo`800000H@3oool2000009D0oooo00020?ooo`030000003oool0oooo0?l0oooo
703oool00080ooooo`00000L000000<0oooo00020?ooo`h0ol3;>03oool[0?l003P0oooo:`000?m:
0?ooo`000P3oool>0?o0bcP0oooo:`3o000h0?ooob/0003oBP3oool00080oooo3P3o`</h0?ooob/0
o`00>03oool[0000odX0oooo00020?ooo`h0ol3;>03oool[0?l003P0oooo:`000?m:0?ooo`000P3o
ool>0?o0bcP0oooo:`3o000h0?ooob/0003oBP3oool00080oooo3P3o`</;0?ooo`030000003oool0
oooo0080oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000103oool2
000000@0oooo00<000000?ooo`3oool0203oool[0?l000/0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`080?ooob/0003oBP3oool00080oooo3P3o`</:0?ooo`<000000`3oool20000
00@0oooo0P0000030?ooo`<000000`3oool2000000@0oooo0P0000030?ooo`<000002@3oool[0?l0
00X0oooo0`0000030?ooo`800000103oool2000000<0oooo0`0000030?ooo`8000000`3oool30000
00<0oooo0`0000090?ooob/0003oBP3oool00080oooo3P3o`</:0?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0
oooo0`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000002@3oool[0?l000X0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000`3oool300000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000090?ooob/0003oBP3oool00080oooo3P3o`</:0?ooo`030000003oool0000000<0oooo
00<000000?ooo`0000000P3oool010000000oooo0000000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000T0
oooo:`3o000:0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool010000000
oooo0000000000020?ooo`030000003oool000000080oooo0P0000001`3oool000000?ooo`3oool0
00000?ooo`0000000`3oool00`000000oooo000000090?ooob/0003oBP3oool00080oooo3P3o`</:
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0000000T0oooo:`3o000:0?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`030000003oool0
000000T0oooo:`000?m:0?ooo`000P3oool>0?o0b`X0oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`00
00002@3oool[0?l000X0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000002@3oool[0000odX0oooo
00020?ooo`h0ol3;2P3oool01P000000oooo0?ooo`000000oooo00000080oooo00@000000?ooo`3o
ool000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000T0oooo:`3o000:0?ooo`06
0000003oool000000000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0000003oool00P0000000`3oool000000?ooo`080?ooob/0003oBP3oool00080oooo3P3o`</:0?oo
o`060000003oool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
oooo0000003oool000000P3oool00`000000oooo0?ooo`070?ooob/0o`002P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`00
0000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
00000080oooo00<000000?ooo`3oool01`3oool[0000odX0oooo00020?ooo`h0ol3;2P3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`00
0000oooo00000080oooo00<000000?ooo`3oool01`3oool[0?l000X0oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`030000003oool0oooo00L0oooo:`000?m:0?ooo`000P3oool>0?o0b`X0oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo00L0oooo:`3o000:0?ooo`060000003oool0oooo0000003o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool0
0`000000oooo0?ooo`070?ooob/0003oBP3oool00080oooo3P3o`</:0?ooo`060000003oool0oooo
0000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000002@3oool[0?l000X0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000oooo00P0
oooo:`000?m:0?ooo`000P3oool>0?o0b`X0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000002@3o
ool[0?l000X0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`0000002@3oool[0000odX0oooo00020?oo
o`h0ol3;1@0000050?ooo`030000003oool000000080oooo0P0000001@3oool000000?ooo`3oool0
00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000050?ooo`@00000:`3o00050000
00D0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`0000001@3oool4000002/0003oBP3oool00080oooo
3P3o`</40?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool010000000
oooo0?ooo`3oool[0?l000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00050?ooo`040000003oool0oooo0?ooob/0003oBP3oool00080oooo3P3o`</40?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`3oool[0?l000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`040000003oool0oooo0?ooob/0
003oBP3oool00080oooo3P3o`</50?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000
1@3oool010000000oooo0?ooo`3oool[0?l000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000050?ooo`040000003oool0oooo0?ooob/0003oBP3oool00080oooo3P3o`</50?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000`3oool2000000@0oooo0P0000030?ooo`03
0000003oool0000000<0oooo0P0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`020?ooob/0o`001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0oooo0P0000040?ooo`8000000`3oool00`000000oooo000000030?ooo`80
00000`3oool00`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool[0000odX0oooo00020?ooo`h0ol3;1@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo0P0000040?ooo`8000000`3oool00`000000oooo000000030?ooo`800000
103oool2000000<0oooo0P0000050?ooo`030000003oool0oooo0080oooo:`3o00050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool2000000@0oooo0P0000030?ooo`030000
003oool0000000<0oooo0P0000040?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0
0P3oool[0000odX0oooo00020?ooo`h0ol3;1@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000103o
ool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooob/0o`001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooob/0003oBP3oool00080oooo3P3o`</50?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo:`3o00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo:`000?m:0?ooo`000P3oool>0?o0
b`H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo:`3o00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooob/0003oBP3oool00080oooo3P3o`</60?ooo`030000003oool0oooo0080
oooo0P0000030?ooo`800000103oool2000000<0oooo0P0000040?ooo`800000103oool2000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooob/0o`001P3oool00`000000
oooo0?ooo`020?ooo`8000000`3oool2000000@0oooo0P0000030?ooo`800000103oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool[0000odX0
oooo00020?ooo`h0ol3;1P3oool200000080oooo00<000000?ooo`0000000`3oool3000000<0oooo
0P0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool[0?l000H0oooo
0P0000020?ooo`030000003oool0000000<0oooo0`0000030?ooo`8000000`3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000030?ooo`030000003oool0oooo00<0oooo:`000?m:0?ooo`000P3oool>0?o0b`L0oooo00D0
00000?ooo`00000000000?ooo`02000000040?ooo`00000000000?ooo`@000000P3oool01@000000
oooo000000000000oooo0080000000H0oooo0000003oool0oooo0000003oool200000080oooo00<0
00000?ooo`0000000P3oool2000000030?ooo`000000oooo00D0oooo:`3o00070?ooo`050000003o
ool000000000003oool00P000000103oool000000000003oool400000080oooo00D000000?ooo`00
000000000?ooo`02000000060?ooo`000000oooo0?ooo`000000oooo0P0000020?ooo`030000003o
ool000000080oooo0P0000000`3oool000000?ooo`050?ooob/0003oBP3oool00080oooo3P3o`</8
0?ooo`8000000`3oool3000000<0oooo0P0000040?ooo`8000000`3oool3000000<0oooo0P000003
0?ooo`<000000`3oool3000000H0oooo:`3o00080?ooo`8000000`3oool3000000<0oooo0P000004
0?ooo`8000000`3oool3000000<0oooo0P0000030?ooo`<000000`3oool3000000H0oooo:`000?m:
0?ooo`000P3oool>0?o0bcP0oooo:`3o000h0?ooob/0003oBP3oool00080oooo3P3o`</h0?ooob/0
o`00>03oool[0000odX0oooo00020?ooo`h0ol3;>03oool[0?l003P0oooo:`000?m:0?ooo`000P3o
ool>0?o0bcP0oooo:`3o000h0?ooob/0003oBP3oool00080oooo3P3o`</h0?ooob/0o`00>03oool[
0000odX0oooo00020?ooo`h0ol3;>03oool[0?l003P0oooo:`000?m:0?ooo`000P3oool>0?o0bol0
oooo4@3oool00080oooo3P3o`<_o0?oooa40oooo00020?ooo`h0ol3;o`3ooolA0?ooo`000P3oool>
0?o0bol0oooo4@3oool00080oooo3P3o`<_o0?oooa40oooo00020?ooo`h0ol3;o`3ooolA0?ooo`00
0P3oool>0?o0bol0oooo4@3oool00080oooo3P3o`<_o0?oooa40oooo00020?ooo`h0ol3;o`3ooolA
0?ooo`000P3oool>0?o0bol0oooo4@3oool00080oooo3P3o`<_o0?oooa40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {56.5625, 0}} -> {0, 0, 0, 0}}],
  "  \n\t  ",
  StyleBox["Figure 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Coupled masses with spring attached to the wall at the left.  \n\n\t\
Assume that the masses slide on a frictionless surface and that the functions \
 ",
  Cell[BoxData[
      RowBox[{\(x[t]\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(y[t]\)}]]],
  "  denote the displacement from ",
  ButtonBox["static equilibrium",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/StaticEquilibrium.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " of the masses  ",
  Cell[BoxData[
      RowBox[{\(m\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(m\_2\)}]]],
  ", respectively.  It can be shown by using ",
  ButtonBox["Newton's second law",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/NewtonsSecondLaw.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["Hooke's law",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/Spring.html"], None},
    ButtonStyle->"Hyperlink"],
  " that the system of  D. E.'s for  ",
  Cell[BoxData[
      RowBox[{\(x[t]\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(y[t]\)}]]],
  "  is  \n\n\t\t",
  Cell[BoxData[
      StyleBox[\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
              x\  + \ \(k\_2\) \((y - x)\)\n
        \(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\)\),
        FontWeight->"Bold"]]],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Equal Masses, Unequal spring constants.  Find the general solution to \
the system of D. E.'s  and plot the solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\)\), "\n", 
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 6, \ m\_2 = 6, \ k\_1 = 3, \ 
      k\_2 = 2\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 6;\)\ \), "\n", 
    \(\(m\_2 = 6;\)\ \), "\n", 
    \(\(k\_1 = 3;\)\ \), "\n", 
    \(\(k\_2 = 2;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des := {m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - 
                    x[t])\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ 
                k\_2\)\ \ \((y[t] - x[t])\)\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t] \[Equal] - \!\(k\_2\)(y[t]-x[t])\>\""];\
\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x \[Equal] 0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]\[ImaginaryI]\), \(\[PlusMinus]\(\[ImaginaryI]\/\@6\
\)\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{"1", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], 
          "=", \(1\/\@6\)}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ 1\/\@6;\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ y\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ y\_2[t, b\_1, 
          b\_2]\ ];\)\ \)}], "Input"],

Cell["We can verify these solutions.  ", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[t], "\< \[Equal] \>", \(-\ 
            k\_2\)\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[t], "\< \[Equal] \>", \(-\ 
            k\_2\)\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-2\), 2}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-2\), 2, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the opposite direction with the frequency  ",
  Cell[BoxData[
      \(\[Omega]\_1\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in same directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nWe could plot infinitely many types of oscillation.  For illustration \
we plot the solution for the coefficients ",
  Cell[BoxData[
      \(a\_1 = 1, a\_2 = 1, b\_1 = 1, b\_2 = 1\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{X[t, 1, 1, 1, 1], Y[t, 1, 1, 1, 1]}\ ], \ {t, 0, 8  \[Pi]}, 
        PlotRange \[Rule] {{0, 8  \[Pi]}, {\(-3.5\), 3.5}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 8  \[Pi], \[Pi]], Range[\(-3\), 3, 1]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The oscillation for  \!\(a\_1\) = 1, \!\(a\_\(\(2\)\(\\\ \
\)\)\)= 1, \!\(b\_1\) = 1, \!\(b\_2\) = 1\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, 1, 1, 1, 1]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, 1, 1, 1, 1]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + X[t, 1, 1, 1, 1], t}, {6 + Y[t, 1, 1, 1, 1], t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 8  \[Pi]}, 
        PlotRange \[Rule] {{\(-1\), 10}, {0, 8  \[Pi]}}, 
        PlotStyle \[Rule] {Magenta, Cyan, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 8  \[Pi], \[Pi]]}, AspectRatio \[Rule] 1, 
        AxesOrigin \[Rule] {\(-1\), 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The oscillation for  \!\(a\_1\) = 1, \!\(a\_\(\(2\)\(\\\ \
\)\)\)= 1, \!\(b\_1\) = 1, \!\(b\_2\) = 1\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, 1, 1, 1, 1]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, 1, 1, 1, 1]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the general solution to the system of D. E.'s  and plot the \
solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\)\), "\n", 
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 2, \ m\_2 = 1, \ k\_1 = 4, \ 
      k\_2 = 2\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 2;\)\ \), "\n", 
    \(\(m\_2 = 1;\)\ \), "\n", 
    \(\(k\_1 = 4;\)\ \), "\n", 
    \(\(k\_2 = 2;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des = {m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - 
                    x[t])\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ 
                k\_2\)\ \ \((y[t] - x[t])\)\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t] \[Equal] - \!\(k\_2\)(y[t]-x[t])\>\""];\
\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x \[Equal] 0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]2\) \[ImaginaryI], \
\(\[PlusMinus]\[ImaginaryI]\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{"2", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], "=", 
          "1"}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ 2;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ y\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ y\_2[t, b\_1, 
          b\_2]\ ];\)\ \)}], "Input"],

Cell["We can verify these solutions.  ", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[t], "\< \[Equal] \>", \(-\ 
            k\_2\)\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[t], "\< \[Equal] \>", \(-\ 
            k\_2\)\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-2\), 2}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-2\), 2, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the opposite direction with the frequency  ",
  Cell[BoxData[
      \(\[Omega]\_1\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in same directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the general solution to the system of D. E.'s  and plot the \
solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\)\), "\n", 
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 2, \ m\_2 = 3, \ k\_1 = 1, \ 
      k\_2 = 2\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 2;\)\ \), "\n", 
    \(\(m\_2 = 3;\)\ \), "\n", 
    \(\(k\_1 = 1;\)\ \), "\n", 
    \(\(k\_2 = 2;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des = {m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - 
                    x[t])\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ 
                k\_2\)\ \ \((y[t] - x[t])\)\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t] \[Equal] - \!\(k\_2\)(y[t]-x[t])\>\""];\
\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x \[Equal] 0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]\[ImaginaryI]\) \@2, \
\(\[PlusMinus]\(\[ImaginaryI]\/\@6\)\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{\(\@2\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], 
          "=", \(1\/\@6\)}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ \@2;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ 1\/\@6;\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\n", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ y\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ y\_2[t, b\_1, 
          b\_2]\ ];\)\ \)}], "Input"],

Cell["We can verify these solutions.  ", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[t], "\< \[Equal] \>", \(-\ 
            k\_2\)\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[t], "\< \[Equal] \>", \(-\ 
            k\_2\)\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotRange \[Rule] {{0, 10  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 10  \[Pi], 2  \[Pi]], 
            Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotRange \[Rule] {{0, 10  \[Pi]}, {\(-\(4\/3\)\), 4\/3}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 10  \[Pi], 2  \[Pi]], 
            Range[\(-\(4\/3\)\), 4\/3, 1\/3]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ Simplify[
          y\_2[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the opposite direction with the frequency  ",
  Cell[BoxData[
      \(\[Omega]\_1\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 10  \[Pi], 2  \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in same directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 10  \[Pi], 2  \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ Simplify[
          y\_2[t, 1, 0]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the general solution to the system of D. E.'s  and plot the \
solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\)\), "\n", 
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 1, \ m\_2 = 4, \ k\_1 = 1, \ 
      k\_2 = 4\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 1;\)\ \), "\n", 
    \(\(m\_2 = 4;\)\ \), "\n", 
    \(\(k\_1 = 1;\)\ \), "\n", 
    \(\(k\_2 = 4;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des = {m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - 
                    x[t])\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ 
                k\_2\)\ \ \((y[t] - x[t])\)\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t] \[Equal] - \!\(k\_2\)(y[t]-x[t])\>\""];\
\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x \[Equal] 0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]\[ImaginaryI]\) \@\(3 + 2\ \@2\), \(\[PlusMinus]\
\[ImaginaryI]\) \@\(3 - 2\ \@2\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{\(\@\(3 + 2\ \@2\)\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], 
          "=", \(\@\(3 - 2\ \@2\)\)}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ \@\(3 + 2\ \@2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ \@\(3 - 2\ \@2\);\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\n", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", 
        Simplify[Y[t, a\_1, a\_2, b\_1, b\_2]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ y\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ y\_2[t, b\_1, 
          b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotRange \[Rule] {{0, 10  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 10  \[Pi], 2  \[Pi]], 
            Chop[Range[\(-1\), 1, 0.20]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotRange \[Rule] {{0, 10  \[Pi]}, {\(-1.22\), 1.22}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 10  \[Pi], 2  \[Pi]], 
            Chop[Range[\(-1.2\), 1.2, 0.20]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ Simplify[
          y\_2[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the opposite direction with the frequency  ",
  Cell[BoxData[
      \(\[Omega]\_1\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 10  \[Pi], 2  \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in same directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 10  \[Pi], 2  \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ Simplify[
          y\_2[t, 1, 0]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Unequal Masses, Equal spring constants.  Find the general solution to \
the system of D. E.'s  and plot the solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\)\), "\n", 
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 1, \ m\_2 = \@2, \ k\_1 = 4, \ 
      k\_2 = 4\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 1;\)\ \), "\n", 
    \(\(m\_2 = \@2;\)\ \), "\n", 
    \(\(k\_1 = 4;\)\ \), "\n", 
    \(\(k\_2 = 4;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des = {m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - 
                    x[t])\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ 
                k\_2\)\ \ \((y[t] - x[t])\)\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t] \[Equal] - \!\(k\_2\)(y[t]-x[t])\>\""];\
\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x \[Equal] 0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]\[ImaginaryI]\) \@\(1 + \@2\), \(\[PlusMinus]\
\[ImaginaryI]\) \@\(2\ \((2 - \@2)\)\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{\(\@\(1 + \@2\)\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], 
          "=", \(\@\(2\ \((2 - \@2)\)\)\)}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ \@\(1 + \@2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ \@\(2\ \((2 - \@2)\)\);\)\), "\[IndentingNewLine]", \

    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\n", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", 
        Simplify[Y[t, a\_1, a\_2, b\_1, b\_2]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-k\_2\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ Simplify[
          y\_1[t, a\_1, a\_2]]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ Simplify[
          y\_2[t, b\_1, b\_2]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotRange \[Rule] {{0, 10  \[Pi]}, {\(-1.4\), 1.4}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 10  \[Pi], 2  \[Pi]], 
            Range[\(-1.25\), 1.25, 0.25]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotRange \[Rule] {{0, 10  \[Pi]}, {\(-1.7\), 1.7}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 10  \[Pi], 2  \[Pi]], 
            Range[\(-1.5\), 1.5, 0.5]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ Simplify[
          y\_2[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the opposite direction with the frequency  ",
  Cell[BoxData[
      \(\[Omega]\_1\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in same directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2\)]],
  ", as seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {2, t}, {6, 
              t}}\ ], \ {t, 0, 10  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ Simplify[
          y\_2[t, 1, 0]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["More Background",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tConsider the system of ",
  ButtonBox["two masses",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  "  ",
  Cell[BoxData[
      RowBox[{\(m\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(m\_2\)}]]],
  " ",
  ButtonBox["and three springs",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " with no external force.  Visualize a wall on the left and to the right a \
spring , a mass, a spring, a mass, a spring and another wall.  Assume that \
the spring constants are  ",
  Cell[BoxData[
      RowBox[{\(k\_1\), ",", 
        RowBox[{\(k\_2\), "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(k\_3\)}]}]]],
  ".   See Figure 2 below.  \n\n\t",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-017 0.2 0.0333333 0.0416667 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .03333 m
1 .03333 L
s
0 0 m
0 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
.5 Mabswid
.23416 .09583 m
.23375 .10045 L
.23318 .10533 L
.23183 .11374 L
.23081 .1185 L
.22972 .12264 L
.22738 .12925 L
.22606 .13196 L
.22459 .13428 L
.22329 .13578 L
.22253 .13643 L
.22182 .1369 L
.22142 .1371 L
.22099 .13728 L
.2202 .13746 L
.21943 .13749 L
.21871 .13738 L
.21827 .13724 L
.21786 .13707 L
.2171 .13663 L
.21629 .13599 L
.21542 .1351 L
.21387 .13296 L
.21249 .1304 L
.21107 .12699 L
.20966 .12274 L
.20836 .11769 L
.20728 .11245 L
.20647 .10746 L
.20575 .10182 L
.20527 .09685 L
.20507 .09402 L
.20491 .09136 L
.20484 .09001 L
.20479 .08859 L
.20471 .08608 L
.20468 .0847 L
.20467 .08343 L
.20466 .08204 L
.20467 .08058 L
.2047 .0782 L
.20474 .07689 L
.20478 .0757 L
.20488 .07358 L
.20501 .07141 L
.20532 .06789 L
.20553 .06603 L
.20575 .06439 L
.20631 .06117 L
.20691 .05868 L
Mistroke
.20763 .05654 L
.20806 .05564 L
.20846 .055 L
.20885 .05456 L
.20922 .0543 L
.20962 .05417 L
.20982 .05417 L
.21005 .05422 L
.21042 .05442 L
.21081 .05479 L
.21118 .0553 L
.21151 .05588 L
.21219 .05754 L
.21277 .05955 L
.21334 .06224 L
.21386 .06561 L
.21423 .06892 L
.21449 .07233 L
.21461 .07439 L
.21469 .07634 L
.21475 .07855 L
.21478 .08094 L
.21478 .08335 L
.21476 .08473 L
.21474 .08602 L
.21467 .0884 L
.21456 .09095 L
.21443 .09326 L
.21428 .09542 L
.21385 .10032 L
.21324 .10555 L
.21255 .11018 L
.2116 .11535 L
.21058 .11981 L
.20846 .12677 L
.20721 .12984 L
.2058 .13258 L
.20453 .13449 L
.20329 .13587 L
.20257 .13647 L
.2019 .13691 L
.20116 .13725 L
.20038 .13745 L
.19961 .1375 L
.19917 .13745 L
.19877 .13737 L
.19804 .13711 L
.19726 .13668 L
.19658 .13616 L
.19594 .13557 L
Mistroke
.19452 .13382 L
.19306 .13135 L
.19178 .12859 L
.1904 .12481 L
.18923 .12083 L
.18745 .11285 L
.18668 .10827 L
.186 .1032 L
.18549 .09825 L
.18528 .09581 L
.18513 .09356 L
.18501 .09156 L
.18491 .08937 L
.18483 .0872 L
.18478 .08492 L
.18475 .08235 L
.18476 .08002 L
.18478 .07882 L
.18481 .07752 L
.18485 .07619 L
.1849 .07496 L
.18502 .07278 L
.18515 .07085 L
.18553 .06682 L
.18594 .06378 L
.18646 .06089 L
.18709 .05838 L
.18772 .05655 L
.18811 .05573 L
.18831 .05537 L
.18853 .05504 L
.18873 .05479 L
.18894 .05457 L
.18933 .05429 L
.1897 .05417 L
.1901 .05421 L
.19048 .0544 L
.19083 .0547 L
.19103 .05495 L
.19125 .05525 L
.19163 .05593 L
.19206 .05694 L
.19244 .05805 L
.19313 .06074 L
.1937 .06384 L
.19415 .06726 L
.19448 .07081 L
.19463 .073 L
.19473 .07507 L
.19478 .07625 L
Mistroke
.19482 .07755 L
.19486 .07997 L
.19488 .08236 L
.19487 .08375 L
.19485 .08506 L
.19482 .08645 L
.19478 .08773 L
.19466 .09065 L
.19453 .09314 L
.19434 .09588 L
.19389 .10085 L
.1933 .10578 L
.19266 .11013 L
.19184 .11462 L
.19082 .11919 L
.18977 .12309 L
.18871 .12635 L
.1864 .13167 L
.18499 .13399 L
.18366 .1356 L
.1829 .13629 L
.1825 .13659 L
.18207 .13686 L
.18128 .13724 L
.18054 .13744 L
.17987 .1375 L
.17915 .13743 L
.17846 .13725 L
.17784 .13697 L
.17715 .13654 L
.17641 .13594 L
.17494 .13428 L
.17338 .13179 L
.17203 .12896 L
.17058 .12509 L
.16934 .1209 L
.16746 .11241 L
.16661 .10718 L
.16597 .10217 L
.16549 .09717 L
.16516 .09257 L
.16503 .09005 L
.16498 .08873 L
.16493 .08732 L
.16487 .08478 L
.16485 .08247 L
.16486 .08019 L
.1649 .07779 L
.16497 .07559 L
.16506 .07363 L
Mistroke
.16516 .07191 L
.1653 .0701 L
.16564 .06667 L
.16589 .0647 L
.16616 .06297 L
.16673 .06011 L
.16742 .05761 L
.16784 .05649 L
.16824 .05565 L
.1686 .05507 L
.16894 .05466 L
.16932 .05435 L
.16973 .05418 L
.17014 .05419 L
.17034 .05427 L
.17057 .05439 L
.17096 .05475 L
.17132 .05522 L
.1717 .05589 L
.17209 .05678 L
.17275 .0588 L
.1734 .06157 L
.17372 .0634 L
.174 .06527 L
.17423 .06713 L
.17442 .06901 L
.17457 .0708 L
.17471 .07278 L
.17482 .07502 L
.1749 .07717 L
.17495 .07956 L
.17497 .08095 L
.17497 .08227 L
.17495 .0844 L
.1749 .08677 L
.17482 .08928 L
.17471 .09164 L
.17443 .0959 L
.17403 .10045 L
.1734 .10572 L
.17268 .11056 L
.17097 .11897 L
.16992 .12289 L
.16885 .12621 L
.16747 .12969 L
.16612 .13235 L
.16464 .13458 L
.16394 .1354 L
.16319 .13613 L
.16237 .13674 L
Mistroke
.16161 .13714 L
.16114 .13732 L
.1607 .13743 L
.15987 .1375 L
.1592 .13743 L
.15847 .13721 L
.1577 .13684 L
.157 .13636 L
.15575 .13517 L
.15445 .13344 L
.15299 .13086 L
.15169 .12789 L
.14949 .12111 L
.14849 .11706 L
.14766 .113 L
.14681 .1079 L
.14617 .10305 L
.14566 .09812 L
.14527 .09291 L
.14513 .09021 L
.14503 .08772 L
.14499 .0863 L
.14497 .08502 L
.14495 .08356 L
.14494 .08219 L
.14495 .08014 L
.14499 .07793 L
.14506 .07569 L
.14515 .07366 L
.14526 .07183 L
.14538 .07021 L
.14572 .0668 L
.14616 .06352 L
.14674 .06046 L
.14736 .05808 L
.14799 .05636 L
.14837 .05559 L
.14878 .05495 L
.14914 .05456 L
.14953 .05428 L
.14976 .0542 L
.14997 .05417 L
.1502 .05419 L
.15043 .05426 L
.15082 .05452 L
.15104 .05474 L
.15125 .05499 L
.1516 .05554 L
.15193 .05619 L
.15231 .05711 L
Mistroke
.15264 .0581 L
.15328 .06054 L
.15387 .06375 L
.15431 .06708 L
.15464 .07052 L
.15479 .07263 L
.1549 .07463 L
.15495 .07577 L
.15499 .07703 L
.15504 .07936 L
.15506 .08145 L
.15505 .0838 L
.15501 .0863 L
.15493 .08867 L
.15484 .09091 L
.15472 .09297 L
.15438 .09761 L
.15392 .10228 L
.15327 .10735 L
.1525 .11212 L
.15152 .11699 L
.15049 .1212 L
.14944 .12473 L
.14715 .13058 L
.14574 .13315 L
.14437 .13503 L
.14356 .13588 L
.14281 .1365 L
.1424 .13678 L
.14195 .13703 L
.14152 .13722 L
.14112 .13735 L
.14032 .13749 L
.13958 .13747 L
.13876 .13728 L
.1383 .1371 L
.13789 .13689 L
.13706 .13633 L
.13616 .13551 L
.13458 .13349 L
.13313 .13094 L
.13165 .12755 L
.13044 .12407 L
.12928 .11996 L
.12833 .11589 L
.12742 .11114 L
.12672 .10663 L
.12617 .10223 L
.12588 .09955 L
.12562 .09661 L
Mistroke
.12544 .09416 L
.12528 .09146 L
.12515 .08858 L
.1251 .08701 L
.12507 .08555 L
.12503 .08298 L
.12503 .08156 L
.12504 .08027 L
.12508 .07796 L
.12514 .07588 L
.12524 .07366 L
.12539 .07139 L
.12557 .06911 L
.12578 .06708 L
.12624 .06362 L
.12678 .06072 L
.12734 .05845 L
.12802 .05649 L
.12843 .05565 L
.12881 .05504 L
.12921 .05458 L
.12959 .0543 L
.1298 .05421 L
.13 .05417 L
.13023 .05418 L
.13045 .05423 L
.13084 .05446 L
.1312 .05481 L
.13158 .05534 L
.13198 .05608 L
.1326 .05768 L
.13322 .05988 L
.13374 .06241 L
.13416 .06507 L
.13456 .06858 L
.13475 .07074 L
.13489 .07282 L
.13499 .07471 L
.13508 .07687 L
.13513 .07919 L
.13515 .08143 L
.13514 .08386 L
.13512 .08524 L
.13509 .08651 L
.13501 .08899 L
.13491 .09136 L
.13474 .09414 L
.13455 .09671 L
.13399 .10249 L
.1334 .10709 L
Mistroke
.13262 .11197 L
.13165 .11686 L
.13064 .121 L
.12841 .12788 L
.12705 .13097 L
.12568 .13338 L
.12436 .13514 L
.12311 .13634 L
.12245 .1368 L
.12171 .13718 L
.12094 .13742 L
.12021 .1375 L
.11947 .13744 L
.11869 .13723 L
.11795 .13688 L
.11729 .13643 L
.11651 .13577 L
.11568 .13487 L
.11422 .13278 L
.11276 .12998 L
.11131 .1264 L
.11016 .12284 L
.10903 .1186 L
.1081 .11434 L
.10736 .11023 L
.10671 .10588 L
.1062 .10173 L
.10574 .09685 L
.10554 .09426 L
.10538 .09151 L
.10526 .0889 L
.10518 .08647 L
.10514 .08432 L
.10512 .08203 L
.10514 .07964 L
.10518 .07751 L
.10527 .07512 L
.10538 .07295 L
.10551 .07101 L
.10565 .06929 L
.10604 .06568 L
.10653 .06248 L
.10716 .05949 L
.1075 .05822 L
.1079 .05704 L
.10829 .05611 L
.10866 .05541 L
.10903 .05487 L
.10924 .05463 L
.10944 .05446 L
Mistroke
.10965 .05431 L
.10989 .05421 L
.11011 .05417 L
.11031 .05418 L
.11072 .05432 L
.11095 .05448 L
.11117 .05467 L
.11159 .05522 L
.11204 .05602 L
.11241 .05689 L
.1128 .05802 L
.11346 .06053 L
.11402 .06353 L
.11446 .06674 L
.11465 .06852 L
.11483 .0705 L
.11495 .07228 L
.11506 .07426 L
.11516 .07648 L
.11521 .0786 L
.11523 .07993 L
.11524 .0812 L
.11524 .08362 L
.1152 .0858 L
.11514 .08813 L
.11506 .09014 L
.11494 .09237 L
.11459 .09737 L
.11413 .10203 L
.11345 .10738 L
.11266 .11228 L
.1108 .12073 L
.10958 .12488 L
.10834 .12828 L
.10688 .13147 L
.10611 .13285 L
.10523 .13417 L
.10448 .13511 L
.10367 .13595 L
.10279 .13664 L
.1024 .13689 L
.10197 .13711 L
.10154 .13728 L
.10114 .13739 L
.10035 .1375 L
.09964 .13745 L
.09888 .13726 L
.09806 .13689 L
.09761 .1366 L
.09719 .13629 L
Mistroke
.09564 .1347 L
.09484 .13361 L
.09398 .13221 L
.09234 .12881 L
.09099 .1252 L
.08987 .12149 L
.08877 .11708 L
.08774 .11191 L
.08693 .10684 L
.08633 .102 L
.08587 .0973 L
.08551 .0923 L
.08539 .08982 L
.08529 .08714 L
.08524 .08464 L
.08522 .08237 L
.08523 .08015 L
.08526 .07819 L
.08532 .07599 L
.08541 .07398 L
.08554 .07185 L
.0857 .0697 L
.08607 .06613 L
.08657 .06274 L
.08722 .05961 L
.08785 .05743 L
.08848 .05591 L
.08884 .05527 L
.08924 .05474 L
.08962 .05439 L
.08998 .05421 L
.09031 .05417 L
.09061 .05423 L
.09095 .0544 L
.09131 .05473 L
.09168 .05521 L
.09203 .05581 L
.09265 .05729 L
.09299 .05833 L
.09334 .05962 L
.09392 .06236 L
.0944 .0655 L
.09477 .06876 L
.09494 .07072 L
.09507 .07264 L
.09518 .07483 L
.09524 .0761 L
.09527 .07727 L
.09532 .07969 L
.09534 .08109 L
Mistroke
.09534 .0824 L
.09532 .08484 L
.09525 .08748 L
.09517 .08977 L
.09506 .09189 L
.09474 .09671 L
.09434 .10094 L
.09383 .10535 L
.09237 .11427 L
.09135 .11893 L
.09028 .12292 L
.0891 .12655 L
.08774 .1299 L
.08615 .13293 L
.08541 .13404 L
.08461 .13507 L
.08384 .13588 L
.08312 .13648 L
.0824 .13694 L
.0817 .13725 L
.0809 .13746 L
.08014 .1375 L
.07932 .13737 L
.07886 .13722 L
.07845 .13704 L
.07773 .13662 L
.07697 .13602 L
.07564 .13459 L
.07426 .13253 L
.07281 .12969 L
.07164 .12678 L
.07046 .12324 L
.06861 .11591 L
.06772 .11125 L
.0669 .10592 L
.06628 .10072 L
.06584 .09583 L
Mfstroke
.23416 .09583 m
.25 .09583 L
s
.06584 .09583 m
.05 .09583 L
s
.58416 .09583 m
.58375 .10045 L
.58318 .10533 L
.58183 .11374 L
.58081 .1185 L
.57972 .12264 L
.57738 .12925 L
.57606 .13196 L
.57459 .13428 L
.57329 .13578 L
.57253 .13643 L
.57182 .1369 L
.57142 .1371 L
.57099 .13728 L
.5702 .13746 L
.56943 .13749 L
.56871 .13738 L
.56827 .13724 L
.56786 .13707 L
.5671 .13663 L
.56629 .13599 L
.56542 .1351 L
.56387 .13296 L
.56249 .1304 L
.56107 .12699 L
.55966 .12274 L
.55836 .11769 L
.55728 .11245 L
.55647 .10746 L
.55575 .10182 L
.55527 .09685 L
.55507 .09402 L
.55491 .09136 L
.55484 .09001 L
.55479 .08859 L
.55471 .08608 L
.55468 .0847 L
.55467 .08343 L
.55466 .08204 L
.55467 .08058 L
.5547 .0782 L
.55474 .07689 L
.55478 .0757 L
.55488 .07358 L
.55501 .07141 L
.55532 .06789 L
.55553 .06603 L
.55575 .06439 L
.55631 .06117 L
.55691 .05868 L
Mistroke
.55763 .05654 L
.55806 .05564 L
.55846 .055 L
.55885 .05456 L
.55922 .0543 L
.55962 .05417 L
.55982 .05417 L
.56005 .05422 L
.56042 .05442 L
.56081 .05479 L
.56118 .0553 L
.56151 .05588 L
.56219 .05754 L
.56277 .05955 L
.56334 .06224 L
.56386 .06561 L
.56423 .06892 L
.56449 .07233 L
.56461 .07439 L
.56469 .07634 L
.56475 .07855 L
.56478 .08094 L
.56478 .08335 L
.56476 .08473 L
.56474 .08602 L
.56467 .0884 L
.56456 .09095 L
.56443 .09326 L
.56428 .09542 L
.56385 .10032 L
.56324 .10555 L
.56255 .11018 L
.5616 .11535 L
.56058 .11981 L
.55846 .12677 L
.55721 .12984 L
.5558 .13258 L
.55453 .13449 L
.55329 .13587 L
.55257 .13647 L
.5519 .13691 L
.55116 .13725 L
.55038 .13745 L
.54961 .1375 L
.54917 .13745 L
.54877 .13737 L
.54804 .13711 L
.54726 .13668 L
.54658 .13616 L
.54594 .13557 L
Mistroke
.54452 .13382 L
.54306 .13135 L
.54178 .12859 L
.5404 .12481 L
.53923 .12083 L
.53745 .11285 L
.53668 .10827 L
.536 .1032 L
.53549 .09825 L
.53528 .09581 L
.53513 .09356 L
.53501 .09156 L
.53491 .08937 L
.53483 .0872 L
.53478 .08492 L
.53475 .08235 L
.53476 .08002 L
.53478 .07882 L
.53481 .07752 L
.53485 .07619 L
.5349 .07496 L
.53502 .07278 L
.53515 .07085 L
.53553 .06682 L
.53594 .06378 L
.53646 .06089 L
.53709 .05838 L
.53772 .05655 L
.53811 .05573 L
.53831 .05537 L
.53853 .05504 L
.53873 .05479 L
.53894 .05457 L
.53933 .05429 L
.5397 .05417 L
.5401 .05421 L
.54048 .0544 L
.54083 .0547 L
.54103 .05495 L
.54125 .05525 L
.54163 .05593 L
.54206 .05694 L
.54244 .05805 L
.54313 .06074 L
.5437 .06384 L
.54415 .06726 L
.54448 .07081 L
.54463 .073 L
.54473 .07507 L
.54478 .07625 L
Mistroke
.54482 .07755 L
.54486 .07997 L
.54488 .08236 L
.54487 .08375 L
.54485 .08506 L
.54482 .08645 L
.54478 .08773 L
.54466 .09065 L
.54453 .09314 L
.54434 .09588 L
.54389 .10085 L
.5433 .10578 L
.54266 .11013 L
.54184 .11462 L
.54082 .11919 L
.53977 .12309 L
.53871 .12635 L
.5364 .13167 L
.53499 .13399 L
.53366 .1356 L
.5329 .13629 L
.5325 .13659 L
.53207 .13686 L
.53128 .13724 L
.53054 .13744 L
.52987 .1375 L
.52915 .13743 L
.52846 .13725 L
.52784 .13697 L
.52715 .13654 L
.52641 .13594 L
.52494 .13428 L
.52338 .13179 L
.52203 .12896 L
.52058 .12509 L
.51934 .1209 L
.51746 .11241 L
.51661 .10718 L
.51597 .10217 L
.51549 .09717 L
.51516 .09257 L
.51503 .09005 L
.51498 .08873 L
.51493 .08732 L
.51487 .08478 L
.51485 .08247 L
.51486 .08019 L
.5149 .07779 L
.51497 .07559 L
.51506 .07363 L
Mistroke
.51516 .07191 L
.5153 .0701 L
.51564 .06667 L
.51589 .0647 L
.51616 .06297 L
.51673 .06011 L
.51742 .05761 L
.51784 .05649 L
.51824 .05565 L
.5186 .05507 L
.51894 .05466 L
.51932 .05435 L
.51973 .05418 L
.52014 .05419 L
.52034 .05427 L
.52057 .05439 L
.52096 .05475 L
.52132 .05522 L
.5217 .05589 L
.52209 .05678 L
.52275 .0588 L
.5234 .06157 L
.52372 .0634 L
.524 .06527 L
.52423 .06713 L
.52442 .06901 L
.52457 .0708 L
.52471 .07278 L
.52482 .07502 L
.5249 .07717 L
.52495 .07956 L
.52497 .08095 L
.52497 .08227 L
.52495 .0844 L
.5249 .08677 L
.52482 .08928 L
.52471 .09164 L
.52443 .0959 L
.52403 .10045 L
.5234 .10572 L
.52268 .11056 L
.52097 .11897 L
.51992 .12289 L
.51885 .12621 L
.51747 .12969 L
.51612 .13235 L
.51464 .13458 L
.51394 .1354 L
.51319 .13613 L
.51237 .13674 L
Mistroke
.51161 .13714 L
.51114 .13732 L
.5107 .13743 L
.50987 .1375 L
.5092 .13743 L
.50847 .13721 L
.5077 .13684 L
.507 .13636 L
.50575 .13517 L
.50445 .13344 L
.50299 .13086 L
.50169 .12789 L
.49949 .12111 L
.49849 .11706 L
.49766 .113 L
.49681 .1079 L
.49617 .10305 L
.49566 .09812 L
.49527 .09291 L
.49513 .09021 L
.49503 .08772 L
.49499 .0863 L
.49497 .08502 L
.49495 .08356 L
.49494 .08219 L
.49495 .08014 L
.49499 .07793 L
.49506 .07569 L
.49515 .07366 L
.49526 .07183 L
.49538 .07021 L
.49572 .0668 L
.49616 .06352 L
.49674 .06046 L
.49736 .05808 L
.49799 .05636 L
.49837 .05559 L
.49878 .05495 L
.49914 .05456 L
.49953 .05428 L
.49976 .0542 L
.49997 .05417 L
.5002 .05419 L
.50043 .05426 L
.50082 .05452 L
.50104 .05474 L
.50125 .05499 L
.5016 .05554 L
.50193 .05619 L
.50231 .05711 L
Mistroke
.50264 .0581 L
.50328 .06054 L
.50387 .06375 L
.50431 .06708 L
.50464 .07052 L
.50479 .07263 L
.5049 .07463 L
.50495 .07577 L
.50499 .07703 L
.50504 .07936 L
.50506 .08145 L
.50505 .0838 L
.50501 .0863 L
.50493 .08867 L
.50484 .09091 L
.50472 .09297 L
.50438 .09761 L
.50392 .10228 L
.50327 .10735 L
.5025 .11212 L
.50152 .11699 L
.50049 .1212 L
.49944 .12473 L
.49715 .13058 L
.49574 .13315 L
.49437 .13503 L
.49356 .13588 L
.49281 .1365 L
.4924 .13678 L
.49195 .13703 L
.49152 .13722 L
.49112 .13735 L
.49032 .13749 L
.48958 .13747 L
.48876 .13728 L
.4883 .1371 L
.48789 .13689 L
.48706 .13633 L
.48616 .13551 L
.48458 .13349 L
.48313 .13094 L
.48165 .12755 L
.48044 .12407 L
.47928 .11996 L
.47833 .11589 L
.47742 .11114 L
.47672 .10663 L
.47617 .10223 L
.47588 .09955 L
.47562 .09661 L
Mistroke
.47544 .09416 L
.47528 .09146 L
.47515 .08858 L
.4751 .08701 L
.47507 .08555 L
.47503 .08298 L
.47503 .08156 L
.47504 .08027 L
.47508 .07796 L
.47514 .07588 L
.47524 .07366 L
.47539 .07139 L
.47557 .06911 L
.47578 .06708 L
.47624 .06362 L
.47678 .06072 L
.47734 .05845 L
.47802 .05649 L
.47843 .05565 L
.47881 .05504 L
.47921 .05458 L
.47959 .0543 L
.4798 .05421 L
.48 .05417 L
.48023 .05418 L
.48045 .05423 L
.48084 .05446 L
.4812 .05481 L
.48158 .05534 L
.48198 .05608 L
.4826 .05768 L
.48322 .05988 L
.48374 .06241 L
.48416 .06507 L
.48456 .06858 L
.48475 .07074 L
.48489 .07282 L
.48499 .07471 L
.48508 .07687 L
.48513 .07919 L
.48515 .08143 L
.48514 .08386 L
.48512 .08524 L
.48509 .08651 L
.48501 .08899 L
.48491 .09136 L
.48474 .09414 L
.48455 .09671 L
.48399 .10249 L
.4834 .10709 L
Mistroke
.48262 .11197 L
.48165 .11686 L
.48064 .121 L
.47841 .12788 L
.47705 .13097 L
.47568 .13338 L
.47436 .13514 L
.47311 .13634 L
.47245 .1368 L
.47171 .13718 L
.47094 .13742 L
.47021 .1375 L
.46947 .13744 L
.46869 .13723 L
.46795 .13688 L
.46729 .13643 L
.46651 .13577 L
.46568 .13487 L
.46422 .13278 L
.46276 .12998 L
.46131 .1264 L
.46016 .12284 L
.45903 .1186 L
.4581 .11434 L
.45736 .11023 L
.45671 .10588 L
.4562 .10173 L
.45574 .09685 L
.45554 .09426 L
.45538 .09151 L
.45526 .0889 L
.45518 .08647 L
.45514 .08432 L
.45512 .08203 L
.45514 .07964 L
.45518 .07751 L
.45527 .07512 L
.45538 .07295 L
.45551 .07101 L
.45565 .06929 L
.45604 .06568 L
.45653 .06248 L
.45716 .05949 L
.4575 .05822 L
.4579 .05704 L
.45829 .05611 L
.45866 .05541 L
.45903 .05487 L
.45924 .05463 L
.45944 .05446 L
Mistroke
.45965 .05431 L
.45989 .05421 L
.46011 .05417 L
.46031 .05418 L
.46072 .05432 L
.46095 .05448 L
.46117 .05467 L
.46159 .05522 L
.46204 .05602 L
.46241 .05689 L
.4628 .05802 L
.46346 .06053 L
.46402 .06353 L
.46446 .06674 L
.46465 .06852 L
.46483 .0705 L
.46495 .07228 L
.46506 .07426 L
.46516 .07648 L
.46521 .0786 L
.46523 .07993 L
.46524 .0812 L
.46524 .08362 L
.4652 .0858 L
.46514 .08813 L
.46506 .09014 L
.46494 .09237 L
.46459 .09737 L
.46413 .10203 L
.46345 .10738 L
.46266 .11228 L
.4608 .12073 L
.45958 .12488 L
.45834 .12828 L
.45688 .13147 L
.45611 .13285 L
.45523 .13417 L
.45448 .13511 L
.45367 .13595 L
.45279 .13664 L
.4524 .13689 L
.45197 .13711 L
.45154 .13728 L
.45114 .13739 L
.45035 .1375 L
.44964 .13745 L
.44888 .13726 L
.44806 .13689 L
.44761 .1366 L
.44719 .13629 L
Mistroke
.44564 .1347 L
.44484 .13361 L
.44398 .13221 L
.44234 .12881 L
.44099 .1252 L
.43987 .12149 L
.43877 .11708 L
.43774 .11191 L
.43693 .10684 L
.43633 .102 L
.43587 .0973 L
.43551 .0923 L
.43539 .08982 L
.43529 .08714 L
.43524 .08464 L
.43522 .08237 L
.43523 .08015 L
.43526 .07819 L
.43532 .07599 L
.43541 .07398 L
.43554 .07185 L
.4357 .0697 L
.43607 .06613 L
.43657 .06274 L
.43722 .05961 L
.43785 .05743 L
.43848 .05591 L
.43884 .05527 L
.43924 .05474 L
.43962 .05439 L
.43998 .05421 L
.44031 .05417 L
.44061 .05423 L
.44095 .0544 L
.44131 .05473 L
.44168 .05521 L
.44203 .05581 L
.44265 .05729 L
.44299 .05833 L
.44334 .05962 L
.44392 .06236 L
.4444 .0655 L
.44477 .06876 L
.44494 .07072 L
.44507 .07264 L
.44518 .07483 L
.44524 .0761 L
.44527 .07727 L
.44532 .07969 L
.44534 .08109 L
Mistroke
.44534 .0824 L
.44532 .08484 L
.44525 .08748 L
.44517 .08977 L
.44506 .09189 L
.44474 .09671 L
.44434 .10094 L
.44383 .10535 L
.44237 .11427 L
.44135 .11893 L
.44028 .12292 L
.4391 .12655 L
.43774 .1299 L
.43615 .13293 L
.43541 .13404 L
.43461 .13507 L
.43384 .13588 L
.43312 .13648 L
.4324 .13694 L
.4317 .13725 L
.4309 .13746 L
.43014 .1375 L
.42932 .13737 L
.42886 .13722 L
.42845 .13704 L
.42773 .13662 L
.42697 .13602 L
.42564 .13459 L
.42426 .13253 L
.42281 .12969 L
.42164 .12678 L
.42046 .12324 L
.41861 .11591 L
.41772 .11125 L
.4169 .10592 L
.41628 .10072 L
.41584 .09583 L
Mfstroke
.58416 .09583 m
.6 .09583 L
s
.41584 .09583 m
.4 .09583 L
s
.93416 .09583 m
.93375 .10045 L
.93318 .10533 L
.93183 .11374 L
.93081 .1185 L
.92972 .12264 L
.92738 .12925 L
.92606 .13196 L
.92459 .13428 L
.92329 .13578 L
.92253 .13643 L
.92182 .1369 L
.92142 .1371 L
.92099 .13728 L
.9202 .13746 L
.91943 .13749 L
.91871 .13738 L
.91827 .13724 L
.91786 .13707 L
.9171 .13663 L
.91629 .13599 L
.91542 .1351 L
.91387 .13296 L
.91249 .1304 L
.91107 .12699 L
.90966 .12274 L
.90836 .11769 L
.90728 .11245 L
.90647 .10746 L
.90575 .10182 L
.90527 .09685 L
.90507 .09402 L
.90491 .09136 L
.90484 .09001 L
.90479 .08859 L
.90471 .08608 L
.90468 .0847 L
.90467 .08343 L
.90466 .08204 L
.90467 .08058 L
.9047 .0782 L
.90474 .07689 L
.90478 .0757 L
.90488 .07358 L
.90501 .07141 L
.90532 .06789 L
.90553 .06603 L
.90575 .06439 L
.90631 .06117 L
.90691 .05868 L
Mistroke
.90763 .05654 L
.90806 .05564 L
.90846 .055 L
.90885 .05456 L
.90922 .0543 L
.90962 .05417 L
.90982 .05417 L
.91005 .05422 L
.91042 .05442 L
.91081 .05479 L
.91118 .0553 L
.91151 .05588 L
.91219 .05754 L
.91277 .05955 L
.91334 .06224 L
.91386 .06561 L
.91423 .06892 L
.91449 .07233 L
.91461 .07439 L
.91469 .07634 L
.91475 .07855 L
.91478 .08094 L
.91478 .08335 L
.91476 .08473 L
.91474 .08602 L
.91467 .0884 L
.91456 .09095 L
.91443 .09326 L
.91428 .09542 L
.91385 .10032 L
.91324 .10555 L
.91255 .11018 L
.9116 .11535 L
.91058 .11981 L
.90846 .12677 L
.90721 .12984 L
.9058 .13258 L
.90453 .13449 L
.90329 .13587 L
.90257 .13647 L
.9019 .13691 L
.90116 .13725 L
.90038 .13745 L
.89961 .1375 L
.89917 .13745 L
.89877 .13737 L
.89804 .13711 L
.89726 .13668 L
.89658 .13616 L
.89594 .13557 L
Mistroke
.89452 .13382 L
.89306 .13135 L
.89178 .12859 L
.8904 .12481 L
.88923 .12083 L
.88745 .11285 L
.88668 .10827 L
.886 .1032 L
.88549 .09825 L
.88528 .09581 L
.88513 .09356 L
.88501 .09156 L
.88491 .08937 L
.88483 .0872 L
.88478 .08492 L
.88475 .08235 L
.88476 .08002 L
.88478 .07882 L
.88481 .07752 L
.88485 .07619 L
.8849 .07496 L
.88502 .07278 L
.88515 .07085 L
.88553 .06682 L
.88594 .06378 L
.88646 .06089 L
.88709 .05838 L
.88772 .05655 L
.88811 .05573 L
.88831 .05537 L
.88853 .05504 L
.88873 .05479 L
.88894 .05457 L
.88933 .05429 L
.8897 .05417 L
.8901 .05421 L
.89048 .0544 L
.89083 .0547 L
.89103 .05495 L
.89125 .05525 L
.89163 .05593 L
.89206 .05694 L
.89244 .05805 L
.89313 .06074 L
.8937 .06384 L
.89415 .06726 L
.89448 .07081 L
.89463 .073 L
.89473 .07507 L
.89478 .07625 L
Mistroke
.89482 .07755 L
.89486 .07997 L
.89488 .08236 L
.89487 .08375 L
.89485 .08506 L
.89482 .08645 L
.89478 .08773 L
.89466 .09065 L
.89453 .09314 L
.89434 .09588 L
.89389 .10085 L
.8933 .10578 L
.89266 .11013 L
.89184 .11462 L
.89082 .11919 L
.88977 .12309 L
.88871 .12635 L
.8864 .13167 L
.88499 .13399 L
.88366 .1356 L
.8829 .13629 L
.8825 .13659 L
.88207 .13686 L
.88128 .13724 L
.88054 .13744 L
.87987 .1375 L
.87915 .13743 L
.87846 .13725 L
.87784 .13697 L
.87715 .13654 L
.87641 .13594 L
.87494 .13428 L
.87338 .13179 L
.87203 .12896 L
.87058 .12509 L
.86934 .1209 L
.86746 .11241 L
.86661 .10718 L
.86597 .10217 L
.86549 .09717 L
.86516 .09257 L
.86503 .09005 L
.86498 .08873 L
.86493 .08732 L
.86487 .08478 L
.86485 .08247 L
.86486 .08019 L
.8649 .07779 L
.86497 .07559 L
.86506 .07363 L
Mistroke
.86516 .07191 L
.8653 .0701 L
.86564 .06667 L
.86589 .0647 L
.86616 .06297 L
.86673 .06011 L
.86742 .05761 L
.86784 .05649 L
.86824 .05565 L
.8686 .05507 L
.86894 .05466 L
.86932 .05435 L
.86973 .05418 L
.87014 .05419 L
.87034 .05427 L
.87057 .05439 L
.87096 .05475 L
.87132 .05522 L
.8717 .05589 L
.87209 .05678 L
.87275 .0588 L
.8734 .06157 L
.87372 .0634 L
.874 .06527 L
.87423 .06713 L
.87442 .06901 L
.87457 .0708 L
.87471 .07278 L
.87482 .07502 L
.8749 .07717 L
.87495 .07956 L
.87497 .08095 L
.87497 .08227 L
.87495 .0844 L
.8749 .08677 L
.87482 .08928 L
.87471 .09164 L
.87443 .0959 L
.87403 .10045 L
.8734 .10572 L
.87268 .11056 L
.87097 .11897 L
.86992 .12289 L
.86885 .12621 L
.86747 .12969 L
.86612 .13235 L
.86464 .13458 L
.86394 .1354 L
.86319 .13613 L
.86237 .13674 L
Mistroke
.86161 .13714 L
.86114 .13732 L
.8607 .13743 L
.85987 .1375 L
.8592 .13743 L
.85847 .13721 L
.8577 .13684 L
.857 .13636 L
.85575 .13517 L
.85445 .13344 L
.85299 .13086 L
.85169 .12789 L
.84949 .12111 L
.84849 .11706 L
.84766 .113 L
.84681 .1079 L
.84617 .10305 L
.84566 .09812 L
.84527 .09291 L
.84513 .09021 L
.84503 .08772 L
.84499 .0863 L
.84497 .08502 L
.84495 .08356 L
.84494 .08219 L
.84495 .08014 L
.84499 .07793 L
.84506 .07569 L
.84515 .07366 L
.84526 .07183 L
.84538 .07021 L
.84572 .0668 L
.84616 .06352 L
.84674 .06046 L
.84736 .05808 L
.84799 .05636 L
.84837 .05559 L
.84878 .05495 L
.84914 .05456 L
.84953 .05428 L
.84976 .0542 L
.84997 .05417 L
.8502 .05419 L
.85043 .05426 L
.85082 .05452 L
.85104 .05474 L
.85125 .05499 L
.8516 .05554 L
.85193 .05619 L
.85231 .05711 L
Mistroke
.85264 .0581 L
.85328 .06054 L
.85387 .06375 L
.85431 .06708 L
.85464 .07052 L
.85479 .07263 L
.8549 .07463 L
.85495 .07577 L
.85499 .07703 L
.85504 .07936 L
.85506 .08145 L
.85505 .0838 L
.85501 .0863 L
.85493 .08867 L
.85484 .09091 L
.85472 .09297 L
.85438 .09761 L
.85392 .10228 L
.85327 .10735 L
.8525 .11212 L
.85152 .11699 L
.85049 .1212 L
.84944 .12473 L
.84715 .13058 L
.84574 .13315 L
.84437 .13503 L
.84356 .13588 L
.84281 .1365 L
.8424 .13678 L
.84195 .13703 L
.84152 .13722 L
.84112 .13735 L
.84032 .13749 L
.83958 .13747 L
.83876 .13728 L
.8383 .1371 L
.83789 .13689 L
.83706 .13633 L
.83616 .13551 L
.83458 .13349 L
.83313 .13094 L
.83165 .12755 L
.83044 .12407 L
.82928 .11996 L
.82833 .11589 L
.82742 .11114 L
.82672 .10663 L
.82617 .10223 L
.82588 .09955 L
.82562 .09661 L
Mistroke
.82544 .09416 L
.82528 .09146 L
.82515 .08858 L
.8251 .08701 L
.82507 .08555 L
.82503 .08298 L
.82503 .08156 L
.82504 .08027 L
.82508 .07796 L
.82514 .07588 L
.82524 .07366 L
.82539 .07139 L
.82557 .06911 L
.82578 .06708 L
.82624 .06362 L
.82678 .06072 L
.82734 .05845 L
.82802 .05649 L
.82843 .05565 L
.82881 .05504 L
.82921 .05458 L
.82959 .0543 L
.8298 .05421 L
.83 .05417 L
.83023 .05418 L
.83045 .05423 L
.83084 .05446 L
.8312 .05481 L
.83158 .05534 L
.83198 .05608 L
.8326 .05768 L
.83322 .05988 L
.83374 .06241 L
.83416 .06507 L
.83456 .06858 L
.83475 .07074 L
.83489 .07282 L
.83499 .07471 L
.83508 .07687 L
.83513 .07919 L
.83515 .08143 L
.83514 .08386 L
.83512 .08524 L
.83509 .08651 L
.83501 .08899 L
.83491 .09136 L
.83474 .09414 L
.83455 .09671 L
.83399 .10249 L
.8334 .10709 L
Mistroke
.83262 .11197 L
.83165 .11686 L
.83064 .121 L
.82841 .12788 L
.82705 .13097 L
.82568 .13338 L
.82436 .13514 L
.82311 .13634 L
.82245 .1368 L
.82171 .13718 L
.82094 .13742 L
.82021 .1375 L
.81947 .13744 L
.81869 .13723 L
.81795 .13688 L
.81729 .13643 L
.81651 .13577 L
.81568 .13487 L
.81422 .13278 L
.81276 .12998 L
.81131 .1264 L
.81016 .12284 L
.80903 .1186 L
.8081 .11434 L
.80736 .11023 L
.80671 .10588 L
.8062 .10173 L
.80574 .09685 L
.80554 .09426 L
.80538 .09151 L
.80526 .0889 L
.80518 .08647 L
.80514 .08432 L
.80512 .08203 L
.80514 .07964 L
.80518 .07751 L
.80527 .07512 L
.80538 .07295 L
.80551 .07101 L
.80565 .06929 L
.80604 .06568 L
.80653 .06248 L
.80716 .05949 L
.8075 .05822 L
.8079 .05704 L
.80829 .05611 L
.80866 .05541 L
.80903 .05487 L
.80924 .05463 L
.80944 .05446 L
Mistroke
.80965 .05431 L
.80989 .05421 L
.81011 .05417 L
.81031 .05418 L
.81072 .05432 L
.81095 .05448 L
.81117 .05467 L
.81159 .05522 L
.81204 .05602 L
.81241 .05689 L
.8128 .05802 L
.81346 .06053 L
.81402 .06353 L
.81446 .06674 L
.81465 .06852 L
.81483 .0705 L
.81495 .07228 L
.81506 .07426 L
.81516 .07648 L
.81521 .0786 L
.81523 .07993 L
.81524 .0812 L
.81524 .08362 L
.8152 .0858 L
.81514 .08813 L
.81506 .09014 L
.81494 .09237 L
.81459 .09737 L
.81413 .10203 L
.81345 .10738 L
.81266 .11228 L
.8108 .12073 L
.80958 .12488 L
.80834 .12828 L
.80688 .13147 L
.80611 .13285 L
.80523 .13417 L
.80448 .13511 L
.80367 .13595 L
.80279 .13664 L
.8024 .13689 L
.80197 .13711 L
.80154 .13728 L
.80114 .13739 L
.80035 .1375 L
.79964 .13745 L
.79888 .13726 L
.79806 .13689 L
.79761 .1366 L
.79719 .13629 L
Mistroke
.79564 .1347 L
.79484 .13361 L
.79398 .13221 L
.79234 .12881 L
.79099 .1252 L
.78987 .12149 L
.78877 .11708 L
.78774 .11191 L
.78693 .10684 L
.78633 .102 L
.78587 .0973 L
.78551 .0923 L
.78539 .08982 L
.78529 .08714 L
.78524 .08464 L
.78522 .08237 L
.78523 .08015 L
.78526 .07819 L
.78532 .07599 L
.78541 .07398 L
.78554 .07185 L
.7857 .0697 L
.78607 .06613 L
.78657 .06274 L
.78722 .05961 L
.78785 .05743 L
.78848 .05591 L
.78884 .05527 L
.78924 .05474 L
.78962 .05439 L
.78998 .05421 L
.79031 .05417 L
.79061 .05423 L
.79095 .0544 L
.79131 .05473 L
.79168 .05521 L
.79203 .05581 L
.79265 .05729 L
.79299 .05833 L
.79334 .05962 L
.79392 .06236 L
.7944 .0655 L
.79477 .06876 L
.79494 .07072 L
.79507 .07264 L
.79518 .07483 L
.79524 .0761 L
.79527 .07727 L
.79532 .07969 L
.79534 .08109 L
Mistroke
.79534 .0824 L
.79532 .08484 L
.79525 .08748 L
.79517 .08977 L
.79506 .09189 L
.79474 .09671 L
.79434 .10094 L
.79383 .10535 L
.79237 .11427 L
.79135 .11893 L
.79028 .12292 L
.7891 .12655 L
.78774 .1299 L
.78615 .13293 L
.78541 .13404 L
.78461 .13507 L
.78384 .13588 L
.78312 .13648 L
.7824 .13694 L
.7817 .13725 L
.7809 .13746 L
.78014 .1375 L
.77932 .13737 L
.77886 .13722 L
.77845 .13704 L
.77773 .13662 L
.77697 .13602 L
.77564 .13459 L
.77426 .13253 L
.77281 .12969 L
.77164 .12678 L
.77046 .12324 L
.76861 .11591 L
.76772 .11125 L
.7669 .10592 L
.76628 .10072 L
.76584 .09583 L
Mfstroke
.93416 .09583 m
.95 .09583 L
s
.76584 .09583 m
.75 .09583 L
s
1 .753 .796 r
0 .03333 m
0 .22083 L
.05 .22083 L
.05 .03333 L
F
1 0 0 r
.25 .03333 m
.25 .15833 L
.4 .15833 L
.4 .03333 L
F
0 0 1 r
.6 .03333 m
.6 .15833 L
.75 .15833 L
.75 .03333 L
F
1 .753 .796 r
.95 .03333 m
.95 .22083 L
1 .22083 L
1 .03333 L
F
0 g
gsave
.15 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.325 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.675 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.85 .0125 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.15 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.325 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.675 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.85 .00417 -69 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 57.5625},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000>B000`400?l00000o`00003o0P3oool0
0`000000oooo0?ooo`0X0?ooo`D00000;@3oool5000002`0oooo1000000]0?ooo`@00000;`3oool2
000002X0oooo00020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;`3oool01000
0000oooo0?ooo`00000Y0?ooo`000P3oool00`000000oooo0?ooo`0Q0?ooo`80000000<0oooo0000
00000000103oool00`000000oooo0?ooo`0V0?ooo`80000000@0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`0U0?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0?ooo`0V
0?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo0?ooo`0W0?ooo`80000000<0
oooo000000000000103oool00`000000oooo0?ooo`0X0?ooo`000P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool09`3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool09P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo02H0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0W0?ooo`000P3oool00`000000oooo0?oo
o`0R0?ooo`<000001@3oool00`000000oooo0?ooo`0W0?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`0V0?ooo`<000000`3oool010000000oooo0?ooo`00000W0?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo02H0oooo0`000003
0?ooo`040000003oool0oooo000002T0oooo00020?ooo`030000003oool0oooo0280oooo00@00000
0?ooo`00000000000`3oool2000002P0oooo0`0000000`3oool000000?ooo`020?ooo`800000:03o
ool010000000oooo0000000000030?ooo`8000009`3oool3000000030?ooo`000000oooo0080oooo
0P00000Y0?ooo`040000003oool00000000000<0oooo0P00000Z0?ooo`000P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`0`0?ooo`000P3oool00`000000oooo0?ooo`0Q0?ooo`800000H@3oool200000640oooo0P00
000b0?ooo`000P3oool00`000000oooo0?ooo`3o0?oooa`0oooo00020?ooool00000700000030?oo
o`000P3oool>0?o0bcP0oooo:`3o000h0?ooob/0003o>03oool>0?o0b`@0oooo00020?ooo`h0ol3;
>03oool[0?l003P0oooo:`000?lh0?ooo`h0ol3;103oool00080oooo3P3o`</h0?ooob/0o`00>03o
ool[0000ocP0oooo3P3o`</40?ooo`000P3oool>0?o0bcP0oooo:`3o000h0?ooob/0003o>03oool>
0?o0b`@0oooo00020?ooo`h0ol3;>03oool[0?l003P0oooo:`000?lh0?ooo`h0ol3;103oool00080
oooo3P3o`</;0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0203oool[0?l000/0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`080?ooob/0003o2`3oool00`000000
oooo0?ooo`020?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00P3oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo00P0oooo3P3o`</40?ooo`000P3oool>0?o0b`X0oooo
0`0000030?ooo`800000103oool2000000<0oooo0`0000030?ooo`800000103oool2000000<0oooo
0`0000090?ooob/0o`002P3oool3000000<0oooo0P0000040?ooo`8000000`3oool3000000<0oooo
0P0000030?ooo`<000000`3oool3000000T0oooo:`000?l:0?ooo`<000000`3oool2000000@0oooo
0P0000030?ooo`<000000`3oool2000000<0oooo0`0000030?ooo`<000002@3oool>0?o0b`@0oooo
00020?ooo`h0ol3;2P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000030?ooo`<000000P3oool00`000000oooo0000
00030?ooo`030000003oool0000000T0oooo:`3o000:0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo0`00
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000002@3oool[0000o`X0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool300000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00090?ooo`h0ol3;103oool00080oooo3P3o`</:0?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool010000000oooo0000000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000T0oooo:`3o
000:0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool010000000oooo0000
000000020?ooo`030000003oool000000080oooo0P0000001`3oool000000?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo000000090?ooob/0003o2P3oool00`000000oooo000000030?oo
o`030000003oool000000080oooo00@000000?ooo`00000000000P3oool00`000000oooo00000002
0?ooo`80000000L0oooo0000003oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000
2@3oool>0?o0b`@0oooo00020?ooo`h0ol3;2P3oool00`000000oooo000000030?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000090?oo
ob/0o`002P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000090?ooob/0003o2P3oool00`000000oooo0000
00030?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000090?ooo`h0ol3;103oool00080oooo3P3o`</:0?ooo`030000003oool000000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0000000T0oooo:`3o000:0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000T0oooo:`000?l:
0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000000T0oooo3P3o`</40?ooo`000P3oool>0?o0b`X0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H0
00000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo000000090?ooob/0o`002P3oool01P000000oooo00000000
0000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`000000oooo00800000
00<0oooo0000003oool0203oool[0000o`X0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`050000003oool0oooo0000003oool00P0000000`3oool000000?oo
o`080?ooo`h0ol3;103oool00080oooo3P3o`</:0?ooo`060000003oool0oooo0000003oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000
oooo0?ooo`070?ooob/0o`002P3oool01P000000oooo0?ooo`000000oooo00000080oooo00@00000
0?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00@000000?ooo`3o
ool000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool01`3o
ool[0000o`X0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00L0oooo3P3o`</40?oo
o`000P3oool>0?o0b`X0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00L0oooo:`3o
000:0?ooo`060000003oool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000020?oo
o`060000003oool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`070?ooob/0003o2P3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`00
0000oooo00000080oooo00<000000?ooo`3oool01`3oool>0?o0b`@0oooo00020?ooo`h0ol3;2P3o
ool01P000000oooo0?ooo`000000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool01`3oool[0?l000X0oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo00L0oooo:`000?l:0?ooo`060000003oool0oooo0000003o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool0
0`000000oooo0?ooo`070?ooo`h0ol3;103oool00080oooo3P3o`</:0?ooo`060000003oool0oooo
0000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000002@3oool[0?l000X0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000oooo00P0
oooo:`000?l:0?ooo`060000003oool000000000003oool000000P3oool010000000oooo0?ooo`00
00020?ooo`060000003oool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000020?oo
o`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`070?ooo`h0ol3;103o
ool00080oooo3P3o`</:0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000T0oooo:`3o000:0?oo
o`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0000000T0oooo:`000?l:0?ooo`030000003oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0000000T0oooo3P3o`</40?ooo`000P3oool>0?o0b`D000001@3oool00`000000oooo0000
00020?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`060000003oool0oooo0000003o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000001@3oool4000002/0o`001@0000050?ooo`030000003oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
000000D0oooo1000000[0000o`D000001@3oool00`000000oooo000000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000050?oo
o`@000003P3o`</40?ooo`000P3oool>0?o0b`@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000050?ooo`040000003oool0oooo0?ooob/0o`00103oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000
00030?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000030?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool0oooo:`000?l40?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`3o
ool>0?o0b`@0oooo00020?ooo`h0ol3;103oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
000000D0oooo00@000000?ooo`3oool0oooo:`3o00040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000001@3oool010000000oooo0?ooo`3oool[0000o`@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000050?ooo`040000003oool0oooo0?ooo`h0ol3;103oool00080oooo
3P3o`</50?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3oool010000000oooo
0?ooo`3oool[0?l000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000050?ooo`04
0000003oool0oooo0?ooob/0003o103oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool00000
00D0oooo00@000000?ooo`3oool0oooo3P3o`</40?ooo`000P3oool>0?o0b`D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`800000103oool2000000<0oooo00<000000?oo
o`0000000`3oool2000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?oo
o`030000003oool0oooo0080oooo:`3o00050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000`3oool2000000@0oooo0P0000030?ooo`030000003oool0000000<0oooo0P0000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?oo
ob/0003o1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo0P0000040?oo
o`8000000`3oool00`000000oooo000000030?ooo`8000000`3oool00`000000oooo000000030?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool>0?o0b`@0oooo00020?ooo`h0
ol3;1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo0P0000040?ooo`80
00000`3oool00`000000oooo000000030?ooo`800000103oool2000000<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo:`3o00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool2000000@0oooo0P0000030?ooo`030000003oool0000000<0oooo0P0000040?ooo`80
00000`3oool2000000D0oooo00<000000?ooo`3oool00P3oool[0000o`D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`800000103oool2000000<0oooo00<000000?ooo`00
00000`3oool2000000@0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`h0
ol3;103oool00080oooo3P3o`</50?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo:`3o00050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo:`000?l50?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000
0`3oool2000000D0oooo00<000000?ooo`3oool00P3oool>0?o0b`@0oooo00020?ooo`h0ol3;1@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooob/0o`001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000103o
ool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooob/0003o1@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`800000103oool2000000<0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo3P3o`</40?ooo`000P3oool>0?o0b`H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo:`3o00060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooob/0003o1@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool>
0?o0b`@0oooo00020?ooo`h0ol3;1P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool20000
00@0oooo0P0000030?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool[0?l000H0oooo00<000000?ooo`3oool00P3oool20000
00<0oooo0P0000040?ooo`8000000`3oool2000000@0oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo:`000?l60?ooo`030000003oool0oooo
0080oooo0P0000030?ooo`800000103oool2000000<0oooo0P0000040?ooo`800000103oool20000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`h0ol3;103oool00080
oooo3P3o`</60?ooo`8000000P3oool00`000000oooo000000030?ooo`<000000`3oool2000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooob/0o`001P3oool200000080
oooo00<000000?ooo`0000000`3oool3000000<0oooo0P0000030?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool00`3oool[0000o`H0oooo0P0000020?ooo`030000003oool0000000<0
oooo0`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`h0ol3;103oool00080oooo3P3o`</70?ooo`050000003oool000000000003o
ool00P000000103oool000000000003oool400000080oooo00D000000?ooo`00000000000?ooo`02
000000060?ooo`000000oooo0?ooo`000000oooo0P0000020?ooo`030000003oool000000080oooo
0P0000000`3oool000000?ooo`050?ooob/0o`001`3oool01@000000oooo000000000000oooo0080
000000@0oooo000000000000oooo100000020?ooo`050000003oool000000000003oool00P000000
1P3oool000000?ooo`3oool000000?ooo`8000000P3oool00`000000oooo000000020?ooo`800000
00<0oooo0000003oool01@3oool[0000o`L0oooo00D000000?ooo`00000000000?ooo`0200000004
0?ooo`00000000000?ooo`@000000P3oool01@000000oooo000000000000oooo0080000000H0oooo
0000003oool0oooo0000003oool200000080oooo00<000000?ooo`0000000P3oool2000000030?oo
o`000000oooo00D0oooo3P3o`</40?ooo`000P3oool>0?o0b`P0oooo0P0000030?ooo`<000000`3o
ool2000000@0oooo0P0000030?ooo`<000000`3oool2000000<0oooo0`0000030?ooo`<000001P3o
ool[0?l000P0oooo0P0000030?ooo`<000000`3oool2000000@0oooo0P0000030?ooo`<000000`3o
ool2000000<0oooo0`0000030?ooo`<000001P3oool[0000o`P0oooo0P0000030?ooo`<000000`3o
ool2000000@0oooo0P0000030?ooo`800000103oool2000000<0oooo0`0000030?ooo`8000001`3o
ool>0?o0b`@0oooo00020?ooo`h0ol3;>03oool[0?l003P0oooo:`000?lh0?ooo`h0ol3;103oool0
0080oooo3P3o`</h0?ooob/0o`00>03oool[0000ocP0oooo3P3o`</40?ooo`000P3oool>0?o0bcP0
oooo:`3o000h0?ooob/0003o>03oool>0?o0b`@0oooo00020?ooo`h0ol3;>03oool[0?l003P0oooo
:`000?lh0?ooo`h0ol3;103oool00080oooo3P3o`</h0?ooob/0o`00>03oool[0000ocP0oooo3P3o
`</40?ooo`000P3oool>0?o0bcP0oooo:`3o000h0?ooob/0003o>03oool>0?o0b`@0oooo00020?oo
o`h0ol3;oP3oool>0?o0b`@0oooo00020?ooo`h0ol3;oP3oool>0?o0b`@0oooo00020?ooo`h0ol3;
oP3oool>0?o0b`@0oooo00020?ooo`h0ol3;oP3oool>0?o0b`@0oooo00020?ooo`h0ol3;oP3oool>
0?o0b`@0oooo00020?ooo`h0ol3;oP3oool>0?o0b`@0oooo00020?ooo`h0ol3;oP3oool>0?o0b`@0
oooo00020?ooo`h0ol3;oP3oool>0?o0b`@0oooo00020?ooo`h0ol3;oP3oool>0?o0b`@0oooo0002
0?ooo`h0ol3;oP3oool>0?o0b`@0oooo00020?ooo`h0ol3;oP3oool>0?o0b`@0oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {56.5625, 0}} -> {0, 0, 0, 0}}],
  "  \n\t",
  StyleBox["Figure 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Coupled masses with springs attached to walls at the left and right.  \n\n\
\tAssume that the masses slide on a frictionless surface and that the \
functions  ",
  Cell[BoxData[
      RowBox[{\(x[t]\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(y[t]\)}]]],
  "  denote the displacement from ",
  ButtonBox["static equilibrium",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/StaticEquilibrium.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " of the masses  ",
  Cell[BoxData[
      RowBox[{\(m\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(m\_2\)}]]],
  ", respectively.  It can be shown by using ",
  ButtonBox["Newton's second law",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/NewtonsSecondLaw.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["Hooke's law",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/physics/Spring.html"], None},
    ButtonStyle->"Hyperlink"],
  " that the system of  D. E.'s for  ",
  Cell[BoxData[
      RowBox[{\(x[t]\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(y[t]\)}]]],
  "  is  \n\n\t\t",
  Cell[BoxData[
      StyleBox[\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
              x\  + \ \(k\_2\) \((y - x)\)\n
        \(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\) - \ \(k\_3\) y\),
        FontWeight->"Bold"]]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Equal Masses, Unequal spring constants.  Find the general solution to \
the system of D. E.'s  and plot the solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\) - \ \(k\_3\) y\), "\n",
     
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 1, \ m\_2 = 1, \ k\_1 = 1, \ k\_2 = 4, \ 
      k\_3 = 1\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 1;\)\ \), "\n", 
    \(\(m\_2 = 1;\)\ \), "\n", 
    \(\(k\_1 = 1;\)\ \), "\n", 
    \(\(k\_2 = 4;\)\ \), "\n", 
    \(\(k\_3 = 1;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des := \n{m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - x[t])\), \n\ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
              k\_3\ \ y[t]\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t]\[Equal] - \!\(k\_2\)(y[t]-x[t]) - \!\(k\
\_3\)y[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x + k\_3\ \ y \[Equal] 
            0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]3\) \[ImaginaryI], \
\(\[PlusMinus]\[ImaginaryI]\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{"3", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], "=", 
          "1"}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ 3;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ y\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ y\_2[t, b\_1, 
          b\_2]\ ];\)\ \)}], "Input"],

Cell["We can verify these solutions.  ", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[
            t], "\< \[Equal] \>", \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
          k\_3\ \ y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[
            t], "\< \[Equal] \>", \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
          k\_3\ \ y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the same direction with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_1 = 1\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {8, t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Black, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in opposite directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2 = 3\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {8, t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Black, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "\n\nWe could plot infinitely many types of oscillation.  For illustration \
we plot the solution for the coefficients ",
  Cell[BoxData[
      \(a\_1 = 1, a\_2 = 1, b\_1 = 1, b\_2 = 1\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{X[t, 1, 1, 1, 1], Y[t, 1, 1, 1, 1]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-2.7\), 2.7}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-3\), 3, 1]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The oscillation for  \!\(a\_1\) = 1, \!\(a\_\(\(2\)\(\\\ \
\)\)\)= 1, \!\(b\_1\) = 1, \!\(b\_2\) = 1\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, 1, 1, 1, 1]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, 1, 1, 1, 1]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + X[t, 1, 1, 1, 1], t}, {6 + Y[t, 1, 1, 1, 1], t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{\(-1\), 9}, {0, 5  \[Pi]}}, 
        PlotStyle \[Rule] {Magenta, Cyan, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, AspectRatio \[Rule] 1, 
        AxesOrigin \[Rule] {\(-1\), 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The oscillation for  \!\(a\_1\) = 1, \!\(a\_\(\(2\)\(\\\ \
\)\)\)= 1, \!\(b\_1\) = 1, \!\(b\_2\) = 1\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, 1, 1, 1, 1]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, 1, 1, 1, 1]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Equal Masses, Unequal spring constants.  Find the general solution to \
the system of D. E.'s  and plot the solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\) - \ \(k\_3\) y\), "\n",
     
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 1, \ m\_2 = 1, \ k\_1 = 1, \ k\_2 = 2, \ 
      k\_3 = 1\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 1;\)\ \), "\n", 
    \(\(m\_2 = 1;\)\ \), "\n", 
    \(\(k\_1 = 1;\)\ \), "\n", 
    \(\(k\_2 = 2;\)\ \), "\n", 
    \(\(k\_3 = 1;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des = \n{m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - x[t])\), \n\ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
              k\_3\ \ y[t]\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t]\[Equal] - \!\(k\_2\)(y[t]-x[t]) - \!\(k\
\_3\)y[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x + k\_3\ \ y \[Equal] 
            0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]\[ImaginaryI]\) \@5, \
\(\[PlusMinus]\[ImaginaryI]\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{\(\@5\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], "=", 
          "1"}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ \@5;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ y\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ y\_2[t, b\_1, 
          b\_2]\ ];\)\ \)}], "Input"],

Cell["We can verify these solutions.  ", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_1[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[
            t], "\< \[Equal] \>", \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
          k\_3\ \ y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Given the D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(x[t_] = x\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(y[t_] = y\_2[t, a\_1, a\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", x[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute them into the D.E.'s\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        m\_1\ \ \(x''\)[t], "\< \[Equal] \>", \(-\ k\_1\)\ \ \ x[t]\  + \ 
          k\_2\ \ \((y[t] - x[t])\)];\)\), "\[IndentingNewLine]", 
    \(\(Print[\ 
        m\_2\ \ \(y''\)[
            t], "\< \[Equal] \>", \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
          k\_3\ \ y[t]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Do we have equality?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Simplify, des]]];\)\)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the same direction with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_1 = 1\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {8, t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Black, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in opposite directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2 = 3\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {8, t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Black, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Equal Masses, Equal spring constants.  Find the general solution to the \
system of D. E.'s  and plot the solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\) - \ \(k\_3\) y\), "\n",
     
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 1, \ m\_2 = 1, \ k\_1 = 1, \ k\_2 = 1, \ 
      k\_3 = 1\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 1;\)\ \), "\n", 
    \(\(m\_2 = 1;\)\ \), "\n", 
    \(\(k\_1 = 1;\)\ \), "\n", 
    \(\(k\_2 = 1;\)\ \), "\n", 
    \(\(k\_3 = 1;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des = \n{m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - x[t])\), \n\ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
              k\_3\ \ y[t]\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t]\[Equal] - \!\(k\_2\)(y[t]-x[t]) - \!\(k\
\_3\)y[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x + k\_3\ \ y \[Equal] 
            0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]\[ImaginaryI]\) \@3, \
\(\[PlusMinus]\[ImaginaryI]\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{\(\@3\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], "=", 
          "1"}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ \@3;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ y\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ y\_2[t, b\_1, 
          b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-1\), 1, 1\/2]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the same direction with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_1 = 1\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {8, t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Black, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in opposite directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2 = 3\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {8, t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Black, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Equal Masses, Unequal spring constants.  Find the general solution to \
the system of D. E.'s  and plot the solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\) - \ \(k\_3\) y\), "\n",
     
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 1, \ m\_2 = 1, \ k\_1 = 2, \ k\_2 = 1, \ 
      k\_3 = 1\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 1;\)\ \), "\n", 
    \(\(m\_2 = 1;\)\ \), "\n", 
    \(\(k\_1 = 2;\)\ \), "\n", 
    \(\(k\_2 = 1;\)\ \), "\n", 
    \(\(k\_3 = 1;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des = \n{m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - x[t])\), \n\ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
              k\_3\ \ y[t]\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t]\[Equal] - \!\(k\_2\)(y[t]-x[t]) - \!\(k\
\_3\)y[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x + k\_3\ \ y \[Equal] 
            0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]\[ImaginaryI]\) \@\(5\/2 + \@5\/2\), \(\[PlusMinus]\
\[ImaginaryI]\) \@\(5\/2 - \@5\/2\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{\(\@\(5\/2 + \@5\/2\)\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], 
          "=", \(\@\(5\/2 - \@5\/2\)\)}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ \@\(5\/2 + \@5\/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ \@\(5\/2 - \@5\/2\);\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", 
        Simplify[Y[t, a\_1, a\_2, b\_1, b\_2]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ Simplify[
          y\_1[t, a\_1, a\_2]]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ Simplify[
          y\_2[t, b\_1, b\_2]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], 
            Chop[Range[\(-1\), 1, 0.2]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ y\_1[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1.7\), 1.7}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-2\), 2, 0.5]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ y\_2[t, 1, 
          0]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in the same direction with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_1 = 1\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {6 + y\_1[t, 1, 0], t}, {8, t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Black, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 6. \
 The two masses move in opposite directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2 = 3\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {6 + y\_2[t, 1, 0], t}, {8, t}, {2, 
              t}, {6, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Black, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ Simplify[
          y\_2[t, 1, 0]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Unequal Masses, Equal spring constants.  Find the general solution to \
the system of D. E.'s  and plot the solution curves. \n\n\t",
  Cell[BoxData[{\(\(m\_1\) \(x'\)' = \(-\ k\_1\) 
            x\  + \ \(k\_2\) \((y - x)\)\), 
    "\n", \(\(m\_2\) \(y'\)' = \(-\ k\_2\) \((y - x)\) - \ \(k\_3\) y\), "\n",
     
      RowBox[{
        StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  "}], 
    "\[IndentingNewLine]", \(m\_1 = 2, \ m\_2 = 1, \ k\_1 = 1, \ k\_2 = 1, \ 
      k\_3 = 1\)}]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(m\_1 = 2;\)\ \), "\n", 
    \(\(m\_2 = 1;\)\ \), "\n", 
    \(\(k\_1 = 1;\)\ \), "\n", 
    \(\(k\_2 = 1;\)\ \), "\n", 
    \(\(k\_3 = 1;\)\ \), "\n", 
    \(\(Clear[t, x, y];\)\), "\[IndentingNewLine]", 
    \(\(des = \n{m\_1\ \ \(x''\)[t] \[Equal] \(-\ k\_1\)\ \ \ x[t]\  + \ 
              k\_2\ \ \((y[t] - x[t])\), \n\ \ m\_2\ \ \(y''\)[
                t] \[Equal] \(-\ k\_2\)\ \ \((y[t] - x[t])\) - 
              k\_3\ \ y[t]\ };\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_1\)x''[t] \[Equal] - \!\(k\_1\)x[t] + \
\!\(k\_2\)(y[t]-x[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(m\_2\)y''[t]\[Equal] - \!\(k\_2\)(y[t]-x[t]) - \!\(k\
\_3\)y[t]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system of D.E.'s\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[MapAll[Expand, des]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Put the D.E.'s in operator form and eliminate ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " to obtain a fourth order D.E. for ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and find the roots of its characteristic equation. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[r, x, y];\)\ \), "\n", 
    \(\(eqns = {m\_1\ \ D\^2\ x + \ k\_1\ \ x\  + \ k\_2\ \ x - \ 
              k\_2\ \ y \[Equal] 
            0, \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\_2\ \ \(D\^2\) y + \ 
              k\_2\ \ y - \ k\_2\ \ x + k\_3\ \ y \[Equal] 
            0\ };\)\ \), "\n", 
    \(\(eqn1 = Eliminate[eqns, y];\)\ \), "\n", 
    \(\(eqn2 = ReplaceAll[eqn1, {x \[Rule] 1, D \[Rule] r}];\)\ \), "\n", 
    \(\(solset = Solve[eqn2, r];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the system\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Use operator notation\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Eliminate y and get\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The characteristic equation for x is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\ \)}], "Input"],

Cell[TextData[{
  "The roots are pure complex,  ",
  Cell[BoxData[
      \(r = \(\[PlusMinus]\[ImaginaryI]\) \@\(3\/2 + \@3\/2\), \(\[PlusMinus]\
\[ImaginaryI]\) \@\(3\/2 - \@3\/2\)\)]],
  ", and the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "=", 
        RowBox[{
          RowBox[{\(\@\(3\/2 + \@3\/2\)\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}], 
          "=", \(\@\(3\/2 - \@3\/2\)\)}]}]]],
  ",  respectively.  The general solution is formed as follows. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]\_1\  = \ \@\(3\/2 + \@3\/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]\_2\  = \ \@\(3\/2 - \@3\/2\);\)\), "\[IndentingNewLine]", 
    \(\(X[t_, a1_, a2_, b1_, b2_] = \ 
        a1\ \ Cos[\(\[Omega]\_1\) t] + a2\ \ Sin[\(\[Omega]\_1\) t]\  + 
          b1\ \ Cos[\(\[Omega]\_2\) t] + 
          b2\ \ Sin[\(\[Omega]\_2\) t];\)\ \), "\n", 
    \(\(Z[t_] = X[t, a1, a2, b1, b2];\)\), "\[IndentingNewLine]", 
    \(\(Y[t_, a1_, a2_, b1_, b2_] = 
        Expand[\((m\_1\ \ \(Z''\)[t] + \ k\_1\ \ Z[t]\  + \ k\_2\ \ Z[t])\)/\ 
            k\_2\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Given the system of D.E.'s\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[des]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The general solution is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<x[t] = \>", X[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Y[t, a\_1, a\_2, b\_1, b\_2]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The ",
  ButtonBox["eigenfrequencies",
    ButtonData:>{
      URL[ 
      "http://scienceworld.wolfram.com/physics/\
SpringsThreeSpringsandTwoMasses.html"], None},
    ButtonStyle->"Hyperlink"],
  " can be obtained by taking the square root of the eigenvalues of the \
matrix ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
            {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
            }], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(-\((\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
              {\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Print", "[", "\"\<A = (\!\(\*GridBox[{
{\(\(-\((\\\ k\_1 + k\_2)\)\)/m\_1\), \(k\_2/m\_1\)},
{\(k\_2/m\_2\), \(\(-\((k\_2 + k\_3)\)\)/m\_2\)}
}]\))\>\"", "]"}], 
      ";"}], "\[IndentingNewLine]", \(Print["\<A = \>", 
        MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<      Eigenvalues = \>", 
        Eigenvalues[
          A]];\), "\[IndentingNewLine]", \(Print["\<Eigen frequencies = \>", 
        Im[\@Eigenvalues[A]]];\)}], "Input"],

Cell[TextData[{
  "It is useful to look at the two natural modes of oscillation of the spring \
mass system and they exhibit the natural frequencies  ",
  Cell[BoxData[
      RowBox[{\(\[Omega]\_1\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(\[Omega]\_2\)}]]],
  ",  respectively. "
}], "Text"],

Cell[BoxData[{
    \(\(x\_1[t_, a1_, a2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_1[t_, a1_, a2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {b1 \[Rule] 0, b2 \[Rule] 0}];\)\ \), "\n", 
    \(\(x\_2[t_, b1_, b2_] = 
        ReplaceAll[
          X[t, a1, a2, b1, b2], {a1 \[Rule] 0, a2 \[Rule] 0}];\)\ \), "\n", 
    \(\(y\_2[t_, b1_, b2_] = 
        ReplaceAll[
          Y[t, a1, a2, b1, b2], {a1 \[Rule] 0, 
            a2 \[Rule] 0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,a1,a2] = \>\"", \ \ x\_1[t, a\_1, 
          a\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,a1,a2] = \>\"", \ \ Simplify[
          y\_1[t, a\_1, a\_2]]\ ];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,b1,b2] = \>\"", \ \ x\_2[t, b\_1, 
          b\_2]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,b1,b2] = \>\"", \ \ Simplify[
          y\_2[t, b\_1, b\_2]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_1[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_1[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in opposite \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_1[t, 1, 0], y\_1[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-3\), 3}}, 
        PlotStyle \[Rule] {Red, Blue}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], Range[\(-3\), 3, 1]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Plot the functions  ",
  Cell[BoxData[
      \(x\_2[t, 1, 0]\)]],
  " and  ",
  Cell[BoxData[
      \(y\_2[t, 1, 0]\)]],
  ".  In this mode of oscillation the masses are moving in the same \
directions. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[\ 
        Evaluate[{x\_2[t, 1, 0], y\_2[t, 1, 0]}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotRange \[Rule] {{0, 5  \[Pi]}, {\(-1\), 1}}, 
        PlotStyle \[Rule] {Magenta, Cyan}, 
        Ticks \[Rule] {Range[0, 5  \[Pi], \[Pi]], 
            Chop[Range[\(-1\), 1, 0.2]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_2\)[t,1,0] = \>\"", \ \ x\_2[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_2\)[t,1,0] = \>\"", \ \ Simplify[
          y\_2[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 7. \
 The two masses move in the same direction with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_1 = 1\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_1[t, 1, 0], t}, {7 + y\_1[t, 1, 0], t}, {11, 
              t}, {2, t}, {7, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Red, Blue, Black, Magenta, Cyan}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {6, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The first natural mode of oscillation has frequency \!\(\
\[Omega]\_1\) = \>\"", \[Omega]\_1];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Assume that the equilibrium position along the horizontal axis is 2 and 7. \
 The two masses move in opposite directions with the frequency ",
  Cell[BoxData[
      \(\[Omega]\_2 = 3\)]],
  ",\nas seen in the next graph, where time is along the vertical axis. "
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[\ 
        Evaluate[{{2 + x\_2[t, 1, 0], t}, {7 + y\_2[t, 1, 0], t}, {11, 
              t}, {2, t}, {7, t}}\ ], \ {t, 0, 5  \[Pi]}, 
        PlotStyle \[Rule] {Magenta, Cyan, Black, Red, Blue}, 
        Ticks \[Rule] {{{2, "\<x[t]\>"}, {7, "\<y[t]\>"}}, 
            Range[0, 5  \[Pi], \[Pi]]}, 
        AspectRatio \[Rule] 1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(k\_1\) = \>\"", k\_1, \*"\"\<,  \!\(m\_1\) = \>\"", 
        m\_1, \*"\"\<,  \!\(k\_2\) = \>\"", 
        k\_2, \*"\"\<,  \!\(m\_2\) = \>\"", 
        m\_2, \*"\"\<,  \!\(k\_3\) = \>\"", 
        k\_3];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The second natural mode of oscillation has frequency \
\!\(\[Omega]\_2\) = \>\"", \[Omega]\_2];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(x\_1\)[t,1,0] = \>\"", \ \ x\_1[t, 1, 
          0]\ ];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(y\_1\)[t,1,0] = \>\"", \ \ Simplify[
          y\_1[t, 1, 0]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Spring Mass Systems",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/N310/projects2/e13.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Spring Mass Oscillations",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/N310/projects2/e13.htm"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Spring Mass Oscillations",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/SpringMassBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Spring Mass Oscillations",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/SpringMassBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1005, 657},
WindowMargins->{{0, Automatic}, {0, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 185, 4, 35, "Text"],
Cell[1964, 59, 1465, 49, 99, "Text"]
}, Closed]],
Cell[3444, 111, 42299, 1765, 302, "Text"],
Cell[45746, 1878, 582, 19, 41, "Text"],
Cell[46331, 1899, 799, 21, 126, "Text"],

Cell[CellGroupData[{
Cell[47155, 1924, 101, 2, 33, "Text"],
Cell[47259, 1928, 1118, 22, 270, "Input"],
Cell[48380, 1952, 274, 8, 33, "Text"],
Cell[48657, 1962, 1154, 19, 332, "Input"],
Cell[49814, 1983, 729, 20, 43, "Text"],
Cell[50546, 2005, 949, 15, 232, "Input"],
Cell[51498, 2022, 581, 19, 41, "Text"],
Cell[52082, 2043, 743, 17, 138, "Input"],
Cell[52828, 2062, 535, 14, 33, "Text"],
Cell[53366, 2078, 1313, 26, 230, "Input"],
Cell[54682, 2106, 48, 0, 33, "Text"],
Cell[54733, 2108, 1118, 19, 270, "Input"],
Cell[55854, 2129, 1119, 19, 270, "Input"],
Cell[56976, 2150, 235, 9, 33, "Text"],
Cell[57214, 2161, 748, 13, 145, "Input"],
Cell[57965, 2176, 235, 9, 33, "Text"],
Cell[58203, 2187, 753, 13, 145, "Input"],
Cell[58959, 2202, 291, 6, 52, "Text"],
Cell[59253, 2210, 1002, 18, 150, "Input"],
Cell[60258, 2230, 283, 6, 52, "Text"],
Cell[60544, 2238, 933, 17, 130, "Input"],
Cell[61480, 2257, 307, 9, 71, "Text"],
Cell[61790, 2268, 708, 11, 130, "Input"],
Cell[62501, 2281, 765, 12, 130, "Input"]
}, Closed]],
Cell[63281, 2296, 758, 21, 123, "Text"],

Cell[CellGroupData[{
Cell[64064, 2321, 101, 2, 33, "Text"],
Cell[64168, 2325, 1117, 22, 270, "Input"],
Cell[65288, 2349, 274, 8, 33, "Text"],
Cell[65565, 2359, 1154, 19, 332, "Input"],
Cell[66722, 2380, 715, 20, 33, "Text"],
Cell[67440, 2402, 944, 15, 210, "Input"],
Cell[68387, 2419, 581, 19, 41, "Text"],
Cell[68971, 2440, 743, 17, 138, "Input"],
Cell[69717, 2459, 535, 14, 33, "Text"],
Cell[70255, 2475, 1313, 26, 230, "Input"],
Cell[71571, 2503, 48, 0, 33, "Text"],
Cell[71622, 2505, 1118, 19, 270, "Input"],
Cell[72743, 2526, 1119, 19, 270, "Input"],
Cell[73865, 2547, 235, 9, 33, "Text"],
Cell[74103, 2558, 748, 13, 145, "Input"],
Cell[74854, 2573, 235, 9, 33, "Text"],
Cell[75092, 2584, 753, 13, 145, "Input"],
Cell[75848, 2599, 291, 6, 52, "Text"],
Cell[76142, 2607, 1002, 18, 150, "Input"],
Cell[77147, 2627, 283, 6, 52, "Text"],
Cell[77433, 2635, 933, 17, 130, "Input"]
}, Closed]],
Cell[78381, 2655, 758, 21, 123, "Text"],

Cell[CellGroupData[{
Cell[79164, 2680, 101, 2, 33, "Text"],
Cell[79268, 2684, 1065, 21, 250, "Input"],
Cell[80336, 2707, 274, 8, 33, "Text"],
Cell[80613, 2717, 1154, 19, 332, "Input"],
Cell[81770, 2738, 737, 20, 43, "Text"],
Cell[82510, 2760, 934, 15, 234, "Input"],
Cell[83447, 2777, 581, 19, 41, "Text"],
Cell[84031, 2798, 743, 17, 138, "Input"],
Cell[84777, 2817, 535, 14, 33, "Text"],
Cell[85315, 2833, 1313, 26, 230, "Input"],
Cell[86631, 2861, 48, 0, 33, "Text"],
Cell[86682, 2863, 1118, 19, 270, "Input"],
Cell[87803, 2884, 1119, 19, 270, "Input"],
Cell[88925, 2905, 235, 9, 33, "Text"],
Cell[89163, 2916, 777, 14, 145, "Input"],
Cell[89943, 2932, 235, 9, 33, "Text"],
Cell[90181, 2943, 802, 14, 158, "Input"],
Cell[90986, 2959, 291, 6, 52, "Text"],
Cell[91280, 2967, 1017, 18, 150, "Input"],
Cell[92300, 2987, 283, 6, 52, "Text"],
Cell[92586, 2995, 948, 17, 130, "Input"]
}, Closed]],
Cell[93549, 3015, 758, 21, 123, "Text"],

Cell[CellGroupData[{
Cell[94332, 3040, 101, 2, 33, "Text"],
Cell[94436, 3044, 1065, 21, 250, "Input"],
Cell[95504, 3067, 274, 8, 33, "Text"],
Cell[95781, 3077, 1154, 19, 332, "Input"],
Cell[96938, 3098, 781, 20, 57, "Text"],
Cell[97722, 3120, 976, 16, 226, "Input"],
Cell[98701, 3138, 581, 19, 41, "Text"],
Cell[99285, 3159, 743, 17, 138, "Input"],
Cell[100031, 3178, 535, 14, 33, "Text"],
Cell[100569, 3194, 1313, 26, 230, "Input"],
Cell[101885, 3222, 235, 9, 33, "Text"],
Cell[102123, 3233, 783, 14, 130, "Input"],
Cell[102909, 3249, 235, 9, 33, "Text"],
Cell[103147, 3260, 798, 14, 130, "Input"],
Cell[103948, 3276, 291, 6, 52, "Text"],
Cell[104242, 3284, 1017, 18, 150, "Input"],
Cell[105262, 3304, 283, 6, 52, "Text"],
Cell[105548, 3312, 948, 17, 130, "Input"]
}, Closed]],
Cell[106511, 3332, 801, 21, 124, "Text"],

Cell[CellGroupData[{
Cell[107337, 3357, 101, 2, 33, "Text"],
Cell[107441, 3361, 1067, 21, 252, "Input"],
Cell[108511, 3384, 274, 8, 33, "Text"],
Cell[108788, 3394, 1154, 19, 332, "Input"],
Cell[109945, 3415, 787, 20, 57, "Text"],
Cell[110735, 3437, 981, 17, 243, "Input"],
Cell[111719, 3456, 581, 19, 41, "Text"],
Cell[112303, 3477, 743, 17, 138, "Input"],
Cell[113049, 3496, 535, 14, 33, "Text"],
Cell[113587, 3512, 1333, 26, 230, "Input"],
Cell[114923, 3540, 235, 9, 33, "Text"],
Cell[115161, 3551, 787, 14, 130, "Input"],
Cell[115951, 3567, 235, 9, 33, "Text"],
Cell[116189, 3578, 789, 14, 130, "Input"],
Cell[116981, 3594, 291, 6, 52, "Text"],
Cell[117275, 3602, 1013, 18, 150, "Input"],
Cell[118291, 3622, 283, 6, 52, "Text"],
Cell[118577, 3630, 944, 17, 130, "Input"]
}, Closed]],
Cell[119536, 3650, 59413, 2518, 302, "Text"],
Cell[178952, 6170, 595, 19, 41, "Text"],
Cell[179550, 6191, 831, 22, 126, "Text"],

Cell[CellGroupData[{
Cell[180406, 6217, 101, 2, 33, "Text"],
Cell[180510, 6221, 1131, 22, 290, "Input"],
Cell[181644, 6245, 274, 8, 33, "Text"],
Cell[181921, 6255, 1181, 20, 332, "Input"],
Cell[183105, 6277, 715, 20, 33, "Text"],
Cell[183823, 6299, 944, 15, 210, "Input"],
Cell[184770, 6316, 594, 19, 41, "Text"],
Cell[185367, 6337, 769, 17, 138, "Input"],
Cell[186139, 6356, 535, 14, 33, "Text"],
Cell[186677, 6372, 1313, 26, 230, "Input"],
Cell[187993, 6400, 48, 0, 33, "Text"],
Cell[188044, 6402, 1144, 20, 270, "Input"],
Cell[189191, 6424, 1145, 20, 270, "Input"],
Cell[190339, 6446, 235, 9, 33, "Text"],
Cell[190577, 6457, 748, 13, 145, "Input"],
Cell[191328, 6472, 235, 9, 33, "Text"],
Cell[191566, 6483, 753, 13, 145, "Input"],
Cell[192322, 6498, 291, 6, 52, "Text"],
Cell[192616, 6506, 1064, 19, 150, "Input"],
Cell[193683, 6527, 292, 6, 52, "Text"],
Cell[193978, 6535, 993, 18, 130, "Input"],
Cell[194974, 6555, 307, 9, 71, "Text"],
Cell[195284, 6566, 708, 11, 130, "Input"],
Cell[195995, 6579, 764, 12, 130, "Input"]
}, Closed]],
Cell[196774, 6594, 831, 22, 123, "Text"],

Cell[CellGroupData[{
Cell[197630, 6620, 101, 2, 33, "Text"],
Cell[197734, 6624, 1130, 22, 290, "Input"],
Cell[198867, 6648, 274, 8, 33, "Text"],
Cell[199144, 6658, 1181, 20, 332, "Input"],
Cell[200328, 6680, 721, 20, 33, "Text"],
Cell[201052, 6702, 946, 15, 212, "Input"],
Cell[202001, 6719, 594, 19, 41, "Text"],
Cell[202598, 6740, 769, 17, 138, "Input"],
Cell[203370, 6759, 535, 14, 33, "Text"],
Cell[203908, 6775, 1313, 26, 230, "Input"],
Cell[205224, 6803, 48, 0, 33, "Text"],
Cell[205275, 6805, 1144, 20, 270, "Input"],
Cell[206422, 6827, 1145, 20, 270, "Input"],
Cell[207570, 6849, 235, 9, 33, "Text"],
Cell[207808, 6860, 678, 12, 125, "Input"],
Cell[208489, 6874, 235, 9, 33, "Text"],
Cell[208727, 6885, 753, 13, 145, "Input"],
Cell[209483, 6900, 291, 6, 52, "Text"],
Cell[209777, 6908, 1064, 19, 150, "Input"],
Cell[210844, 6929, 292, 6, 52, "Text"],
Cell[211139, 6937, 993, 18, 130, "Input"]
}, Closed]],
Cell[212147, 6958, 829, 22, 123, "Text"],

Cell[CellGroupData[{
Cell[213001, 6984, 101, 2, 33, "Text"],
Cell[213105, 6988, 1130, 22, 290, "Input"],
Cell[214238, 7012, 274, 8, 33, "Text"],
Cell[214515, 7022, 1181, 20, 332, "Input"],
Cell[215699, 7044, 721, 20, 33, "Text"],
Cell[216423, 7066, 946, 15, 212, "Input"],
Cell[217372, 7083, 594, 19, 41, "Text"],
Cell[217969, 7104, 769, 17, 138, "Input"],
Cell[218741, 7123, 535, 14, 33, "Text"],
Cell[219279, 7139, 1313, 26, 230, "Input"],
Cell[220595, 7167, 235, 9, 33, "Text"],
Cell[220833, 7178, 748, 13, 145, "Input"],
Cell[221584, 7193, 235, 9, 33, "Text"],
Cell[221822, 7204, 753, 13, 145, "Input"],
Cell[222578, 7219, 291, 6, 52, "Text"],
Cell[222872, 7227, 1064, 19, 150, "Input"],
Cell[223939, 7248, 292, 6, 52, "Text"],
Cell[224234, 7256, 993, 18, 130, "Input"]
}, Closed]],
Cell[225242, 7277, 831, 22, 123, "Text"],

Cell[CellGroupData[{
Cell[226098, 7303, 101, 2, 33, "Text"],
Cell[226202, 7307, 1130, 22, 290, "Input"],
Cell[227335, 7331, 274, 8, 33, "Text"],
Cell[227612, 7341, 1181, 20, 332, "Input"],
Cell[228796, 7363, 793, 20, 70, "Text"],
Cell[229592, 7385, 999, 16, 287, "Input"],
Cell[230594, 7403, 594, 19, 41, "Text"],
Cell[231191, 7424, 769, 17, 138, "Input"],
Cell[231963, 7443, 535, 14, 33, "Text"],
Cell[232501, 7459, 1333, 26, 230, "Input"],
Cell[233837, 7487, 235, 9, 33, "Text"],
Cell[234075, 7498, 766, 14, 130, "Input"],
Cell[234844, 7514, 235, 9, 33, "Text"],
Cell[235082, 7525, 756, 13, 130, "Input"],
Cell[235841, 7540, 291, 6, 52, "Text"],
Cell[236135, 7548, 1074, 19, 150, "Input"],
Cell[237212, 7569, 292, 6, 52, "Text"],
Cell[237507, 7577, 1003, 18, 130, "Input"]
}, Closed]],
Cell[238525, 7598, 832, 22, 123, "Text"],

Cell[CellGroupData[{
Cell[239382, 7624, 102, 2, 33, "Text"],
Cell[239487, 7628, 1130, 22, 290, "Input"],
Cell[240620, 7652, 274, 8, 33, "Text"],
Cell[240897, 7662, 1181, 20, 332, "Input"],
Cell[242081, 7684, 793, 20, 70, "Text"],
Cell[242877, 7706, 980, 15, 287, "Input"],
Cell[243860, 7723, 594, 19, 41, "Text"],
Cell[244457, 7744, 769, 17, 138, "Input"],
Cell[245229, 7763, 535, 14, 33, "Text"],
Cell[245767, 7779, 1333, 26, 230, "Input"],
Cell[247103, 7807, 235, 9, 33, "Text"],
Cell[247341, 7818, 755, 13, 130, "Input"],
Cell[248099, 7833, 235, 9, 33, "Text"],
Cell[248337, 7844, 781, 14, 130, "Input"],
Cell[249121, 7860, 291, 6, 52, "Text"],
Cell[249415, 7868, 1075, 19, 150, "Input"],
Cell[250493, 7889, 292, 6, 52, "Text"],
Cell[250788, 7897, 1004, 18, 130, "Input"]
}, Closed]],
Cell[251807, 7918, 752, 22, 30, "Text"],
Cell[252562, 7942, 158, 3, 35, "Text"],
Cell[252723, 7947, 563, 16, 33, "Text"],
Cell[253289, 7965, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

