(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37445,       1083]*)
(*NotebookOutlinePosition[     38139,       1107]*)
(*  CellTagsIndexPosition[     38095,       1103]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Parabolic P.D.E.'s",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background for Parabolic Equations",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Heat Equation",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["As an example of ",
    FontFamily->"Times New Roman"],
  ButtonBox["parabolic partial differential equations",
    ButtonData:>{
      URL[ 
      "http://mathworld.wolfram.com/ParabolicPartialDifferentialEquation.\
html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[", we consider the one-dimensional ",
    FontFamily->"Times New Roman"],
  ButtonBox["heat equation",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/HeatConductionEquation.html"], None},
    
    ButtonStyle->"Hyperlink"],
  StyleBox["  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(u\_t\) \((x, t)\) = \(c\^2\) \(u\_xx\) \((x, t)\)\)]],
  StyleBox["    for   ",
    FontFamily->"Times New Roman"],
  StyleBox["0 < x < a",
    FontFamily->"Courier New"],
  StyleBox["   and   ",
    FontFamily->"Times New Roman"],
  StyleBox["0 < t < b",
    FontFamily->"Courier New"],
  StyleBox[".  \n\t\nwith the initial condition  \n\n\t\t",
    FontFamily->"Times New Roman"],
  "   ",
  Cell[BoxData[
      \(u \((x, 0)\) = f \((x)\)\)]],
  StyleBox["    for    ",
    FontFamily->"Times New Roman"],
  StyleBox["t = 0",
    FontFamily->"Courier New"],
  StyleBox["   and    ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(0\  \[LessEqual] \ x\  \[LessEqual] a\),
        FontFamily->"Courier New"]]],
  StyleBox[".  \n\nand the boundary conditions  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(u \((0, t)\)\  = \ \(\(g\_1\) \((t)\)\  = \ c\_1\)\)]],
  "    for",
  StyleBox["   ",
    FontFamily->"Times New Roman"],
  StyleBox["x = 0",
    FontFamily->"Courier New"],
  StyleBox["   and    ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(0\  \[LessEqual] \ t\  \[LessEqual] b\),
        FontFamily->"Courier New"]]],
  StyleBox[",   ",
    FontFamily->"Times New Roman"],
  "\n\t\t\n\t\t",
  Cell[BoxData[
      \(u \((a, t)\)\  = \ \(\(g\_2\) \((t)\)\  = \ c\_2\)\)]],
  "    for",
  StyleBox["   ",
    FontFamily->"Times New Roman"],
  StyleBox["x = a",
    FontFamily->"Courier New"],
  StyleBox["   and    ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(0\  \[LessEqual] \ t\  \[LessEqual] b\),
        FontFamily->"Courier New"]]],
  StyleBox[".  \n\n",
    FontFamily->"Times New Roman"],
  StyleBox["The heat equation models the temperature in an insulated rod with \
ends held at constant temperatures ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(c\_1\)]],
  StyleBox[" and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(c\_2\)]],
  StyleBox[" and the initial temperature distribution along the rod being   ",
    
    FontFamily->"Times-Roman"],
  StyleBox["f(x)",
    FontFamily->"Courier New"],
  StyleBox[".  Although analytic solutions to the heat equation can be \
obtained with Fourier series, we use the problem as a prototype of a \
parabolic equation for numerical solution.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CrankNicolsonProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CrankNicolsonProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CrankNicolsonProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CrankNicolsonProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Program ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" (Forward-Difference method for the heat equation)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To approximate the solution of the heat equation  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(u\_t\) \((x, t)\) = \(c\^2\) \(u\_xx\) \((x, t)\)\)]],
  "  ",
  StyleBox["over the rectangle  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["R",
          FontWeight->"Bold",
          FontSlant->"Italic"], 
        "=", \({\((x, t)\) : 0 \[LessEqual] x \[LessEqual] a, 
          0 \[LessEqual] t \[LessEqual] b}\)}]]],
  "  with    ",
  Cell[BoxData[
      \(u \((x, 0)\) = f \((x)\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] x \[LessEqual] a\)]],
  ".  and  ",
  Cell[BoxData[
      RowBox[{\(u \((0, t)\)\), "=", 
        RowBox[{
          RowBox[{\(c\_1\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", "u", \((a, t)\)}], 
          "=", \(c\_2\)}]}]]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] b\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(FDgrid[n_, 
          m_] := \[IndentingNewLine]Module[{i, j}, \[IndentingNewLine]u\  = \ 
            Table[1, {n}, {m}]; \ \ \[IndentingNewLine]For[\ i = 1, \ 
            i \[LessEqual] 
              n, \ \(i++\), \
\[IndentingNewLine]\(u\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\)\  = \ f[i];\)\ ]; \ \[IndentingNewLine]For[\ 
            j = 1, \ j \[LessEqual] 
              m, \ \(j++\), \
\[IndentingNewLine]u\_\(\(\[LeftDoubleBracket]\)\(1, j\)\(\
\[RightDoubleBracket]\)\)\  = \ 
              g\_1[j]; \ \ \
\[IndentingNewLine]u\_\(\(\[LeftDoubleBracket]\)\(n, j\)\(\
\[RightDoubleBracket]\)\)\  = \ g\_2[j];\ ];\ ];\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(FDsolve[n_, 
          m_] := \[IndentingNewLine]Module[{i, 
            j}, \[IndentingNewLine]\(For[\ j = 2, \ 
              j \[LessEqual] 
                m, \ \(j++\), \[IndentingNewLine]\(For[\ i = 2, \ 
                  i \[LessEqual] 
                    n - 1, \ \(i++\), \[IndentingNewLine]u\_\(\(\
\[LeftDoubleBracket]\)\(i, j\)\(\[RightDoubleBracket]\)\)\  = \ \((1 - 
                            2\ r)\)\ u\_\(\(\[LeftDoubleBracket]\)\(i, j - \
1\)\(\[RightDoubleBracket]\)\) + 
                      r\ \((u\_\(\(\[LeftDoubleBracket]\)\(i - 1, j - 1\)\(\
\[RightDoubleBracket]\)\) + 
                            u\_\(\(\[LeftDoubleBracket]\)\(i + 1, j - 1\)\(\
\[RightDoubleBracket]\)\))\)];\)\ ];\)\ ];\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Consider the heat equation where  ",
  Cell[BoxData[
      \(c\^2 = 1\)]],
  ".   The length of the rod is  ",
  Cell[BoxData[
      \(L = 1\)]],
  ".  Assume that the ends of the rod are held at the temperature  ",
  Cell[BoxData[
      \(u = 0\)]],
  ".  Assume that the initial temperature distribution is\n\n      ",
  Cell[BoxData[
      \(u \((x, 0)\)\  = \ \(f \((x)\)\  = \ 4  x\  - \ 4  x\^2\)\)]],
  ".\n      \nApply the forward difference method with  ",
  Cell[BoxData[
      \(r = 1\)]],
  "  and  obtain temperature distributions for  ",
  Cell[BoxData[
      \(t = 0.02, 0.04, 0.06, \[CenterEllipsis], 0.20\)]],
  ".\nWe will use  ",
  Cell[BoxData[
      \(c = 1, \ h = 0.2, \ k = 0.02\)]],
  " .  This forces  ",
  Cell[BoxData[
      \(r\  = \ \(\(c\^2\ k\)\/h\^2 = \(\(1 \((\ 0.02)\)\)\/\((0.2)\)\^2 = \ 
            0.5\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(a\  = \ 1.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 0.2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(c\  = \ 1.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n\  = \ 6;\)\ \ \), "\n", 
    \(\(m\  = 11;\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[x_] = \ 4  x\  - \ 4  x\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(G\_1[t_] = \ 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(G\_2[t_] = \ 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(h\  = \ a\/\(n - 1\);\)\ \ \), "\n", 
    \(\(k\  = \ b\/\(m - 1\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[i_]\  = F[h\ \((i - 1)\)];\)\ \ \), "\n", 
    \(\(g\_1[j_]\  = G\_1[k \((j - 1)\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(g\_2[j_]\  = G\_2[k \((j - 1)\)];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["Now set up the table of solutions.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(FDgrid[n, m];\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell["Next, solve it.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(r\  = \ \(c\^2\ k\)\/h\^2;\)\ \ \), "\n", 
    \(\(FDsolve[n, m];\)\ \)}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(ListPlot3D[u, AxesLabel \[Rule] {"\<t(j)\>", "\<x(i)\>", "\<u   \>"}, 
        ViewPoint \[Rule] {4, 2, 3}, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical solution to the P.D.E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_t\)(x,t) = \!\(u\_xx\)(x,t)\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\< u(x,0) = f(x) = \>", F[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<c = \>", c];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<h = \>", h];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<k = \>", k];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\(\(c\^2\) k\)\/h\^2\) = \>\"", \(c\^2\ \
k\)\/h\^2];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["To see the numerical values enter the command:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<The numerical solution to the P.D.E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_t\)(x,t) = \!\(u\_xx\)(x,t)\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\< u(x,0) = f(x) = \>", F[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[TableForm[N[Transpose[Chop[u]]]], 6]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Consider the heat equation where  ",
  Cell[BoxData[
      \(c\^2 = 1\)]],
  ".   The length of the rod is  ",
  Cell[BoxData[
      \(L = 1\)]],
  ".  Assume that the ends of the rod are held at the temperature  ",
  Cell[BoxData[
      \(u = 0\)]],
  ".  Assume that the initial temperature distribution is\n\n      ",
  Cell[BoxData[
      \(u \((x, 0)\)\  = \ \(f \((x)\)\  = \ 4  x\  - \ 4  x\^2\)\)]],
  ".\n      \n",
  "Now investigate what happens when the step size is too large.  This time \
the t interval is larger  [0.0, 0.35], and the step size is \"too large.\"",
  "\nApply the forward difference method with  ",
  Cell[BoxData[
      \(r = 1\)]],
  "  and  obtain temperature distributions for  ",
  Cell[BoxData[
      \(t = 0.035, 0.070, \[CenterEllipsis], 0.35\)]],
  ".\nWe will use  ",
  Cell[BoxData[
      \(c = 1, \ h = 0.2, \ k = 0.035\)]],
  " .  This forces  ",
  Cell[BoxData[
      \(r\  = \ \(\(c\^2\ k\)\/h\^2 = \(\(1\ \((0.035)\)\)\/\((0.2)\)\^2 = \ 
            0.8749999999999998`\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(a\  = \ 1.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 0.35;\)\ \ \), "\[IndentingNewLine]", 
    \(\(c\  = \ 1.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n\  = \ 6;\)\ \ \), "\n", 
    \(\(m\  = 11;\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[x_] = \ 4  x\  - \ 4  x\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(G\_1[t_] = \ 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(G\_2[t_] = \ 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(h\  = \ a\/\(n - 1\);\)\ \ \), "\n", 
    \(\(k\  = \ b\/\(m - 1\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[i_]\  = F[h\ \((i - 1)\)];\)\ \ \), "\n", 
    \(\(g\_1[j_]\  = G\_1[k \((j - 1)\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(g\_2[j_]\  = G\_2[k \((j - 1)\)];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["Now set up the table of solutions.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(FDgrid[n, m];\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell["Next, solve it.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(r\  = \ \(c\^2\ k\)\/h\^2;\)\ \ \), "\n", 
    \(\(FDsolve[n, m];\)\ \)}], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(ListPlot3D[u, AxesLabel \[Rule] {"\<t(j)\>", "\<x(i)\>", "\<u   \>"}, 
        ViewPoint \[Rule] {4, 2, 3}, 
        ColorFunction \[Rule] Hue];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical solution to the P.D.E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_t\)(x,t) = \!\(u\_xx\)(x,t)\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\< u(x,0) = f(x) = \>", F[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<c = \>", c];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<h = \>", h];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<k = \>", k];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\(c\^2\\\ k\)\/h\^2\) = \>\"", \(c\^2\ k\)\/h\^2];\)\
\)}], "Input",
  AspectRatioFixed->True],

Cell["To see the numerical values enter the command:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<The numerical solution to the P.D.E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_t\)(x,t) = \!\(u\_xx\)(x,t)\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\< u(x,0) = f(x) = \>", F[x]];\)\), "\[IndentingNewLine]", 
    \(Print[NumberForm[TableForm[N[Transpose[Chop[u]]]], 6]]\ \ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Crank-Nicolson Method",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["An implicit scheme, invented b  ",
    FontFamily->"Times New Roman"],
  StyleBox[ButtonBox["John Crank",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Crank.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Times New Roman"],
  StyleBox[" (1916-) and  ",
    FontFamily->"Times New Roman"],
  StyleBox[ButtonBox["Phyllis Nicolson",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Nicolson.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Times New Roman"],
  StyleBox[" (1917-1968), is based on numerical approximations for solutions \
at the point  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\((x, t + k\/2)\)\)]],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["that lies between the rows in the grid.  Specifically, the \
approximation used for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(u\_t\) \((x, t + k\/2)\)\)]],
  "  ",
  StyleBox["is obtained from the central-difference formula, \n\n\t\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(u\_t\) \((x, 
            t + k\/2)\)\  = \ \(u \((x, t + k)\) - u \((x, t)\)\)\/k\  + \ 
          O \((k\^2)\)\)]],
  StyleBox[". ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CrankNicolsonProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CrankNicolsonProof.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CrankNicolsonProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CrankNicolsonProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Program ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" (",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Crank-Nicolson",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" method for the heat equation)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  To approximate the solution of the heat equation  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\(u\_t\) \((x, t)\) = \(c\^2\) \(u\_xx\) \((x, t)\)\)]],
  "  ",
  StyleBox["over the rectangle  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["R",
          FontWeight->"Bold",
          FontSlant->"Italic"], 
        "=", \({\((x, t)\) : 0 \[LessEqual] x \[LessEqual] a, 
          0 \[LessEqual] t \[LessEqual] b}\)}]]],
  "  with    ",
  Cell[BoxData[
      \(u \((x, 0)\) = f \((x)\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] x \[LessEqual] a\)]],
  ".  and  ",
  Cell[BoxData[
      RowBox[{\(u \((0, t)\)\), "=", 
        RowBox[{
          RowBox[{\(c\_1\), "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman"], "  ", "u", \((a, t)\)}], 
          "=", \(c\_2\)}]}]]],
  ",  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] b\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(CNgrid[n_, 
          m_] := \[IndentingNewLine]Module[{i, j}, \[IndentingNewLine]u\  = \ 
            Table[1, {n}, {m}]; \[IndentingNewLine]For[\ i = 1, \ 
            i \[LessEqual] 
              n, \ \(i++\), \
\[IndentingNewLine]\(u\_\(\(\[LeftDoubleBracket]\)\(i, 1\)\(\
\[RightDoubleBracket]\)\) = f[i];\)\ ]; \[IndentingNewLine]For[\ j = 1, \ 
            j \[LessEqual] 
              m, \ \(j++\), \
\[IndentingNewLine]u\_\(\(\[LeftDoubleBracket]\)\(1, j\)\(\
\[RightDoubleBracket]\)\)\  = \ 
              g\_1[j]; \[IndentingNewLine]u\_\(\(\[LeftDoubleBracket]\)\(n, j\
\)\(\[RightDoubleBracket]\)\)\  = \ 
              g\_2[j];\ \ ];\ \ ];\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(CoeffMat[
          n_] := \[IndentingNewLine]Module[{}, \[IndentingNewLine]Va\  = \ \
\(Vc\  = \ Table[\(-1\), {n - 
                    1}]\); \[IndentingNewLine]Va\_\(\(\[LeftDoubleBracket]\)\(\
n - 1\)\(\[RightDoubleBracket]\)\)\  = \ \
\(Vc\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\  = \ 
              0\); \[IndentingNewLine]Vd\  = \ 
            Table[2 + 
                2\/r, {n}]; \[IndentingNewLine]Vd\_\(\(\[LeftDoubleBracket]\)\
\(1\)\(\[RightDoubleBracket]\)\)\  = \ \
\(Vd\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\  = \ 
              1\);\ \ ];\)\(\ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(TriDiagonal[a0_, d0_, c0_, 
          b0_]\  := \[IndentingNewLine]Module[{\ a = a0, b = b0, c = c0, 
            d = d0, k, m, n = Length[b0], x\ }, \[IndentingNewLine]For[\ 
            k = 2, \ k \[LessEqual] 
              n, \ \(k++\), \
\[IndentingNewLine]d\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\
\)\  = \ d\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\ \  - \
\ \(\(\ \)\(a\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\[RightDoubleBracket]\)\)\
\)\)\/\(\(\ \)\(d\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\[RightDoubleBracket]\
\)\)\)\)\ \ c\_\(\(\[LeftDoubleBracket]\)\(k - \
1\)\(\[RightDoubleBracket]\)\); \ \[IndentingNewLine]b\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\  = \ 
              b\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\  \
- \ \(\(\ \)\(a\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\[RightDoubleBracket]\)\
\)\)\)\/\(\(\ \)\(d\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\)\)\)\ b\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\);\ ]; \ \[IndentingNewLine]x = 
            Table[0, {n}]; \ \[IndentingNewLine]x\_\(\(\[LeftDoubleBracket]\)\
\(n\)\(\[RightDoubleBracket]\)\)\  = \(\(\ \
\)\(b\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\)\)\)\/d\_\(\(\
\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\)\); \ \
\[IndentingNewLine]For[\ k = n - 1, \ 
            1 \[LessEqual] 
              k, \ \(k--\), \
\[IndentingNewLine]\(x\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\
\)\)\  = \ \(b\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\  \
- \ c\_\(\(\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\)\ x\_\(\(\
\[LeftDoubleBracket]\)\(k + 1\)\(\[RightDoubleBracket]\)\)\)\/d\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\);\)\ ]; \ \
\[IndentingNewLine]Return[x];\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(CNsolve[n_, 
          m_] := \[IndentingNewLine]Module[{b, i, 
            j}, \[IndentingNewLine]b\  = \ 
            Table[0, {n}]; \[IndentingNewLine]For[\ j = 2, \ 
            j \[LessEqual] 
              m, \ \(j++\), \
\[IndentingNewLine]b\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)\  = \ g\_1[
                j]; \[IndentingNewLine]b\_\(\(\[LeftDoubleBracket]\)\(n\)\(\
\[RightDoubleBracket]\)\)\  = \ g\_2[j]; \[IndentingNewLine]For[\ i = 2, \ 
              i \[LessEqual] 
                n - 1, \ \(i++\), \[IndentingNewLine]\(b\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ 
                  u\_\(\(\[LeftDoubleBracket]\)\(i - 1, j - 1\)\(\
\[RightDoubleBracket]\)\) + \((2\/r - 
                          2)\)\ u\_\(\(\[LeftDoubleBracket]\)\(i, j - 1\)\(\
\[RightDoubleBracket]\)\) + 
                    u\_\(\(\[LeftDoubleBracket]\)\(i + 1, j - 1\)\(\
\[RightDoubleBracket]\)\);\)\ ]; \[IndentingNewLine]u\_\(\(\
\[LeftDoubleBracket]\)\(All, j\)\(\[RightDoubleBracket]\)\)\  = \ 
              TriDiagonal[Va, Vd, Vc, b];\ \ ];\ \ ];\)\(\ \ \)\)\)], "Input",\

  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the heat equation where  ",
  Cell[BoxData[
      \(c\^2 = 1\)]],
  ".  The length of the rod is  ",
  Cell[BoxData[
      \(L = 1\)]],
  ".  Assume that the ends of the rod are held at the temperature  ",
  Cell[BoxData[
      \(u = 0\)]],
  ".  Assume that the initial temperature distribution is \n\n\t\t",
  Cell[BoxData[
      \(u \((x, 0)\)\  = \ \(f \((x)\)\  = \ 
          sin \((\[Pi]\ x)\) + \ \ sin \((3  \[Pi]\ x)\)\)\)]],
  ". \n      \nApply the Crank-Nicolson method with  ",
  Cell[BoxData[
      \(r = 1\)]],
  "  and obtain temperature distributions for  ",
  Cell[BoxData[
      \(t = 0.01, 0.02, 0.03, \[CenterEllipsis], 0.10\)]],
  ".  Compare the solution with the exact solution: \n\n\t\t",
  Cell[BoxData[
      \(u \((x, t)\)\  = \ 
        sin \((\[Pi]\ x)\) \[ExponentialE]\^\(-t\[Pi]\^2\) + \ \ sin \((3  \
\[Pi]\ x)\) \[ExponentialE]\^\(\(-9\) t\[Pi]\^2\)\)]],
  ". \n     \nWe will use  ",
  Cell[BoxData[
      \(c = 1, \ h = 0.1, \ k = 0.01\)]],
  " .  This forces  This forces  ",
  Cell[BoxData[
      \(r\  = \ \ \(\(c\^2\ k\)\/h\^2\  = \ \(\(1\ \((0.01)\)\)\/\((0.1)\)\^2\
\  = \ 1\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(a\  = \ 1.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 0.1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(c\  = \ 1.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n\  = \ 11;\)\ \ \), "\n", 
    \(\(m\  = 11;\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[x_] = \ 
        Sin[\[Pi]\ x] + Sin[3\ \[Pi]\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(G\_1[t_] = \ 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(G\_2[t_] = \ 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(h\  = \ a\/\(n - 1\);\)\ \ \), "\n", 
    \(\(k\  = \ b\/\(m - 1\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[i_]\  = F[h\ \((i - 1)\)];\)\ \ \), "\n", 
    \(\(g\_1[j_]\  = G\_1[k \((j - 1)\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(g\_2[j_]\  = G\_2[k \((j - 1)\)];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["Now set up the table of solutions.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(CNgrid[n, m];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Setting up the tri-diagonal matrx with n rows.  Indeed, we could get away \
with  ",
  Cell[BoxData[
      \(n - 2\)]],
  "  rows, but the implementation is nice this way.  The following matrix \
will usually use  ",
  Cell[BoxData[
      \(r = 1\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(r\  = \ \(c\^2\ k\)\/h\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(CoeffMat[n];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["Next, solve it.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(CNsolve[n, m];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(ListPlot3D[u, AxesLabel \[Rule] {"\<t(j)\>", "\<x(i)\>", "\<u   \>"}, 
        ViewPoint \[Rule] {4, 2, 3}, 
        ColorFunction \[Rule] Hue];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical solution to the P.D.E.\>"];\)\), "\n", 
    \(Print[\*"\"\<\!\(u\_t\)(x,t) = \!\(u\_xx\)(x,t)\>\""]; \), "\n", 
    \(Print["\< u(x,0) = f(x) = \>", F[x]]; \), "\n", 
    \(Print["\<c = \>", c]; \), "\n", 
    \(Print["\<h = \>", h]; \), "\n", 
    \(Print["\<k = \>", k]; \), "\n", 
    \(\(Print[\*"\"\<\!\(\(\(c\^2\) k\)\/h\^2\) = \>\"", \(c\^2\ \
k\)\/h\^2];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["Compare with the analytic solution.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(U[x_, t_] = 
        Sin[\[Pi]\ x] \[ExponentialE]\^\(\(-\ t\)\ \[Pi]\^2\) + \ \ Sin[
              3  \[Pi]\ x] \[ExponentialE]\^\(\(-\ 9\) t\ \[Pi]\^2\);\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(SetOptions[Plot3D, PlotPoints \[Rule] {n, m}];\)\ \ \), "\n", 
    \(\(Plot3D[U[x, t], {t, 0, 0.1}, {x, 0, 1.0}, 
        ViewPoint \[Rule] {4, 2, 3}, Lighting \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,t] = \>", U[x, t]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the heat equation where  ",
  Cell[BoxData[
      \(c\^2 = 1\)]],
  ".  The length of the rod is  ",
  Cell[BoxData[
      \(L = 1\)]],
  ".  Assume that the ends of the rod are held at the temperature  ",
  Cell[BoxData[
      \(u = 0\)]],
  ".  Assume that the initial temperature distribution is \n\n\t\t",
  Cell[BoxData[
      \(u \((x, 0)\)\  = \ \(f \((x)\)\  = \ 
          sin \((\[Pi]\ x)\) + \ \ sin \((3  \[Pi]\ x)\)\)\)]],
  ". \n      \nApply the Crank-Nicolson method with  ",
  Cell[BoxData[
      \(r = 1\)]],
  "  and obtain temperature distributions for  ",
  Cell[BoxData[
      \(t = 0.01, 0.02, 0.03, \[CenterEllipsis], 0.10\)]],
  ".  Compare the solution with the exact solution: \n\n\t\t",
  Cell[BoxData[
      \(u \((x, t)\)\  = \ 
        sin \((\[Pi]\ x)\) \[ExponentialE]\^\(-t\[Pi]\^2\) + \ \ sin \((3  \
\[Pi]\ x)\) \[ExponentialE]\^\(\(-9\) t\[Pi]\^2\)\)]],
  ". \n     \n(Is the Crank-Nicolson method stable when r > 1 ?) "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(a\  = \ 1.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(b\  = \ 0.2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(c\  = \ 1.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(n\  = \ 11;\)\ \ \), "\n", 
    \(\(m\  = 11;\)\ \ \), "\[IndentingNewLine]", 
    \(\(F[x_] = \ 
        Sin[\[Pi]\ x] + Sin[3\ \[Pi]\ x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(G\_1[t_] = \ 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(G\_2[t_] = \ 0.0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(h\  = \ a\/\(n - 1\);\)\ \ \), "\n", 
    \(\(k\  = \ b\/\(m - 1\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(f[i_]\  = F[h\ \((i - 1)\)];\)\ \ \), "\n", 
    \(\(g\_1[j_]\  = G\_1[k \((j - 1)\)];\)\ \ \), "\[IndentingNewLine]", 
    \(\(g\_2[j_]\  = G\_2[k \((j - 1)\)];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["Now set up the table of solutions.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(CNgrid[n, m];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Setting up the tri-diagonal matrx with n rows.  Indeed, we could get away \
with  ",
  Cell[BoxData[
      \(n - 2\)]],
  "  rows, but the implementation is nice this way.  The following matrix \
will usually use  ",
  Cell[BoxData[
      \(r = 1\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(r\  = \ \(c\^2\ k\)\/h\^2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(CoeffMat[n];\)\ \ \)}], "Input",
  AspectRatioFixed->False],

Cell["Next, solve it.", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\(CNsolve[n, m];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(ListPlot3D[u, AxesLabel \[Rule] {"\<t(j)\>", "\<x(i)\>", "\<u   \>"}, 
        ViewPoint \[Rule] {4, 2, 3}, 
        ColorFunction \[Rule] Hue];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The numerical solution to the P.D.E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_t\)(x,t) = \!\(u\_xx\)(x,t)\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\< u(x,0) = f(x) = \>", F[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<c = \>", c];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<h = \>", h];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<k = \>", k];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\(c\^2\\\ k\)\/h\^2\) = \>\"", \(c\^2\ k\)\/h\^2];\)\
\)}], "Input",
  AspectRatioFixed->True],

Cell["Compare with the analytic solution.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(U[x_, t_] = 
        Sin[\[Pi]\ x] \[ExponentialE]\^\(\(-\ t\)\ \[Pi]\^2\) + \ \ Sin[
              3  \[Pi]\ x] \[ExponentialE]\^\(\(-\ 9\) t\ \[Pi]\^2\);\)\ \ \
\), "\[IndentingNewLine]", 
    \(\(SetOptions[Plot3D, PlotPoints \[Rule] {n, m}];\)\ \ \), "\n", 
    \(\(Plot3D[U[x, t], {t, 0, 0.2}, {x, 0, 1.0}, 
        ViewPoint \[Rule] {4, 2, 3}, Lighting \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The analytic solution to the P.D.E.\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(u\_t\)(x,t) = \!\(u\_xx\)(x,t)\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\< u(x,0) = f(x) = \>", F[x]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,t] = \>", U[x, t]\ ];\)\ \ \)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/CrankNicolsonBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Crank-Nicolson Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/CrankNicolsonBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 171, 4, 35, "Text"],
Cell[1950, 59, 1464, 49, 96, "Text"]
}, Closed]],
Cell[3429, 111, 3422, 105, 391, "Text"],
Cell[6854, 218, 632, 21, 33, "Text"],
Cell[7489, 241, 618, 20, 33, "Text"],
Cell[8110, 263, 1267, 40, 52, "Text"],
Cell[9380, 305, 727, 15, 170, "Input"],
Cell[10110, 322, 795, 15, 110, "Input"],
Cell[10908, 339, 1061, 34, 153, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11994, 377, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[12147, 383, 777, 14, 296, "Input"],
Cell[12927, 399, 99, 2, 33, "Text",
  Evaluatable->False],
Cell[13029, 403, 89, 2, 30, "Input"],
Cell[13121, 407, 80, 2, 33, "Text",
  Evaluatable->False],
Cell[13204, 411, 133, 3, 66, "Input"],
Cell[13340, 416, 755, 14, 186, "Input"],
Cell[14098, 432, 110, 2, 33, "Text",
  Evaluatable->False],
Cell[14211, 436, 364, 7, 90, "Input"]
}, Closed]],
Cell[14590, 446, 1237, 37, 169, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[15852, 487, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[16005, 493, 778, 14, 296, "Input"],
Cell[16786, 509, 99, 2, 33, "Text",
  Evaluatable->False],
Cell[16888, 513, 89, 2, 30, "Input"],
Cell[16980, 517, 80, 2, 33, "Text",
  Evaluatable->False],
Cell[17063, 521, 133, 3, 66, "Input"],
Cell[17199, 526, 756, 14, 186, "Input"],
Cell[17958, 542, 110, 2, 33, "Text",
  Evaluatable->False],
Cell[18071, 546, 352, 6, 90, "Input"]
}, Closed]],
Cell[18438, 555, 1599, 48, 134, "Text"],
Cell[20040, 605, 632, 21, 33, "Text"],
Cell[20675, 628, 618, 20, 33, "Text"],
Cell[21296, 650, 1474, 47, 52, "Text"],
Cell[22773, 699, 730, 15, 170, "Input"],
Cell[23506, 716, 676, 13, 146, "Input"],
Cell[24185, 731, 1922, 31, 292, "Input"],
Cell[26110, 764, 1172, 23, 208, "Input"],
Cell[27285, 789, 1310, 38, 210, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28620, 831, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[28773, 837, 801, 15, 296, "Input"],
Cell[29577, 854, 99, 2, 33, "Text",
  Evaluatable->False],
Cell[29679, 858, 87, 2, 30, "Input"],
Cell[29769, 862, 337, 12, 33, "Text",
  Evaluatable->False],
Cell[30109, 876, 150, 3, 66, "Input"],
Cell[30262, 881, 80, 2, 33, "Text",
  Evaluatable->False],
Cell[30345, 885, 88, 2, 30, "Input"],
Cell[30436, 889, 636, 12, 186, "Input"],
Cell[31075, 903, 99, 2, 33, "Text",
  Evaluatable->False],
Cell[31177, 907, 555, 10, 93, "Input"]
}, Closed]],
Cell[31747, 920, 1132, 31, 201, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32904, 955, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[33057, 961, 801, 15, 296, "Input"],
Cell[33861, 978, 99, 2, 33, "Text",
  Evaluatable->False],
Cell[33963, 982, 87, 2, 30, "Input"],
Cell[34053, 986, 337, 12, 33, "Text",
  Evaluatable->False],
Cell[34393, 1000, 150, 3, 66, "Input"],
Cell[34546, 1005, 80, 2, 33, "Text",
  Evaluatable->False],
Cell[34629, 1009, 88, 2, 30, "Input"],
Cell[34720, 1013, 756, 14, 186, "Input"],
Cell[35479, 1029, 99, 2, 33, "Text",
  Evaluatable->False],
Cell[35581, 1033, 813, 15, 153, "Input"]
}, Closed]],
Cell[36409, 1051, 158, 3, 32, "Text"],
Cell[36570, 1056, 575, 17, 33, "Text"],
Cell[37148, 1075, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

