(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    189636,       5218]*)
(*NotebookOutlinePosition[    190886,       5257]*)
(*  CellTagsIndexPosition[    190842,       5253]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for Eigenvalues and Eigenvectors",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["We will now review some ideas from linear algebra. Proofs of the \
theorems are either left as exercises or can be found in any standard text on \
linear algebra.  We know how to solve ",
    FontFamily->"Times New Roman"],
  StyleBox["n ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["linear equations in ",
    FontFamily->"Times New Roman"],
  StyleBox["n ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["unknowns.  It was assumed that the determinant of the matrix was \
nonzero and hence that the solution was unique. In the case of a homogeneous \
system ",
    FontFamily->"Times New Roman"],
  StyleBox["AX ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["= ",
    FontFamily->"Times New Roman"],
  StyleBox["0",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[", if  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(det \((a)\) \[NotEqual] 0\),
        FontFamily->"Courier New",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontFamily->"Times New Roman"],
  StyleBox[",  the unique solution is the trivial solution ",
    FontFamily->"Times New Roman"],
  StyleBox["X ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["= ",
    FontFamily->"Times New Roman"],
  StyleBox["0",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[".  If  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(det \((a)\) = 0\),
        FontFamily->"Courier New",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontFamily->"Times New Roman"],
  StyleBox[",  there exist nontrivial solutions to ",
    FontFamily->"Times New Roman"],
  StyleBox["AX ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["= ",
    FontFamily->"Times New Roman"],
  StyleBox["0",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[". Suppose that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      StyleBox[\(det \((a)\) = 0\),
        FontFamily->"Courier New",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontFamily->"Times New Roman"],
  StyleBox[",  and consider solutions to the homogeneous linear\nsystem",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[{
      \(\(a\_\(1, 1\)\) x\_1 + \(a\_\(1, 2\)\) x\_2 + \(a\_\(1, 3\)\) 
            x\_3 + \[CenterEllipsis] + \(a\_\(1, n - 1\)\) 
            x\_\(n - 1\) + \(a\_\(1, n\)\) x\_n\  = \ 0\), 
    "\[IndentingNewLine]", 
      \(\(a\_\(2, 1\)\) x\_1 + \(a\_\(2, 2\)\) x\_2 + \(a\_\(2, 3\)\) 
            x\_3 + \[CenterEllipsis] + \(a\_\(2, n - 1\)\) 
            x\_\(n - 1\) + \(a\_\(2, n\)\) x\_n\  = \ 0\), "\n", 
      \(\(\(\(a\_\(3, 1\)\) x\_1 + \(a\_\(3, 2\)\) x\_2 + \(a\_\(3, 3\)\) 
            x\_3 + \[CenterEllipsis] + \(a\_\(3, n - 1\)\) 
            x\_\(n - 1\) + \(a\_\(3, n\)\) x\_n\  = \ 
        0\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \(\(\[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\
\ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\(a\_\(n, 1\)\) x\_1 + \(a\_\(n, 2\)\) x\_2 + \(a\_\(n, 3\)\) 
            x\_3 + \[CenterEllipsis] + \(a\_\(n, n - 1\)\) 
            x\_\(n - 1\) + \(a\_\(n, n\)\) x\_n\  = \ b\_n\)}]],
  "     "
}], "Text"],

Cell[TextData[{
  StyleBox["A homogeneous system of equations always has the trivial solution \
",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_1 = 0, \ x\_2 = 0,  ... , x\_n = 0\)]],
  StyleBox[".  Gaussian elimination can be used to obtain the reduced row \
echelon form which will be used to form a set of relationships between the \
variables, and a non-trivial solution.  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the nontrivial solutions to the homogeneous system  \n\n\t\t",
  Cell[BoxData[{
      \(\ \ \ x\_1\  + \ 2  x\_2\  - \ \ x\_3\ \  = \ 0\), "\n", 
      \(2  x\_1\  + \ \ \ \ x\_2\  + \ \ x\_3\ \  = \ 0\), "\n", 
      \(5  x\_1\  + \ 4  x\_2\  + \ \ x\_3\ \  = \ 0\)}]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Use Gaussian elimination to eliminate  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_1\)]],
  StyleBox["  and the result is  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[{
      \(\ \ \ x\_1\  + \ 2  x\_2\  - \ \ \ \ x\_3\ \  = \ \ 0\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \(-\ \ 3\)\ x\_2\  + \ 3\ x\_3\ \  = \ 0\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \(-\ \ 6\)\ x\_2\  + \ 6\ x\_3\ \  = \ 0\)}]]
}], "Text"],

Cell[TextData[{
  StyleBox["Since the third equation is a multiple of the second equation, \
this system reduces to two equations in three unknowns: \n",
    FontFamily->"Times-Roman"],
  StyleBox["\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[{
      \(\ \ \ x\_1\  + \ x\_2\  - \ \ x\_3\ \  = \ 0\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \(-\ \ x\_2\)\  + \ \ x\_3\ \  = \ 0\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["We can select one unknown and use it as a parameter.  For \
instance, let  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_3 = t\)]],
  StyleBox[";  then the second equation implies that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_2 = t\)]],
  StyleBox["and the first equation is used to compute ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(x\_1 = t\)]],
  StyleBox[".  Therefore, the solution can be expressed as the set of \
relations:\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[{
      \(x\_1\  = \ \(-t\)\), "\n", 
      \(x\_2\  = \ \ \ t\), "\n", 
      \(x\_3\  = \ \ \ t\)}]],
  "  \n\tor\n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox["X",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(x\_1\)},
                {\(x\_2\)},
                {\(x\_3\)}
                }], ")"}], " ", "=", " ", 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {\(-t\)},
                  {"t"},
                  {"t"}
                  }], ")"}], " ", "=", " ", 
            RowBox[{"t", " ", 
              RowBox[{"(", GridBox[{
                    {\(-1\)},
                    {"1"},
                    {"1"}
                    }], ")"}]}]}]}]}]]],
  " "
}], "Text"],

Cell[TextData[{
  "We can fin the solution by entering the equations into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(eqns\  = \ {\ \ \ x\_1\  + \ 2\ x\_2\  - \ x\_3 \[Equal] \ 
            0, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ 2 
                 x\_1\  + \ \ \ \ x\_2\  + \ x\_3 \[Equal] \ 
            0, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ 5  x\_1\  + \ 
              4\ x\_2\  + x\_3 \[Equal] \ \ 0\ \ };\)\)], "Input"],

Cell[TextData[{
  "Identify the matrix of coefficients ",
  StyleBox["A",
    FontWeight->"Bold"],
  " and column vector ",
  StyleBox["B",
    FontWeight->"Bold"],
  " for the matrix problem ",
  StyleBox["AX",
    FontWeight->"Bold"],
  " = ",
  StyleBox["B",
    FontWeight->"Bold"],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(mats = 
        LinearEquationsToMatrices[eqns, vars];\)\), "\[IndentingNewLine]", 
    \(\(A = 
        mats\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\),\
 "\[IndentingNewLine]", 
    \(\(B = 
        mats\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\),\
 "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equations\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[TableForm[eqns]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<B = \>", MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation A X = B\>"];\)\), "\n", 
    \(\(Print["\< A  = \>", MatrixForm[A] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<|A| = \>", Det[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Hence the system will have non-trivial \
solutions.\>"];\)\)}], "Input"],

Cell[TextData[{
  "Form the augmented matrix  ",
  StyleBox["M",
    FontWeight->"Bold"],
  " = [",
  StyleBox["A",
    FontWeight->"Bold"],
  ", ",
  StyleBox["B",
    FontWeight->"Bold"],
  "]  and perform Gauss-Jordan elimination with row interchanges."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(b = Partition[B, 1];\)\), "\[IndentingNewLine]", 
    \(M = AppendRows[A, b]; \ m = M;\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<B = \>", MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix M = [A,B] is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<M = \>", MatrixForm[M]];\)\)}], "Input"],

Cell[TextData[{
  "Find the reduced row echelon form of the augmented matrix  ",
  StyleBox["M",
    FontWeight->"Bold"],
  " = [",
  StyleBox["A",
    FontWeight->"Bold"],
  ", ",
  StyleBox["B",
    FontWeight->"Bold"],
  "].  "
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<The augmented matrix M = [A,B] is\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<M = \>", MatrixForm[M]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) - 
          2  M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\
\), "\[IndentingNewLine]", 
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\) - 
          5  M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\);\)\
\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) = \(-\ \
\(1\/3\)\)\ \
M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) - 
          2  M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\
\), "\[IndentingNewLine]", 
    \(\(M\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\) = 
        M\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\) + 
          6  M\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\);\)\
\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[M]];\)\)}], "Input"],

Cell[TextData[{
  "The equation form for this matrix is  \n\n",
  StyleBox["\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[{
      \(\ \ \ x\_1\ \ \ \ \ \  + \ x\_3\ \  = \ \ 0\), "\n", 
      \(\ \ \ \ \ \ \ \ x\_2\  - \ x\_3\ \  = \ 0\)}]],
  "\n\nThere is one free variable which we choose to be  ",
  Cell[BoxData[
      \(x\_3 = t\)]],
  ".  It is used in computing  ",
  Cell[BoxData[
      \(x\_2 = \(t\ \ and\ \ x\_1 = \(-t\)\)\)]],
  ".  \n\nThe solution vector  ",
  Cell[BoxData[
      InterpretationBox[
        RowBox[{
          StyleBox["X",
            FontWeight->"Bold"], " ", "=", " ", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(x\_1\)},
                {\(x\_2\)},
                {\(x\_3\)}
                }], "\[NoBreak]", ")"}]}],
        MatrixForm[ {
          Subscript[ x, 1], 
          Subscript[ x, 2], 
          Subscript[ x, 3]}]]]],
  "  is"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"X", "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(\(-\ t\)\(\ \)\)},
                {\(\(\ \)\(t\)\(\ \ \ \ \)\)},
                {\(\(\ \ \)\(t\)\(\ \ \)\)}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input"],

Cell[TextData[{
  StyleBox["We are done.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n\n",
    FontWeight->"Bold"],
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can verify that this is the solution by direct multiplication ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ",
  StyleBox["X",
    FontWeight->"Bold"],
  ".  This is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(Print["\<Solve the equation A X = 0\>"];\)\), "\n", 
    \(\(Print["\<  A = \>", MatrixForm[A] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  X = \>", MatrixForm[vars], "\< = \>", 
        MatrixForm[X]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", MatrixForm[A], MatrixForm[X], "\< = \>", 
        MatrixForm[B], "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<      \>", MatrixForm[A . X], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print[Flatten[A . X] \[Equal] Flatten[B]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " find the reduced row echelon matrix.  This is just for fun !"
}], "Text"],

Cell[BoxData[{
    \(\(M = m;\)\), "\n", 
    \(\(Print["\<M = \>", MatrixForm[M]];\)\), "\n", 
    \(\(Print["\<The row reduced echelon form is\>"];\)\), "\n", 
    \(\(Print["\<    \>", MatrixForm[RowReduce[M]]];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background for Eigenvalues and Eigenvectors",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Definition (Linearly Independent).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["The vectors  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "1"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "2"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "n"]}]]],
  StyleBox["  are said to be ",
    FontFamily->"Times New Roman"],
  ButtonBox["linearly independent",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LinearlyIndependent.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["if the equation  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{\(c\_1\), 
                SubscriptBox[
                  StyleBox["U",
                    FontWeight->"Bold"], "1"]}], "+", 
              RowBox[{\(c\_2\), 
                SubscriptBox[
                  StyleBox["U",
                    FontWeight->"Bold"], "2"]}], "+"}], "..."}], "+", 
          RowBox[{\(c\_n\), 
            SubscriptBox[
              StyleBox["U",
                FontWeight->"Bold"], "n"]}]}], "=", "0"}]]],
  StyleBox["\n\n",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["implies that ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{\(c\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(c\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(c\_n = 0\)}]]],
  StyleBox[".   If the vectors are not linearly independent they are said to \
be linearly dependent.  \n\nTwo vectors in ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[GothicCapitalR]",
          FontWeight->"Bold"], "2"]]],
  StyleBox[" are linearly independent if and only if they are not parallel.  \
Three vectors in ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[GothicCapitalR]",
          FontWeight->"Bold"], "3"]]],
  StyleBox["  are linearly independent if and only if they do not lie in the \
same plane. \n\n",
    FontFamily->"Times New Roman"],
  StyleBox["Definition (Linearly Dependent).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["The vectors   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "1"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "2"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "n"]}]]],
  StyleBox["  are said to be ",
    FontFamily->"Times New Roman"],
  ButtonBox["linearly dependent",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LinearlyDependentVectors.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" if there exists a set of numbers ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(c\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(c\_2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(c\_n\)}], "}"}]]],
  StyleBox[" not all zero, such that\n\n\t\t ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{\(c\_1\), 
                SubscriptBox[
                  StyleBox["U",
                    FontWeight->"Bold"], "1"]}], "+", 
              RowBox[{\(c\_2\), 
                SubscriptBox[
                  StyleBox["U",
                    FontWeight->"Bold"], "2"]}], "+"}], "..."}], "+", 
          RowBox[{\(c\_n\), 
            SubscriptBox[
              StyleBox["U",
                FontWeight->"Bold"], "n"]}]}], "=", "0"}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["The vectors  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "1"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "2"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["U",
            FontWeight->"Bold"], "n"]}]]],
  StyleBox["  are linearly dependent if and only if at least one of them is a \
linear combination of the others.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["\<\
\tA desirable feature for a vector space is the ability to express \
each vector as s linear combination of vectors chosen from a small subset of \
vectors.  This motivates the next definition.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition (Basis).",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Suppose that  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"S", " ", "=", " ", 
        RowBox[{"{", 
          RowBox[{
            SubscriptBox[
              StyleBox["U",
                FontWeight->"Bold"], "1"], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            SubscriptBox[
              StyleBox["U",
                FontWeight->"Bold"], "2"], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            SubscriptBox[
              StyleBox["U",
                FontWeight->"Bold"], "m"]}], "}"}]}]]],
  StyleBox[" is a set of  m",
    FontFamily->"Times New Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["vectors in ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[GothicCapitalR]",
          FontWeight->"Bold"], "n"]]],
  StyleBox[".  The set  S",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["i s called a ",
    FontFamily->"Times New Roman"],
  ButtonBox["basis",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/VectorSpaceBasis.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["for  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[GothicCapitalR]",
          FontWeight->"Bold"], "n"]]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["if for every vector  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["X",
          FontWeight->"Bold"], " ", "\[Element]", " ", 
        SuperscriptBox[
          StyleBox["\[GothicCapitalR]",
            FontWeight->"Bold"], "n"]}]]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["there exists a unique set\nof scalars ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{\(c\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(c\_2\), 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(c\_m\)}], "}"}]]],
  StyleBox[" so that  ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["can be expressed as the linear combination  \n\n\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["X",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{\(c\_1\), 
                SubscriptBox[
                  StyleBox["U",
                    FontWeight->"Bold"], "1"]}], "+", 
              RowBox[{\(c\_2\), 
                SubscriptBox[
                  StyleBox["U",
                    FontWeight->"Bold"], "2"]}], "+"}], "..."}], "+", 
          RowBox[{\(c\_n\), 
            SubscriptBox[
              StyleBox["U",
                FontWeight->"Bold"], "n"]}]}]}]]]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["In  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[GothicCapitalR]",
          FontWeight->"Bold"], "n"]]],
  StyleBox[",  any set of  ",
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FontFamily->"Times New Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["linearly independent vectors forms a basis of  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[GothicCapitalR]",
          FontWeight->"Bold"], "n"]]],
  StyleBox[".  Each vector  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["X",
          FontWeight->"Bold"], " ", "\[Element]", " ", 
        SuperscriptBox[
          StyleBox["\[GothicCapitalR]",
            FontWeight->"Bold"], "n"]}]]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["is uniquely expressed as a linear combination of the basis \
vectors.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem.",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Let  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["K",
            FontWeight->"Bold"], "1"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["K",
            FontWeight->"Bold"], "2"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["K",
            FontWeight->"Bold"], "m"]}]]],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["be vectors in  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["\[GothicCapitalR]",
          FontWeight->"Bold"], "n"]]],
  ".  \n",
  StyleBox["\n",
    FontFamily->"Times New Roman"],
  StyleBox["(i)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\tIf  ",
    FontFamily->"Times New Roman"],
  StyleBox["m>n",
    FontFamily->"Courier New"],
  StyleBox[",  then the vectors are linearly independent.  \n\n",
    FontFamily->"Times New Roman"],
  StyleBox["(ii)",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\tIf  ",
    FontFamily->"Times New Roman"],
  StyleBox["m=n",
    FontFamily->"Courier New"],
  StyleBox[",  then the vectors are linearly dependent if and only if   ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"det", 
          RowBox[{"(", 
            StyleBox["K",
              FontWeight->"Bold"], ")"}]}], "=", "0"}]]],
  StyleBox[",  where  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["K",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"[", 
          RowBox[{
            SubscriptBox[
              StyleBox["K",
                FontWeight->"Bold"], "1"], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            SubscriptBox[
              StyleBox["K",
                FontWeight->"Bold"], "2"], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "...", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            SubscriptBox[
              StyleBox["K",
                FontWeight->"Bold"], "m"]}], "]"}]}]]],
  StyleBox[".  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Eigenvalues and Eigenvectors",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/EigenvaluesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Eigenvalues and Eigenvectors",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/EigenvaluesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["\tApplications of mathematics sometimes encounter the following \
questions:  What are the singularities of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "-", 
        StyleBox[
          RowBox[{"\[Lambda]", 
            StyleBox["I",
              FontWeight->"Bold"]}]]}]]],
  StyleBox[",  where  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["is a parameter?  What is the behavior of the sequence of vectors  \
",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          RowBox[{
            SuperscriptBox[
              StyleBox["A",
                FontWeight->"Bold"], "j"], 
            SubscriptBox[
              StyleBox["X",
                FontWeight->"Bold"], "0"]}], "}"}], \(j = 0\), 
        "\[Infinity]"]]],
  StyleBox["?  What are the geometric features of a linear transformation?  \
Solutions for problems in many different disciplines, such as economics, \
engineering, and physics, can involve ideas related to these equations. The \
theory of eigenvalues and eigenvectors is powerful enough to help solve these \
otherwise intractable problems.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["\tLet  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  be a square matrix of dimension  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[" \[Times] ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  and let",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["be a vector of dimension  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[".  The product  ",
    FontFamily->"Times-Roman"],
  StyleBox["Y",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" = ",
    FontFamily->"Times New Roman"],
  StyleBox["AX",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times-BoldItalic",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["can be viewed as a linear transformation from  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["-dimensional space into itself.  We want to find scalars  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["for which there exists a nonzero vector",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["such that\n\n(1)\t\t  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["AX",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox[
          RowBox[{"\[Lambda]", 
            StyleBox["X",
              FontWeight->"Bold"]}]]}]]],
  ";  ",
  StyleBox[" \n",
    FontFamily->"Times-Roman"],
  StyleBox["\n",
    FontFamily->"MTSYN"],
  StyleBox["that is, the linear transformation  ",
    FontFamily->"Times-Roman"],
  StyleBox["T(",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[") = ",
    FontFamily->"Times New Roman"],
  StyleBox["AX",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times-BoldItalic",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["maps",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["onto the multiple  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      StyleBox[
        RowBox[{"\[Lambda]", 
          StyleBox["X",
            FontWeight->"Bold"]}]]]],
  StyleBox[".  When this occurs, we call",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["an eigenvector that corresponds to the eigenvalue  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox[", and together they form the eigenpair  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"\[Lambda]", ",", 
        StyleBox["A",
          FontWeight->"Bold"]}]]],
  StyleBox[" ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontFamily->"Times-BoldItalic",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["for  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[".  In general, the scalar  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["and vector",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["can involve complex numbers.  For simplicity, most of our \
illustrations will involve real calculations.  However, the techniques are \
easily extended to the complex case.  The ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[" \[Times] ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[" identity matrix",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["I",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  can be used to write equation (1) in the form\n\n(2)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], "-", 
              StyleBox[
                RowBox[{"\[Lambda]", 
                  StyleBox["I",
                    FontWeight->"Bold"]}]]}], ")"}], 
          StyleBox["X",
            FontWeight->"Bold"]}], " ", "=", " ", "0"}]]],
  ".  ",
  StyleBox["\n\n",
    FontFamily->"Times-BoldItalic"],
  StyleBox["The significance of equation (2) is that the product of the \
matrix  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "-", 
        StyleBox[
          RowBox[{"\[Lambda]", 
            StyleBox["I",
              FontWeight->"Bold"]}]]}]]],
  StyleBox["  and the nonzero vector",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["X",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["  ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["is the zero vector!  The theorem of homogeneous linear system \
says that (2) has nontrivial solutions if and only if the matrix  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "-", 
        StyleBox[
          RowBox[{"\[Lambda]", 
            StyleBox["I",
              FontWeight->"Bold"]}]]}]]],
  StyleBox["  is singular, that is,\n\n(3)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"det", 
          RowBox[{"(", 
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], "-", 
              StyleBox[
                RowBox[{"\[Lambda]", 
                  StyleBox["I",
                    FontWeight->"Bold"]}]]}], ")"}]}], " ", "=", " ", 
        "0"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["This determinant can be written in the form  \n\n(4)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        TagBox[
          RowBox[{"|", GridBox[{
                {\(a\_\(1, 1\) - \[Lambda]\), \(a\_\(1, 2\)\), \(a\_\(1, 
                      3\)\), "\[CenterEllipsis]", \(a\_\(1, 
                      n - 1\)\), \(a\_\(1, n\)\)},
                {\(a\_\(2, 1\)\), \(a\_\(2, 2\) - \[Lambda]\), \(a\_\(2, 
                      3\)\), "\[CenterEllipsis]", \(a\_\(2, 
                      n - 1\)\), \(a\_\(2, n\)\)},
                {\(a\_\(3, 1\)\), \(a\_\(3, 
                      2\)\), \(a\_\(3, 3\) - \[Lambda]\), 
                  "\[CenterEllipsis]", \(a\_\(3, n - 1\)\), \(a\_\(3, n\)\)},
                {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                  "\[VerticalEllipsis]", "\[DescendingEllipsis]", 
                  "\[VerticalEllipsis]", "\[VerticalEllipsis]"},
                {\(a\_\(n - 1, 1\)\), \(a\_\(n - 1, 2\)\), \(a\_\(n - 1, 
                      3\)\), "\[CenterEllipsis]", \(a\_\(n - 1, n - 1\) - \
\[Lambda]\), \(a\_\(n - 1, n\)\)},
                {\(a\_\(n, 1\)\), \(a\_\(n, 2\)\), \(a\_\(n, 3\)\), 
                  "\[CenterEllipsis]", \(a\_\(n, 
                      n - 1\)\), \(a\_\(n, n\) - \[Lambda]\)}
                }], "|"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], "=", "0"}]]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Characteristic Polynomial).",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["When the determinant in (4) is expanded, it becomes a polynomial \
of degree ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[", which is called ",
    FontFamily->"Times-Roman"],
  StyleBox["the ",
    FontFamily->"Times New Roman"],
  ButtonBox["characteristic polynomial",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/CharacteristicPolynomial.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  StyleBox["   \n\n(5)\t\t",
    FontFamily->"Times New Roman"],
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(p \((\[Lambda])\)\), "=", 
          RowBox[{"det", 
            RowBox[{"(", 
              RowBox[{
                StyleBox["A",
                  FontWeight->"Bold"], "-", 
                StyleBox[
                  RowBox[{"\[Lambda]", 
                    StyleBox["I",
                      FontWeight->"Bold"]}]]}], ")"}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{\(p \((\[Lambda])\)\), "=", 
        RowBox[{\(\((\(-1\))\)\^n\), 
          RowBox[{
            StyleBox["(",
              
              FontWeight->
                "Bold"], \(\(\[Lambda]\^n\  + \ \(c\_1\) \[Lambda]\^\(n - 1\) \
+ \(c\_2\) \[Lambda]\^\(n - 2\)\  +  ... \) + \ \(c\_\(n - 
                      2\)\) \[Lambda]\^2 + \(c\_\(n - 1\)\) \[Lambda]\  + 
              c\_n\), 
            StyleBox[")",
              FontWeight->"Bold"]}]}]}]}]],
  "    "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Exploration for p(",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  Cell[BoxData[
      \(\[Lambda]\)],
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[")",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[{
    \(\(n = 2;\)\), "\[IndentingNewLine]", 
    \(\(A = Table[a\_\(i, j\), {i, n}, {j, n}];\)\), "\[IndentingNewLine]", 
    \(\(I\_n = IdentityMatrix[n];\)\), "\[IndentingNewLine]", 
    \(\(p[\[Lambda]_] = 
        Det[A - \[Lambda]\ I\_n];\)\), "\[IndentingNewLine]", 
    \(\(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  A  = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = Det[\>", 
        MatrixForm[
          A - \[Lambda]\ I\_n], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = \>", 
        Collect[Expand[p[\[Lambda]] - p[0]], \[Lambda]], "\<+(\>", 
        Expand[p[0]], "\<)\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve p[\[Lambda]] = 0 and get\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[TableForm[solset]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(n = 3;\)\), "\[IndentingNewLine]", 
    \(\(A = Table[a\_\(i, j\), {i, n}, {j, n}];\)\), "\[IndentingNewLine]", 
    \(\(I\_n = IdentityMatrix[n];\)\), "\[IndentingNewLine]", 
    \(\(p[\[Lambda]_] = 
        Det[A - \[Lambda]\ I\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  A  = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = Det[\>", 
        MatrixForm[
          A - \[Lambda]\ I\_n], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = \>", 
        Collect[Expand[p[\[Lambda]] - p[0]], \[Lambda]], "\<+(\>", 
        Expand[p[0]], "\<)\>"];\)\)}], "Input"],

Cell[BoxData[{
    \(\(n = 4;\)\), "\[IndentingNewLine]", 
    \(\(A = Table[a\_\(i, j\), {i, n}, {j, n}];\)\), "\[IndentingNewLine]", 
    \(\(I\_n = IdentityMatrix[n];\)\), "\[IndentingNewLine]", 
    \(\(p[\[Lambda]_] = 
        Det[A - \[Lambda]\ I\_n];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  A  = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = Det[\>", 
        MatrixForm[
          A - \[Lambda]\ I\_n], "\<]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = \>", 
        Collect[Expand[p[\[Lambda]] - p[0]], \[Lambda]], "\<+(\>", 
        Expand[p[0]], "\<)\>"];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["\tThere exist exactly ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[" roots (not necessarily distinct) of a polynomial of degree ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[".  Each root  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["can be substituted into equation (3) to obtain an underdetermined \
system of equations that has a corresponding nontrivial solution vector ",
    FontFamily->"Times-Roman"],
  StyleBox["X",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[".  If   ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["is real, a real eigenvector  ",
    FontFamily->"Times-Roman"],
  StyleBox["X",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  can be constructed. For emphasis, we state the following \
definitions.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Eigenvalue).",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["If  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  is and  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[" \[Times] ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  real matrix, then its  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  ButtonBox["eigenvalues",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Eigenvalue.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(\[Lambda]\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\[Lambda]\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\[Lambda]\_n\)}]]],
  "  ",
  StyleBox["are the real and complex roots of the characteristic polynomial  \
\n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(p \((\[Lambda])\)\), "=", 
        RowBox[{"det", 
          RowBox[{"(", 
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], "-", 
              StyleBox[
                RowBox[{"\[Lambda]", 
                  StyleBox["I",
                    FontWeight->"Bold"]}]]}], ")"}]}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Eigenvector).",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["If   ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["is an eigenvalue of  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  and the nonzero vector  ",
    FontFamily->"Times-Roman"],
  StyleBox["V",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  has the property that \n\n\t\t  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        StyleBox["AV",
          FontWeight->"Bold"], " ", "=", " ", 
        StyleBox[
          RowBox[{"\[Lambda]", 
            StyleBox["V",
              FontWeight->"Bold"]}]]}]]],
  "    ",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  StyleBox["\n\n",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["then  ",
    FontFamily->"Times-Roman"],
  StyleBox["V",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  is called an ",
    FontFamily->"Times-Roman"],
  ButtonBox["eigenvector",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Eigenvector.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" of  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  corresponding to the eigenvalue  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox[".  Together, this eigenvalue ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox[" and eigenvector ",
    FontFamily->"Times-Roman"],
  StyleBox["V",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[" is called an eigenpair  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"\[Lambda]", ",", 
        StyleBox["V",
          FontWeight->"Bold"]}]]],
  StyleBox[". ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["\tThe characteristic polynomial  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(p \((\[Lambda])\)\), "=", 
        RowBox[{\(\((\(-1\))\)\^n\), 
          RowBox[{
            StyleBox["(",
              
              FontWeight->
                "Bold"], \(\(\[Lambda]\^n\  + \ \(c\_1\) \[Lambda]\^\(n - 1\) \
+ \(c\_2\) \[Lambda]\^\(n - 2\)\  +  ... \) + \ \(c\_\(n - 
                      2\)\) \[Lambda]\^2 + \(c\_\(n - 1\)\) \[Lambda]\  + 
              c\_n\), 
            StyleBox[")",
              FontWeight->"Bold"]}]}]}]]],
  StyleBox[" can be factored in the form\n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p \((\[Lambda])\) = \(\(\(\((\(-1\))\)\^n\) \((\[Lambda] - \
\[Lambda]\_1)\)\^m\_1\ \((\[Lambda] - \[Lambda]\_2)\)\^m\_2\  ... \) \((\
\[Lambda] - \[Lambda]\_j)\)\^m\_j\  ... \) \((\[Lambda] - \[Lambda]\_\(m\_\(k \
- 1\)\))\)\^m\_\(k - 1\)\ \((\[Lambda] - \[Lambda]\_\(m\_k\))\)\^m\_k\)]],
  "  \n\t\t",
  StyleBox["\n",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["where  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(m\_j\)]],
  "  ",
  StyleBox["is called the ",
    FontFamily->"Times-Roman"],
  ButtonBox["multiplicity",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Multiplicity.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" of the eigenvalue ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\_j\)]],
  StyleBox[". The sum of the multiplicities of all eigenvalues is  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[";  that is, \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(n = \(\(m\_1 + m\_2 +  ... \) + m\_j +  ... \) + m\_\(k - 1\) + 
          m\_k\)]],
  ".  "
}], "Text"],

Cell[TextData[StyleBox["The next three results concern the existence of \
eigenvectors.",
  FontFamily->"Times-Roman"]], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Corresponding Eigenvectors).",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  Suppose that  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  is and  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[" \[Times] ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  square matrix.    ",
    FontFamily->"Times-Roman"],
  StyleBox["\n",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["(a) \tFor each distinct eigenvalue  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  there exists at least one eigenvector  ",
    FontFamily->"Times-Roman"],
  StyleBox["V",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  corresponding to  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox[".\n(b) \tIf  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  has multiplicity  ",
    FontFamily->"Times-Roman"],
  StyleBox["r",
    FontFamily->"Courier New"],
  StyleBox[",  then there exist at most  ",
    FontFamily->"Times-Roman"],
  StyleBox["r",
    FontFamily->"Courier New"],
  StyleBox["  linearly independent eigenvectors",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "1"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "2"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "r"]}]]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["that correspond to  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox[".",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Linearly Independent Eigenvectors).",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["Suppose that  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  is and  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[" \[Times] ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  square matrix.  If the eigenvalues ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(\[Lambda]\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\[Lambda]\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\[Lambda]\_k\)}]]],
  StyleBox[" ",
    FontFamily->"Times-Italic",
    FontSlant->"Italic"],
  StyleBox["are distinct and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(\[Lambda]\_1\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "1"], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["  ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(\[Lambda]\_12\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["V",
                  FontWeight->"Bold"], "2"], 
              StyleBox[";",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "..."}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(\[Lambda]\_k\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "k"]}]]],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  StyleBox["are the ",
    FontFamily->"Times-Roman"],
  StyleBox["k",
    FontFamily->"Courier New"],
  StyleBox[" eigenpairs, then  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "1"], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "2"], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "...", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "k"]}], "}"}]]],
  StyleBox[" ",
    FontFamily->"MTSYN"],
  StyleBox["is a set of  ",
    FontFamily->"Times-Roman"],
  StyleBox["k",
    FontFamily->"Courier New"],
  StyleBox[" linearly independent vectors. ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem (Complete Set of Eigenvectors).",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["Suppose that  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  is and  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox[" \[Times] ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  square matrix.  If the eigenvalues of  ",
    FontFamily->"Times-Roman"],
  StyleBox["A",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["  are all distinct, then there exist  ",
    FontFamily->"Times-Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  nearly independent eigenvectors",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "1"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "2"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "n"]}]]],
  ".",
  StyleBox["  ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Eigenvalues and Eigenvectors",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/EigenvaluesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Eigenvalues and Eigenvectors",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/EigenvaluesProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["\tFinding eigenpairs by hand computations is usually done in the \
following manner.  The eigenvalue",
    FontFamily->"Times New Roman"],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  StyleBox["of multiplicity",
    FontFamily->"Times New Roman"],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  StyleBox["r",
    FontFamily->"Courier New"],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  StyleBox["is substituted into the equation\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], "-", 
              StyleBox[
                RowBox[{"\[Lambda]", 
                  StyleBox["I",
                    FontWeight->"Bold"]}]]}], ")"}], 
          StyleBox["V",
            FontWeight->"Bold"]}], " ", "=", " ", "0"}]]],
  ".  ",
  StyleBox["\n\nThen Gaussian elimination can be performed to obtain the row \
reduced echelon form, which will involve  ",
    FontFamily->"Times New Roman"],
  StyleBox["n-k",
    FontFamily->"Courier New"],
  StyleBox["  equations in  ",
    FontFamily->"Times New Roman"],
  StyleBox["n",
    FontFamily->"Courier New"],
  StyleBox["  unknowns, where  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(1 \[LessEqual] k \[LessEqual] r\)]],
  StyleBox[".  Hence there are  ",
    FontFamily->"Times New Roman"],
  StyleBox["k",
    FontFamily->"Courier New"],
  StyleBox["  free variables to choose. The free variables can be selected in \
a judicious manner to produce  ",
    FontFamily->"Times New Roman"],
  StyleBox["k",
    FontFamily->"Courier New"],
  StyleBox["  linearly independent solution vectors",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "1"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "2"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "k"]}]]],
  StyleBox[" ",
    FontFamily->"Times-Italic",
    FontSlant->"Italic"],
  StyleBox["that correspond to",
    FontFamily->"Times New Roman"],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Lambda]\)]],
  StyleBox[".",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Eigenvalues and Eigenvectors",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/n2003/EigenvaluesProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Eigenvalues and Eigenvectors",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/EigenvaluesProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[BoxData[
    \(\(\(NewtonRaphson[x0_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{}, \[IndentingNewLine]k\
\  = \ 0; \ \[IndentingNewLine]p0\  = \ 
          N[x0]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {16, 16}], \*"\"\<,   f[\!\(p\_0\)] = \>\"", 
          NumberForm[f[p0], 16]\ ]; \ \[IndentingNewLine]p1\  = \ 
          p0; \ \[IndentingNewLine]While[\ 
          k < max, \[IndentingNewLine]p0\  = \ 
            p1; \ \[IndentingNewLine]p1\  = \ 
            p0\  - \ f[p0]\/\(f'\)[p0]; \ \[IndentingNewLine]k\  = \ 
            k + 1; \ \ \[IndentingNewLine]Print["\<p\>"\_k, "\< = \>", 
            PaddedForm[p1, {16, 16}], "\<,   f[\>", "\<p\>"\_k, "\<] = \>", 
            NumberForm[f[p1], 
              16]\ ];\ ]; \ \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p1, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", Abs[p1 - p0]\ ]; \ \[IndentingNewLine]Print["\<f[p] = \>", 
          NumberForm[f[p1], 16]\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the eigenvalues and eigenvectors of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"1", "2"},
              {"1", "1"}
              }], ")"}]}]]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold"]], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2"},
              {"1", "1"}
              }], ")"}]}], ";"}], "\n", 
    RowBox[{\(I\_2 = IdentityMatrix[2];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_2\ ;\), "\n", \(p[\[Lambda]_] = 
        Det[M];\), "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]]\  \[Equal] \ 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(Print["\<  A  = \>", 
        MatrixForm[\ A\ ]\ ];\), "\n", \(Print["\<  M  = \>", 
        MatrixForm[\ 
          M\ ]\ ];\), "\n", \(Print["\<p[\[Lambda]] = Det[M] = \>", \ 
        p[\[Lambda]]];\), "\[IndentingNewLine]", \(Print["\<Solve \
p[\[Lambda]] = 0  get\>"];\), "\[IndentingNewLine]", \(Print[
        TableForm[solset]];\)}], "Input"],

Cell[BoxData[{
    \(\(i = 1;\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda]\_i = 1 - \@2\ ;\)\), "\n", 
    \(\(B = {0, 0};\)\), "\[IndentingNewLine]", 
    \(\(b = Partition[B, 1];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M1 = AppendRows[M, b];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix M is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<M\>"\_i, "\< = \>", 
        MatrixForm[M1]];\)\), "\[IndentingNewLine]", 
    \(\(M1 = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(M1 = AppendRows[M1, b];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix M is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<M\>"\_i, "\< = \>", 
        MatrixForm[M1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form is\>"];\)\), "\
\[IndentingNewLine]", 
    \(Print[MatrixForm[\ RowReduce[\ M1]\ ]]\)}], "Input"],

Cell[TextData[{
  "This is equivalent to the linear system\n\n\t",
  Cell[BoxData[
      \(x\_1\  + \ \(\@2\) x\_2\  = \ 0\)]],
  "\n\nSet ",
  Cell[BoxData[
      \(x\_2 = \(-1\)\)]],
  " and solve for  ",
  Cell[BoxData[
      \(x\_1\  = \ \@2\)]],
  ", and get the eigenvector  "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(V\_1\), "=", 
        RowBox[{"(", GridBox[{
              {\(\@2\)},
              {\(-1\)}
              }], ")"}]}], ";"}]], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = (\>", \[Lambda]\_i, \
"\<)\>", MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i], "\< = \>", 
        ExpandAll[
          MatrixForm[\(\[Lambda]\_i\) V\_i]]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[A . V\_i]\  \[Equal] \ 
          ExpandAll[\(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(i = 2;\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda]\_i = 1 + \@2\ ;\)\), "\n", 
    \(\(B = {0, 0};\)\), "\[IndentingNewLine]", 
    \(\(b = Partition[B, 1];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M1 = AppendRows[M, b];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix M is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<M\>"\_i, "\< = \>", 
        MatrixForm[M1]];\)\), "\[IndentingNewLine]", 
    \(\(M1 = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(M1 = AppendRows[M1, b];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix M is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<M\>"\_i, "\< = \>", 
        MatrixForm[M1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form is\>"];\)\), "\
\[IndentingNewLine]", 
    \(Print[MatrixForm[\ RowReduce[\ M1]\ ]]\)}], "Input"],

Cell[TextData[{
  "This is equivalent to the linear system\n\n\t",
  Cell[BoxData[
      \(x\_1\  - \ \(\@2\) x\_2\  = \ 0\)]],
  "\n\nSet ",
  Cell[BoxData[
      \(x\_2 = 1\)]],
  " and solve for  ",
  Cell[BoxData[
      \(x\_1\  = \ \@2\)]],
  ", and get the eigenvector  "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(V\_2\), "=", 
        RowBox[{"(", GridBox[{
              {\(\@2\)},
              {"1"}
              }], ")"}]}], ";"}]], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = (\>", \[Lambda]\_i, \
"\<)\>", MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i], "\< = \>", 
        ExpandAll[
          MatrixForm[\(\[Lambda]\_i\) V\_i]]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[A . V\_i]\  \[Equal] \ 
          ExpandAll[\(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " Newton's method can be used to find the roots of the characteristic \
polynomial. "
}], "Text"],

Cell["For the first eigenvalue. ", "Text"],

Cell[BoxData[{
    \(\(f[x_] = p[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", \ p[x]];\)\), "\[IndentingNewLine]", 
    \(\(NewtonRaphson[\(-0.5\), 4];\)\)}], "Input"],

Cell["Which is an approximation to the eigenvalue", "Text"],

Cell[BoxData[
    \(\(Print["\<\[Lambda]\>"\_1, "\< = \>", \[Lambda]\_1, "\< = \>", 
        NumberForm[N[\[Lambda]\_1], 17]];\)\)], "Input"],

Cell["For the second eigenvalue. ", "Text"],

Cell[BoxData[{
    \(\(f[x_] = p[x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[x] = \>", \ p[x]];\)\), "\[IndentingNewLine]", 
    \(\(NewtonRaphson[1.5, 6];\)\)}], "Input"],

Cell["Which is an approximation to the eigenvalue", "Text"],

Cell[BoxData[
    \(\(Print["\<\[Lambda]\>"\_2, "\< = \>", \[Lambda]\_2, "\< = \>", 
        NumberForm[N[\[Lambda]\_2], 17]];\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Free Variables",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWhen the linear system is underdetermined, we needed to introduce \
free variables in the proper location. The following subroutine will \
rearrange the equations and introduce free variables in the location they are \
needed.  Then all that is needed to do is find the row reduced echelon form a \
second time.  This is done at the end of the next example."
}], "Text"],

Cell[BoxData[
    \(FreeVariables[M0_]\  := \ 
      Module[{c, i, k, L, M = M0, m, n, 
          Z}, \[IndentingNewLine]n = \(Dimensions[M]\)\_\(\(\
\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\); \[IndentingNewLine]m \
= \(Dimensions[M]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\
\); \[IndentingNewLine]L = {t, s, r, q, p, u, v, w, z, y, 
            x}; \[IndentingNewLine]Z = Table[0, {m}]; \[IndentingNewLine]c = 
          1; \[IndentingNewLine]For[i = 1, 
          i \[LessEqual] 
            n, \(i++\), \[IndentingNewLine]\(If[
              M\_\(\(\[LeftDoubleBracket]\)\(i, \
i\)\(\[RightDoubleBracket]\)\) \[Equal] 
                0, \[IndentingNewLine]\(For[k = n, 
                  i < k, \(k--\), \[IndentingNewLine]M\_\(\(\
\[LeftDoubleBracket]\)\(k\)\(\[RightDoubleBracket]\)\) = 
                    M\_\(\(\[LeftDoubleBracket]\)\(k - 1\)\(\
\[RightDoubleBracket]\)\)\ \ ];\)\ ];\)\ ]; \[IndentingNewLine]For[i = n, 
          1 \[LessEqual] 
            i, \(i--\), \[IndentingNewLine]\(If[
              M\_\(\(\[LeftDoubleBracket]\)\(i, \
i\)\(\[RightDoubleBracket]\)\) \[Equal] 
                0, \[IndentingNewLine]M\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\) = 
                Z; \[IndentingNewLine]M\_\(\(\[LeftDoubleBracket]\)\(i, i\)\(\
\[RightDoubleBracket]\)\) = 
                1; \[IndentingNewLine]M\_\(\(\[LeftDoubleBracket]\)\(i, m\)\(\
\[RightDoubleBracket]\)\) = 
                L\_\(\(\[LeftDoubleBracket]\)\(c\)\(\[RightDoubleBracket]\)\);\
 \[IndentingNewLine]c = c + 1;\ ];\)\ ]; \[IndentingNewLine]Return[
          M]]\)], "Input"],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the eigenvalues and eigenvectors of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"2", \(-1\), "1"},
              {\(-1\), "2", "1"},
              {"1", \(-1\), "2"}
              }], ")"}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Find the characteristic polynomial and the eigenvalues.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"2", \(-1\), "1"},
              {\(-1\), "2", "1"},
              {"1", \(-1\), "2"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(n = Length[A];\), "\[IndentingNewLine]",
   
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]]\  \[Equal] \ 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 0];\)}], "Input"],

Cell[TextData[{
  "Let us plot ",
  Cell[BoxData[
      \(p[\[Lambda]] = 
        6 - 11\ \[Lambda] + 6\ \[Lambda]\^2 - \[Lambda]\^3\)]],
  " and see where the roots are located"
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[p[\[Lambda]], {\[Lambda], 0, 3.5}, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = \>", p[\[Lambda]]];\)\)}], "Input"],

Cell["\<\
Although this example has been \"cooked up\" so that the values are \
simple, we should be aware that a root finding method could be employed to \
find the eigenvalues.  For illustration, we can use the Newton-Raphson \
method. \
\>", "Text"],

Cell[BoxData[
    \(\(f[x_] = p[x];\)\)], "Input"],

Cell[BoxData[
    \(\(NewtonRaphson[1.2, 6];\)\)], "Input"],

Cell[BoxData[
    \(\(NewtonRaphson[2.2, 4];\)\)], "Input"],

Cell[BoxData[
    \(\(NewtonRaphson[3.2, 5];\)\)], "Input"],

Cell["\<\
Since we have solved for roots in previous modules, we will \
concentrate our effort on solving for the eigenvectors.
First, we shall automate the procedure for finding the roots of the \
characteristic polynomial, which is one way to find the eigenvalues.\
\>", \
"Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"2", \(-1\), "1"},
              {\(-1\), "2", "1"},
              {"1", \(-1\), "2"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(n = Length[A];\), "\[IndentingNewLine]",
   
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 
          0];\), "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]Print["\<  \>", "\<\[Lambda]\>"\_i, \
"\< = \>", \[Lambda]\_i, "\< = \>", Chop[N[\[Lambda]\_i]]]\ ];\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_1, V\_1\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 1;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_2, V\_2\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 2;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_3, V\_3\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 3;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell["The three eigen-pairs are:", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          3, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", \[Lambda]\_i, "\<,  \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[V\_i]];\)\ ];\)\)}], "Input"],

Cell[TextData[{
  "We can compare this with the results obtained using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Eigensystem",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " procedure. "
}], "Text"],

Cell[BoxData[{
    \(\(sol = Eigensystem[A];\)\), "\[IndentingNewLine]", 
    \(\(n = Length[A];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", sol\_\(\(\[LeftDoubleBracket]\)\(1, i\)\(\[RightDoubleBracket]\)\), "\<, \
 \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[
              sol\_\(\(\[LeftDoubleBracket]\)\(2, \
i\)\(\[RightDoubleBracket]\)\)]];\)\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the eigenvalues and eigenvectors of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"2", \(-1\), "1"},
              {\(-1\), "2", \(-1\)},
              {"1", \(-1\), "2"}
              }], ")"}]}]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Find the characteristic polynomial and the eigenvalues.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"2", \(-1\), "1"},
              {\(-1\), "2", \(-1\)},
              {"1", \(-1\), "2"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(n = Length[A];\), "\[IndentingNewLine]",
   
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 
          0];\), "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]Print["\<  \>", "\<\[Lambda]\>"\_i, \
"\< = \>", \[Lambda]\_i, "\< = \>", Chop[N[\[Lambda]\_i]]]\ ];\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pairs  ",
  Cell[BoxData[
      \(\[Lambda]\_1, V\_1\)]],
  "  and   ",
  Cell[BoxData[
      \(\[Lambda]\_2, V\_2\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(i = 1;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["\<\
The eigenvalue is repeated, and there are two linearly independent \
eigenvectors. \
\>", "Text"],

Cell[TextData[{
  "Investigate the eigen-pairs  ",
  Cell[BoxData[
      \(\[Lambda]\_1, V\_1\)]],
  "  and   ",
  Cell[BoxData[
      \(\[Lambda]\_2, V\_2\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(W = V\_i;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<W = \>", MatrixForm[W]];\)\)}], "Input"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(V\_1\)]],
  ", set  ",
  StyleBox["s=0",
    FontFamily->"Courier New"],
  "  in  ",
  StyleBox["W",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and get "
}], "Text"],

Cell[BoxData[{
    \(\(\[Lambda]\_1\  = \ \[Lambda]\_1;\)\), "\[IndentingNewLine]", 
    \(\(V\_i = ReplaceAll[W, {s \[Rule] 0}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(V\_2\)]],
  ", set  ",
  StyleBox["t=0",
    FontFamily->"Courier New"],
  "  in  ",
  StyleBox["W",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and get "
}], "Text"],

Cell[BoxData[{
    \(\(i = 2;\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda]\_i\  = \ \[Lambda]\_1;\)\), "\[IndentingNewLine]", 
    \(\(V\_i = ReplaceAll[W, {t \[Rule] 0}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_3, V\_3\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 3;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell["\<\
It was good fortune that the three eigenvectors are linearly \
independent.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          3, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", \[Lambda]\_i, "\<,  \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[V\_i]];\)\ ];\)\)}], "Input"],

Cell[TextData[{
  "We can compare this with the results obtained using Mathematicas ",
  StyleBox["Eigensystem",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " procedure. "
}], "Text"],

Cell[BoxData[{
    \(\(sol = Eigensystem[A];\)\), "\[IndentingNewLine]", 
    \(\(n = Length[A];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", sol\_\(\(\[LeftDoubleBracket]\)\(1, i\)\(\[RightDoubleBracket]\)\), "\<, \
 \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[
              sol\_\(\(\[LeftDoubleBracket]\)\(2, \
i\)\(\[RightDoubleBracket]\)\)]];\)\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the eigenvalues and eigenvectors of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"1", "0", "3"},
              {"1", \(-1\), \(-3\)},
              {\(-1\), "2", \(-1\)}
              }], ")"}]}]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Find the characteristic polynomial and the eigenvalues.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"1", "0", "3"},
              {"1", \(-1\), \(-3\)},
              {\(-1\), "2", \(-1\)}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(n = Length[A];\), "\[IndentingNewLine]",
   
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 
          0];\), "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]Print["\<  \>", "\<\[Lambda]\>"\_i, \
"\< = \>", \[Lambda]\_i, "\< = \>", Chop[N[\[Lambda]\_i]]]\ ];\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_1, V\_1\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 1;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "In this case the eigenvector will have a nicer appearance if we replace ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["13t",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(V\_i = 13  V\_i;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = (\>", \[Lambda]\_i, \
"\<)\>", MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_2, V\_2\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 2;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "In this case the eigenvector will have a nicer appearance if we replace ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["13t",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(V\_i = 13  V\_i;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = (\>", \[Lambda]\_i, \
"\<)\>", MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_3, V\_3\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 3;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell["The three eigen-pairs are:", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          3, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", \[Lambda]\_i, "\<,  \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[V\_i]];\)\ ];\)\)}], "Input"],

Cell[TextData[{
  "We can compare this with the results obtained using Mathematicas ",
  StyleBox["Eigensystem",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " procedure. "
}], "Text"],

Cell[BoxData[{
    \(\(sol = Eigensystem[A];\)\), "\[IndentingNewLine]", 
    \(\(n = Length[A];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", sol\_\(\(\[LeftDoubleBracket]\)\(1, i\)\(\[RightDoubleBracket]\)\), "\<, \
 \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[
              sol\_\(\(\[LeftDoubleBracket]\)\(2, \
i\)\(\[RightDoubleBracket]\)\)]];\)\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the eigenvalues and eigenvectors of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"1", \(-1\), "0", "0"},
              {"1", "2", "0", "0"},
              {"0", "1", "1", \(-3\)},
              {"0", "0", "1", "2"}
              }], ")"}]}]]],
  ".  \nDo this by constructing the characteristic polynomial and finding its \
roots, and compare with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Eigenvalues",
    FontWeight->"Bold"],
  " procedure."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Find the characteristic polynomial and the eigenvalues.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          RowBox[{"(", GridBox[{
                {"1", \(-1\), "0", "0"},
                {"1", "2", "0", "0"},
                {"0", "1", "1", \(-3\)},
                {"0", "0", "1", "2"}
                }], ")"}]}], ";"}], 
      "  "}], "\[IndentingNewLine]", \(n = 
        Length[A];\), "\[IndentingNewLine]", 
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 
          0];\), "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]Print["\<  \>", "\<\[Lambda]\>"\_i, \
"\< = \>", \[Lambda]\_i, "\< = \>", Chop[N[\[Lambda]\_i]]]\ ];\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_1, V\_1\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 1;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "In this case the eigenvector will have a nicer appearance if we replace ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["2t",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(V\_i = 2  V\_i;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = (\>", \[Lambda]\_i, \
"\<)\>", MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_2, V\_2\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 2;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "In this case the eigenvector will have a nicer appearance if we replace ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["2t",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(V\_i = 2  V\_i;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = (\>", \[Lambda]\_i, \
"\<)\>", MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_3, V\_3\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 3;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "In this case the eigenvector will have a nicer appearance if we replace ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["2t",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(V\_i = 2  V\_i;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_4, V\_4\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 4;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "In this case the eigenvector will have a nicer appearance if we replace ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " with ",
  StyleBox["2t",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(V\_i = 2  V\_i;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell["The four eigen-pairs are:", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          4, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", \[Lambda]\_i, "\<,  \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[V\_i]];\)\ ];\)\)}], "Input"],

Cell[TextData[{
  "We can compare this with the results obtained using Mathematicas ",
  StyleBox["Eigensystem",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " procedure. "
}], "Text"],

Cell[BoxData[{
    \(\(sol = Eigensystem[A];\)\), "\[IndentingNewLine]", 
    \(\(n = Length[A];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", sol\_\(\(\[LeftDoubleBracket]\)\(1, i\)\(\[RightDoubleBracket]\)\), "\<, \
 \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[
              sol\_\(\(\[LeftDoubleBracket]\)\(2, \
i\)\(\[RightDoubleBracket]\)\)]];\)\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the eigenvalues and eigenvectors of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"2", "1", "0", "0", "0"},
              {"1", "2", "1", "0", "0"},
              {"0", "1", "2", "1", "0"},
              {"0", "0", "1", "2", "1"},
              {"0", "0", "0", "1", "2"}
              }], ")"}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Find the characteristic polynomial and the eigenvalues.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
              {"2", "1", "0", "0", "0"},
              {"1", "2", "1", "0", "0"},
              {"0", "1", "2", "1", "0"},
              {"0", "0", "1", "2", "1"},
              {"0", "0", "0", "1", "2"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(n = Length[A];\), "\[IndentingNewLine]",
   
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 
          0];\), "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]Print["\<  \>", "\<\[Lambda]\>"\_i, \
"\< = \>", \[Lambda]\_i, "\< = \>", Chop[N[\[Lambda]\_i]]]\ ];\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_1, V\_1\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 1;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4\ , 
          x\_5};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_2, V\_2\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 2;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4\ , 
          x\_5};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_3, V\_3\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 3;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4\ , 
          x\_5};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_4, V\_4\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 4;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4\ , 
          x\_5};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell[TextData[{
  "Investigate the eigen-pair  ",
  Cell[BoxData[
      \(\[Lambda]\_5, V\_5\)]]
}], "Text"],

Cell[BoxData[{
    \(\(i = 5;\)\), "\[IndentingNewLine]", 
    \(\(A\_i = 
        ReplaceAll[
          M, \[Lambda] \[Rule] \[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(vars = {x\_1\ , x\_2\ , x\_3, x\_4\ , 
          x\_5};\)\), "\[IndentingNewLine]", 
    \(\(B = {0, 0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(M\_i = 
        AppendRows[A\_i, Partition[B, 1]];\)\ \), "\[IndentingNewLine]", 
    \(\(RM\_i = RowReduce[\ M\_i];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`MatrixManipulation`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<For the eigenvalue   \>", "\<\[Lambda]\>"\_i, "\< = \>", \
\[Lambda]\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solve the equation \>", "\<A\>"\_i\ , "\< X = 0\>"];\)\), "\n\
", 
    \(\(Print["\<A\>"\_i\ , "\< X = \>", 
        MatrixForm[A\_i] MatrixForm[vars], "\< = \>", 
        MatrixForm[B]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The augmented matrix \>", "\<M\>"\_i, "\< = [A,B] \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  \>", "\<M\>"\_i, "\< = \>", 
        MatrixForm[M\_1]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The row reduced echelon form for \>", "\<M\>"\_i, "\< \
is\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<     \>", MatrixForm[\ RM\_i\ ]];\)\)}], "Input"],

Cell["Introduce the free variables and find the eigenvector.", "Text"],

Cell[BoxData[{
    \(\(Print["\<Introduce the free variables\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(FM\_i = FreeVariables[RM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[FM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Find the reduced row echelon form\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(SM\_i = RowReduce[\ FM\_i];\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[SM\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The eigenvector is in the last column\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(V\_i = TakeColumns[SM\_i, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", MatrixForm[V\_i]];\)\)}], "Input"],

Cell["Verify the eigenpair. ", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\< = \>", \[Lambda]\_i];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<V\>"\_i, "\< = \>", 
        MatrixForm[V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Does  \>", "\<A \>", "\<V\>"\_i, "\< = \>", \
"\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< ?\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A \>", "\<V\>"\_i, "\< = \>", MatrixForm[A], 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[A . V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Lambda]\>"\_i, "\<V\>"\_i, "\< = \>", \[Lambda]\_i, 
        MatrixForm[V\_i], "\< = \>", 
        MatrixForm[\(\[Lambda]\_i\) V\_i]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        ExpandAll[
          A . V\_i\  \[Equal] \ \(\[Lambda]\_i\) V\_i]];\)\)}], "Input"],

Cell["The five eigen-pairs are:", "Text"],

Cell[BoxData[{
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          5, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", \[Lambda]\_i, "\<,  \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[V\_i]];\)\ ];\)\)}], "Input"],

Cell[TextData[{
  "We can compare this with the results obtained using Mathematicas ",
  StyleBox["Eigensystem",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  " procedure. "
}], "Text"],

Cell[BoxData[{
    \(\(sol = Eigensystem[A];\)\), "\[IndentingNewLine]", 
    \(\(n = Length[A];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", sol\_\(\(\[LeftDoubleBracket]\)\(1, i\)\(\[RightDoubleBracket]\)\), "\<, \
 \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[
              sol\_\(\(\[LeftDoubleBracket]\)\(2, \
i\)\(\[RightDoubleBracket]\)\)]];\)\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the eigenvalues and eigenvectors of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"2", "1", "0", "0", "0", "0"},
              {"1", "2", "1", "0", "0", "0"},
              {"0", "1", "2", "1", "0", "0"},
              {"0", "0", "1", "2", "1", "0"},
              {"0", "0", "0", "1", "2", "1"},
              {"0", "0", "0", "0", "1", "2"}
              }], ")"}]}]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          RowBox[{"(", GridBox[{
                {"2", "1", "0", "0", "0", "0"},
                {"1", "2", "1", "0", "0", "0"},
                {"0", "1", "2", "1", "0", "0"},
                {"0", "0", "1", "2", "1", "0"},
                {"0", "0", "0", "1", "2", "1"},
                {"0", "0", "0", "0", "1", "2"}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(n = Length[A];\), "\[IndentingNewLine]",
   
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 
          0];\), "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]Print["\<  \>", "\<\[Lambda]\>"\_i, \
"\< = \>", \[Lambda]\_i, "\< = \>", Chop[N[\[Lambda]\_i]]]\ ];\)}], "Input"],

Cell["\<\
Symbolic solution of the eigenvectors for this example can be done, \
however the numerical solution is easier to read.\
\>", "Text"],

Cell[BoxData[{
    \(\(sol = Eigensystem[N[A]];\)\), "\[IndentingNewLine]", 
    \(\(n = Length[A];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", sol\_\(\(\[LeftDoubleBracket]\)\(1, i\)\(\[RightDoubleBracket]\)\), "\<, \
 \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[
              sol\_\(\(\[LeftDoubleBracket]\)\(2, \
i\)\(\[RightDoubleBracket]\)\)]];\)\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Find the eigenvalues and eigenvectors of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {"5", "1", "2", "0", "4"},
              {"1", "4", "2", "1", "3"},
              {"2", "2", "5", "4", "0"},
              {"0", "1", "4", "1", "3"},
              {"4", "3", "0", "3", "4"}
              }], ")"}]}]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          RowBox[{"(", GridBox[{
                {"5", "1", "2", "0", "4"},
                {"1", "4", "2", "1", "3"},
                {"2", "2", "5", "4", "0"},
                {"0", "1", "4", "1", "3"},
                {"4", "3", "0", "3", "4"}
                }], ")"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(n = Length[A];\), "\[IndentingNewLine]",
   
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 
          0];\), "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]Print["\<  \>", "\<\[Lambda]\>"\_i, \
"\< = \>", \[Lambda]\_i, "\< = \>", Chop[N[\[Lambda]\_i]]]\ ];\)}], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " did not make a mistake !  We just don't know what it meant !  Just ask it \
for those numbers !  "
}], "Text"],

Cell[BoxData[
    \(\(\(N[solset]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We could have avoided the problem completely by just using the numerical \
features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(NSolve[p[\[Lambda]] \[Equal] 0]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(Eigenvalues[N[A]]\)\(\ \ \)\)\)], "Input"],

Cell["\<\
Symbolic solution of the eigenvectors for this example can be done, \
however the numerical solution is easier to read.\
\>", "Text"],

Cell[BoxData[{
    \(\(sol = Eigensystem[N[A]];\)\), "\[IndentingNewLine]", 
    \(\(n = Length[A];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<A = \>", MatrixForm[A]];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(Print["\<\[Lambda]\>"\_i, "\< = \
\>", sol\_\(\(\[LeftDoubleBracket]\)\(1, i\)\(\[RightDoubleBracket]\)\), "\<, \
 \>", "\<V\>"\_i, "\< = \>", 
            MatrixForm[
              sol\_\(\(\[LeftDoubleBracket]\)\(2, \
i\)\(\[RightDoubleBracket]\)\)]];\)\ ];\)\)}], "Input"],

Cell[TextData[{
  "Here is the documentation for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  ".  \nYou can find it by going to the Help menu and locating help for ",
  StyleBox["GroebnerBasis",
    FontWeight->"Bold"],
  ", \nthen scroll down and go to: Implementation Notes: see section ",
  ButtonBox["A.9.5",
    ButtonData:>{"A.9.5", "5.7"},
    ButtonStyle->"MainBookLink"],
  ".  \n\nExact equation solving \n1.\tFor linear equations Gaussian \
elimination and other methods of linear algebra are used. \n2.\t",
  StyleBox["Root",
    FontWeight->"Bold"],
  " objects representing algebraic numbers are usually isolated and \
manipulated using validated numerical methods. \n\tWith  ",
  StyleBox["ExactRootIsolation->True",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["Root",
    FontWeight->"Bold"],
  "  uses for real roots a continued fraction version of an algorithm based \
on Descartes' rule of signs,\n\tand for complex roots the \
Collins\[Hyphen]Krandick algorithm. \n3.\tFor single polynomial equations, ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " uses explicit formulas up to degree four,attempts to reduce polynomials \
using ",
  StyleBox["Factor",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Decompose",
    FontWeight->"Bold"],
  ",\n\tand recognizes cyclotomic and other special polynomials. \n4.\tFor \
systems of polynomial equations, ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " constructs a Gr\[ODoubleDot]bner basis. \n5.\t",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GrobnerBasis",
    FontWeight->"Bold"],
  " use an efficient version of the Buchberger algorithm. \n6.\tFor non\
\[Hyphen]polynomial equations, ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " attempts to change variables and add polynomial side conditions. \n7.\t\
The code inside ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  " is about ",
  StyleBox["500 pages long",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["Comments.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  How much do we know or teach about polynomials ?  How much should we ?  \
The area of computer science called artificial intelligence treats the topic \
of \"expert system.\"  To construct an \"expert system\" you tap into the \
brains of the experts, and program them into your computer.  Apparently ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has already done this, it took 500 lines of code.  They speak of \
\"information overload\" in the future.  The future was 13 years ago with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \[Copyright]1988",
  StyleBox[" ",
    FontSlant->"Italic"],
  " and 20 years ago with Maple \[Copyright]1981."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Find the eigenvalues of the matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["A",
          FontWeight->"Bold"], "=", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(1\/2\), \(1\/3\), "0", "0", "0", "0", "0", "0", "0", "0", 
                  "0"},
                {\(1\/2\), \(1\/3\), \(1\/3\), "0", "0", "0", "0", "0", "0", 
                  "0", "0"},
                {"0", \(1\/3\), \(1\/3\), \(1\/3\), "0", "0", "0", "0", "0", 
                  "0", "0"},
                {"0", "0", \(1\/3\), \(1\/3\), \(1\/3\), "0", "0", "0", "0", 
                  "0", "0"},
                {"0", "0", "0", \(1\/3\), \(1\/3\), \(1\/3\), "0", "0", "0", 
                  "0", "0"},
                {"0", "0", "0", "0", \(1\/3\), \(1\/3\), \(1\/3\), "0", "0", 
                  "0", "0"},
                {"0", "0", "0", "0", "0", \(1\/3\), \(1\/3\), \(1\/3\), "0", 
                  "0", "0"},
                {"0", "0", "0", "0", "0", "0", \(1\/3\), \(1\/3\), \(1\/3\), 
                  "0", "0"},
                {"0", "0", "0", "0", "0", "0", 
                  "0", \(1\/3\), \(1\/3\), \(1\/3\), "0"},
                {"0", "0", "0", "0", "0", "0", "0", 
                  "0", \(1\/3\), \(1\/3\), \(1\/2\)},
                {"0", "0", "0", "0", "0", "0", "0", "0", 
                  "0", \(1\/3\), \(1\/2\)}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}]]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"A", "=", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(1\/2\), \(1\/3\), "0", "0", "0", "0", "0", "0", "0", "0",
                     "0"},
                  {\(1\/2\), \(1\/3\), \(1\/3\), "0", "0", "0", "0", "0", "0",
                     "0", "0"},
                  {"0", \(1\/3\), \(1\/3\), \(1\/3\), "0", "0", "0", "0", "0",
                     "0", "0"},
                  {"0", "0", \(1\/3\), \(1\/3\), \(1\/3\), "0", "0", "0", "0",
                     "0", "0"},
                  {"0", "0", "0", \(1\/3\), \(1\/3\), \(1\/3\), "0", "0", "0",
                     "0", "0"},
                  {"0", "0", "0", "0", \(1\/3\), \(1\/3\), \(1\/3\), "0", "0",
                     "0", "0"},
                  {"0", "0", "0", "0", "0", \(1\/3\), \(1\/3\), \(1\/3\), "0",
                     "0", "0"},
                  {"0", "0", "0", "0", "0", "0", \(1\/3\), \(1\/3\), \(1\/3\),
                     "0", "0"},
                  {"0", "0", "0", "0", "0", "0", 
                    "0", \(1\/3\), \(1\/3\), \(1\/3\), "0"},
                  {"0", "0", "0", "0", "0", "0", "0", 
                    "0", \(1\/3\), \(1\/3\), \(1\/2\)},
                  {"0", "0", "0", "0", "0", "0", "0", "0", 
                    "0", \(1\/3\), \(1\/2\)}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]]}], ";"}], 
      "  "}], "\[IndentingNewLine]", \(n = 
        Length[A];\), "\[IndentingNewLine]", 
    RowBox[{\(I\_n = IdentityMatrix[n];\), 
      " "}], "\n", \(M = A - \[Lambda]\ I\_n;\), "\[IndentingNewLine]", 
    RowBox[{\(p[\[Lambda]_] = Det[A - \[Lambda]\ I\_n];\), 
      " "}], "\[IndentingNewLine]", \(solset = 
        Solve[p[\[Lambda]] \[Equal] 
            0, \[Lambda]];\), "\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]\(\[Lambda]\_i\  = \ 
            solset\_\(\(\[LeftDoubleBracket]\)\(i, 1, 2\)\(\
\[RightDoubleBracket]\)\);\)]\ ;\), "\[IndentingNewLine]", \(Print["\<      A \
= \>", MatrixForm[
          A]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\>"\
\_n, "\< = \>", MatrixForm[A], "\< - \[Lambda]\>", 
        MatrixForm[
          I\_n]];\), "\[IndentingNewLine]", \(Print["\<A - \[Lambda]\>", "\<I\
\>"\_n, "\< = \>", 
        MatrixForm[
          M]];\), "\[IndentingNewLine]", \(Print["\<The characteristic \
polynomial is\>"];\), "\[IndentingNewLine]", \(Print[\*"\"\<p[\[Lambda]] = \
|A-\[Lambda] \!\(I\_n\)|\>\""];\), "\[IndentingNewLine]", \(Print["\<p[\
\[Lambda]] = \>", p[\[Lambda]]];\), "\[IndentingNewLine]", \(q[\[Lambda]_] = 
        Factor[p[\[Lambda]]];\), "\[IndentingNewLine]", \(If[
        Not[p[\[Lambda]] === q[\[Lambda]]], 
        Print["\<p[\[Lambda]] = \>", 
          q[\[Lambda]]]];\), "\[IndentingNewLine]", \(Print["\<To find the \
eigenvalues of the matrix A\>"];\), "\[IndentingNewLine]", \(Print["\<Solve  \
\>", p[\[Lambda]] \[Equal] 
          0];\), "\[IndentingNewLine]", \(Print["\<Get\>"];\), "\
\[IndentingNewLine]", \(For[i = 1, 
        i \[LessEqual] 
          n, \(i++\), \[IndentingNewLine]Print["\<  \>", "\<\[Lambda]\>"\_i, \
"\< = \>", Chop[N[\[Lambda]\_i]]]\ ];\)}], "Input"],

Cell[BoxData[{
    \(\(solset2 = Eigenvalues[N[A]];\)\), "\[IndentingNewLine]", 
    \(Sort[Chop[solset2], Less]\)}], "Input"],

Cell["\<\
Are the answers the same ?  It might be good to sort the answers \
for comparison. \
\>", "Text"],

Cell[BoxData[
    \(Sort[
      Chop[N[solset\_\(\(\[LeftDoubleBracket]\)\(All, 1, 2\)\(\
\[RightDoubleBracket]\)\)]], Less]\)], "Input"],

Cell[TextData[{
  "Of course they are the same (when ",
  Cell[BoxData[
      \(n \[LessEqual] 20\)]],
  ").\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a very accurate NSolve, Eigenvalues subroutine. We expect them to \
agree.  But root finding algorithms have their limitations. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the eigenvalues of the following matrix  ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(n = 25;\)\ \), "\[IndentingNewLine]", 
    \(\(A = 
        DiagonalMatrix[Table[1\/3, {n}]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] 
          n - 1, \(i++\), \
\[IndentingNewLine]\(A\_\(\(\[LeftDoubleBracket]\)\(i, i + 1\)\(\
\[RightDoubleBracket]\)\) = \(A\_\(\(\[LeftDoubleBracket]\)\(i + 1, i\)\(\
\[RightDoubleBracket]\)\) = 1\/3\);\)];\)\), "\[IndentingNewLine]", 
    \(\(A\_\(\(\[LeftDoubleBracket]\)\(1, 1\)\(\[RightDoubleBracket]\)\) = \
\(A\_\(\(\[LeftDoubleBracket]\)\(2, 1\)\(\[RightDoubleBracket]\)\) = \ \
\(A\_\(\(\[LeftDoubleBracket]\)\(n - 1, n\)\(\[RightDoubleBracket]\)\) = \
\(A\_\(\(\[LeftDoubleBracket]\)\(n, n\)\(\[RightDoubleBracket]\)\) = 
              1\/2\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(Print[MatrixForm[A]];\)\ \), "\[IndentingNewLine]", 
    \(\(Id = IdentityMatrix[n];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Clear[p, \[Lambda]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(p[\[Lambda]_] = 
        Det[A - Id\ \[Lambda]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = \>", 
        p[\[Lambda]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(solset1 = 
        NSolve[p[\[Lambda]] \[Equal] 0];\)\), "\[IndentingNewLine]", 
    \(\(solset2 = Eigenvalues[N[A]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solution for the eigenvalues\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<By using Root Finding and solving p[\[Lambda]] = 0\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<By using Mathematica's procedure `Eigenvalues`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Transpose[{Sort[
                solset1\_\(\(\[LeftDoubleBracket]\)\(All, 1, 2\)\(\
\[RightDoubleBracket]\)\), Greater], Sort[solset2, Greater]}], 
          TableHeadings \[Rule] {None, {"\<Root Finding\>", "\<Eigenvalue \
Procedure\>"}}]];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Which method do we trust ?  \nAre the answers on the left better or are \
the answers on right better ?\n\nWe trust ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Eigenvalue subroutine !   \n\nWe should go with the answers on the \
right.  This is a transition matrix and it is known that one of its \
eigenvalues is  ",
  Cell[BoxData[
      \(\[Lambda] = 1\)]],
  ".   \n\nThe eigenvalue-eigenvector methods we study seem overbearing, but \
they are necessary when ",
  Cell[BoxData[
      \(n > 20\)]],
  ". "
}], "Text"],

Cell["\<\
We could try to envision the difficulties of finding the root of \
\
\>", "Text"],

Cell[BoxData[{
    \(\(Plot[p[\[Lambda]], {\[Lambda], \(-0.4\), 1.1}, 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<p[\[Lambda]] = \>", p[\[Lambda]]];\)\)}], "Input"],

Cell[BoxData[{
    \(\(f[x_] = 376572715308  p[x];\)\), "\[IndentingNewLine]", 
    \(\(Plot[p[x], {x, \(-0.4\), 1.1}, 
        PlotStyle \[Rule] Magenta];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\), "\[IndentingNewLine]", 
    \(NewtonRaphson[1.01, 50]\)}], "Input"],

Cell["\<\
Clearly, there are computational problems in evaluating the \
Newton-Raphson iteration function.  This is why there are methods for finding \
eigenvalues that do not rely on finding roots of polynomials.  \
\>", "Text"]
}, Closed]],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Eigenvalues and Eigenvectors",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/EigenvaluesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Eigenvalues and Eigenvectors",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/EigenvaluesBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 181, 4, 35, "Text"],
Cell[1960, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3439, 111, 3023, 93, 144, "Text"],
Cell[6465, 206, 1298, 26, 145, "Text"],
Cell[7766, 234, 444, 10, 52, "Text"],
Cell[8213, 246, 391, 9, 107, "Text"],

Cell[CellGroupData[{
Cell[8629, 259, 101, 2, 33, "Text"],
Cell[8733, 263, 469, 11, 107, "Text"],
Cell[9205, 276, 410, 10, 88, "Text"],
Cell[9618, 288, 1369, 45, 169, "Text"],
Cell[10990, 335, 148, 5, 33, "Text"],
Cell[11141, 342, 340, 5, 70, "Input"],
Cell[11484, 349, 306, 14, 33, "Text"],
Cell[11793, 365, 1113, 21, 270, "Input"],
Cell[12909, 388, 316, 13, 33, "Text",
  Evaluatable->False],
Cell[13228, 403, 423, 7, 130, "Input"],
Cell[13654, 412, 242, 11, 33, "Text"],
Cell[13899, 425, 159, 3, 50, "Input"],
Cell[14061, 430, 566, 9, 70, "Input"],
Cell[14630, 441, 247, 5, 63, "Input"],
Cell[14880, 448, 566, 9, 70, "Input"],
Cell[15449, 459, 923, 29, 188, "Text"],
Cell[16375, 490, 333, 9, 57, "Input"],
Cell[16711, 501, 429, 16, 71, "Text"],
Cell[17143, 519, 623, 10, 130, "Input"],
Cell[17769, 531, 244, 8, 33, "Text"],
Cell[18016, 541, 230, 4, 90, "Input"]
}, Closed]],
Cell[18261, 548, 7552, 228, 258, "Text"],
Cell[25816, 778, 1535, 48, 33, "Text"],
Cell[27354, 828, 217, 4, 33, "Text"],
Cell[27574, 834, 4970, 153, 90, "Text"],
Cell[32547, 989, 1280, 42, 33, "Text"],
Cell[33830, 1033, 3980, 126, 109, "Text"],
Cell[37813, 1161, 631, 20, 33, "Text"],
Cell[38447, 1183, 1372, 39, 71, "Text"],
Cell[39822, 1224, 7137, 248, 301, "Text"],
Cell[46962, 1474, 1445, 29, 149, "Text"],
Cell[48410, 1505, 1706, 50, 107, "Text"],

Cell[CellGroupData[{
Cell[50141, 1559, 266, 10, 33, "Text"],
Cell[50410, 1571, 905, 18, 210, "Input"],
Cell[51318, 1591, 647, 12, 150, "Input"],
Cell[51968, 1605, 647, 12, 150, "Input"]
}, Closed]],
Cell[52630, 1620, 1155, 37, 50, "Text"],
Cell[53788, 1659, 2305, 75, 72, "Text"],
Cell[56096, 1736, 2153, 78, 111, "Text"],
Cell[58252, 1816, 1822, 52, 147, "Text"],
Cell[60077, 1870, 128, 2, 33, "Text"],
Cell[60208, 1874, 2819, 95, 73, "Text"],
Cell[63030, 1971, 7162, 217, 53, "Text"],
Cell[70195, 2190, 2170, 72, 53, "Text"],
Cell[72368, 2264, 631, 20, 33, "Text"],
Cell[73002, 2286, 3362, 108, 128, "Text"],
Cell[76367, 2396, 617, 19, 33, "Text"],
Cell[76987, 2417, 1069, 18, 310, "Input"],
Cell[78059, 2437, 380, 14, 41, "Text"],

Cell[CellGroupData[{
Cell[78464, 2455, 101, 2, 33, "Text"],
Cell[78568, 2459, 795, 17, 222, "Input"],
Cell[79366, 2478, 1124, 22, 312, "Input"],
Cell[80493, 2502, 294, 11, 109, "Text"],
Cell[80790, 2515, 179, 6, 47, "Input"],
Cell[80972, 2523, 38, 0, 33, "Text"],
Cell[81013, 2525, 947, 18, 150, "Input"],
Cell[81963, 2545, 1124, 22, 312, "Input"],
Cell[83090, 2569, 289, 11, 109, "Text"],
Cell[83382, 2582, 176, 6, 47, "Input"],
Cell[83561, 2590, 38, 0, 33, "Text"],
Cell[83602, 2592, 947, 18, 150, "Input"],
Cell[84552, 2612, 196, 6, 33, "Text"],
Cell[84751, 2620, 42, 0, 33, "Text"],
Cell[84796, 2622, 184, 3, 70, "Input"],
Cell[84983, 2627, 59, 0, 33, "Text"],
Cell[85045, 2629, 141, 2, 30, "Input"],
Cell[85189, 2633, 43, 0, 33, "Text"],
Cell[85235, 2635, 179, 3, 70, "Input"],
Cell[85417, 2640, 59, 0, 33, "Text"],
Cell[85479, 2642, 141, 2, 30, "Input"]
}, Closed]],
Cell[85635, 2647, 483, 9, 87, "Text"],
Cell[86121, 2658, 1625, 30, 352, "Input"],
Cell[87749, 2690, 431, 15, 57, "Text"],

Cell[CellGroupData[{
Cell[88205, 2709, 101, 2, 33, "Text"],
Cell[88309, 2713, 71, 0, 33, "Text"],
Cell[88383, 2715, 1792, 36, 400, "Input"],
Cell[90178, 2753, 190, 6, 33, "Text"],
Cell[90371, 2761, 264, 4, 70, "Input"],
Cell[90638, 2767, 252, 5, 33, "Text"],
Cell[90893, 2774, 50, 1, 30, "Input"],
Cell[90946, 2777, 59, 1, 30, "Input"],
Cell[91008, 2780, 59, 1, 30, "Input"],
Cell[91070, 2783, 59, 1, 30, "Input"],
Cell[91132, 2786, 282, 6, 52, "Text"],
Cell[91417, 2794, 2053, 41, 460, "Input"],
Cell[93473, 2837, 108, 4, 33, "Text"],
Cell[93584, 2843, 1358, 27, 310, "Input"],
Cell[94945, 2872, 70, 0, 33, "Text"],
Cell[95018, 2874, 676, 12, 190, "Input"],
Cell[95697, 2888, 38, 0, 33, "Text"],
Cell[95738, 2890, 856, 16, 150, "Input"],
Cell[96597, 2908, 108, 4, 33, "Text"],
Cell[96708, 2914, 1358, 27, 310, "Input"],
Cell[98069, 2943, 70, 0, 33, "Text"],
Cell[98142, 2945, 676, 12, 190, "Input"],
Cell[98821, 2959, 38, 0, 33, "Text"],
Cell[98862, 2961, 856, 16, 150, "Input"],
Cell[99721, 2979, 108, 4, 33, "Text"],
Cell[99832, 2985, 1358, 27, 310, "Input"],
Cell[101193, 3014, 70, 0, 33, "Text"],
Cell[101266, 3016, 676, 12, 190, "Input"],
Cell[101945, 3030, 38, 0, 33, "Text"],
Cell[101986, 3032, 856, 16, 150, "Input"],
Cell[102845, 3050, 42, 0, 33, "Text"],
Cell[102890, 3052, 313, 6, 70, "Input"],
Cell[103206, 3060, 245, 9, 34, "Text"],
Cell[103454, 3071, 559, 11, 110, "Input"]
}, Closed]],
Cell[104028, 3085, 432, 15, 54, "Text"],

Cell[CellGroupData[{
Cell[104485, 3104, 101, 2, 33, "Text"],
Cell[104589, 3108, 71, 0, 33, "Text"],
Cell[104663, 3110, 2056, 41, 460, "Input"],
Cell[106722, 3153, 180, 8, 33, "Text"],
Cell[106905, 3163, 1358, 27, 310, "Input"],
Cell[108266, 3192, 70, 0, 33, "Text"],
Cell[108339, 3194, 676, 12, 190, "Input"],
Cell[109018, 3208, 107, 3, 33, "Text"],
Cell[109128, 3213, 180, 8, 33, "Text"],
Cell[109311, 3223, 119, 2, 50, "Input"],
Cell[109433, 3227, 233, 12, 34, "Text"],
Cell[109669, 3241, 230, 3, 70, "Input"],
Cell[109902, 3246, 38, 0, 33, "Text"],
Cell[109943, 3248, 856, 16, 150, "Input"],
Cell[110802, 3266, 233, 12, 34, "Text"],
Cell[111038, 3280, 274, 4, 90, "Input"],
Cell[111315, 3286, 38, 0, 33, "Text"],
Cell[111356, 3288, 856, 16, 150, "Input"],
Cell[112215, 3306, 108, 4, 33, "Text"],
Cell[112326, 3312, 1358, 27, 310, "Input"],
Cell[113687, 3341, 70, 0, 33, "Text"],
Cell[113760, 3343, 676, 12, 190, "Input"],
Cell[114439, 3357, 38, 0, 33, "Text"],
Cell[114480, 3359, 856, 16, 150, "Input"],
Cell[115339, 3377, 99, 3, 33, "Text"],
Cell[115441, 3382, 313, 6, 70, "Input"],
Cell[115757, 3390, 197, 6, 34, "Text"],
Cell[115957, 3398, 559, 11, 110, "Input"]
}, Closed]],
Cell[116531, 3412, 432, 15, 54, "Text"],

Cell[CellGroupData[{
Cell[116988, 3431, 101, 2, 33, "Text"],
Cell[117092, 3435, 71, 0, 33, "Text"],
Cell[117166, 3437, 2056, 41, 460, "Input"],
Cell[119225, 3480, 108, 4, 33, "Text"],
Cell[119336, 3486, 1358, 27, 310, "Input"],
Cell[120697, 3515, 70, 0, 33, "Text"],
Cell[120770, 3517, 676, 12, 190, "Input"],
Cell[121449, 3531, 221, 8, 33, "Text"],
Cell[121673, 3541, 140, 2, 50, "Input"],
Cell[121816, 3545, 38, 0, 33, "Text"],
Cell[121857, 3547, 859, 16, 150, "Input"],
Cell[122719, 3565, 108, 4, 33, "Text"],
Cell[122830, 3571, 1358, 27, 310, "Input"],
Cell[124191, 3600, 70, 0, 33, "Text"],
Cell[124264, 3602, 676, 12, 190, "Input"],
Cell[124943, 3616, 221, 8, 33, "Text"],
Cell[125167, 3626, 140, 2, 50, "Input"],
Cell[125310, 3630, 38, 0, 33, "Text"],
Cell[125351, 3632, 859, 16, 150, "Input"],
Cell[126213, 3650, 108, 4, 33, "Text"],
Cell[126324, 3656, 1358, 27, 310, "Input"],
Cell[127685, 3685, 70, 0, 33, "Text"],
Cell[127758, 3687, 676, 12, 190, "Input"],
Cell[128437, 3701, 38, 0, 33, "Text"],
Cell[128478, 3703, 856, 16, 150, "Input"],
Cell[129337, 3721, 42, 0, 33, "Text"],
Cell[129382, 3723, 313, 6, 70, "Input"],
Cell[129698, 3731, 197, 6, 34, "Text"],
Cell[129898, 3739, 559, 11, 110, "Input"]
}, Closed]],
Cell[130472, 3753, 706, 23, 89, "Text"],

Cell[CellGroupData[{
Cell[131203, 3780, 101, 2, 33, "Text"],
Cell[131307, 3784, 71, 0, 33, "Text"],
Cell[131381, 3786, 2144, 43, 478, "Input"],
Cell[133528, 3831, 108, 4, 33, "Text"],
Cell[133639, 3837, 1367, 27, 310, "Input"],
Cell[135009, 3866, 70, 0, 33, "Text"],
Cell[135082, 3868, 676, 12, 190, "Input"],
Cell[135761, 3882, 220, 8, 33, "Text"],
Cell[135984, 3892, 139, 2, 50, "Input"],
Cell[136126, 3896, 38, 0, 33, "Text"],
Cell[136167, 3898, 859, 16, 150, "Input"],
Cell[137029, 3916, 108, 4, 33, "Text"],
Cell[137140, 3922, 1367, 27, 310, "Input"],
Cell[138510, 3951, 70, 0, 33, "Text"],
Cell[138583, 3953, 676, 12, 190, "Input"],
Cell[139262, 3967, 220, 8, 33, "Text"],
Cell[139485, 3977, 139, 2, 50, "Input"],
Cell[139627, 3981, 38, 0, 33, "Text"],
Cell[139668, 3983, 859, 16, 150, "Input"],
Cell[140530, 4001, 108, 4, 33, "Text"],
Cell[140641, 4007, 1367, 27, 310, "Input"],
Cell[142011, 4036, 70, 0, 33, "Text"],
Cell[142084, 4038, 676, 12, 190, "Input"],
Cell[142763, 4052, 220, 8, 33, "Text"],
Cell[142986, 4062, 139, 2, 50, "Input"],
Cell[143128, 4066, 38, 0, 33, "Text"],
Cell[143169, 4068, 856, 16, 150, "Input"],
Cell[144028, 4086, 108, 4, 33, "Text"],
Cell[144139, 4092, 1367, 27, 310, "Input"],
Cell[145509, 4121, 70, 0, 33, "Text"],
Cell[145582, 4123, 676, 12, 190, "Input"],
Cell[146261, 4137, 220, 8, 33, "Text"],
Cell[146484, 4147, 139, 2, 50, "Input"],
Cell[146626, 4151, 38, 0, 33, "Text"],
Cell[146667, 4153, 856, 16, 150, "Input"],
Cell[147526, 4171, 41, 0, 33, "Text"],
Cell[147570, 4173, 313, 6, 70, "Input"],
Cell[147886, 4181, 197, 6, 34, "Text"],
Cell[148086, 4189, 559, 11, 110, "Input"]
}, Closed]],
Cell[148660, 4203, 534, 17, 86, "Text"],

Cell[CellGroupData[{
Cell[149219, 4224, 101, 2, 33, "Text"],
Cell[149323, 4228, 71, 0, 33, "Text"],
Cell[149397, 4230, 2156, 43, 496, "Input"],
Cell[151556, 4275, 108, 4, 33, "Text"],
Cell[151667, 4281, 1389, 28, 310, "Input"],
Cell[153059, 4311, 70, 0, 33, "Text"],
Cell[153132, 4313, 676, 12, 190, "Input"],
Cell[153811, 4327, 38, 0, 33, "Text"],
Cell[153852, 4329, 856, 16, 150, "Input"],
Cell[154711, 4347, 108, 4, 33, "Text"],
Cell[154822, 4353, 1389, 28, 310, "Input"],
Cell[156214, 4383, 70, 0, 33, "Text"],
Cell[156287, 4385, 676, 12, 190, "Input"],
Cell[156966, 4399, 38, 0, 33, "Text"],
Cell[157007, 4401, 856, 16, 150, "Input"],
Cell[157866, 4419, 108, 4, 33, "Text"],
Cell[157977, 4425, 1389, 28, 310, "Input"],
Cell[159369, 4455, 70, 0, 33, "Text"],
Cell[159442, 4457, 676, 12, 190, "Input"],
Cell[160121, 4471, 38, 0, 33, "Text"],
Cell[160162, 4473, 856, 16, 150, "Input"],
Cell[161021, 4491, 108, 4, 33, "Text"],
Cell[161132, 4497, 1389, 28, 310, "Input"],
Cell[162524, 4527, 70, 0, 33, "Text"],
Cell[162597, 4529, 676, 12, 190, "Input"],
Cell[163276, 4543, 38, 0, 33, "Text"],
Cell[163317, 4545, 856, 16, 150, "Input"],
Cell[164176, 4563, 108, 4, 33, "Text"],
Cell[164287, 4569, 1389, 28, 310, "Input"],
Cell[165679, 4599, 70, 0, 33, "Text"],
Cell[165752, 4601, 676, 12, 190, "Input"],
Cell[166431, 4615, 38, 0, 33, "Text"],
Cell[166472, 4617, 856, 16, 150, "Input"],
Cell[167331, 4635, 41, 0, 33, "Text"],
Cell[167375, 4637, 313, 6, 70, "Input"],
Cell[167691, 4645, 197, 6, 34, "Text"],
Cell[167891, 4653, 559, 11, 110, "Input"]
}, Closed]],
Cell[168465, 4667, 603, 18, 102, "Text"],

Cell[CellGroupData[{
Cell[169093, 4689, 101, 2, 33, "Text"],
Cell[169197, 4693, 2267, 45, 514, "Input"],
Cell[171467, 4740, 143, 3, 33, "Text"],
Cell[171613, 4745, 562, 11, 110, "Input"]
}, Closed]],
Cell[172190, 4759, 533, 17, 86, "Text"],

Cell[CellGroupData[{
Cell[172748, 4780, 101, 2, 33, "Text"],
Cell[172852, 4784, 2194, 44, 496, "Input"],
Cell[175049, 4830, 182, 5, 33, "Text"],
Cell[175234, 4837, 56, 1, 30, "Input"],
Cell[175293, 4840, 180, 6, 33, "Text"],
Cell[175476, 4848, 78, 1, 30, "Input"],
Cell[175557, 4851, 66, 1, 30, "Input"],
Cell[175626, 4854, 143, 3, 33, "Text"],
Cell[175772, 4859, 562, 11, 110, "Input"],
Cell[176337, 4872, 2869, 79, 375, "Text"]
}, Closed]],
Cell[179221, 4954, 1598, 37, 280, "Text"],

Cell[CellGroupData[{
Cell[180844, 4995, 102, 2, 33, "Text"],
Cell[180949, 4999, 3298, 64, 715, "Input"],
Cell[184250, 5065, 126, 2, 50, "Input"],
Cell[184379, 5069, 107, 3, 33, "Text"],
Cell[184489, 5074, 137, 3, 30, "Input"],
Cell[184629, 5079, 314, 9, 52, "Text"]
}, Closed]],
Cell[184958, 5091, 213, 8, 30, "Text"],

Cell[CellGroupData[{
Cell[185196, 5103, 102, 2, 33, "Text"],
Cell[185301, 5107, 1901, 37, 373, "Input"],
Cell[187205, 5146, 557, 15, 166, "Text"],
Cell[187765, 5163, 91, 3, 33, "Text"],
Cell[187859, 5168, 200, 3, 50, "Input"],
Cell[188062, 5173, 293, 5, 90, "Input"],
Cell[188358, 5180, 229, 4, 33, "Text"]
}, Closed]],
Cell[188602, 5187, 158, 3, 32, "Text"],
Cell[188763, 5192, 573, 16, 33, "Text"],
Cell[189339, 5210, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

