(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23856,        780]*)
(*NotebookOutlinePosition[     24549,        804]*)
(*  CellTagsIndexPosition[     24505,        800]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the study of Earthquake Induced \
Vibrations",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIn the study of earthquake induced vibrations on multistory \
buildings, the free transverse oscillations satisfy the equation  \n\n(1)\t\t\
",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["m",
              FontWeight->"Bold"], " ", 
            RowBox[{
              RowBox[{
                StyleBox["X",
                  FontWeight->"Bold"], "'"}], "'"}]}], " ", "=", " ", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold"], " ", 
            StyleBox["X",
              FontWeight->"Bold"]}]}], " "}]]],
  ",  \n\nwhere the forces acting on the i-th floor are  \n\t\n\t\t",
  Cell[BoxData[
      \(k \((x\_i - x\_\(i - 1\))\) + k \((x\_\(i + 1\) - x\_i)\) = 
        k \((x\_\(i + 1\) - 2  x\_i + x\_\(i - 1\))\)\)]],
  ".  \n\nConsider a building with  n floors each of mass  m  slugs and the \
horizontal restoring force of   k tons/foot  between floors. Then this system \
reduces to the form  \n\n(2)\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["X",
                FontWeight->"Bold"], "'"}], "'"}], " ", "=", " ", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Bold"], " ", 
            StyleBox["X",
              FontWeight->"Bold"]}]}], " "}]]],
  ", \nwhere \n\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox["a",
          FontWeight->"Bold"], "=", 
        RowBox[{\(k\/m\), 
          RowBox[{"(", GridBox[{
                {\(-2\), "1", "0", "0", "0", "0", "0"},
                {"1", \(-2\), "1", "0", "0", "0", "0"},
                {"0", "\[DescendingEllipsis]", "\[DescendingEllipsis]", 
                  "\[DescendingEllipsis]", "\[CenterEllipsis]", 
                  "\[CenterEllipsis]", "0"},
                {"0", "\[CenterEllipsis]", "1", \(-2\), "1", 
                  "\[CenterEllipsis]", "0"},
                {"0", "0", "\[CenterEllipsis]", "\[DescendingEllipsis]", 
                  "\[DescendingEllipsis]", "\[DescendingEllipsis]", "0"},
                {"0", "0", "0", "0", "1", \(-2\), "1"},
                {"0", "0", "0", "0", "0", "1", \(-1\)}
                }], ")"}]}]}]]],
  " .  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof  ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Earthquake Models",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/EarthquakeModelProof.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Earthquake Models",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/EarthquakeModelProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Earthquake Models",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/EarthquakeModelProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Earthquake Models",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/EarthquakeModelProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Consider a building with  n = 6  floors each of mass  m = 1250 slugs \
(weight of 20 tons) \nand the horizontal restoring force of   k = 10,000 \
lb/ft = 5 tons/foot  between floors. \nThen  ",
  Cell[BoxData[
      \(c = \(k\/m = \(10000\/1250 = 8\)\)\)]],
  ",  and this system reduces to the form  ",
  "\n\nCompute the eigenvalues of matrix  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["a",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", GridBox[{
              {\(-16\), "8", "0", "0", "0", "0"},
              {"8", \(-16\), "8", "0", "0", "0"},
              {"0", "8", \(-16\), "8", "0", "0"},
              {"0", "0", "8", \(-16\), "8", "0"},
              {"0", "0", "0", "8", \(-16\), "8"},
              {"0", "0", "0", "0", "8", \(-8\)}
              }], ")"}]}]]],
  ", \nand the natural frequencies  ",
  Cell[BoxData[
      \(\[Omega]\)]],
  "  and  periods  ",
  StyleBox["P",
    FontFamily->"Courier New"],
  "  of oscillation of the building. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the matrix  ",
  StyleBox["a",
    FontWeight->"Bold"],
  "  into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(k = 10000.0;\), " "}], "\n", 
    RowBox[{\(m = 1250.0;\), " "}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"a", "=", 
          RowBox[{\(k\/m\), 
            RowBox[{"(", GridBox[{
                  {\(-2\), "1", "0", "0", "0", "0"},
                  {"1", \(-2\), "1", "0", "0", "0"},
                  {"0", "1", \(-2\), "1", "0", "0"},
                  {"0", "0", "1", \(-2\), "1", "0"},
                  {"0", "0", "0", "1", \(-2\), "1"},
                  {"0", "0", "0", "0", "1", \(-1\)}
                  }], ")"}]}]}], ";"}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\<a = \>", MatrixForm[a]\ ];\), " "}]}], "Input"],

Cell[TextData[{
  "Compute the eigenvalues ",
  Cell[BoxData[
      \(\[Lambda]\)]],
  " of the matrix  ",
  StyleBox["a",
    FontWeight->"Bold"],
  ", and the natural frequencies  ",
  Cell[BoxData[
      \(\[Omega]\)]],
  "  and  periods  ",
  StyleBox["p",
    FontFamily->"Courier New"],
  "  of oscillation of the building. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[j, L, \[Lambda], P, p, 
        W, \[Omega]];\)\ \), "\[IndentingNewLine]", 
    \(\(L = Eigenvalues[a];\)\ \), "\n", 
    \(\(W\  = \ \@Abs[L];\)\ \), "\n", 
    \(\(P\  = \ \(2  \[Pi]\)\/W;\)\ \), "\n", 
    \(\(sp = Table["\<  \>", {i, 6}];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        NumberForm[
          TableForm[Transpose[{sp, L, sp, W, sp, P}], 
            TableHeadings \[Rule] {Automatic, {"\<\>", "\<   \[Lambda]\>", \
"\<\>", \*"\"\<\[Omega] = \!\(\@\(\(|\)\(\[Lambda]\)\(|\)\)\)\>\"", "\<\>", \
\*"\"\<p = \!\(\(2  \[Pi]\)\/\[Omega]\)\>\""}}]]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["More Background.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tA horizontal earthquake oscillation of amplitude  ",
  Cell[BoxData[
      \(e\)]],
  "  of the form  ",
  Cell[BoxData[
      \(e\ Cos[\[Omega]\ t]\)]],
  "  will produce an acceleration  ",
  Cell[BoxData[
      \(\(-\ e\)\ \[Omega]\^2\ Cos[\[Omega]\ t]\)]],
  ", and the opposite internal force on each floor of the building is   ",
  Cell[BoxData[
      \(f\  = \ m\ \ e\ \[Omega]\^2\ Cos[\[Omega]\ t]\)]],
  ".  The resulting non-homogeneous system is   \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["X",
              FontWeight->"Bold"], "'"}], "'"}], " ", "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox["a",
              FontWeight->"Bold"], " ", 
            StyleBox["X",
              FontWeight->"Bold"]}], " ", "+", "  ", 
          RowBox[{"e", "  ", \(\[Omega]\^2\), " ", \(Cos[\[Omega]\ t]\), 
            StyleBox["b",
              FontWeight->"Bold"]}]}]}]]],
  ",   where   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["b",
          FontWeight->"Bold"], 
        "=", \({1, 1, \[CenterEllipsis], 1, \[CenterEllipsis], 1, 
              1}\^T\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Solving the above non-homogeneous system for the coefficient vector  ",
  StyleBox["v",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  for  ",
  StyleBox["X",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["[t]",
    FontFamily->"Courier New"],
  ".  \nThe vector  ",
  StyleBox["v",
    FontWeight->"Bold"],
  "  is the solution to the equation  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(\[Omega]\^2\), " ", 
                StyleBox["I",
                  FontWeight->"Bold"]}], " ", "-", 
              StyleBox["a",
                FontWeight->"Bold"]}], ")"}], 
          StyleBox["v",
            FontWeight->"Bold"]}], "=", 
        RowBox[{\(-\ e\), " ", \(\[Omega]\^2\), " ", 
          StyleBox["b",
            FontWeight->"Bold"]}]}]]],
  ".  \nUse the earthquake amplitude  ",
  StyleBox["e = 0.075",
    FontFamily->"Courier New"],
  " ft",
  StyleBox[" = 0.9",
    FontFamily->"Courier New"],
  " in.  for this example. \n\nSolve the linear system using the parameters  \
",
  Cell[BoxData[
      \(\[Omega] = 2.1\)]],
  " and  ",
  StyleBox["e = 0.075",
    FontFamily->"Courier New"],
  ".  \n\nFind the coefficient vector  ",
  StyleBox["v",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  and the vector  ",
  StyleBox["X",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["[t]",
    FontFamily->"Courier New"],
  ".  Plot the vibrations of each floor. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, enter the column vector  ",
  StyleBox["b",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"b", "=", 
          RowBox[{"(", GridBox[{
                {"1.0"},
                {"1.0"},
                {"1.0"},
                {"1.0"},
                {"1.0"},
                {"1.0"}
                }], ")"}]}], ";"}], " "}]], "Input"],

Cell[TextData[{
  "Second, create the matrix ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(\[Omega]\^2\), " ", 
            StyleBox["I",
              FontWeight->"Bold"]}], " ", "-", 
          StyleBox["a",
            FontWeight->"Bold"]}], ")"}]]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[m, \[Omega]];\)\ \), "\[IndentingNewLine]", 
    \(\(d = \[Omega]\^2\ \ DiagonalMatrix[{1, 1, 1, 1, 1, 1}];\)\ \), "\n", 
    \(\(m[\[Omega]_] = d + a;\)\ \), "\n", 
    \(\(Print[MatrixForm[m[\[Omega]]]\ ];\)\ \)}], "Input"],

Cell["Print the linear system we want to solve. ", "Text"],

Cell[BoxData[
    \(\(\(Print[MatrixForm[m[\[Omega]]], "\<V = \>", 
        MatrixForm[\ \(-\ e\)\ \ \[Omega]\^2\ b]];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Third, solve the linear system using  ",
  Cell[BoxData[
      \(\[Omega] = 2.1\)]],
  " and  ",
  StyleBox["e = 0.075",
    FontFamily->"Courier New"],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Print[MatrixForm[m[2.1]], "\<V = \>", 
        MatrixForm[\(-\ 
              0.075\)*\ \((2.1)\)\^2\ b]];\)\ \), "\[IndentingNewLine]", 
    \(\(V = 
        LinearSolve[
          m[2.1], \ \(-\ 
              0.075\)*\ \((2.1)\)\^2\ b];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<V = \>", MatrixForm[V]\ ];\)\ \)}], "Input"],

Cell["We can convert these values to inches if desired. ", "Text"],

Cell[BoxData[
    \(\(\(Print["\<12V = \>", MatrixForm[12  V]\ ];\)\(\ \)\)\)], "Input"],

Cell["\<\
Fourth, find the maximum amplitude of oscillation of the floors in feet and \
in inches. 
On what floor did the maximum amplitude of oscillation occur ? \
\>", "Text"],

Cell[BoxData[
    \(\(\(Max[Abs[V]]\)\(\ \)\)\)], "Input"],

Cell["The maximum amplitude of oscillation in inches is: ", "Text"],

Cell[BoxData[
    \(\(\(12\)\(\ \ \)\(Max[Abs[V]]\)\(\ \)\)\)], "Input"],

Cell["Notice that it occurs on the second floor. ", "Text"],

Cell["\<\
Fifth, find the minimum amplitude of oscillation of the floors in feet and in \
inches.  
On what floor would did the minimum amplitude of of oscillation occur  ? \
\>", "Text"],

Cell[BoxData[
    \(\(\(Min[Abs[V]]\)\(\ \)\)\)], "Input"],

Cell["The minimum amplitude of oscillation in inches is: ", "Text"],

Cell[BoxData[
    \(\(\(12\)\(\ \)\(Min[Abs[V]]\)\(\ \)\)\)], "Input"],

Cell["Notice that it occurs on the fifth floor. ", "Text"],

Cell[TextData[{
  "Sixth, form  ",
  StyleBox["X",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["[t]",
    FontFamily->"Courier New"],
  ",  but plot  ",
  StyleBox["X",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox["[t]",
    FontFamily->"Courier New"],
  StyleBox[" + k",
    FontFamily->"Courier New"],
  "  for floor  ",
  StyleBox["k",
    FontFamily->"Courier New"],
  ".  \nDo this on one graph by forming a set of functions to plot \
parametrically. "
}], "Text"],

Cell[BoxData[{
    \(\(X[t_] = Flatten[V]\ Cos[2.1\ t];\)\ \), "\n", 
    \(\(f[t_] = X[t] + {1, 2, 3, 4, 5, 6};\)\ \), "\n", 
    \(\(funs\  = \ 
        Transpose[{f[t], {t, t, t, t, t, t}}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<X[t] = \>", 
        MatrixForm[X[t]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[t] = \>", MatrixForm[f[t]]\ ];\)\ \)}], "Input"],

Cell[TextData[{
  "Now plot the functions.  \nImagine a vertical line through  ",
  StyleBox["x = 1,2,3,4,5,6",
    FontFamily->"Courier New"],
  "  which would represent no movements of the floors."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1 = 
        ParametricPlot[Evaluate[funs], {t, 0, 10}, 
          AxesLabel \[Rule] {"\<x-feet\>", "\<t-sec\>"}, \n\t
          PlotStyle \[Rule] {Blue, Red, Brown, Magenta, Green, Orange}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(lins = 
        Transpose[{{1, 2, 3, 4, 5, 6}, {t, t, t, t, t, 
              t}}];\)\ \), "\[IndentingNewLine]", 
    \(\(g2 = 
        ParametricPlot[Evaluate[lins], {t, 0, 10}, 
          AxesLabel \[Rule] {"\<x-feet\>", "\<t-sec\>"}, \n\t
          PlotStyle \[Rule] {Cyan, Cyan, Cyan, Cyan, Cyan}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[g1, g2, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[t] = \>", MatrixForm[f[t]]\ ];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For the above non-homogeneous system the coefficient vector  ",
  StyleBox["v",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  "  is the solution to the equation  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(\[Omega]\^2\), " ", 
                StyleBox["I",
                  FontWeight->"Bold"]}], " ", "-", 
              StyleBox["a",
                FontWeight->"Bold"]}], ")"}], 
          StyleBox["c",
            FontWeight->"Bold"]}], "=", 
        RowBox[{\(-\ e\), " ", \(\[Omega]\^2\), " ", 
          StyleBox["b",
            FontWeight->"Bold"]}]}]]],
  ".  \n\nPlot the maximum amplitude of oscillation of the floors vs the \
parameter  ",
  Cell[BoxData[
      \(\[Omega]\)]],
  "  over the interval  ",
  Cell[BoxData[
      \(0 \[LessEqual] \ \[Omega] \[LessEqual] 6\)]],
  ",  \nthis graph should have six vertical asymptotes corresponding to each \
value  ",
  Cell[BoxData[
      \(\[Omega]\)]],
  "  in the table above.  \nThen plot the maximum amplitude as a function of \
the period  ",
  StyleBox["p",
    FontFamily->"Courier New"],
  "  in seconds. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "First, create the following function of the two variables  ",
  Cell[BoxData[
      \(\[Omega]\)]],
  "  and  ",
  StyleBox["e",
    FontFamily->"Courier New"],
  ".  \nDo this carefully, each time ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " plots one point on the graph it will need to solve a 6 by 6 linear system \
and find the maximum of the absolute value of the entries in the vector  ",
  StyleBox["v",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[
    \(\(\(g[\[Omega]_, 
        e_]\)\(:=\)\(Module[{}, \[IndentingNewLine]v = 
          LinearSolve[
            m[\[Omega]], \ \(-\ 
                e\)\ \ \[Omega]\^2\ b]; \ \[IndentingNewLine]max = 
          Max[Abs[v]]; \ \[IndentingNewLine]Return[
          max];\ ]\)\(\ \ \)\)\)], "Input"],

Cell[TextData[{
  "Test the function with the information in Example 2.  It should look like \
\n\t",
  StyleBox["g[2.1, 0.075]",
    FontWeight->"Bold"],
  "\n\t0.388417"
}], "Text"],

Cell[BoxData[
    StyleBox[\(\(g[2.1, \ 0.075]\)\(\ \)\),
      FontWeight->"Bold"]], "Input"],

Cell[TextData[{
  "Now plot  ",
  StyleBox["g[",
    FontFamily->"Courier New"],
  "\[Omega]",
  StyleBox[", 0.075]",
    FontFamily->"Courier New"],
  "  and observe that there is a vertical asymptote for each of the values",
  "  ",
  Cell[BoxData[
      \(\[Omega]\)]],
  "  ",
  " in the table in Example 1."
}], "Text"],

Cell[BoxData[{
    \(\(Plot[g[\[Omega], 0.075], {\[Omega], 0, 6}, 
        PlotStyle \[Rule] Blue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Omega] = \>", Sort[W, Less]];\)\ \)}], "Input"],

Cell[TextData[{
  "Now make two plots for  ",
  StyleBox["g[",
    FontFamily->"Courier New"],
  "\[Omega]",
  StyleBox[", 0.075]",
    FontFamily->"Courier New"],
  "  as a function of the period  ",
  StyleBox["p",
    FontFamily->"Courier New"],
  "  in seconds."
}], "Text"],

Cell[BoxData[{
    \(\(ParametricPlot[{\(2\ \[Pi]\)\/\[Omega], 
          g[\[Omega], 0.075]}, {\[Omega], 0.5, 10}, PlotPoints \[Rule] 100, 
        PlotRange \[Rule] {{0, 11}, {0, 3}}, 
        PlotStyle \[Rule] Orange];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p = \>", Sort[P, Less]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(ParametricPlot[{\(2\ \[Pi]\)\/\[Omega], 
          g[\[Omega], 0.075]}, {\[Omega], 1.5, 10}, PlotPoints \[Rule] 100, 
        PlotRange \[Rule] {{0, 4}, {0, 2}}, 
        PlotStyle \[Rule] Red];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<p = \>", Take[Sort[P, Less], 5]\ ];\)\ \)}], "Input"],

Cell["What is \"bad timing\" for the period of an earthquake ? ", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Old Lab Project (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Earthquake Induced Vibrations",
    ButtonData:>{
      URL[ "http://ecs.fullerton.edu/~mathews/N310/projects2/e15.htm"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Earthquake Induced Vibrations",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/N310/projects2/e15.htm"], None},
    
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to an old lab project.  "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Earthquake Models",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/EarthquakeModelBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Earthquake Models",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/EarthquakeModelBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 197, 5, 35, "Text"],
Cell[1976, 60, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3455, 112, 2329, 61, 384, "Text"],
Cell[5787, 175, 630, 22, 33, "Text"],
Cell[6420, 199, 621, 21, 33, "Text"],
Cell[7044, 222, 1105, 31, 203, "Text"],

Cell[CellGroupData[{
Cell[8174, 257, 101, 2, 33, "Text"],
Cell[8278, 261, 164, 8, 33, "Text"],
Cell[8445, 271, 679, 15, 183, "Input"],
Cell[9127, 288, 343, 14, 33, "Text"],
Cell[9473, 304, 615, 12, 180, "Input"]
}, Closed]],
Cell[10103, 319, 1283, 40, 125, "Text"],
Cell[11389, 361, 1633, 57, 149, "Text"],

Cell[CellGroupData[{
Cell[13047, 422, 101, 2, 33, "Text"],
Cell[13151, 426, 113, 5, 33, "Text"],
Cell[13267, 433, 303, 11, 105, "Input"],
Cell[13573, 446, 302, 11, 33, "Text"],
Cell[13878, 459, 254, 4, 90, "Input"],
Cell[14135, 465, 58, 0, 33, "Text"],
Cell[14196, 467, 141, 2, 31, "Input"],
Cell[14340, 471, 190, 8, 33, "Text"],
Cell[14533, 481, 355, 8, 72, "Input"],
Cell[14891, 491, 66, 0, 33, "Text"],
Cell[14960, 493, 88, 1, 30, "Input"],
Cell[15051, 496, 177, 4, 52, "Text"],
Cell[15231, 502, 58, 1, 30, "Input"],
Cell[15292, 505, 67, 0, 33, "Text"],
Cell[15362, 507, 72, 1, 30, "Input"],
Cell[15437, 510, 59, 0, 33, "Text"],
Cell[15499, 512, 187, 4, 52, "Text"],
Cell[15689, 518, 58, 1, 30, "Input"],
Cell[15750, 521, 67, 0, 33, "Text"],
Cell[15820, 523, 70, 1, 30, "Input"],
Cell[15893, 526, 58, 0, 33, "Text"],
Cell[15954, 528, 514, 20, 53, "Text"],
Cell[16471, 550, 382, 7, 110, "Input"],
Cell[16856, 559, 211, 5, 52, "Text"],
Cell[17070, 566, 923, 18, 170, "Input"]
}, Closed]],
Cell[18008, 587, 1290, 40, 145, "Text"],

Cell[CellGroupData[{
Cell[19323, 631, 101, 2, 33, "Text"],
Cell[19427, 635, 518, 16, 53, "Text"],
Cell[19948, 653, 313, 7, 93, "Input"],
Cell[20264, 662, 183, 6, 71, "Text"],
Cell[20450, 670, 94, 2, 30, "Input"],
Cell[20547, 674, 324, 13, 33, "Text"],
Cell[20874, 689, 197, 3, 50, "Input"],
Cell[21074, 694, 278, 11, 33, "Text"],
Cell[21355, 707, 314, 5, 63, "Input"],
Cell[21672, 714, 319, 5, 63, "Input"],
Cell[21994, 721, 73, 0, 33, "Text"]
}, Closed]],
Cell[22082, 724, 739, 22, 30, "Text"],
Cell[22824, 748, 158, 3, 35, "Text"],
Cell[22985, 753, 571, 17, 33, "Text"],
Cell[23559, 772, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

