(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    109123,       3147]*)
(*NotebookOutlinePosition[    109817,       3171]*)
(*  CellTagsIndexPosition[    109773,       3167]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Golden Ratio Search for a Minimum",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Bracketing Search Methods",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["An approach for finding the minimum of",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["in a given interval is to evaluate the function many times and \
search for a local minimum.  To reduce the number of function evaluations it \
is important to have a good strategy for determining where",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is to be evaluated.  Two efficient bracketing methods are the ",
    FontFamily->"Times-Roman"],
  StyleBox["golden ratio",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" and ",
    FontFamily->"Times-Roman"],
  StyleBox["Fibonacci",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" searches.  To use either bracketing method for finding the \
minimum of",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox[",  a special condition must be met to ensure that there is a \
proper minimum in the given interval.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Unimodal Function)",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  The function",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is unimodal on",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(I = \([a, b]\)\)]],
  StyleBox[",  if there exists a unique number ",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(p \[Element] I\)]],
  "  ",
  StyleBox["such that  \n\t\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is decreasing on",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\([a, p]\)\)]],
  StyleBox[",  \n\tand\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is increasing on",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\([p, b]\)\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Golden Ratio Search",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  "\n\t",
  StyleBox["If",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is known to be unimodal on",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[",  then it is possible to replace the interval with a subinterval \
on which",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["takes on its minimum value.  One approach is to select two \
interior points  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(c < d\)]],
  StyleBox[".  This results in  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(a < c < d < b\)]],
  StyleBox[".  The condition",
    FontFamily->"Times-Roman"],
  StyleBox[" ",
    FontFamily->"Times-Bold"],
  StyleBox["that",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is unimodal guarantees that the function values",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(f \((c)\)\)]],
  StyleBox[" ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["and",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(f \((d)\)\)]],
  " ",
  StyleBox["are less than  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(max {f \((a)\), f \((b)\)}\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["\tIf  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((c)\) \[LessEqual] f \((d)\)\)]],
  StyleBox[",  then the minimum must occur in the subinterval ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([a, d]\)\)]],
  StyleBox[", and we replace ",
    FontFamily->"Times-Roman"],
  StyleBox["b",
    FontFamily->"Courier New"],
  StyleBox[" with ",
    FontFamily->"Times-Roman"],
  StyleBox["d",
    FontFamily->"Courier New"],
  StyleBox[" and continue the search in the new subinterval",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(\([a, d]\)\)]],
  StyleBox[".   If  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((d)\) < f \((c)\)\)]],
  ",",
  StyleBox[" then the minimum must occur in the subinterval",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(\([c, b]\)\)]],
  StyleBox[", and we replace ",
    FontFamily->"Times-Roman"],
  StyleBox["a",
    FontFamily->"Courier New"],
  StyleBox[" with ",
    FontFamily->"Times-Roman"],
  StyleBox["c",
    FontFamily->"Courier New"],
  StyleBox[" and continue the search in the new subinterval",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(\([c, b]\)\)]],
  ".  These choices are shown in Figure 1 below.  \n\n",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0 0.824045 [
[.04546 -0.0125 -5 -12.5625 ]
[.04546 -0.0125 5 0 ]
[.26006 -0.0125 -5 -12.5625 ]
[.26006 -0.0125 5 0 ]
[.3927 -0.0125 -5 -12.5625 ]
[.3927 -0.0125 5 0 ]
[.6073 -0.0125 -5 -12.5625 ]
[.6073 -0.0125 5 0 ]
[.95455 -0.0125 -5 -12.5625 ]
[.95455 -0.0125 5 0 ]
[.03295 .0824 -18 -4.5 ]
[.03295 .0824 0 4.5 ]
[.03295 .16481 -18 -4.5 ]
[.03295 .16481 0 4.5 ]
[.03295 .24721 -18 -4.5 ]
[.03295 .24721 0 4.5 ]
[.03295 .32962 -18 -4.5 ]
[.03295 .32962 0 4.5 ]
[.03295 .41202 -18 -4.5 ]
[.03295 .41202 0 4.5 ]
[.03295 .49443 -18 -4.5 ]
[.03295 .49443 0 4.5 ]
[.03295 .57683 -18 -4.5 ]
[.03295 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04546 0 m
.04546 .00625 L
s
gsave
.04546 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.26006 0 m
.26006 .00625 L
s
gsave
.26006 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.3927 0 m
.3927 .00625 L
s
gsave
.3927 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6073 0 m
.6073 .00625 L
s
gsave
.6073 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.95455 0 m
.95455 .00625 L
s
gsave
.95455 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
.04545 .0824 m
.0517 .0824 L
s
[(0.1)] .03295 .0824 1 0 Mshowa
.04545 .16481 m
.0517 .16481 L
s
[(0.2)] .03295 .16481 1 0 Mshowa
.04545 .24721 m
.0517 .24721 L
s
[(0.3)] .03295 .24721 1 0 Mshowa
.04545 .32962 m
.0517 .32962 L
s
[(0.4)] .03295 .32962 1 0 Mshowa
.04545 .41202 m
.0517 .41202 L
s
[(0.5)] .03295 .41202 1 0 Mshowa
.04545 .49443 m
.0517 .49443 L
s
[(0.6)] .03295 .49443 1 0 Mshowa
.04545 .57683 m
.0517 .57683 L
s
[(0.7)] .03295 .57683 1 0 Mshowa
.04545 0 m
.04545 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.04545 .57683 m
.08233 .44945 L
.12255 .33776 L
.16033 .25547 L
.19665 .19429 L
.2169 .16695 L
.23532 .14588 L
.27254 .11328 L
.29082 .10166 L
.31066 .09198 L
.32959 .08535 L
.33914 .0829 L
.34454 .08177 L
.34966 .08085 L
.35429 .08016 L
.35934 .07954 L
.36393 .07911 L
.36819 .07881 L
.3708 .07867 L
.37207 .07862 L
.37325 .07857 L
.3743 .07854 L
.37545 .07852 L
.37661 .07849 L
.37784 .07848 L
.37853 .07848 L
.37918 .07847 L
.3804 .07847 L
.38109 .07848 L
.38172 .07848 L
.38242 .07849 L
.38316 .0785 L
.38437 .07853 L
.38552 .07856 L
.38812 .07865 L
.39044 .07876 L
.3926 .07889 L
.39751 .07926 L
.40228 .07972 L
.40739 .08033 L
.42505 .08329 L
.43483 .08547 L
.44543 .08823 L
.46466 .09422 L
.50372 .10982 L
.54133 .12836 L
.5775 .14872 L
.616 .17243 L
.65306 .19671 L
.69246 .22361 L
Mistroke
.73042 .25024 L
.76692 .27628 L
.80577 .30423 L
.84317 .33128 L
.88291 .36008 L
.92121 .38785 L
.95455 .41202 L
Mfstroke
1 .8 .85 r
.05091 .55636 m
.07348 .47773 L
.0981 .4025 L
.12121 .34106 L
.14345 .28973 L
.16711 .24278 L
.18989 .20445 L
.21411 .17045 L
.23743 .14368 L
.25988 .12296 L
.28375 .10583 L
.29562 .09905 L
.30674 .09366 L
.31807 .08909 L
.32884 .08557 L
.34067 .08256 L
.3515 .08056 L
.3571 .0798 L
.36017 .07946 L
.36307 .07918 L
.36577 .07897 L
.3687 .07878 L
.37136 .07865 L
.37381 .07856 L
.37524 .07852 L
.37655 .0785 L
.37728 .07849 L
.37766 .07848 L
.37806 .07848 L
.37881 .07847 L
.3795 .07847 L
.38012 .07847 L
.3808 .07848 L
.38144 .07848 L
.38202 .07849 L
.38267 .0785 L
.38338 .07851 L
.38481 .07854 L
.38639 .07859 L
.38783 .07864 L
.39106 .0788 L
.39405 .07899 L
.39688 .0792 L
.40256 .07975 L
.40857 .08049 L
.41935 .08219 L
.44148 .08715 L
.46505 .09436 L
.48773 .10293 L
.51185 .11356 L
.53508 .12508 L
.55742 .13715 L
.5812 .15091 L
.60409 .1649 L
.6073 .16692 L
.6073 0 L
.05091 0 L
F
1 0 0 r
.05091 .55636 m
.07348 .47773 L
.0981 .4025 L
.12121 .34106 L
.14345 .28973 L
.16711 .24278 L
.18989 .20445 L
.21411 .17045 L
.23743 .14368 L
.25988 .12296 L
.28375 .10583 L
.29562 .09905 L
.30674 .09366 L
.31807 .08909 L
.32884 .08557 L
.34067 .08256 L
.3515 .08056 L
.3571 .0798 L
.36017 .07946 L
.36307 .07918 L
.36577 .07897 L
.3687 .07878 L
.37136 .07865 L
.37381 .07856 L
.37524 .07852 L
.37655 .0785 L
.37728 .07849 L
.37766 .07848 L
.37806 .07848 L
.37881 .07847 L
.3795 .07847 L
.38012 .07847 L
.3808 .07848 L
.38144 .07848 L
.38202 .07849 L
.38267 .0785 L
.38338 .07851 L
.38481 .07854 L
.38639 .07859 L
.38783 .07864 L
.39106 .0788 L
.39405 .07899 L
.39688 .0792 L
.40256 .07975 L
.40857 .08049 L
.41935 .08219 L
.44148 .08715 L
.46505 .09436 L
.48773 .10293 L
.51185 .11356 L
Mistroke
.53508 .12508 L
.55742 .13715 L
.5812 .15091 L
.60409 .1649 L
.6073 .16692 L
Mfstroke
.02 w
.04545 .57683 Mdot
.95455 .41202 Mdot
0 0 1 r
.3927 .0789 Mdot
.6073 .16692 Mdot
0 1 0 r
.26006 .12281 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool5000003@0oooo0`00
000P0?ooo`<00000=@3oool4000005@0oooo1000000E0?ooo`006`3oool4000003@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0e0?ooo`040000003oool0oooo000005H0oooo00@0
00000?ooo`3oool00000503oool001h0oooo00<000000?ooo`3oool0<P3oool4000001l0oooo00<0
00000?ooo`3oool0=@3oool010000000oooo0?ooo`00001F0?ooo`040000003oool0oooo000001@0
oooo000L0?ooo`<00000=@3oool200000240oooo0`00000e0?ooo`<00000EP3oool3000001D0oooo
002a0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool05@3oool00;00oooo0P00001E
0?ooo`8000005`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00140ooooo`000007000000T0oooo000M0?ooo`030000003oool0olcI0900
olcI00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0C0?ooo`007@3oool00`000000oooo
0?o<f@2@0?o<f@030000003oool0oooo05L0oooo00<000000?ooo`3oool04`3oool001d0oooo00<0
00000?ooo`3oc=T0T03oc=U`0?ooo`007@3oool00`000000oooo0?o<f@2@0?o<fG00oooo000M0?oo
o`030000003oool0olcI0900olcIL03oool001d0oooo00<000000?ooo`3oc=T0T03oc=U`0?ooo`00
7@3oool00`000000oooo0?o<f@2@0?o<fG00oooo000M0?ooo`030000003oool0olcI0900olcIL03o
ool001d0oooo00<000000?ooo`3oc=T0T03oc=U`0?ooo`007@3oool00`000000oooo0?o<f@2@0?o<
fG00oooo000M0?ooo`030000003oool0olcI0900olcIL03oool001d0oooo00<000000?ooo`3oc=T0
T03oc=U`0?ooo`007@3oool00`000000oooo0?o<f@2@0?o<fG00oooo000M0?ooo`030000003oool0
olcI0900olcIL03oool001d0oooo00<000000?ooo`3oc=T0T03oc=U`0?ooo`007@3oool00`000000
oooo0?o<f@2@0?o<fG00oooo000M0?ooo`030000003oool0olcI0900olcIL03oool001d0oooo00<0
00000?ooo`3oc=T0T03oc=U`0?ooo`007@3oool00`000000oooo0?o<f@1G0?o<f@<0003o=P3oc=U`
0?ooo`002P3oool2000000@0oooo0P0000030?ooo`D000000`3oool00`000000oooo0?o<f@1F0?o<
f@D0003o=@3oc=U`0?ooo`002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oc=T0C03oc=T:0?l000D0003o0`3o000b0?o<fG00oooo00090?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool2000004X0olcI0`3o00000`3o
0?l0oooo0?ooo`070?ooo`D0003o0`3oool40?l002h0olcIL03oool000T0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0olcI04H0olcI0`3o000>0?oo
o`<0003o203oool40?l002X0olcIL03oool000T0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0olcI04<0olcI0`3o000P0?ooo`@0o`009P3oc=U`0?oo
o`002P3oool2000000X0oooo0P0000050?ooo`030000003oool0olcI0400olcI0`3o000V0?ooo`04
0?l0o`3o0000o`000?l002<0olcIL03oool001d0oooo00<000000?ooo`3oc=T0?P3oc=T20?l002`0
oooo00@0o`3o0?l0003o0000o`00803oc=U`0?ooo`007@3oool00`000000oooo0?o<f@0l0?o<f@80
o`00<@3oool00`3o0?l0o`000?l0000N0?o<fG00oooo000M0?ooo`030000003oool0olcI03/0olcI
00<0o`000?l0o`3oool0<`3oool00`3o0?l0o`000?l0000L0?o<fG00oooo000M0?ooo`030000003o
ool0olcI03T0olcI0P3o000i0?ooo`80o`006P3oc=U`0?ooo`007@3oool00`000000oooo0?o<f@0d
0?o<f@<00?l000<0olcI0?l0003oool0?03oool20?l001P0olcIL03oool001d0oooo00<000000?oo
o`3oc=T0<`3oc=T5003o0400oooo0P3o000F0?o<fG00oooo000M0?ooo`030000003oool0olcI03<0
olcI1@00o`120?ooo`80o`00503oc=U`0?ooo`007@3oool00`000000oooo0?o<f@0c0?o<f@D00?l0
A03oool20?l00180olcIL03oool001d0oooo00<000000?ooo`3oc=T0<`3oc=T0103o00000?l0003o
0000o`170?ooo`80o`00403oc=U`0?ooo`007@3oool00`000000oooo0?o<f@0b0?o<f@030?l0003o
ool0oooo04X0oooo00<0o`3o0?l0003o00003P3oc=U`0?ooo`007@3oool00`000000oooo0?o<f@0a
0?o<f@030?l0003oool0oooo04d0oooo00<0o`3o0?l0003o0000303oc=U`0?ooo`007@3oool00`00
0000oooo0?o<f@0`0?o<f@030?l0003oool0oooo0500oooo00<0o`3o0?l0003o00002P3oc=U`0?oo
o`007@3oool00`000000oooo0?o<f@0_0?o<f@030?l0003oool0oooo05<0oooo00<0o`3o0?l0003o
c=T0203oc=U`0?ooo`007@3oool00`000000oooo0?o<f@0^0?o<f@030?l0003oool0oooo05H0oooo
0P3o00070?o<fG00oooo000M0?ooo`030000003oool0olcI02d0olcI00<0o`000?ooo`3oool0F@3o
ool00`3o0000olcI0?o<f@040?o<fG00oooo000:0?ooo`800000103oool2000000<0oooo10000004
0?ooo`030000003oool0olcI02`0olcI00<0o`000?ooo`3oool0F`3oool20?l000@0olcIL03oool0
00T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0
olcI02`0olcI00<0o`000?ooo`3oool0G@3oool20?l000040?o<f@000?l0003o0000ofh0oooo0009
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000002`0olcI00<0
o`000?ooo`3oool0H03oool50000ofd0oooo00090?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?o<f@0Z0?o<f@030?l0003oool0oooo0640oooo1@00
0?m]0?ooo`002@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oc=T0:@3oc=T00`3o0000oooo0?ooo`1R0?ooo`D0003oK@3oool000X0oooo0P00
000:0?ooo`8000001@3oool00`000000oooo0?o<f@0X0?o<f@030?l0003o0?l0oooo06@0oooo0`00
0?l00`3oool0o`3o0?l0o`1[0?ooo`007@3oool00`000000oooo0?o<f@0X0?o<f@030?l0003oool0
oooo06X0oooo00<0o`3o0?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oc=T09`3oc=T00`3o
0000oooo0?ooo`1/0?ooo`030?l0o`3oool0oooo06L0oooo000M0?ooo`030000003oool0olcI02H0
olcI00<0o`000?ooo`3oool0KP3oool20?l0ofL0oooo000M0?ooo`030000003oool0olcI02H0olcI
00<0o`000?ooo`3oool0L03oool00`3o0?l0oooo0?ooo`1T0?ooo`007@3oool00`000000oooo0?o<
f@0U0?o<f@030?l0003oool0oooo0780oooo0P3o0?mT0?ooo`007@3oool00`000000oooo0?o<f@0T
0?o<f@030?l0003oool0oooo07D0oooo00<0o`3o0?ooo`3oool0H@3oool001d0oooo00<000000?oo
o`3oc=T0903oc=T00`3o0000oooo0?ooo`1f0?ooo`80o`3oH@3oool001d0oooo00<000000?ooo`3o
c=T08`3oc=T00`3o0000oooo0?ooo`1i0?ooo`030?l0o`3oool0oooo05h0oooo000M0?ooo`030000
003oool0olcI0280olcI00<0o`000?ooo`3oool0N`3oool00`3o0?l0oooo0?ooo`1M0?ooo`007@3o
ool00`000000oooo0?o<f@0R0?o<f@030?l0003oool0oooo07`0oooo0P3o0?mM0?ooo`007@3oool0
0`000000oooo0?o<f@0Q0?o<f@030?l0003oool0oooo07l0oooo00<0o`3o0?ooo`3oool0FP3oool0
01d0oooo00<000000?ooo`3oc=T08@3oc=T00`3o0000oooo0?ooo`200?ooo`80o`3oFP3oool001d0
oooo00<000000?ooo`3oc=T0803oc=T00`3o0000oooo0?ooo`230?ooo`030?l0o`3oool0oooo05L0
oooo000M0?ooo`030000003oool0olcI01l0olcI00<0o`000?ooo`3oool0Q@3oool20?l0oeL0oooo
000M0?ooo`030000003oool0olcI01l0olcI00<0o`000?ooo`3oool0Q`3oool00`3o0?l0oooo0?oo
o`1D0?ooo`007@3oool00`000000oooo0?o<f@0N0?o<f@030?l0003oool0oooo08T0oooo00<0o`3o
0?ooo`3oool0D`3oool000X0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oc=T07P3oc=T00`3o0000oooo0?ooo`2:0?ooo`80o`3oD`3oool000T0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0olcI01d0olcI00<0o`00
0?ooo`3oool0S@3oool00`3o0?l0oooo0?ooo`1@0?ooo`002@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo00<0oooo0P00000M0?o<f@030?l0003oool0oooo08l0oooo0P3o0?m@
0?ooo`002@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oc=T0703oc=T00`3o0000oooo0?ooo`2A0?ooo`030?l0o`3oool0oooo04d0oooo00090?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?o<
f@0K0?o<f@030?l0003oool0oooo09<0oooo0P3o0?m=0?ooo`002P3oool2000000X0oooo0P000005
0?ooo`030000003oool0olcI01/0olcI00<0o`000?ooo`3oool0U@3oool00`3o0?l0oooo0?ooo`1:
0?ooo`007@3oool00`000000oooo0?o<f@0J0?o<f@030?l0003oool0oooo09L0oooo0P3o0?m:0?oo
o`007@3oool00`000000oooo0?o<f@0J0?o<f@030?l0003oool0oooo09T0oooo00<0o`3o0?ooo`3o
ool0A`3oool001d0oooo00<000000?ooo`3oc=T06@3oc=T00`3o0000oooo0?ooo`2K0?ooo`80o`3o
A`3oool001d0oooo00<000000?ooo`3oc=T06@3oc=T00`3o0000oooo0?ooo`2M0?ooo`030?l0o`3o
ool0oooo04@0oooo000M0?ooo`030000003oool0olcI01P0olcI00<0o`000?ooo`3oool0W`3oool0
0`3o0?l0oooo0?ooo`130?ooo`007@3oool00`000000oooo0?o<f@0H0?o<f@030?l0003oool0oooo
0:00oooo0P3o0?m30?ooo`007@3oool00`000000oooo0?o<f@0G0?o<f@030?l0003oool0oooo0:<0
oooo00<0o`3o0?ooo`3oool0@03oool001d0oooo00<000000?ooo`3oc=T05`3oc=T00`3o0000oooo
0?ooo`2T0?ooo`030?l0o`3oool0oooo03l0oooo000M0?ooo`030000003oool0olcI01L0olcI00<0
o`000?ooo`3oool0Y@3oool00`3o0?l0oooo0?ooo`0n0?ooo`007@3oool00`000000oooo0?o<f@0F
0?o<f@030?l0003oool0oooo0:L0oooo0P3o0?ln0?ooo`007@3oool00`000000oooo0?o<f@0F0?o<
f@030?l0003oool0oooo0:T0oooo00<0o`3o0?ooo`3oool0>`3oool001d0oooo00<000000?ooo`3o
c=T05@3oc=T00`3o0000oooo0?ooo`2[0?ooo`030?l0o`3oool0oooo03X0oooo000M0?ooo`030000
003oool0olcI01D0olcI00<0o`000?ooo`3oool0[03oool20?l0ocX0oooo000M0?ooo`030000003o
ool0olcI01@0olcI00<0o`000?ooo`3oool0[`3oool00`3o0?l0oooo0?ooo`0g0?ooo`007@3oool0
0`000000oooo0?o<f@0D0?o<f@030?l0003oool0oooo0;00oooo00<0o`3o0?ooo`3oool0=P3oool0
00X0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oc=T04`3oc=T00`3o
0000oooo0?ooo`2b0?ooo`80o`3o=P3oool000T0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0olcI01<0olcI00<0o`000?ooo`3oool0]03oool00`3o
0?l0oooo0?ooo`0c0?ooo`002@3oool010000000oooo0?ooo`0000080?ooo`D000000`3oool20000
01<0olcI00<0o`000?ooo`3oool0]P3oool20?l0oc<0oooo00090?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?o<f@0B0?o<f@030?l0003oool0
oooo0;P0oooo00<0o`3o0?ooo`3oool0<03oool000T0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo000000040?ooo`030000003oool0olcI0140olcI00<0o`000?ooo`3oool0^P3oool2
0?l0oc00oooo000:0?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3oc=T04@3oc=T00`3o
0000oooo0?ooo`2l0?ooo`030?l0o`3oool0oooo02d0oooo000M0?ooo`030000003oool0olcI0140
olcI00<0o`000?ooo`3oool0_@3oool20?l0obd0oooo000M0?ooo`030000003oool0olcI0100olcI
00<0o`000?ooo`3oool0`03oool20?l0ob/0oooo000M0?ooo`030000003oool0olcI0100olcI00<0
o`000?ooo`3oool0`P3oool00`3o0?l0oooo0?ooo`0X0?ooo`007@3oool00`000000oooo0?o<f@0?
0?o<f@030?l0003oool0oooo0<@0oooo0P3o0?lX0?ooo`007@3oool00`000000oooo0?o<f@0?0?o<
f@030?l0003oool0oooo0<H0oooo00<0o`3o0?ooo`3oool09@3oool001d0oooo00<000000?ooo`3o
c=T03`3oc=T00`3o0000oooo0?ooo`370?ooo`80o`3o9@3oool001d0oooo00<000000?ooo`3oc=T0
3P3oc=T00`3o0000oooo0?ooo`3:0?ooo`030?l0o`3oool0oooo0280oooo000M0?ooo`030000003o
ool0olcI00h0olcI00<0o`000?ooo`3oool0b`3oool00`3o0?l0oooo0?ooo`0Q0?ooo`007@3oool0
0`000000oooo0?o<f@0>0?o<f@030?l0003oool0oooo0<`0oooo0P3o0?lQ0?ooo`007@3oool00`00
0000oooo0?o<f@0=0?o<f@030?l0003oool0oooo0<l0oooo00<0o`3o0?ooo`3oool07P3oool001d0
oooo00<000000?ooo`3oc=T03@3oc=T00`3o0000oooo0?ooo`3@0?ooo`80o`3o7P3oool001d0oooo
00<000000?ooo`3oc=T0303oc=T00`3o0000o`3o0?ooo`3C0?ooo`030?l0o`3oool0oooo01/0oooo
000M0?ooo`030000003oool0olcI00`0olcI00<0o`000?ooo`3oool0e03oool00`3o0?l0oooo0?oo
o`0J0?ooo`007@3oool00`000000oooo0?o<f@0<0?o<f@030?l0003oool0oooo0=D0oooo00<0o`3o
0?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oc=T02`3oc=T00`3o0000o`3o0?ooo`3G0?oo
o`030?l0o`3oool0oooo01P0oooo000M0?ooo`030000003oool0olcI00/0olcI00<0o`000?ooo`3o
ool0f03oool20?l0oaP0oooo000:0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000
003oool0olcI00/0olcI00<0o`000?ooo`3oool0fP3oool0103o0?l0o`000?l0003o000D0?ooo`00
2@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oc=T02P3oc=T00`3o0000o`3o0?ooo`3K0?ooo`D0o`004`3oool000T0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`020?ooo`8000002`3oc=T00`3o0000oooo0?ooo`3K0?oo
o`D0o`004`3oool000T0oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?oo
o`3oc=T02P3oc=T00`3o0000oooo0?ooo`3K0?ooo`D0o`004`3oool000T0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0olcI00T0olcI00<0o`000?l0
o`3oool0g@3oool30?l001@0oooo000:0?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3o
c=T02@3oc=T00`3o0000oooo0?ooo`3d0?ooo`007@3oool00`000000oooo0?o<f@090?o<f@030?l0
003oool0oooo0?@0oooo000M0?ooo`030000003oool0olcI00T0olcI00<0o`000?ooo`3oool0m03o
ool001d0oooo00<000000?ooo`3oc=T0203oc=T00`3o0000oooo0?ooo`3e0?ooo`007@3oool00`00
0000oooo0?o<f@080?o<f@030?l0003oool0oooo0?D0oooo000M0?ooo`030000003oool0olcI00P0
olcI00<0o`000?ooo`3oool0m@3oool001d0oooo00<000000?ooo`3oc=T01`3oc=T00`3o0000oooo
0?ooo`3f0?ooo`007@3oool00`000000oooo0?o<f@070?o<f@030?l0003oool0oooo0?H0oooo000M
0?ooo`030000003oool0olcI00L0olcI00<0o`000?ooo`3oool0mP3oool001d0oooo00<000000?oo
o`3oc=T01P3oc=T00`3o0000oooo0?ooo`3g0?ooo`007@3oool00`000000oooo0?o<f@060?o<f@03
0?l0003oool0oooo0?L0oooo000M0?ooo`030000003oool0olcI00H0olcI00<0o`000?ooo`3oool0
m`3oool001d0oooo00<000000?ooo`3oc=T01P3oc=T00`3o0000oooo0?ooo`3g0?ooo`007@3oool0
0`000000oooo0?o<f@050?o<f@030?l0003oool0oooo0?P0oooo000M0?ooo`030000003oool0olcI
00D0olcI00<0o`000?ooo`3oool0n03oool001d0oooo00<000000?ooo`3oc=T01@3oc=T00`3o0000
oooo0?ooo`3h0?ooo`002P3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo
0?o<f@040?o<f@030?l0003oool0oooo0?T0oooo00090?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?o<f@040?o<f@030?l0003oool0oooo0?T0
oooo00090?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool20000
00D0olcI00<0o`000?ooo`3oool0n@3oool000T0oooo00@000000?ooo`3oool00000203oool30000
00D0oooo00<000000?ooo`3oc=T00`3oc=T00`3o0000oooo0?ooo`3j0?ooo`002@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oc=T00`3oc=T00`3o
0000oooo0?ooo`3j0?ooo`002P3oool2000000X0oooo0`0000040?ooo`030000003oool0olcI00<0
olcI00<0o`000?ooo`3oool0nP3oool001d0oooo00<000000?ooo`3oc=T00`3oc=T00`3o0000oooo
0?ooo`3j0?ooo`007@3oool00`000000oooo0?o<f@020?o<f@030?l0003oool0oooo0?/0oooo000M
0?ooo`030000003oool0olcI0080olcI00<0o`000?ooo`3oool0n`3oool001d0oooo00<000000?oo
o`3oc=T00P3oc=T00`3o0000oooo0?ooo`3k0?ooo`007@3oool01@000000oooo0?o<f@3oc=T0o`00
0?h0oooo000M0?ooo`050000003oool0olcI0?o<f@3o0000oP3oool001d0oooo00D000000?ooo`3o
c=T0olcI0?l0003n0?ooo`007@3oool010000000oooo0?o<f@3o003o0?ooo`007@3oool010000000
oooo0?o<f@3o003o0?ooo`007@3oool010000000oooo0?o<f@3o003o0?ooo`007@3oool010000000
oooo0?o<f@3o003o0?ooo`007@3oool00`000000oooo0?l0003o0?ooo`40oooo000M0?ooo`030000
003oool0o`000?l0oooo0@3oool001d0oooo00<000000?ooo`3o0?l0o`3oool10?ooo`007@3oool0
0`000000o`3o0?ooo`3o0?ooo`40oooo000M0?ooo`030000003o0?l0oooo0?l0oooo0@3oool000X0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<0o`00o`3oool20?ooo`00
2@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0?ooo`D0o`00o`3oool10?oo
o`002@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0?ooo`D0o`00o`3oool1
0?ooo`002@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00D0o`00o`3oool1
0?ooo`002@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0`3o
003o0?ooo`80oooo000:0?ooo`8000002@3oool4000000@0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooo`40oooo000M0?ooo`030000003oool0oooo0?l0
oooo0@3oool001d0oooo00<000000?ooo`3oool0o`3oool10?ooo`007@3oool00`000000oooo0?oo
o`3o0?ooo`40oooo000M0?ooo`030000003oool0oooo0?l0oooo0@3oool001d0oooo00<000000?oo
o`3oool0o`3oool10?ooo`007@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, 0, 0, 0}}],
  "            ",
  Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0 0.824045 [
[.04546 -0.0125 -5 -12.5625 ]
[.04546 -0.0125 5 0 ]
[.3927 -0.0125 -5 -12.5625 ]
[.3927 -0.0125 5 0 ]
[.6073 -0.0125 -5 -12.5625 ]
[.6073 -0.0125 5 0 ]
[.73994 -0.0125 -5 -12.5625 ]
[.73994 -0.0125 5 0 ]
[.95455 -0.0125 -5 -12.5625 ]
[.95455 -0.0125 5 0 ]
[.03295 .0824 -18 -4.5 ]
[.03295 .0824 0 4.5 ]
[.03295 .16481 -18 -4.5 ]
[.03295 .16481 0 4.5 ]
[.03295 .24721 -18 -4.5 ]
[.03295 .24721 0 4.5 ]
[.03295 .32962 -18 -4.5 ]
[.03295 .32962 0 4.5 ]
[.03295 .41202 -18 -4.5 ]
[.03295 .41202 0 4.5 ]
[.03295 .49443 -18 -4.5 ]
[.03295 .49443 0 4.5 ]
[.03295 .57683 -18 -4.5 ]
[.03295 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04546 0 m
.04546 .00625 L
s
gsave
.04546 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.3927 0 m
.3927 .00625 L
s
gsave
.3927 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6073 0 m
.6073 .00625 L
s
gsave
.6073 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.73994 0 m
.73994 .00625 L
s
gsave
.73994 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.95455 0 m
.95455 .00625 L
s
gsave
.95455 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
.04545 .0824 m
.0517 .0824 L
s
[(0.1)] .03295 .0824 1 0 Mshowa
.04545 .16481 m
.0517 .16481 L
s
[(0.2)] .03295 .16481 1 0 Mshowa
.04545 .24721 m
.0517 .24721 L
s
[(0.3)] .03295 .24721 1 0 Mshowa
.04545 .32962 m
.0517 .32962 L
s
[(0.4)] .03295 .32962 1 0 Mshowa
.04545 .41202 m
.0517 .41202 L
s
[(0.5)] .03295 .41202 1 0 Mshowa
.04545 .49443 m
.0517 .49443 L
s
[(0.6)] .03295 .49443 1 0 Mshowa
.04545 .57683 m
.0517 .57683 L
s
[(0.7)] .03295 .57683 1 0 Mshowa
.04545 0 m
.04545 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.04545 .41202 m
.08233 .38528 L
.12255 .35612 L
.16033 .32875 L
.19665 .30248 L
.23532 .27467 L
.27254 .24815 L
.3121 .22045 L
.35022 .19451 L
.38689 .17059 L
.42589 .14672 L
.46346 .12584 L
.49957 .10835 L
.51965 .09997 L
.53803 .09331 L
.55722 .0875 L
.57504 .08327 L
.58381 .08164 L
.59316 .08026 L
.5985 .07964 L
.60353 .07917 L
.60805 .07885 L
.6106 .07871 L
.61294 .07861 L
.61415 .07857 L
.61529 .07854 L
.61632 .07851 L
.61743 .07849 L
.61862 .07848 L
.61973 .07847 L
.62092 .07847 L
.6216 .07848 L
.62223 .07848 L
.6233 .07849 L
.62441 .07851 L
.62537 .07853 L
.62641 .07856 L
.62874 .07865 L
.63091 .07876 L
.63591 .07909 L
.64045 .07952 L
.64569 .08016 L
.65063 .0809 L
.65991 .08269 L
.66974 .08516 L
.68735 .09117 L
.70604 .09993 L
.72352 .11054 L
.76058 .14165 L
.78079 .16411 L
Mistroke
.79998 .18942 L
.83648 .24943 L
.87533 .3326 L
.91273 .43429 L
.95247 .56899 L
.95455 .57683 L
Mfstroke
1 .8 .85 r
.3927 .16692 m
.41549 .1529 L
.44035 .13841 L
.46369 .12572 L
.48614 .11451 L
.51004 .10385 L
.53304 .09502 L
.55749 .08742 L
.56974 .0844 L
.58105 .08212 L
.59205 .0804 L
.5976 .07973 L
.60371 .07916 L
.60678 .07893 L
.60969 .07876 L
.61231 .07864 L
.61378 .07858 L
.61516 .07854 L
.61594 .07852 L
.61678 .07851 L
.61748 .07849 L
.61825 .07848 L
.61869 .07848 L
.61909 .07848 L
.61951 .07847 L
.61997 .07847 L
.62039 .07847 L
.6208 .07847 L
.62155 .07848 L
.62227 .07848 L
.62303 .07849 L
.62367 .0785 L
.62439 .07851 L
.62598 .07855 L
.62748 .0786 L
.63025 .07872 L
.63328 .0789 L
.63939 .07941 L
.64504 .08007 L
.6503 .08085 L
.66237 .08325 L
.67334 .08622 L
.68466 .09011 L
.69692 .09534 L
.72106 .1089 L
.74431 .12647 L
.76666 .14798 L
.79046 .17636 L
.81336 .20954 L
.83771 .25175 L
.86117 .2998 L
.88373 .35349 L
.90774 .41939 L
.93086 .4921 L
.95455 .57683 L
.95455 0 L
.3927 0 L
F
1 0 0 r
.3927 .16692 m
.41549 .1529 L
.44035 .13841 L
.46369 .12572 L
.48614 .11451 L
.51004 .10385 L
.53304 .09502 L
.55749 .08742 L
.56974 .0844 L
.58105 .08212 L
.59205 .0804 L
.5976 .07973 L
.60371 .07916 L
.60678 .07893 L
.60969 .07876 L
.61231 .07864 L
.61378 .07858 L
.61516 .07854 L
.61594 .07852 L
.61678 .07851 L
.61748 .07849 L
.61825 .07848 L
.61869 .07848 L
.61909 .07848 L
.61951 .07847 L
.61997 .07847 L
.62039 .07847 L
.6208 .07847 L
.62155 .07848 L
.62227 .07848 L
.62303 .07849 L
.62367 .0785 L
.62439 .07851 L
.62598 .07855 L
.62748 .0786 L
.63025 .07872 L
.63328 .0789 L
.63939 .07941 L
.64504 .08007 L
.6503 .08085 L
.66237 .08325 L
.67334 .08622 L
.68466 .09011 L
.69692 .09534 L
.72106 .1089 L
.74431 .12647 L
.76666 .14798 L
.79046 .17636 L
.81336 .20954 L
.83771 .25175 L
Mistroke
.86117 .2998 L
.88373 .35349 L
.90774 .41939 L
.93086 .4921 L
.95455 .57683 L
Mfstroke
.02 w
.04545 .41202 Mdot
.95455 .57683 Mdot
0 0 1 r
.3927 .16692 Mdot
.6073 .0789 Mdot
0 1 0 r
.73994 .12281 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
    ImageSize->{288, 177.938},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool5000005L0oooo0`00
000e0?ooo`@000007P3oool3000003<0oooo1000000E0?ooo`006`3oool4000005L0oooo00<00000
0?ooo`3oool0=@3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo03D0oooo00@0
00000?ooo`3oool00000503oool001h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0e0?ooo`040000003oool0oooo000001h0oooo1000000d0?ooo`040000003oool0oooo000001@0
oooo000L0?ooo`<00000F03oool3000003D0oooo0`00000O0?ooo`800000=@3oool3000001D0oooo
002a0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool05@3oool00;00oooo0P00001E
0?ooo`8000005`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00140ooooo`000007000000T0oooo000M0?ooo`030000003oool0oooo05P0
ooooTP3oc=T00`000000oooo0?ooo`0C0?ooo`007@3oool00`000000oooo0?ooo`1H0?oooi80olcI
00<000000?ooo`3oool04`3oool001d0oooo00<000000?ooo`3oool0F03ooonB0?o<fAH0oooo000M
0?ooo`030000003oool0oooo05P0ooooTP3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`1H0?oo
oi80olcI5P3oool001d0oooo00<000000?ooo`3oool0F03ooonB0?o<fAH0oooo000M0?ooo`030000
003oool0oooo05P0ooooTP3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`1H0?oooi80olcI5P3o
ool001d0oooo00<000000?ooo`3oool0F03ooonB0?o<fAH0oooo000M0?ooo`030000003oool0oooo
05P0ooooTP3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`1H0?oooi80olcI5P3oool001d0oooo
00<000000?ooo`3oool0F03ooonB0?o<fAH0oooo000M0?ooo`030000003oool0oooo05P0ooooTP3o
c=TF0?ooo`007@3oool00`000000oooo0?ooo`1H0?oooi80olcI5P3oool001d0oooo00<000000?oo
o`3oool0F03ooonB0?o<fAH0oooo000M0?ooo`030000003oool0oooo05P0ooooTP3oc=TF0?ooo`00
7@3oool00`000000oooo0?ooo`1H0?oooi80olcI5P3oool001d0oooo00<000000?ooo`3oool0F03o
oonB0?o<fAH0oooo000M0?ooo`030000003oool0oooo05P0oooo=`3oc=T30000oeP0olcI5P3oool0
00X0oooo0P0000040?ooo`8000000`3oool5000000<0oooo00<000000?ooo`3oool0F03ooolf0?o<
f@D0003oE`3oc=TF0?ooo`002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0F03ooolc0?o<f@<0o`001@000?l:0?l004d0olcI5P3oool000T0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`<00000F03oool]0?o<
f@H0o`0000<0o`3o0?ooo`3oool01@000?l90?ooo`040?l0o`3o0000o`000?l004X0olcI5P3oool0
00T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo05P0oooo:P3oc=T30?l000030?l0o`3oool0oooo00L0oooo0`000?l=0?ooo`040?l0o`3o0000
o`000?l004L0olcI5P3oool000T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo05P0oooo9P3oc=T40?l00240oooo0`3o00140?o<fAH0oooo000:
0?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0F03ooolS0?o<f@<0o`000P3o0?lV
0?ooo`80o`00@P3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`1H0?ooob00olcI0`3o00000`3o
0?l0oooo0?ooo`0Z0?ooo`80o`00@03oc=TF0?ooo`007@3oool00`000000oooo0?ooo`1H0?oooah0
olcI0P3o00000`3o0?l0oooo0?ooo`0_0?ooo`030?l0003oc=T0olcI03d0olcI5P3oool001d0oooo
00<000000?ooo`3oool0F03ooolL0?o<f@80o`0000<0o`3o0?ooo`3oool0<P3oool20?l003d0olcI
5P3oool001d0oooo00<000000?ooo`3oool0F03ooolJ0?o<f@80o`0000<0o`3o0?ooo`3oool0=P3o
ool00`3o0000olcI0?o<f@0j0?o<fAH0oooo000M0?ooo`030000003oool0oooo05P0oooo603oc=T2
0?l000030?l0o`3oool0oooo03T0oooo0P3o0000103oc=T00?l0003o0000o`0f0?o<fAH0oooo000M
0?ooo`030000003oool0oooo05P0oooo5P3oc=T20?l000030?l0o`3oool0oooo03d0oooo1@00o`0e
0?o<fAH0oooo000M0?ooo`030000003oool0oooo05P0oooo503oc=T20?l00480oooo1@00o`0e0?o<
fAH0oooo000M0?ooo`030000003oool0oooo05P0oooo4P3oc=T20?l004@0oooo1@00o`0e0?o<fAH0
oooo000M0?ooo`030000003oool0oooo05P0oooo403oc=T20?l004L0oooo0`00o`000`3o0000olcI
0?o<f@0c0?o<fAH0oooo000M0?ooo`030000003oool0oooo05P0oooo3P3oc=T20?l004d0oooo00<0
o`000?o<f@3oc=T0<P3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`1H0?ooo``0olcI0P3o001@
0?ooo`030?l0003oc=T0olcI0340olcI5P3oool001d0oooo00<000000?ooo`3oool0F03oool:0?o<
f@80o`0000<0o`3o0?ooo`3oool0D03oool00`3o0000olcI0?o<f@0`0?o<fAH0oooo000M0?ooo`03
0000003oool0oooo05P0oooo2@3oc=T00`3o0000o`3o0?ooo`1D0?ooo`030?l0003oc=T0olcI02l0
olcI5P3oool001d0oooo00<000000?ooo`3oool0F03oool70?o<f@80o`00F03oool00`3o0000olcI
0?o<f@0^0?o<fAH0oooo000M0?ooo`030000003oool0oooo05P0oooo1P3oc=T00`3o0000o`3o0?oo
o`1I0?ooo`030?l0003oc=T0olcI02d0olcI5P3oool000X0oooo0P0000040?ooo`8000000`3oool4
000000@0oooo00<000000?ooo`3oool0F03oool40?o<f@80o`00G@3oool00`3o0000olcI0?o<f@0/
0?o<fAH0oooo00090?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1G0?ooo`<0003o00<0olcI0?l0003oool0G`3oool00`3o0000olcI0?o<f@0[
0?o<fAH0oooo00090?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool3
000005H0oooo1@000?mQ0?ooo`030?l0003oc=T0olcI02/0olcI5P3oool000T0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05H0oooo1@000?mR
0?ooo`030?l0003oc=T0olcI02X0olcI5P3oool000T0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo05H0oooo1@000?mS0?ooo`030?l0003o
c=T0olcI02T0olcI5P3oool000X0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`1D
0?ooo`80o`3o00@0oooo0000o`000?l0003oI@3oool00`3o0000olcI0?o<f@0X0?o<fAH0oooo000M
0?ooo`030000003oool0oooo05<0oooo00<0o`3o0?ooo`3oool0JP3oool00`3o0000olcI0?o<f@0W
0?o<fAH0oooo000M0?ooo`030000003oool0oooo0540oooo0P3o0?m]0?ooo`030?l0003oc=T0olcI
02L0olcI5P3oool001d0oooo00<000000?ooo`3oool0D03oool00`3o0?l0oooo0?ooo`1^0?ooo`03
0?l0003oc=T0olcI02H0olcI5P3oool001d0oooo00<000000?ooo`3oool0CP3oool20?l0og80oooo
00<0o`000?o<f@3oc=T09@3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`1=0?ooo`030?l0o`3o
ool0oooo0780oooo00<0o`000?o<f@3oc=T09@3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`1;
0?ooo`80o`3oMP3oool00`3o0000olcI0?o<f@0T0?o<fAH0oooo000M0?ooo`030000003oool0oooo
04X0oooo00<0o`3o0?ooo`3oool0M`3oool00`3o0000olcI0?o<f@0S0?o<fAH0oooo000M0?ooo`03
0000003oool0oooo04T0oooo00<0o`3o0?ooo`3oool0N03oool00`3o0000olcI0?o<f@0S0?o<fAH0
oooo000M0?ooo`030000003oool0oooo04L0oooo0P3o0?ml0?ooo`030?l0003oc=T0olcI0280olcI
5P3oool001d0oooo00<000000?ooo`3oool0AP3oool00`3o0?l0oooo0?ooo`1m0?ooo`030?l0003o
c=T0olcI0240olcI5P3oool001d0oooo00<000000?ooo`3oool0A03oool20?l0oh00oooo00<0o`00
0?o<f@3oc=T08@3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`130?ooo`030?l0o`3oool0oooo
0840oooo00<0o`000?o<f@3oc=T0803oc=TF0?ooo`007@3oool00`000000oooo0?ooo`110?ooo`80
o`3oQ03oool00`3o0?l0o`000?o<f@0P0?o<fAH0oooo000M0?ooo`030000003oool0oooo0400oooo
00<0o`3o0?ooo`3oool0Q@3oool00`3o0000olcI0?o<f@0O0?o<fAH0oooo000M0?ooo`030000003o
ool0oooo03h0oooo0P3o0?n90?ooo`030?l0003oc=T0olcI01h0olcI5P3oool001d0oooo00<00000
0?ooo`3oool0?03oool20?l0oh/0oooo00<0o`000?o<f@3oc=T07P3oc=TF0?ooo`002P3oool20000
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0k0?ooo`030?l0o`3oool0oooo
08`0oooo00<0o`000?o<f@3oc=T07@3oc=TF0?ooo`002@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>@3oool20?l0ohl0oooo00<0o`3o
0?l0003oc=T07@3oc=TF0?ooo`002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00<0oooo0`00000h0?ooo`030?l0o`3oool0oooo0900oooo00<0o`000?o<f@3oc=T0703oc=TF
0?ooo`002@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0=`3oool00`3o0?l0oooo0?ooo`2A0?ooo`030?l0o`3o0000olcI01`0olcI5P3oool0
00T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo03D0oooo0P3o0?nE0?ooo`030?l0003oc=T0olcI01/0olcI5P3oool000X0oooo0P00000:
0?ooo`8000001@3oool00`000000oooo0?ooo`0d0?ooo`030?l0o`3oool0oooo09D0oooo00<0o`3o
0?l0003oc=T06`3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`0c0?ooo`030?l0o`3oool0oooo
09L0oooo00<0o`000?o<f@3oc=T06P3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`0a0?ooo`80
o`3oVP3oool00`3o0?l0o`000?o<f@0J0?o<fAH0oooo000M0?ooo`030000003oool0oooo0300oooo
00<0o`3o0?ooo`3oool0V`3oool00`3o0000olcI0?o<f@0I0?o<fAH0oooo000M0?ooo`030000003o
ool0oooo02l0oooo00<0o`3o0?ooo`3oool0W03oool00`3o0?l0o`000?o<f@0I0?o<fAH0oooo000M
0?ooo`030000003oool0oooo02d0oooo0P3o0?nP0?ooo`030?l0003oc=T0olcI01P0olcI5P3oool0
01d0oooo00<000000?ooo`3oool0;03oool00`3o0?l0oooo0?ooo`2P0?ooo`030?l0o`3o0000olcI
01P0olcI5P3oool001d0oooo00<000000?ooo`3oool0:`3oool00`3o0?l0oooo0?ooo`2R0?ooo`03
0?l0003oc=T0olcI01L0olcI5P3oool001d0oooo00<000000?ooo`3oool0:@3oool20?l0ojD0oooo
00<0o`3o0?l0003oc=T05`3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`0X0?ooo`030?l0o`3o
ool0oooo0:H0oooo00<0o`000?o<f@3oc=T05P3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`0V
0?ooo`80o`3oZ@3oool00`3o0?l0o`000?o<f@0F0?o<fAH0oooo000M0?ooo`030000003oool0oooo
02D0oooo00<0o`3o0?ooo`3oool0ZP3oool00`3o0000olcI0?o<f@0E0?o<fAH0oooo000M0?ooo`03
0000003oool0oooo02<0oooo0P3o0?n]0?ooo`030?l0003oc=T0olcI01D0olcI5P3oool001d0oooo
00<000000?ooo`3oool08P3oool00`3o0?l0oooo0?ooo`2^0?ooo`030?l0003oc=T0olcI01@0olcI
5P3oool001d0oooo00<000000?ooo`3oool08@3oool00`3o0?l0oooo0?ooo`2_0?ooo`030?l0003o
c=T0olcI01@0olcI5P3oool001d0oooo00<000000?ooo`3oool07`3oool20?l0ok<0oooo00<0o`00
0?o<f@3oc=T04`3oc=TF0?ooo`002P3oool2000000@0oooo0P0000050?ooo`<000000`3oool00`00
0000oooo0?ooo`0N0?ooo`030?l0o`3oool0oooo0;<0oooo00<0o`000?o<f@3oc=T04`3oc=TF0?oo
o`002@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0703oool20?l0okL0oooo00<0o`000?o<f@3oc=T04P3oc=TF0?ooo`002@3oool010000000
oooo0?ooo`0000080?ooo`D000000`3oool3000001/0oooo00<0o`3o0?ooo`3oool0]`3oool00`3o
0000olcI0?o<f@0B0?o<fAH0oooo00090?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0I0?ooo`80o`3o^P3oool00`3o0000olcI0?o<f@0B
0?o<fAH0oooo00090?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0H0?ooo`030?l0o`3oool0oooo0;/0oooo00<0o`000?o<f@3oc=T04@3oc=TF
0?ooo`002P3oool2000000/0oooo0P0000040?ooo`030000003oool0oooo01L0oooo00<0o`3o0?oo
o`3oool0_03oool00`3o0000olcI0?o<f@0A0?o<fAH0oooo000M0?ooo`030000003oool0oooo01D0
oooo0P3o0?o00?ooo`030?l0003oc=T0olcI0100olcI5P3oool001d0oooo00<000000?ooo`3oool0
503oool00`3o0?l0oooo0?ooo`300?ooo`030?l0003oc=T0olcI0100olcI5P3oool001d0oooo00<0
00000?ooo`3oool04P3oool20?l0ol@0oooo00<0o`000?o<f@3oc=T03`3oc=TF0?ooo`007@3oool0
0`000000oooo0?ooo`0A0?ooo`030?l0o`3oool0oooo0<@0oooo00<0o`000?o<f@3oc=T03`3oc=TF
0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`030?l0o`3oool0oooo0<D0oooo00<0o`000?o<
f@3oc=T03`3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`0>0?ooo`80o`3ob@3oool00`3o0000
olcI0?o<f@0>0?o<fAH0oooo000M0?ooo`030000003oool0oooo00d0oooo00<0o`3o0?ooo`3oool0
b@3oool00`3o0000olcI0?o<f@0>0?o<fAH0oooo000M0?ooo`030000003oool0oooo00`0oooo00<0
o`3o0?ooo`3oool0bP3oool00`3o0000olcI0?o<f@0>0?o<fAH0oooo000M0?ooo`030000003oool0
oooo00/0oooo00<0o`3o0?ooo`3oool0c03oool00`3o0000olcI0?o<f@0=0?o<fAH0oooo000M0?oo
o`030000003oool0oooo00T0oooo0P3o0?o?0?ooo`030?l0003oc=T0olcI00d0olcI5P3oool001d0
oooo00<000000?ooo`3oool0203oool00`3o0?l0oooo0?ooo`3?0?ooo`030?l0003oc=T0olcI00d0
olcI5P3oool001d0oooo00<000000?ooo`3oool01`3oool00`3o0?l0oooo0?ooo`3A0?ooo`030?l0
003oc=T0olcI00`0olcI5P3oool001d0oooo00<000000?ooo`3oool01@3oool20?l0om@0oooo00<0
o`000?o<f@3oc=T0303oc=TF0?ooo`007@3oool00`000000oooo0?ooo`040?ooo`030?l0o`3oool0
oooo0=@0oooo00<0o`3o0?l0003oc=T0303oc=TF0?ooo`007@3oool00`000000oooo0?ooo`030?oo
o`030?l0o`3oool0oooo0=H0oooo00<0o`000?o<f@3oc=T02`3oc=TF0?ooo`007@3oool010000000
oooo0?ooo`3oool20?l0omT0oooo00<0o`000?o<f@3oc=T02`3oc=TF0?ooo`002P3oool2000000@0
oooo0P0000040?ooo`800000103oool30?l000030?ooo`3o0?l0oooo0=X0oooo00<0o`3o0?l0003o
c=T02`3oc=TF0?ooo`002@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo1@3o003M0?ooo`030?l0003oc=T0olcI00X0olcI5P3oool000T0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`050?l00=d0oooo00<0o`000?o<f@3oc=T02P3oc=TF0?oo
o`002@3oool010000000oooo0?ooo`0000090?ooo`8000000`3oool50?l00=d0oooo00<0o`3o0?l0
003oc=T02P3oc=TF0?ooo`002@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00<0oooo0`3o003O0?ooo`030?l0003oc=T0olcI00T0olcI5P3oool000X0oooo0P00000:0?ooo`<0
0000103oool00`000000oooo0?ooo`3N0?ooo`030?l0003oc=T0olcI00T0olcI5P3oool001d0oooo
00<000000?ooo`3oool0gP3oool00`3o0?l0o`000?o<f@090?o<fAH0oooo000M0?ooo`030000003o
ool0oooo0=l0oooo00<0o`000?o<f@3oc=T0203oc=TF0?ooo`007@3oool00`000000oooo0?ooo`3O
0?ooo`030?l0003oc=T0olcI00P0olcI5P3oool001d0oooo00<000000?ooo`3oool0g`3oool00`3o
0?l0o`000?o<f@080?o<fAH0oooo000M0?ooo`030000003oool0oooo0>00oooo00<0o`000?o<f@3o
c=T01`3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`3P0?ooo`030?l0003oc=T0olcI00L0olcI
5P3oool001d0oooo00<000000?ooo`3oool0h03oool00`3o0?l0o`000?o<f@070?o<fAH0oooo000M
0?ooo`030000003oool0oooo0>40oooo00<0o`000?o<f@3oc=T01P3oc=TF0?ooo`007@3oool00`00
0000oooo0?ooo`3Q0?ooo`030?l0003oc=T0olcI00H0olcI5P3oool001d0oooo00<000000?ooo`3o
ool0h@3oool00`3o0000olcI0?o<f@060?o<fAH0oooo000M0?ooo`030000003oool0oooo0>80oooo
00<0o`000?o<f@3oc=T01@3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`3R0?ooo`030?l0003o
c=T0olcI00D0olcI5P3oool001d0oooo00<000000?ooo`3oool0hP3oool00`3o0000olcI0?o<f@05
0?o<fAH0oooo000M0?ooo`030000003oool0oooo0>80oooo00<0o`3o0?l0003oc=T01@3oc=TF0?oo
o`007@3oool00`000000oooo0?ooo`3S0?ooo`030?l0003oc=T0olcI00@0olcI5P3oool000X0oooo
0P0000040?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0h`3oool00`3o0000olcI
0?o<f@040?o<fAH0oooo00090?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`3S0?ooo`030?l0o`3o0000olcI00@0olcI5P3oool000T0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`<00000i03oool00`3o
0000olcI0?o<f@030?o<fAH0oooo00090?ooo`040000003oool0oooo000000P0oooo0`0000050?oo
o`030000003oool0oooo0>@0oooo00<0o`000?o<f@3oc=T00`3oc=TF0?ooo`002@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0i03oool00`3o
0?l0o`000?o<f@030?o<fAH0oooo000:0?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3o
ool0i@3oool00`3o0000olcI0?o<f@020?o<fAH0oooo000M0?ooo`030000003oool0oooo0>D0oooo
00<0o`000?o<f@3oc=T00P3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`3U0?ooo`030?l0003o
c=T0olcI0080olcI5P3oool001d0oooo00<000000?ooo`3oool0iP3oool0103o0000olcI0?o<f@3o
c=TF0?ooo`007@3oool00`000000oooo0?ooo`3V0?ooo`040?l0003oc=T0olcI0?o<fAH0oooo000M
0?ooo`030000003oool0oooo0>H0oooo00@0o`000?o<f@3oc=T0olcI5P3oool001d0oooo00<00000
0?ooo`3oool0iP3oool0103o0000olcI0?o<f@3oc=TF0?ooo`007@3oool00`000000oooo0?ooo`3W
0?ooo`030?l0003oc=T0olcI01H0oooo000M0?ooo`030000003oool0oooo0>L0oooo00<0o`000?o<
f@3oc=T05P3oool001d0oooo00<000000?ooo`3oool0i`3oool00`3o0000olcI0?o<f@0F0?ooo`00
7@3oool00`000000oooo0?ooo`3X0?ooo`030?l0003oc=T0oooo01D0oooo000M0?ooo`030000003o
ool0oooo0>P0oooo00<0o`000?o<f@3oool05@3oool001d0oooo00<000000?ooo`3oool0j03oool0
0`3o0000olcI0?ooo`0E0?ooo`007@3oool00`000000oooo0?ooo`3X0?ooo`030?l0003oc=T0oooo
01D0oooo000M0?ooo`030000003oool0oooo0>T0oooo00<0o`000?ooo`3oool0503oool001d0oooo
00<000000?ooo`3oool0j@3oool00`3o0000oooo0?ooo`0D0?ooo`007@3oool00`000000oooo0?oo
o`3Y0?ooo`030?l0003o0?l0oooo01@0oooo000:0?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`3Y0?ooo`<0o`00503oool000T0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>P0oooo1@3o000C
0?ooo`002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo0`00003X
0?ooo`D0o`004`3oool000T0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0>P0oooo1@3o000C0?ooo`002@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0j@3oool30?l001@0oooo000:
0?ooo`8000002@3oool4000000@0oooo00<000000?ooo`3oool0o`3oool10?ooo`007@3oool00`00
0000oooo0?ooo`3o0?ooo`40oooo000M0?ooo`030000003oool0oooo0?l0oooo0@3oool001d0oooo
00<000000?ooo`3oool0o`3oool10?ooo`007@3oool00`000000oooo0?ooo`3o0?ooo`40oooo000M
0?ooo`030000003oool0oooo0?l0oooo0@3oool001d0oooo00<000000?ooo`3oool0o`3oool10?oo
o`007@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0000\
\>"],
    ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, 0, 0, 0}}],
  StyleBox["\nIf ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((c)\) \[LessEqual] f \((d)\)\)]],
  ", then squeeze from the right and use the                       ",
  StyleBox["If ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((d)\) < f \((c)\)\)]],
  ", then squeeze from the left and use the \nnew interval ",
  Cell[BoxData[
      \(\([a, d]\)\)]],
  " and the four points  ",
  Cell[BoxData[
      \({a, e, c, d}\)]],
  ".                      new interval ",
  Cell[BoxData[
      \(\([c, b]\)\)]],
  " and the four points  ",
  Cell[BoxData[
      \({c, d, e, b}\)]],
  ". \n\n\t\t\t\t\t",
  StyleBox["Figure 1.",
    FontFamily->"Times-Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  The decision process for the golden ratio search.   ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["\tThe interior points ",
    FontFamily->"Times-Roman"],
  StyleBox["c",
    FontFamily->"Courier New"],
  StyleBox[" and ",
    FontFamily->"Times-Roman"],
  StyleBox["d",
    FontFamily->"Courier New"],
  StyleBox[" of the original interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ",  must be constructed",
  StyleBox[" so that the resulting intervals ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([a, c]\)\)]],
  StyleBox[",",
    FontFamily->"Times-Roman"],
  StyleBox["  ",
    FontFamily->"MTSYN"],
  StyleBox["and ",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(\([d, b]\)\)]],
  " ",
  StyleBox["are symmetrical in  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".",
  StyleBox["   This requires that  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(b - d\  = \ c - a\)]],
  ",  and produces the two equations  ",
  StyleBox["\n\n(1)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(c\  = \ \(a\  + \ \((1 - r)\) \((b - a)\)\  = \ 
          r\ a\  + \ \((1 - r)\) b\)\)]],
  ",  ",
  StyleBox["\n\tand\n(2)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(d\  = \ \(b\  - \ \((1 - r)\) \((b - a)\)\  = \ \((1 - r)\) 
              a + \ \ r\ b\)\)]],
  ",  \n\n\twhere\t",
  Cell[BoxData[
      \(1\/2 < r < 1\)]],
  "   ",
  StyleBox["(to preserve the ordering  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(c < d\)]],
  StyleBox[").",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["\tWe want the value of  ",
    FontFamily->"Times-Roman"],
  StyleBox["r",
    FontFamily->"Courier New"],
  StyleBox["  to remain constant on each subinterval.  If  ",
    FontFamily->"Times-Roman"],
  StyleBox["r",
    FontFamily->"Courier New"],
  StyleBox["  is chosen judicially then only one new point  ",
    FontFamily->"Times-Roman"],
  StyleBox["e",
    FontFamily->"Courier New"],
  StyleBox["  (shown in green in Figure 1) needs to be constructed for the \
next iteration.  Additionally, one of the old interior points (either ",
    FontFamily->"Times-Roman"],
  StyleBox["c",
    FontFamily->"Courier New"],
  StyleBox[" or ",
    FontFamily->"Times-Roman"],
  StyleBox["d",
    FontFamily->"Courier New"],
  StyleBox[") will be used as an interior point of the next subinterval, \
while the other interior point (",
    FontFamily->"Times-Roman"],
  StyleBox["d",
    FontFamily->"Courier New"],
  StyleBox[" or ",
    FontFamily->"Times-Roman"],
  StyleBox["c",
    FontFamily->"Courier New"],
  StyleBox[") will become an endpoint of the next subinterval in the \
iteration process.  Thus, for each iteration only one new point ",
    FontFamily->"Times-Roman"],
  StyleBox["e",
    FontFamily->"Courier New"],
  StyleBox[" will have to be constructed and only one new function evaluation \
",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((e)\)\)]],
  ", ",
  StyleBox["will have to be made.   As a consequence, this means that the \
value  ",
    FontFamily->"Times-Roman"],
  StyleBox["r",
    FontFamily->"Courier New"],
  StyleBox["  must be chosen carefully to split the interval of ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[" ",
    FontFamily->"MTSYN"],
  StyleBox["into subintervals which have the following ratios: \n\n(3)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(c - a = \((1 - r)\) \((b - a)\)\)]],
  "    and    ",
  Cell[BoxData[
      \(b - c\  = \ r \((b - a)\)\)]],
  ",  \n\tand",
  StyleBox["\n(4)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(b - d = \((1 - r)\) \((b - a)\)\)]],
  "    and    ",
  Cell[BoxData[
      \(d - a\  = \ r \((b - a)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["If ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((c)\) \[LessEqual] f \((d)\)\)]],
  " ",
  StyleBox["and only one new function evaluation is to be made in the \
interval ",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(\([a, d]\)\)]],
  StyleBox[", then we must have \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(d - a\)\/\(b - a\)\  = \ \(c - a\)\/\(d - a\)\)]],
  ".",
  StyleBox["  \n\nUse the facts in (3) and (4) to rewrite this equation and \
then simplify.  \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(r \((b - a)\)\)\/\(b - a\)\ \  = \ \(\((1 - r)\) \((b - a)\)\)\/\(r \
\((b - a)\)\)\)]],
  ",",
  StyleBox["  \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(r\  = \ \(1 - r\)\/r\)]],
  ",  \n\n\t\t",
  Cell[BoxData[
      \(r\^2\  = \ 1\  - \ r\)]],
  ",  \n\n\t\t",
  Cell[BoxData[
      \(r\^2\  + \ r\  - \ 1\  = \ 0\)]],
  ".  \n\nNow the quadratic equation can be applied and we get  \n\n\t\t",
  Cell[BoxData[
      \(r\  = \ 1\/2\ \((\(-1\) \[PlusMinus] \@5)\)\)]],
  ".  \n\nThe value we seek is  ",
  Cell[BoxData[
      \(r\  = \ \(\@5 - 1\)\/2\)]],
  "  and it is often referred to as the \"",
  ButtonBox["golden ratio",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GoldenRatio.html"], None},
    ButtonStyle->"Hyperlink"],
  ".\"   Similarly, if ",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((d)\) < f \((c)\)\)]],
  ", then it can be shown that  ",
  Cell[BoxData[
      \(r\  = \ \(\@5 - 1\)\/2\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/GoldenRatioSearchProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/GoldenRatioSearchProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(Golden Ratio Search for a Minimum",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[")",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[".",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk"],
  "To numerically approximate the minimum of  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  by using a golden ratio search.  Proceed with the method only if  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is a unimodal function on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".  Terminate the process after  ",
  StyleBox["max ",
    FontFamily->"Courier New"],
  " iterations have been completed.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/GoldenRatioSearchProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   ",
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/GoldenRatioSearchProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Golden Ratio Search for a \
Minimum).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(GoldenSearch[a0_, b0_, 
          max_] := \[IndentingNewLine]Module[{a\  = \ N[a0], b\  = \ N[b0], 
            c, d, h, k, m, r, Ya, Yb, Yc, 
            Yd}, \ \[IndentingNewLine]r\_1\  = \ \(\@5 - 1\)\/2\ ; \ \
\[IndentingNewLine]r\_2\  = \ \((r\_1)\)\^2; \ \[IndentingNewLine]h\  = \ 
            b\  - \ a; \ \[IndentingNewLine]Ya\  = \ 
            f[a]; \[IndentingNewLine]Yb\  = \ 
            f[b]; \[IndentingNewLine]c\  = \ 
            a\  + \ r\_2\ h; \ \[IndentingNewLine]d\  = \ 
            a\  + \ r\_1\ h; \ \[IndentingNewLine]Yc\  = \ 
            f[c]; \[IndentingNewLine]Yd\  = \ 
            f[d]; \[IndentingNewLine]Print["\<f[\>", 
            PaddedForm[{a, c, d, b}, {7, 6}], "\<] = \>", 
            PaddedForm[{Ya, Yc, Yd, Yb}, {9, 8}]\ ]; \[IndentingNewLine]m = 
            1; \[IndentingNewLine]While[\ 
            m \[LessEqual] max, \[IndentingNewLine]If[\ 
              Yc < Yd, \[IndentingNewLine]Module[{}, \[IndentingNewLine]b\  = \
\ d; \ \[IndentingNewLine]Yb\  = \ Yd; \ \[IndentingNewLine]d\  = \ 
                  c; \ \[IndentingNewLine]Yd\  = \ 
                  Yc; \ \[IndentingNewLine]h\  = \ 
                  b\  - \ a; \ \[IndentingNewLine]c\  = \ 
                  a\  + \ r\_2\ h; \ \[IndentingNewLine]Yc\  = \ 
                  f[c];\ ], \[IndentingNewLine]\(Module[{}, \
\[IndentingNewLine]a\  = \ c; \ \[IndentingNewLine]Ya\  = \ 
                    Yc; \ \[IndentingNewLine]c\  = \ 
                    d; \ \[IndentingNewLine]Yc\  = \ 
                    Yd; \ \[IndentingNewLine]h\  = \ 
                    b\  - \ a; \ \[IndentingNewLine]d\  = \ 
                    a\  + \ r\_1\ \ h; \ \[IndentingNewLine]Yd\  = \ 
                    f[d];\ \ ];\)\ ]; \ \[IndentingNewLine]Print["\<f[\>", 
              PaddedForm[{a, c, d, b}, {7, 6}], "\<] = \>", 
              PaddedForm[{Ya, Yc, Yd, Yb}, {9, 
                  8}]\ ]; \ \[IndentingNewLine]m = 
              m + 1;\ ]; \ \[IndentingNewLine]p\  = \ 
            a; \ \[IndentingNewLine]Yp\  = \ Ya; \ \[IndentingNewLine]If[\ 
            Yb < Ya, \ p = b; \ 
            Yp = Yb\ ]; \ \[IndentingNewLine]Print["\<After m = \>", 
            m - 1, "\< iterations\>"]; \ \[IndentingNewLine]Print["\<{  a,   \
b,   c,   d}  = \>", 
            PaddedForm[{a, c, d, b}, {7, 
                6}]]; \ \[IndentingNewLine]Print["\<{f[a],f[b],f[c],f[d]} = \
\>", PaddedForm[{Ya, Yc, Yd, Yb}, {13, 
                12}]]; \ \[IndentingNewLine]Return[{Yp, 
              p}];\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[StyleBox["The next example compares the secant method for \
root-finding with the golden ratio search method.  ",
  FontFamily->"Times-Roman"]], "Text"],

Cell[TextData[{
  StyleBox["Algorithm (",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Secant Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SecantMethod.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[").",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk"],
  "Find a root of  ",
  Cell[BoxData[
      \(g \((x)\) = \(f' \((x)\) = 0\)\)]],
  "  given two initial approximations  ",
  Cell[BoxData[
      RowBox[{\(p\_0\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman"], "  ", \(p\_1\)}]]],
  "  using the iteration  \n\n\t",
  Cell[BoxData[
      RowBox[{\(p\_\(k + 1\)\), " ", "=", " ", 
        RowBox[{\(p\_k\), " ", "-", " ", 
          FractionBox[
            RowBox[{
              StyleBox["g",
                FontSize->12], 
              StyleBox[\((p\_k)\),
                FontSize->12], 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(p\_k\),
                    FontSize->12], " ", "-", "  ", 
                  StyleBox[\(p\_\(k - 1\)\),
                    FontSize->12]}], ")"}]}], 
            RowBox[{
              StyleBox[\(g \((p\_k)\)\),
                FontSize->12], " ", "-", "  ", 
              StyleBox[\(g \((p\_\(k - 1\))\)\),
                FontSize->12]}]]}]}]]],
  "   for    ",
  Cell[BoxData[
      \(\(\(k\  = \ 
        1\)\(,\)\(2\)\(,\)\(\[CenterEllipsis]\)\(\ \)\(,\)\(m\)\(\ \)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Secant Method",
    ButtonData:>{
      URL[ 
      "http://www.ecs.fullerton.edu/~mathews/n2003/SecantMethodProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Secant Method",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/SecantMethodProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Secant Method).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(SecantMethod[x0_, x1_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{\(k\)\(,\)}, \
\[IndentingNewLine]k\  = \ 1; \ \[IndentingNewLine]p0\  = \ 
          N[x0]; \ \[IndentingNewLine]p1\  = \ 
          N[x1]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {16, 16}], \*"\"\<,   g[\!\(p\_0\)] = \>\"", 
          NumberForm[g[p0], 
            16]\ ]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_1\) = \>\"", 
          PaddedForm[p1, {16, 16}], \*"\"\<,   g[\!\(p\_1\)] = \>\"", 
          NumberForm[g[p1], 16]\ ]; \ \ \[IndentingNewLine]p2\  = \ 
          p1; \ \[IndentingNewLine]p1\  = \ p0; \ \[IndentingNewLine]While[\ 
          k < max, \[IndentingNewLine]p0\  = \ 
            p1; \ \[IndentingNewLine]p1\  = \ 
            p2; \ \[IndentingNewLine]p2\  = \ 
            p1\  - \ \(g[p1] \((p1\  - \ p0)\)\)\/\(g[p1]\  - \ g[p0]\); \ \
\[IndentingNewLine]k\  = \ 
            k + 1; \ \[IndentingNewLine]Print["\<p\>"\_k, "\< = \>", 
            PaddedForm[p2, {16, 16}], "\<,   g[\>", "\<p\>"\_k, "\<] = \>", 
            NumberForm[g[p2], 
              16]\ ];\ ]; \ \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p2, 
            16]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", Abs[p2 - p1]\ ]; \ \[IndentingNewLine]Print["\<g[p] = \>", 
          NumberForm[g[p2], 16]\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["Find the minimum of the unimodal function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\)\  = \ x\^2 - sin \((x)\)\)],
    AspectRatioFixed->True],
  StyleBox["  on the interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = x\^2 - Sin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(g[x_] = \(f'\)[x];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 1}, PlotRange \[Rule] {{0, 1}, {\(-0.25\), 0.2}}, 
        Ticks \[Rule] {Range[0, 1, 0.2], Range[\(-0.4\), 0.2, 0.1]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<   y = f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = f'[x] = \>", g[x]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Solution by solving",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(f' \((x)\) = 0\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tA root-finding method can be used to determine where the \
derivative  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((x)\)\  = \ 2\ x - cos \((x)\)\)]],
  StyleBox["  is zero. \n\nSince  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((0)\)\  = \ \(-1\)\)]],
  StyleBox["  and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((1)\)\  = \ 1.4596977\)]],
  "  have opposite signs,",
  StyleBox[" by the intermediate value theorem a root of ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((x)\)\)]],
  StyleBox[" lies in the interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  StyleBox[".  The results obtained by using the secant method with the \
initial values  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0 = 0\)]],
  "  ",
  StyleBox["and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_1 = 1\)]],
  "  are given by the following computations.  "
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[g[x], {x, 0, 1}, PlotRange \[Rule] {{0, 1}, {\(-1.0\), 1.5}}, 
        Ticks \[Rule] {Range[0, 1, 0.2], Range[\(-1.0\), 1.5, 0.5]}, 
        PlotStyle \[Rule] Blue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<g[x] = f'[x] = \>", 
        g[x], "\<\n\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(SecantMethod[0, 1, 7];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["\tThe conclusion from applying the ",
    FontFamily->"Times-Roman"],
  ButtonBox["secant method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SecantMethod.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" is that  \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((0.45018361129475976)\)\  = \ \
\(-2.7711166694643907\)*10\^\(-13\)\  \[TildeTilde] \ 0\)]],
  " ",
  StyleBox["\n\nThe second derivative is  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f'' \((x)\)\  = \ 2 + sin \((x)\)\)]],
  "  ",
  StyleBox["and we compute  \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f'' \((0.45018361129475976)\)\  = \ 2.435130859036607\  > \ 0\)]],
  "  ",
  StyleBox["\n\nHence, by the ",
    FontFamily->"Times-Roman"],
  ButtonBox["second derivative test",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SecondDerivativeTest.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[", the ",
    FontFamily->"Times-Roman"],
  " ",
  ButtonBox["local minimum",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LocalMinimum.html"], None},
    ButtonStyle->"Hyperlink"],
  " ",
  StyleBox[" of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\)\)],
    AspectRatioFixed->True],
  StyleBox["  on the ",
    FontFamily->"Times-Roman"],
  "interval ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  " ",
  StyleBox["is  \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((0.45018361129475976)\)\  = \ \(-0.23246557515821564\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Solution using the golden ratio search for the minimum of",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontFamily->"Times-Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(f \((x)\)\)],
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\nLet  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(a\_0 = 0\)]],
  "  ",
  StyleBox["and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(b\_0 = 1\)]],
  ", and start with the initial interval  ",
  Cell[BoxData[
      \(\([a\_0, b\_0]\) = \([0, 1]\)\)]],
  StyleBox[".   Formulas (1) and (2) yield",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(a\_0 = 0.0;\)\ \), "\n", 
    \(\(b\_0 = 1.0;\)\), "\n", 
    \(\(r\  = \ 1\/2\ \((\(-1\) + \@5)\);\)\ \), "\[IndentingNewLine]", 
    \(\(c\_0\  = \ 
        a\_0\  + \ \((1 - \(\(-1\) + \@5\)\/2\ )\) \((b\_0 - 
                a\_0)\);\)\ \), "\n", 
    \(\(d\_0\  = \ 
        b\_0\  - \ \((1 - \(\(-1\) + \@5\)\/2\ )\) \((b\_0 - 
                a\_0)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_0\) = \!\(a\_0\) + (1-\!\(\(\(-1\) + \@5\)\/2\) \
)(\!\(b\_0\)-\!\(a\_0\))\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_0\) = \>\"", a\_0, "\< + \>", "\<(\>", 
        1 - \(\(-1\) + \@5\)\/2\ , "\<)(\>", 
        b\_0 - a\_0, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_0\) = \>\"", a\_0, "\< + \>", "\<(\>", 
        N[1 - \(\(-1\) + \@5\)\/2\ ], "\<)(\>", 
        b\_0 - a\_0, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_0\) = \>\"", 
        c\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(d\_0\) = \!\(b\_0\) - (1-\!\(\(\(-1\) + \@5\)\/2\) \
)(\!\(b\_0\)-\!\(a\_0\))\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(d\_0\) = \>\"", b\_0, "\< - \>", "\<(\>", 
        1 - \(\(-1\) + \@5\)\/2\ , "\<)(\>", 
        b\_0 - a\_0, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(d\_0\) = \>\"", b\_0, "\< - \>", "\<(\>", 
        N[1 - \(\(-1\) + \@5\)\/2\ ], "\<)(\>", 
        b\_0 - a\_0, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(d\_0\) = \>\"", 
        d\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The function values are\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(c\_0\)] = \>\"", 
        f[c\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(d\_0\)] = \>\"", 
        f[d\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Is  f[\!\(c\_0\)] < f[\!\(d\_0\)] ?  \>\"", 
        f[c\_0]\  < \ f[d\_0]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Since  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[c\_0]\  < \ f[d\_0]\)]],
  StyleBox[", the new subinterval is",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\([a\_0, d\_0]\) = \([0.000000, 0.618034]\)\)]],
  StyleBox[".  \nTo continue the iteration we set ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(a\_1 = a\_0\)]],
  StyleBox[", ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(b\_1 = d\_0\)]],
  StyleBox[", ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(d\_1 = c\_0\)]],
  StyleBox[", and compute ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(c\_1 = a\_1\  + \ \((1 - r)\) \((b\_1 - a\_1)\)\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(a\_1 = a\_0;\)\ \), "\n", 
    \(\(b\_1 = d\_0;\)\), "\[IndentingNewLine]", 
    \(\(d\_1 = c\_0;\)\), "\[IndentingNewLine]", 
    \(\(c\_1 = 
        a\_1\  + \ \((1 - r)\) \((b\_1 - 
                a\_1)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(a\_1\) = \>\"", 
        a\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(b\_1\) = \>\"", 
        b\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(c\_1\) = \>\"", 
        c\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(d\_1\) = \>\"", 
        d\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\<The function values are\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(c\_1\)] = \>\"", 
        f[c\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[\!\(d\_1\)] = \>\"", f[d\_1]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Now compute and compare ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((c\_1)\)\)]],
  " ",
  StyleBox["and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((d\_1)\)\)]],
  " ",
  StyleBox["to determine the new subinterval and continue the iteration \
process.  The list of computations are obtained by using the ",
    FontFamily->"Times-Roman"],
  StyleBox["GoldenSearch",
    FontFamily->"Courier New"],
  StyleBox[" subroutine are:  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(GoldenSearch[0, 1, 25];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["At the twenty-fifth iteration the interval has been narrowed down \
to \n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([a\_25, b\_25]\)\  = \ \([0.450179, 0.450185]\)\)]],
  StyleBox[".   \n\n",
    FontFamily->"MTSYN"],
  StyleBox["This interval has width  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(\(\ \)\(b\_25 - a\_25 = \(0.000006 = 
          6.0\[Times]10\^\(-6\)\)\)\)\)]],
  StyleBox[".  \n\nHowever, the computed function values at the endpoints \
agree to ten decimal places  \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((a\_25)\)\  = \ \(-0.232465575132\)\)]],
  "  ",
  StyleBox["\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((b\_25)\)\  = \ \(-0.232465575156\)\)]],
  "  ",
  StyleBox["\n\nhence the algorithm is terminated. A difficulty in using \
search methods is that the function may be \"flat\" near the minimum, and \
this limits the accuracy that can be obtained.  The secant method was able to \
find the more accurate answer\n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_6\  = \ 0.4501836112947597\)]],
  "\n\tand\n\t\t",
  Cell[BoxData[
      \(f \((p\_6)\)\  = \ \(-0.23246557515821564\)\)]],
  StyleBox["\n",
    FontFamily->"Times-Roman"],
  StyleBox["\n",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["Although the golden ratio search is the",
    FontFamily->"Times-Roman"],
  StyleBox[" ",
    FontFamily->"RMTMI"],
  StyleBox["slower in this example, it has desirable feature that it can be \
applied in cases where ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  " ",
  StyleBox["is not differentiable.  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  "Let us compare these answers with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine ",
  StyleBox["FindMinimum",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sol = FindMinimum[f[x], {x, 0.5}];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print[sol];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\[RightDoubleBracket]\)\
\), 6]];\)\ \), "\n", 
    \(\(Print["\<f[p] = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), 
          12]];\)\ \)}], "Input"],

Cell["\<\
This is close to the values obtained with the golden ratio search.  If more \
decimal places are needed, we can print them out. \
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<  p  = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\[RightDoubleBracket]\)\
\), 12]];\)\ \), "\n", 
    \(\(Print["\<f[p] = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), 
          17]];\)\ \)}], "Input"],

Cell[TextData[{
  "However, they are not as accurate as those computed with the secant method \
applied to solving  ",
  Cell[BoxData[
      \(\(f'\)[x] = 0\)]],
  ". "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "The following changes can be made in the golden ratio search subroutine so \
that it can try to determine the minimum with desired accuracy ",
  Cell[BoxData[
      \(\[Delta], \[Epsilon]\)]],
  " for the abscissa and ordinate, respectively.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(Golden Ratio Search for a Minimum",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[")",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[".",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk"],
  "To numerically approximate the minimum of  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  by using a golden ratio search.  Proceed with the method only if  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is a unimodal function on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".  Terminate the iteration when we have achieved either  ",
  Cell[BoxData[
      \(\(\(|\)\(b - a\)\(|\)\(\(\[LessEqual]\)\(\[Delta]\)\)\)\)]],
  "  or  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((b)\) - 
          f \((a)\)\)\(|\)\(\(\[LessEqual]\)\(\[Epsilon]\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[StyleBox["Mathematica Subroutine (Golden Ratio Search for a \
Minimum).",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[BoxData[
    \(\(\(GoldenSearch[a0_, 
          b0_, \[Delta]_, \[Epsilon]_] := \[IndentingNewLine]Module[{a\  = \ 
              N[a0], b\  = \ N[b0], c, d, h, k, r, Ya, Yb, Yc, 
            Yd}, \ \[IndentingNewLine]r\_1\  = \ \(\@5 - 1\)\/2\ ; \ \
\[IndentingNewLine]r\_2\  = \ \((r\_1)\)\^2; \ \[IndentingNewLine]h\  = \ 
            b\  - \ a; \ \[IndentingNewLine]Ya\  = \ 
            f[a]; \[IndentingNewLine]Yb\  = \ 
            f[b]; \[IndentingNewLine]c\  = \ 
            a\  + \ r\_2\ h; \ \[IndentingNewLine]d\  = \ 
            a\  + \ r\_1\ h; \ \[IndentingNewLine]Yc\  = \ 
            f[c]; \[IndentingNewLine]Yd\  = \ 
            f[d]; \[IndentingNewLine]Print["\<f[\>", 
            PaddedForm[{a, c, d, b}, {7, 6}], "\<] = \>", 
            PaddedForm[{Ya, Yc, Yd, Yb}, {10, 
                9}]\ ]; \[IndentingNewLine]While[\ 
            Or[\ Abs[Yb - Ya] > \[Epsilon]\ , \ 
              h > \[Delta]\ ], \[IndentingNewLine]If[\ 
              Yc < Yd, \[IndentingNewLine]Module[{}, \[IndentingNewLine]b\  = \
\ d; \ \[IndentingNewLine]Yb\  = \ Yd; \ \[IndentingNewLine]d\  = \ 
                  c; \ \[IndentingNewLine]Yd\  = \ 
                  Yc; \ \[IndentingNewLine]h\  = \ 
                  b\  - \ a; \ \[IndentingNewLine]c\  = \ 
                  a\  + \ r\_2\ h; \ \[IndentingNewLine]Yc\  = \ 
                  f[c];\ ], \[IndentingNewLine]\(Module[{}, \
\[IndentingNewLine]a\  = \ c; \ \[IndentingNewLine]Ya\  = \ 
                    Yc; \ \[IndentingNewLine]c\  = \ 
                    d; \ \[IndentingNewLine]Yc\  = \ 
                    Yd; \ \[IndentingNewLine]h\  = \ 
                    b\  - \ a; \ \[IndentingNewLine]d\  = \ 
                    a\  + \ r\_1\ \ h; \ \[IndentingNewLine]Yd\  = \ 
                    f[d];\ \ ];\)\ ]; \ \[IndentingNewLine]Print["\<f[\>", 
              PaddedForm[{a, c, d, b}, {7, 6}], "\<] = \>", 
              PaddedForm[{Ya, Yc, Yd, Yb}, {10, 
                  9}]\ ];\ ]; \ \[IndentingNewLine]p\  = \ 
            a; \ \[IndentingNewLine]Yp\  = \ Ya; \ \[IndentingNewLine]If[\ 
            Yb < Ya, \ p = b; \ 
            Yp = Yb\ ]; \ \[IndentingNewLine]Print["\<{  a,   b,   c,   d}  = \
\>", PaddedForm[{a, c, d, b}, {7, 
                6}]]; \ \[IndentingNewLine]Print["\<{f[a],f[b],f[c],f[d]} = \
\>", PaddedForm[{Ya, Yc, Yd, Yb}, {13, 
                12}]]; \ \[IndentingNewLine]Return[{Yp, 
              p}];\ ];\)\(\ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the local minimum of the function  ",
  Cell[BoxData[
      \(f \((x)\) = \[ExponentialE]\^x - sin \((2  x)\)\)]],
  "  over  ",
  Cell[BoxData[
      \(\([\(-1\), 1]\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = \[ExponentialE]\^x - 
          Sin[2  x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-1\), 1}, PlotRange \[Rule] {{\(-1\), 1}, {0, 1.8}}, 
        Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 2, 0.5]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the local minimum lies in the interval  ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\({Yp, p} = 
        GoldenSearch[0, 1, 10\^\(-6\), 
          10\^\(-6\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Print["\<The function is f[x] = \>", 
        f[x]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<A local minimum of f[x] is:\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", 
        NumberForm[p, 8]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[p] = \>", NumberForm[Yp, 12]];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Let us compare this answer with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine FindMinimum."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sol = FindMinimum[f[x], {x, 0.5}];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print[sol];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\[RightDoubleBracket]\)\
\), 8]];\)\ \), "\n", 
    \(\(Print["\<f[p] = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), 
          12]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the local maximum of the function  ",
  Cell[BoxData[
      \(f \((x)\) = \[ExponentialE]\^x - sin \((2  x)\)\)]],
  "  in the interval  ",
  Cell[BoxData[
      \(\([\(-3\), 1]\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = \[ExponentialE]\^x - 
          Sin[2  x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-3\), 1}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the local maximum lies in the interval  ",
  Cell[BoxData[
      \(\([\(-1\), 0]\)\)]],
  ".\n\nSo we will search for the local minimum of   ",
  Cell[BoxData[
      \(f[x] = \(-\[ExponentialE]\^x\) + Sin[2  x]\)]],
  "  in the interval  ",
  Cell[BoxData[
      \(\([\(-1\), 0]\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(-f[x]\);\)\), "\[IndentingNewLine]", 
    \(\({Yp, p} = 
        GoldenSearch[\(-1\), 0, 10\^\(-6\), 
          10\^\(-6\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[\ f[x], {x, \(-1\), 0}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The function is f[x] = \>", 
        f[x]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<A local minimum of f[x] is:\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", p];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[p] = \>", Yp];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Therefore, to find the local maximum of  ",
  Cell[BoxData[
      \(f[x] = \[ExponentialE]\^x - Sin[2  x]\)]],
  " we take the negative of the local minimum of  ",
  Cell[BoxData[
      \(f[x] = \(-\ \[ExponentialE]\^x\) + Sin[2  x]\)]],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[x_] = \[ExponentialE]\^x - 
          Sin[2  x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-3\), 1}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<A local maximum of f[x] is:\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", 
        NumberForm[p, 8]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[p] = \>", NumberForm[\(-Yp\), 12]];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Let us compare this answer with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine FindMinimum."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sol = FindMinimum[\(-f[x]\), {x, \(-0.5\)}];\)\ \), "\n", 
    \(\(Print["\<-f[x] = \>", \(-f[x]\)];\)\ \), "\n", 
    \(\(Print[sol];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", 
        sol\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Print["\<f[p] = \>", \(-sol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\)];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the maximum of the function  ",
  Cell[BoxData[
      \(f \((x)\) = 140 \( \[ExponentialE]\^\(\(-x\)/9\)\) sin \((x)\)\)]],
  "  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] x\)]],
  ".  Use the Golden Ratio Search.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = 
        140 \( \[ExponentialE]\^\(\(-x\)/9\)\) 
          Sin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 20}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the local maximum lies in the interval  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  " and this is the maximum for  ",
  Cell[BoxData[
      \(0 \[LessEqual] x\)]],
  ". \n\nSo we will search for the local minimum of  ",
  Cell[BoxData[
      \(f[x] = \(-140\) \(\[ExponentialE]\^\(\(-x\)/9\)\) Sin[x]\)]],
  "  in the interval  ",
  Cell[BoxData[
      \(\([0, 3]\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = \(-f[x]\);\)\), "\[IndentingNewLine]", 
    \(\(GoldenSearch[0, 3, 10\^\(-6\), 
        10\^\(-6\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[\ f[x], {x, 0, 3}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The function is f[x] = \>", 
        f[x]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<A local minimum of f[x] is:\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", p];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[p] = \>", Yp];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Therefore, to find the local maximum of",
  "  ",
  Cell[BoxData[
      \(f[x] = 140 \( \[ExponentialE]\^\(\(-x\)/9\)\) Sin[x]\)]],
  "  ",
  "we take the negative of the local minimum of  ",
  Cell[BoxData[
      \(f[x] = \(-140\) \(\[ExponentialE]\^\(\(-x\)/9\)\) Sin[x]\)]],
  "  .   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[x_] = 
        140 \( \[ExponentialE]\^\(\(-x\)/9\)\) 
          Sin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[\ f[x], {x, 0, 3}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The function is f[x] = \>", 
        f[x]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<A local maximum of f[x] is:\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", p];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[p] = \>", \(-Yp\)];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Let us compare this answer with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine ",
  StyleBox["FindMinimum",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sol = FindMinimum[\(-f[x]\), {x, 2.0}];\)\ \), "\n", 
    \(\(Print["\<-f[x] = \>", \(-f[x]\)];\)\ \), "\n", 
    \(\(Print[sol];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", 
        sol\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Print["\<f[p] = \>", \(-sol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\)];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The voltage input to an electrical component is  ",
  Cell[BoxData[
      \(f \((x)\) = 140 \( \[ExponentialE]\^\(\(-x\)/9\)\) sin \((x)\)\)]],
  "  for  ",
  Cell[BoxData[
      \(0 \[LessEqual] x\)]],
  ".  The manufacturer states that the voltage is not to exceed  ",
  Cell[BoxData[
      \(\(\[PlusMinus]120\)\)]],
  " or else the component will \"burn out.\"  Can we expect that the \
component will be o.k. or will it  \"burn out.\"  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "We must determine if  ",
  Cell[BoxData[
      \(\(\(|\)\(f[x]\)\(|\)\(\(<\)\(120\)\)\)\)]],
  "  ",
  " for  ",
  Cell[BoxData[
      \(0 \[LessEqual] x\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(f[x_] = 
        140 \( \[ExponentialE]\^\(\(-x\)/9\)\) 
          Sin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 20}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<y = f[x] = \>", f[x]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the local minimum that lies in the interval  ",
  Cell[BoxData[
      \(\([3, 6]\)\)]],
  " and this is the minimum for  ",
  Cell[BoxData[
      \(0 \[LessEqual] x\)]],
  ". \n\nSo we will search for the local minimum of  ",
  Cell[BoxData[
      \(f[x]\)]],
  " in the interval  ",
  Cell[BoxData[
      \(\([3, 6]\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(GoldenSearch[3, 6, 10\^\(-6\), 
        10\^\(-6\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Plot[f[x], {x, 0, 20}, PlotRange \[Rule] All, 
        PlotStyle \[Rule] Magenta];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The function is f[x] = \>", 
        f[x]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<A local minimum of f[x] is:\>"];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", p];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[p] = \>", Yp];\)\ \ \)}], "Input"],

Cell[TextData[{
  "Combining this with the result from Exercises 4 we obtain \n\n\t",
  Cell[BoxData[
      \(\(-83.4463\)\  \[LessEqual] \ f \((t)\)\  \[LessEqual] \ 
        118.3054\)]],
  "     for  ",
  Cell[BoxData[
      \(0 \[LessEqual] t\)]],
  ". \n\nTherefore, the component will be o.k. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Various Scenarios",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" and Animations for the Secant Method.",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(GoldenSearch[a0_, b0_, 
          max_] := \[IndentingNewLine]Module[{a\  = \ N[a0], b\  = \ N[b0], 
            c, d, h, k, r, Ya, Yb, Yc, 
            Yd}, \[IndentingNewLine]r\_1\  = \ \(\@5 - 1\)\/2\ ; \ \
\[IndentingNewLine]r\_2\  = \ \((r\_1)\)\^2; \ \[IndentingNewLine]h\  = \ 
            b\  - \ a; \ \[IndentingNewLine]Ya\  = \ 
            f[a]; \[IndentingNewLine]Yb\  = \ 
            f[b]; \[IndentingNewLine]c\  = \ 
            a\  + \ r\_2\ h; \ \[IndentingNewLine]d\  = \ 
            a\  + \ r\_1\ h; \ \[IndentingNewLine]Yc\  = \ 
            f[c]; \[IndentingNewLine]Yd\  = \ 
            f[d]; \[IndentingNewLine]pointsab = {{Red, PointSize[0.02], 
                Point[{a, f[a]}], Point[{b, f[b]}]}, {Blue, PointSize[0.02], 
                Point[{c, f[c]}], 
                Point[{d, f[d]}]}}; \ \ \[IndentingNewLine]dotsab = 
            Graphics[pointsab]; \ \ \[IndentingNewLine]gr0 = 
            Plot[f[x], {x, a0, b0}, 
              PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.75}}, 
              PlotStyle \[Rule] Magenta, 
              DisplayFunction \[Rule] Identity]; \ \[IndentingNewLine]gr1 = 
            FilledPlot[f[x], {x, a + 0.006, b}, 
              PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
              PlotStyle \[Rule] Red, Fills \[Rule] {RGBColor[1, 0.8, 0.85]}, 
              Curves \[Rule] Front, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[gr0, 
            gr1, dotsab, 
            PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
            Ticks \[Rule] {Range[0, 2, 0.1], Range[0, 2, 0.1]}, 
            DisplayFunction \[Rule] $DisplayFunction]; \ \[IndentingNewLine]k \
= 1; \ \[IndentingNewLine]Print["\<{  a,   b,   c,   d}  = \>", 
            PaddedForm[{a, c, d, b}, {7, 
                6}]]; \ \[IndentingNewLine]Print["\<{f[a],f[b],f[c],f[d]} = \
\>", PaddedForm[{Ya, Yc, Yd, Yb}, {13, 12}]]; \ \[IndentingNewLine]While[\ 
            k < max, \[IndentingNewLine]If[\ 
              Yc < Yd, \[IndentingNewLine]Module[{}, \[IndentingNewLine]b\  = \
\ d; \ \[IndentingNewLine]Yb\  = \ Yd; \ \[IndentingNewLine]d\  = \ 
                  c; \ \[IndentingNewLine]Yd\  = \ 
                  Yc; \ \[IndentingNewLine]h\  = \ 
                  b\  - \ a; \ \[IndentingNewLine]c\  = \ 
                  a\  + \ r\_2\ h; \ \[IndentingNewLine]Yc\  = \ 
                  f[c];\ ], \[IndentingNewLine]\(Module[{}, \
\[IndentingNewLine]a\  = \ c; \ \[IndentingNewLine]Ya\  = \ 
                    Yc; \ \[IndentingNewLine]c\  = \ 
                    d; \ \[IndentingNewLine]Yc\  = \ 
                    Yd; \ \[IndentingNewLine]h\  = \ 
                    b\  - \ a; \ \[IndentingNewLine]d\  = \ 
                    a\  + \ r\_1\ \ h; \ \[IndentingNewLine]Yd\  = \ 
                    f[d];\ \ ];\)\ ]; \ \[IndentingNewLine]pointsab = {{Red, 
                  PointSize[0.02], Point[{a, f[a]}], 
                  Point[{b, f[b]}]}, {Blue, PointSize[0.02], 
                  Point[{c, f[c]}], 
                  Point[{d, f[d]}]}}; \ \ \[IndentingNewLine]dotsab = 
              Graphics[pointsab]; \ \ \[IndentingNewLine]gr0 = 
              Plot[f[x], {x, a0, b0}, 
                PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.75}}, 
                PlotStyle \[Rule] Magenta, 
                DisplayFunction \[Rule] Identity]; \ \[IndentingNewLine]gr1 = 
              FilledPlot[f[x], {x, a, b}, 
                PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
                PlotStyle \[Rule] Red, 
                Fills \[Rule] {RGBColor[1, 0.8, 0.85]}, Curves \[Rule] Front, 
                DisplayFunction \[Rule] Identity]; \[IndentingNewLine]If[
              b - a > 0.1, \[IndentingNewLine]Show[gr0, gr1, dotsab, 
                PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
                Ticks \[Rule] {Range[0, 2, 0.1], Range[0, 2, 0.1]}, 
                DisplayFunction \[Rule] $DisplayFunction], \
\[IndentingNewLine]\(Show[gr0, gr1, dotsab, 
                  PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
                  Ticks \[Rule] {Range[0, 2, 0.1], Range[0, 2, 0.1]}, 
                  DisplayFunction \[Rule] $DisplayFunction];\)]; \ \
\[IndentingNewLine]k = 
              k + 1; \ \[IndentingNewLine]Print["\<{  a,   b,   c,   d}  = \
\>", PaddedForm[{a, c, d, b}, {7, 
                  6}]]; \ \[IndentingNewLine]Print["\<{f[a],f[b],f[c],f[d]} = \
\>", PaddedForm[{Ya, Yc, Yd, Yb}, {13, 
                  12}]];\ \ ]; \ \[IndentingNewLine]p\  = \ 
            a; \ \[IndentingNewLine]Yp\  = \ Ya; \ \[IndentingNewLine]If[\ 
            Yb < Ya, \ p = b; \ 
            Yp = Yb\ ]; \ \[IndentingNewLine]Return[{Yp, 
              p}];\ ];\)\ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  "Find the minimum of  ",
  Cell[BoxData[
      \(f[x] = 1\/2 + x\^5 - \(4\/5\) x\)],
    AspectRatioFixed->True],
  StyleBox["  on the interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = 1\/2 + x\^5 - \(4\/5\) x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a0 = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(GoldenSearch[a0, b0, 10];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/a2001/Animations/Optimization/\
GoldenRatio1/GoldenRatioaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    Background->None],
  "  ",
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Optimization/\
GoldenRatio1/GoldenRatioaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" (",
    FontWeight->"Bold"],
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/a2001/Animations/Optimization/\
GoldenRatio1/GoldenRatio.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Optimization/\
GoldenRatio1/GoldenRatio.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations. "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/GoldenRatioSearchBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Golden Ratio Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/GoldenRatioSearchBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{969, 636},
WindowMargins->{{Automatic, 20}, {Automatic, 1}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 190, 4, 35, "Text"],
Cell[1969, 59, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3448, 111, 1332, 41, 106, "Text"],
Cell[4783, 154, 1027, 44, 109, "Text"],
Cell[5813, 200, 1598, 66, 109, "Text"],
Cell[7414, 268, 48476, 1327, 349, "Text"],
Cell[55893, 1597, 1568, 59, 169, "Text"],
Cell[57464, 1658, 2231, 69, 185, "Text"],
Cell[59698, 1729, 1621, 54, 398, "Text"],
Cell[61322, 1785, 644, 23, 33, "Text"],
Cell[61969, 1810, 1074, 34, 52, "Text"],
Cell[63046, 1846, 631, 22, 33, "Text"],
Cell[63680, 1870, 165, 3, 33, "Text"],
Cell[63848, 1875, 2572, 45, 833, "Input"],
Cell[66423, 1922, 166, 2, 33, "Text"],
Cell[66592, 1926, 1702, 51, 76, "Text"],
Cell[68297, 1979, 600, 20, 33, "Text"],
Cell[68900, 2001, 143, 2, 33, "Text"],
Cell[69046, 2005, 1422, 24, 390, "Input"],
Cell[70471, 2031, 526, 19, 33, "Text"],

Cell[CellGroupData[{
Cell[71022, 2054, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[71175, 2060, 567, 9, 150, "Input"],
Cell[71745, 2071, 1360, 46, 128, "Text"],
Cell[73108, 2119, 449, 7, 90, "Input"],
Cell[73560, 2128, 1602, 53, 223, "Text"],
Cell[75165, 2183, 764, 27, 71, "Text"],
Cell[75932, 2212, 2027, 38, 566, "Input"],
Cell[77962, 2252, 777, 28, 52, "Text"],
Cell[78742, 2282, 870, 19, 230, "Input"],
Cell[79615, 2303, 540, 18, 52, "Text"],
Cell[80158, 2323, 131, 2, 50, "Input"],
Cell[80292, 2327, 1764, 51, 375, "Text"],
Cell[82059, 2380, 251, 10, 33, "Text",
  Evaluatable->False],
Cell[82313, 2392, 536, 12, 130, "Input"],
Cell[82852, 2406, 152, 3, 33, "Text"],
Cell[83007, 2411, 327, 8, 50, "Input"],
Cell[83337, 2421, 180, 6, 33, "Text"]
}, Closed]],
Cell[83532, 2430, 275, 6, 49, "Text"],
Cell[83810, 2438, 1228, 38, 52, "Text"],
Cell[85041, 2478, 165, 3, 33, "Text"],
Cell[85209, 2483, 2472, 43, 773, "Input"],
Cell[87684, 2528, 350, 13, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[88059, 2545, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[88212, 2551, 457, 8, 90, "Input"],
Cell[88672, 2561, 131, 5, 33, "Text"],
Cell[88806, 2568, 181, 4, 51, "Input"],
Cell[88990, 2574, 353, 7, 90, "Input"],
Cell[89346, 2583, 196, 7, 33, "Text",
  Evaluatable->False],
Cell[89545, 2592, 536, 12, 130, "Input"]
}, Closed]],
Cell[90096, 2607, 361, 13, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[90482, 2624, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[90635, 2630, 371, 7, 90, "Input"],
Cell[91009, 2639, 334, 11, 71, "Text"],
Cell[91346, 2652, 242, 5, 71, "Input"],
Cell[91591, 2659, 441, 8, 110, "Input"],
Cell[92035, 2669, 325, 10, 33, "Text",
  Evaluatable->False],
Cell[92363, 2681, 608, 11, 150, "Input"],
Cell[92974, 2694, 196, 7, 33, "Text",
  Evaluatable->False],
Cell[93173, 2703, 553, 10, 150, "Input"]
}, Closed]],
Cell[93741, 2716, 391, 13, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[94157, 2733, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[94310, 2739, 391, 8, 90, "Input"],
Cell[94704, 2749, 420, 14, 71, "Text"],
Cell[95127, 2765, 216, 4, 71, "Input"],
Cell[95346, 2771, 436, 8, 110, "Input"],
Cell[95785, 2781, 367, 12, 33, "Text",
  Evaluatable->False],
Cell[96155, 2795, 557, 11, 130, "Input"],
Cell[96715, 2808, 249, 10, 33, "Text",
  Evaluatable->False],
Cell[96967, 2820, 548, 10, 150, "Input"]
}, Closed]],
Cell[97530, 2833, 608, 17, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[98163, 2854, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[98316, 2860, 196, 9, 33, "Text"],
Cell[98515, 2871, 391, 8, 90, "Input"],
Cell[98909, 2881, 372, 14, 71, "Text"],
Cell[99284, 2897, 160, 3, 51, "Input"],
Cell[99447, 2902, 435, 8, 110, "Input"],
Cell[99885, 2912, 312, 9, 109, "Text"]
}, Closed]],
Cell[100212, 2924, 303, 10, 32, "Text"],
Cell[100518, 2936, 4955, 83, 1273, "Input"],
Cell[105476, 3021, 460, 18, 36, "Text"],

Cell[CellGroupData[{
Cell[105961, 3043, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[106114, 3049, 306, 5, 123, "Input"],
Cell[106423, 3056, 814, 27, 33, "Text"]
}, Closed]],
Cell[107252, 3086, 826, 26, 30, "Text"],
Cell[108081, 3114, 158, 3, 35, "Text"],
Cell[108242, 3119, 581, 18, 33, "Text"],
Cell[108826, 3139, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

