(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     86852,       2417]*)
(*NotebookOutlinePosition[     87580,       2442]*)
(*  CellTagsIndexPosition[     87536,       2438]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Module for the Quadratic and Cubic Search for a \
Minimum",
  FontFamily->"New Century Schlbk",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Background for Search Methods",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\t",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  StyleBox["An approach for finding the minimum of",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["in a given interval is to evaluate the function many times and \
search for a local minimum.  To reduce the number of function evaluations it \
is important to have a good strategy for determining where",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is to be evaluated.  Two efficient bracketing methods are the ",
    FontFamily->"Times-Roman"],
  StyleBox["golden ratio",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" and ",
    FontFamily->"Times-Roman"],
  StyleBox["Fibonacci",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" searches.  To use either bracketing method for finding the \
minimum of",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  StyleBox[",  a special condition must be met to ensure that there is a \
proper minimum in the given interval.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition (Unimodal Function)",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  The function",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is unimodal on",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(I = \([a, b]\)\)]],
  StyleBox[",  if there exists a unique number ",
    FontFamily->"Times-Roman"],
  " ",
  Cell[BoxData[
      \(p \[Element] I\)]],
  "  ",
  StyleBox["such that  \n\t\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is decreasing on",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\([a, p]\)\)]],
  StyleBox[",  \n\tand\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is increasing on",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\([p, b]\)\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Minimization Using Derivatives",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tSuppose that",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is unimodal over",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  ",
  StyleBox["and has a unique minimum at",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(x = p\)]],
  StyleBox[".  Also,  assume that",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f' \((x)\)\)]],
  "  ",
  StyleBox["is defined at all points in",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\((a, b)\)\)]],
  StyleBox[".   Let the starting value  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0\)]],
  StyleBox["  lie in",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\((a, b)\)\)]],
  StyleBox[".   If ",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f' \((p\_0)\) < 0\)]],
  "  ",
  StyleBox[",  then the minimum point  ",
    FontFamily->"Times-Roman"],
  StyleBox["p",
    FontFamily->"Courier New"],
  StyleBox["  lies to the right of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0\)]],
  StyleBox[".  If ",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f' \((p\_0)\) > 0\)]],
  "  ",
  StyleBox[",  then the minimum point  ",
    FontFamily->"Times-Roman"],
  StyleBox["p",
    FontFamily->"Courier New"],
  StyleBox["  lies to the left of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Background for Bracketing the Minimum",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tOur first task is to obtain three test values,  \n\t\n(1)\t\
\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(p\_0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(p\_1 = p\_0 + h\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            StyleBox["  ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], \(p\_2\)}], 
          "=", \(p\_0 + 2  h\)}]}]]],
  ", ",
  StyleBox["\n\tso that\n(2)\t\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(f \((p\_0)\) > f \((p\_1)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            StyleBox["   ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "f", \((p\_1)\)}], 
          "<", \(f \((p\_2)\)\)}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Suppose that  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((p\_0)\) < 0\)]],
  StyleBox[";  then  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0 < p\)]],
  "  ",
  StyleBox["and the step size  ",
    FontFamily->"Times-Roman"],
  StyleBox["h",
    FontFamily->"Courier New"],
  StyleBox["  should be chosen positive.  It is an easy task to find a value \
of  ",
    FontFamily->"Times-Roman"],
  StyleBox["h",
    FontFamily->"Courier New"],
  StyleBox["  so that the three points in (1) satisfy (2).  Start with  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h = 1\)]],
  StyleBox["  in formula (1) (provided that  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(a + 1 < b\)]],
  StyleBox[");  if not, take  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h = 1\/2\)]],
  StyleBox[",  and so on.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Case (i)",
    FontFamily->"Times-Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \tIf (2) is satisfied we are done.  \n\n",
    FontFamily->"Times-Roman"],
  StyleBox["Case (ii)",
    FontFamily->"Times-Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \tIf  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(f \((p\_0)\) > f \((p\_1)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman"], 
            StyleBox["   ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "f", \((p\_1)\)}], 
          ">", \(f \((p\_2)\)\)}]}]]],
  StyleBox[", then  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_2 < p\)]],
  StyleBox[".  \n\t\tWe need to check points that lie farther to the right.  \
Double the step size and repeat the process.  \n\n",
    FontFamily->"Times-Roman"],
  StyleBox["Case (iii)",
    FontFamily->"Times-Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \tIf  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((p\_0)\) < f \((p\_1)\)\)]],
  StyleBox[", we have jumped over  ",
    FontFamily->"Times-Roman"],
  StyleBox["p",
    FontFamily->"Courier New"],
  StyleBox["  and  ",
    FontFamily->"Times-Roman"],
  StyleBox["h",
    FontFamily->"Courier New"],
  StyleBox["  is too large.  \n\t\tWe need to check values closer to  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0\)]],
  StyleBox[".  Reduce the step size by a factor of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(1\/2\)]],
  "  ",
  StyleBox["and repeat the process.  \n\nWhen  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((p\_0)\) > 0\)]],
  StyleBox[",  the step size  ",
    FontFamily->"Times-Roman"],
  StyleBox["h",
    FontFamily->"Courier New"],
  StyleBox["  should be chosen negative and then cases similar to (i), (ii), \
and (iii) can be used.  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Quadratic Approximation to Find  p",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\nFinally, we have three points (1) that satisfy (2).  We will \
use quadratic interpolation to find  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_min\)]],
  StyleBox[",  which is an approximation to  ",
    FontFamily->"Times-Roman"],
  StyleBox["p",
    FontFamily->"Courier New"],
  StyleBox[".  The Lagrange polynomial based on the nodes in (1) is\n\n(3)\t\t\
",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(Q \((x)\)\ \  = \ \ \(y\_0\) \(\((x - p\_1)\) \((x - p\_2)\)\)\/\(2  \
h\^2\)\ \  - \ \ \(y\_1\) \(\((x - p\_0)\) \((x - p\_2)\)\)\/h\^2\ \  + \ \ \
\(y\_2\) \(\((x - p\_0)\) \((x - p\_1)\)\)\/\(2  h\^2\)\)]],
  ",  ",
  StyleBox["\n",
    FontFamily->"Times-Roman"],
  StyleBox["\n",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["where  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(y\_i\), " ", "=", " ", 
          RowBox[{
            RowBox[{"f", \((p\_i)\), 
              StyleBox["   ",
                FontFamily->"Times New Roman"], 
              StyleBox["for",
                FontFamily->"Times New Roman"], 
              StyleBox["    ",
                FontFamily->"Times New Roman"], "i"}], "=", "1"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman"], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman"], "3"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["The derivative of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(Q \((x)\)\)]],
  StyleBox["  is  \n\n(4)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(Q' \((x)\)\ \  = \ \ \(y\_0\) \((2  x - p\_1 - p\_2)\)\/\(2  h\^2\)\ \
\  - \ \ \(y\_1\) \((2  x - p\_0 - p\_2)\)\/h\^2\ \  + \ \ \(y\_2\) \((2  x - \
p\_0 - p\_1)\)\/\(2  h\^2\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Solving  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(Q' \((x)\) = 0\)]],
  StyleBox["  in the form  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(Q \((p\_0 + h\_min)\) = 0\)]],
  StyleBox["  yields  \n\n(5)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(0\ \  = \ \ \(y\_0\) \((2 \((p\_0 + h\_min)\) - p\_1 - p\_2)\)\/\(2  \
h\^2\)\ \  - \ \ \(y\_1\) \((4 \((p\_0 + h\_min)\) - 2  p\_0 - 2  \
p\_2)\)\/\(2  h\^2\)\ \  + \ \ \(y\_2\) \((2 \((p\_0 + h\_min)\) - p\_0 - \
p\_1)\)\/\(2  h\^2\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Multiply each term in (5) by  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(2  h\^2\)]],
  "  ",
  StyleBox["and collect terms involving   ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\_min\)]],
  StyleBox[": \n\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(0\ \  = \ \ \(h\_min\) \((2  y\_0 - 4\ y\_1 + 
                2\ y\_2)\) + \(y\_0\) \((2\ p\_0 - p\_1 - 
                p\_2)\) - \(y\_1\) \((4\ p\_0 - 2\ p\_0 - 
                2\ p\_2)\) + \(y\_2\) \((2  p\_0 - p\_0 - p\_1)\)\)]],
  "  \n",
  StyleBox["\n\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(0\ \  = \ \ \(h\_min\) \((2\ \ y\_0 - 4\ \ y\_1 + 
                2\ \ y\_2)\)\  + \ \(y\_0\) \((2\ p\_0 - p\_1 - 
                p\_2)\)\  - \ \(y\_1\) \((2\ p\_0 - 
                2\ p\_2)\)\  + \ \(y\_2\) \((p\_0 - p\_1)\)\)]],
  "  \n\n\t",
  Cell[BoxData[
      \(0\ \  = \ \ \(h\_min\) \((2\ \ y\_0 - 4\ \ y\_1 + 2\ \ y\_2)\)\  - \ 
          3\ h\ y\_0\  + \ 4\ h\ y\_1\  - \ h\ y\_2\)]],
  "  \n\n\t",
  Cell[BoxData[
      \(0\ \  = \ \(-\ h\_min\) 2 \((2\ \ y\_1 - y\_0 - y\_2)\) + 
          h \((4\ y\_1 - 3\ y\_0 - y\_2)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["This last quantity is easily solved for  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\_min\)]],
  StyleBox[": \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\_min\ \  = \ \ \(h \((4\ y\_1 - 3\ y\_0 - y\_2)\)\)\/\(2 \((2\ y\_1 \
- \ y\_0 - y\_2)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/QuadraticSearchProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/QuadraticSearchProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["The value  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_min\  = \ p\_0\  + \ h\_min\)]],
  StyleBox["  is a better approximation to  ",
    FontFamily->"Times-Roman"],
  StyleBox["p",
    FontFamily->"Courier New"],
  StyleBox["  than  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0\)]],
  StyleBox[".  Hence we can replace  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0\)]],
  StyleBox["  with  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_min\)]],
  StyleBox["  and repeat the two processes outlined above to determine a new  \
",
    FontFamily->"Times-Roman"],
  StyleBox["h",
    FontFamily->"Courier New"],
  StyleBox["  and a new  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\_min\)]],
  StyleBox[".   Continue the iteration until the desired accuracy is \
achieved.  In this algorithm the derivative of the objective function",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["was used implicitly in (4) to locate the minimum of the \
interpolatory quadratic.  The reader should note that the subroutine makes no \
explicit use of the derivative.  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Cubic Approximation to Find  p",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n\n\tWe now consider an approach that utilizes functional \
evaluations of both",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["and",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f' \((x)\)\)]],
  StyleBox[".  An alternative approach that uses both functional and \
derivative evaluations explicitly is to find the minimum of a third-degree \
polynomial that interpolates the objective function",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["at two points.  Assume that",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  ",
  StyleBox["is unimodal and differentiable on",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  StyleBox[",  and has a unique minimum at",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(x = p\)]],
  StyleBox[".  Let  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0 = a\)]],
  StyleBox[".  Any good step size  ",
    FontFamily->"Times-Roman"],
  StyleBox["h",
    FontFamily->"Courier New"],
  StyleBox["  can be used to start the iteration.  The ",
    FontFamily->"Times-Roman"],
  ButtonBox["Mean Value Theorem",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Mean-ValueTheorem.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" could be used to obtain  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((c)\) = \(f \((a + h)\) - f \((a)\)\)\/h\)]],
  "  and if  ",
  Cell[BoxData[
      \(a + h\)]],
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  "was just to the right of the minimum, then the slope",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((a)\)\)]],
  " might be twice",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((c)\)\)]],
  " which would mean that ",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(1\/2\) f' \((a)\) = \(f \((a + h)\) - f \((a)\)\)\/h\)]],
  "  we do not know how much further to the right",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(c = a + h\)]],
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  "lies, so we can imagine that",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((a + h)\)\)]],
  " is close to",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f \((b)\)\)]],
  " and estimate",
  StyleBox[" ",
    FontFamily->"Times-Roman"],
  StyleBox["h",
    FontFamily->"Courier New"],
  StyleBox[" with the formula:    \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\  = \ \(2 \((f[b] - f[a])\)\)\/\(f'\)[a]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Thus  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(p\_1\), "=", 
        StyleBox[" ",
          FontFamily->"Times-Roman"], \(p\_0 + h\)}]]],
  StyleBox[".  The cubic approximating polynomial  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(P[x]\)]],
  " ",
  StyleBox["is expanded in a Taylor series about  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(x = p\_2\)]],
  " (which is ",
  StyleBox["the abscissa of the minimum).  At the minimum we have  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(P'\)[p\_2] = 0\)]],
  ", and we write",
  StyleBox["  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(P[x]\)]],
  " in the form:    ",
  StyleBox["\n\n(6)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(\(\ \ \)\(P[
          x]\ \  = \ \ \(\[Alpha]\/h\^3\) \((x - p\_2)\)\^3\ \  + \ \ \(\
\[Beta]\/h\^2\) \((x - p\_2)\)\^2\ \  + \ \ f[p\_2]\)\)\)]],
  ",  \n\tand\n(7)\t\t",
  Cell[BoxData[
      \(\(P'\)[
          x]\ \  = \ \ \(\(\(3\)\(\ \)\(\[Alpha]\)\(\ \)\)\/h\^3\) \((x - \
p\_2)\)\^2\  + \ \ \(\(\(2\)\(\ \)\(\[Beta]\)\(\ \)\)\/h\^2\) \((x - 
                p\_2)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["The introduction of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"h", "=", 
        RowBox[{\(p\_1\), "-", 
          StyleBox[" ",
            FontFamily->"Times-Roman"], \(p\_0\)}]}]]],
  "  ",
  StyleBox["in the denominators of (6) and (7) will make further calculations \
less tiresome.  It is required that  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(P[p\_0]\  = \ f[p\_0]\)]],
  ",  ",
  Cell[BoxData[
      \(P[p\_1]\  = \ f[p\_1]\)]],
  ",  ",
  Cell[BoxData[
      \(\(P'\)[p\_0]\  = \ \(f'\)[p\_0]\)]],
  ",  and  ",
  Cell[BoxData[
      \(\(P'\)[p\_1]\  = \ \(f'\)[p\_1]\)]],
  StyleBox[".  ",
    FontFamily->"RMTMI",
    FontSlant->"Italic"],
  StyleBox["To find  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_2\)]],
  " ",
  StyleBox["we define:  \n\n(8)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(p\_2\), "=", 
        StyleBox[" ",
          FontFamily->"Times-Roman"], \(p\_0 + \[Gamma]\ h\)}]]],
  ",   \n\nand we must go through several intermediate calculations before we \
end up with ",
  Cell[BoxData[
      \(\[Gamma]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Use use (6) to obtain    \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[p\_1] - 
          f[p\_0]\ \  = \ \ \(\[Alpha]\ \((p\_1 - p\_2)\)\^3 - \[Alpha]\ \((p\
\_0 - p\_2)\)\^3\)\/h\^3 + \(\[Beta]\ \((p\_1 - p\_2)\)\^2 - \[Beta]\ \((p\_0 \
- p\_2)\)\^2\)\/h\^2\)]],
  "  \n\t\t\n",
  StyleBox["Then use (8) to get  ",
    FontFamily->"Times-Roman"],
  "\n\n\t\t",
  Cell[BoxData[
      \(f[p\_1] - 
          f[p\_0]\ \  = \ \ \[Alpha]\ \[Gamma]\^3 + \(\[Alpha]\ \((\(-h\)\ \
\[Gamma] - p\_0 + p\_1)\)\^3\)\/h\^3 + \(\[Beta]\ \((\(-h\)\ \[Gamma] - p\_0 \
+ p\_1)\)\^2\)\/h\^2 - \[Beta]\ \[Gamma]\^2\)]],
  "  \n\n",
  StyleBox["Then substitute  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"h", "=", 
        RowBox[{\(p\_1\), "-", 
          StyleBox[" ",
            FontFamily->"Times-Roman"], \(p\_0\)}]}]]],
  StyleBox[" and we have  \n\n(9)\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(F\ \  = \ \ \(f[p\_1] - 
            f[p\_0]\ \  = \ \ \[Alpha]\ \((3\ \[Gamma]\^2 - 3\ \[Gamma] + 
                  1)\) + \[Beta] \((1 - 2\ \[Gamma])\)\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Use use (7) to obtain    \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(f'\)[p\_1] - \(f'\)[
            p\_0]\ \  = \ \ \(3\ \[Alpha]\ \((p\_1 - p\_2)\)\^2 - 3\ \[Alpha]\
\ \((p\_0 - p\_2)\)\^2\)\/h\^3\  + \ \(2\ \[Beta]\ \((p\_1 - p\_2)\) - 2\ \
\[Beta]\ \((p\_0 - p\_2)\)\)\/h\^2\)]],
  "  ",
  StyleBox["\n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h \((\(f'\)[p\_1] - \(f'\)[
                p\_0])\)\ \  = \ \ \(3\ \[Alpha]\ \((p\_1 - p\_2)\)\^2 - 3\ \
\[Alpha]\ \((p\_0 - p\_2)\)\^2\)\/h\^2\  + \ \(2\ \[Beta]\ \((p\_1 - p\_2)\) \
- 2\ \[Beta]\ \((p\_0 - p\_2)\)\)\/h\)]],
  "  \n\n",
  StyleBox["Then use (8) to get  ",
    FontFamily->"Times-Roman"],
  "\n\n\t\t",
  Cell[BoxData[
      \(h \((\(f'\)[p\_1] - \(f'\)[
                p\_0])\)\ \  = \ \ \ \(3\ \[Alpha]\ \((\(-h\)\ \[Gamma] - \
p\_0 + p\_1)\)\^2 - 3  h\^2\ \[Alpha]\ \[Gamma]\^2\)\/h\^2\  + \ \(2\ \[Beta]\
\ \((\(-h\)\ \[Gamma] - p\_0 + p\_1)\) + 2\ h\ \[Beta]\ \[Gamma]\)\/h\)]],
  "  \n\n",
  StyleBox["Then substitute  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{"h", "=", 
        RowBox[{\(p\_1\), "-", 
          StyleBox[" ",
            FontFamily->"Times-Roman"], \(p\_0\)}]}]]],
  StyleBox[" and we have  \n",
    FontFamily->"Times-Roman"],
  "\n(10)\t\t",
  Cell[BoxData[
      \(G\ \  = \ \ \(h \((\(f'\)[p\_1] - \(f'\)[
                  p\_0])\)\ \  = \ \ 3  \[Alpha]\ \((1 - 2\ \[Gamma])\) + 
            2\ \[Beta]\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Finally, use (7) and write  \n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\ \(f'\)[
            p\_0]\ \  = \ \ h\ \((\(3\ \[Alpha]\ \((p\_0 - p\_2)\)\^2\)\/h\^3 \
+ \(2\ \[Beta]\ \((p\_0 - p\_2)\)\)\/h\^2)\)\)]],
  "\n\n",
  StyleBox["Then use (8) to get  ",
    FontFamily->"Times-Roman"],
  "\n\n(11)\t\t",
  Cell[BoxData[
      \(h\ \(f'\)[p\_0]\ \  = \ \ 3\ \[Alpha]\ \[Gamma]\^2 - 
          2\ \[Beta]\ \[Gamma]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Now we will use the three nonlinear equations (9), 10), (11) \
listed below in (12).  The order of determining the variables will be  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(F, G, \[Alpha], \[Gamma]\)]],
  "  (the variable ",
  Cell[BoxData[
      \(\[Beta]\)]],
  " will be eliminated). ",
  StyleBox["\n\n\t\t",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(F\ \  = \ \ \[Alpha]\ \((3\ \[Gamma]\^2 - 3\ \[Gamma] + 
                1)\) + \[Beta] \((1 - 2\ \[Gamma])\)\)]],
  "  \n(12)\t\t",
  Cell[BoxData[
      \(G\ \  = \ \ 3  \[Alpha]\ \((1 - 2\ \[Gamma])\) + 2\ \[Beta]\)]],
  "  \n\t\t",
  Cell[BoxData[
      \(h\ \(f'\)[p\_0]\ \  = \ \ 3\ \[Alpha]\ \[Gamma]\^2 - 
          2\ \[Beta]\ \[Gamma]\)]],
  " "
}], "Text"],

Cell[TextData[{
  "First, we will find  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  "  which is accomplished by combining the equation in (12) as follows:  \n\n\
\t",
  Cell[BoxData[
      \(G\  - 2 \((F - h\ \(f'\)[p\_0])\) = 
        3  \[Alpha]\ \((1 - 2\ \[Gamma])\) + 2\ \[Beta]\  - 
          2 \((\[Alpha]\ \((3\ \[Gamma]\^2 - 3\ \[Gamma] + 
                      1)\) + \[Beta] \((1 - 
                      2\ \[Gamma])\) - \((3\ \[Alpha]\ \[Gamma]\^2 - 
                    2\ \[Beta]\ \[Gamma])\))\)\)]],
  "   \n\nStraightforward simplification yields  ",
  Cell[BoxData[
      \(G\  - 2 \((F - h\ \(f'\)[p\_0])\)\ \  = \ \ \[Alpha]\)]],
  ",  therefore  ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  "  is given by  \n\n(13)\t\t",
  Cell[BoxData[
      \(\[Alpha]\ \  = \ \ G\  - 2 \((F - h\ \(f'\)[p\_0])\)\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  "Second, we will eliminate  ",
  Cell[BoxData[
      \(\[Beta]\)]],
  "  by combining the equation in (12) as follows, multiply the first \
equation by  ",
  Cell[BoxData[
      \(\[Gamma]\)]],
  "  and add it to the third equation    \n\n\t\t",
  Cell[BoxData[
      \(G\ \[Gamma]\  = \ 
        3\ \[Alpha]\ \[Gamma] - 6\ \[Alpha]\ \[Gamma]\^2 + 
          2\ \[Beta]\ \[Gamma]\)]],
  "  \n\t\t",
  Cell[BoxData[
      \(h\ \(f'\)[p\_0]\ \  = \ \ 3\ \[Alpha]\ \[Gamma]\^2 - 
          2\ \[Beta]\ \[Gamma]\)]],
  "  \n\t\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(G\ \[Gamma]\), "+", 
          RowBox[{"h", " ", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", \(p\_0\), "]"}]}]}], " ", "=", 
        " ", \(3\ \[Alpha]\ \[Gamma] - 3\ \[Alpha]\ \[Gamma]\^2\)}]]],
  "  \n\nwhich can be rearranged in the form  \n\n\t\t",
  Cell[BoxData[
      \(G\ \[Gamma] - 3\ \[Alpha]\ \[Gamma] + 3\ \[Alpha]\ \[Gamma]\^2 + 
          h\ \(f'\)[p\_0]\  = \ 0\)]],
  "  \n\nNow the quadratic equation can be used to solve for  ",
  Cell[BoxData[
      \(\[Gamma]\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(\[Gamma]\ \  = \ \ \(\((G - 3\ \[Alpha])\) - \@\(\((G - 3\ \
\[Alpha])\)\^2 - 12\ h\ \[Alpha]\ \(f'\)[p\_0]\)\)\/\(\(-6\)\ \[Alpha]\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "It will take a bit of effort to simplify this equation into its \
computationally preferred form. \n\n\t\t",
  Cell[BoxData[
      \(\(\((G - 3\ \[Alpha])\) - \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ h\ \
\[Alpha]\ \(f'\)[p\_0]\)\)\/\(\(-6\)\ \[Alpha]\)\  = \ \(\(\((G - 
                    3\ \[Alpha])\) + \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ h\ \
\[Alpha]\ \(f'\)[p\_0]\)\)\/\(\((G - 
                    3\ \[Alpha])\) + \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ h\ \
\[Alpha]\ \(f'\)[p\_0]\)\)\) \(\((G - 3\ \[Alpha])\) - \@\(\((G - 3\ \
\[Alpha])\)\^2 - 12\ h\ \[Alpha]\ \(f'\)[p\_0]\)\)\/\(\(-6\)\ \[Alpha]\)\)]],
  "  \n\t\t\n\t\t",
  Cell[BoxData[
      \(\(\((G - 3\ \[Alpha])\) - \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ h\ \
\[Alpha]\ \(f'\)[p\_0]\)\)\/\(\(-6\)\ \[Alpha]\)\  = \(12\ h\ \[Alpha]\ \
\(f'\)[p\_0]\)\/\(\((\((G - 3\ \[Alpha])\) + \@\(\((G - 3\ \[Alpha])\)\^2 - \
12\ h\ \[Alpha]\ \(f'\)[p\_0]\))\) \((\(-6\)\ \[Alpha])\)\)\)]],
  "  \n\t\t\n\t\t",
  Cell[BoxData[
      \(\(\((G - 3\ \[Alpha])\) - \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ h\ \
\[Alpha]\ \(f'\)[p\_0]\)\)\/\(\(-6\)\ \[Alpha]\)\  = \(\(-2\)\ h\ \
\(f'\)[p\_0]\)\/\(\((G - 3\ \[Alpha])\) + \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ \
h\ \[Alpha]\ \(f'\)[p\_0]\)\)\)]],
  "\nHence,  \n\n(14)\t\t",
  Cell[BoxData[
      \(\[Gamma]\ \  = \ \ \(\(-2\)\ h\ \(f'\)[p\_0]\)\/\(\((G - 3\ \[Alpha])\
\) + \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ h\ \[Alpha]\ \(f'\)[p\_0]\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Therefore, the value of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_2\)]],
  StyleBox["  is found by substituting the calculated value of  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\[Gamma]\)]],
  StyleBox["  in (14) into the formula  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      RowBox[{\(p\_2\), "=", 
        StyleBox[" ",
          FontFamily->"Times-Roman"], \(p\_0 + \[Gamma]\ h\)}]]],
  StyleBox[".  To continue the iteration process, let  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\  = \ p\_2 - p\_1\)]],
  StyleBox["  and replace ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0\)]],
  " ",
  StyleBox["and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_1\)]],
  StyleBox[" with ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_1\)]],
  " ",
  StyleBox["and ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_2\)]],
  StyleBox[", respectively, in formulas (12), (13), and (14).  The algorithm \
outlined above is ",
    FontFamily->"Times-Roman"],
  StyleBox["not",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" a bracketing method.  Thus determining stopping criteria becomes \
more problematic.  One technique would be to require that ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\(\(|\)\(f' \((p\_n)\)\)\(|\)\(\(<\)\(\[Epsilon]\)\)\)\)]],
  StyleBox[",  since  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f' \((p)\) = 0\)]],
  StyleBox[".",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/n2003/QuadraticSearchProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/QuadraticSearchProof.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Algorithm ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(Quadratic Search for a Minimum",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[")",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[".",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk"],
  "To numerically approximate the minimum of  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  by using a \"quadratic interpolative\" search.  Proceed with the method \
only if  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is a unimodal function on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".   The initial step size is chosen to be "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/QuadraticSearchProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/QuadraticSearchProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Quadratic Search",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" for a Minimum).",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    \(\(\(QuadraticSearch[x0_, 
          x1_, \[Delta]_, \[Epsilon]_] := \[IndentingNewLine]Module[{e, H, 
            Jmax = 50, Kmax = 50}, \ \[IndentingNewLine]p\_0 = 
            N[x0]; \ \[IndentingNewLine]Print["\<p\>"\_0, "\<  = \>", 
            PaddedForm[p\_0, {9, 8}\ ], "\<,  f[\>", 
            PaddedForm[p\_0, {9, 8}\ ], "\< ] = \>", 
            PaddedForm[Y\_0, {11, 10}]\ ]; \[IndentingNewLine]Err = 
            1.0; \ \[IndentingNewLine]h = \(x1 - x0\)\/2; \ \
\[IndentingNewLine]k = 0; \ \[IndentingNewLine]While[\ 
            k < Kmax\  && \ 
              Err > \[Epsilon], \ \[IndentingNewLine]If[\ \(f'\)[p\_0] > 0, \ 
              h\  = \ \(-Abs[h]\)\ ]; \ \[IndentingNewLine]p\_1\  = \ 
              p\_0 + h; \ \[IndentingNewLine]p\_2\  = \ 
              p\_0 + 2\ h; \ \[IndentingNewLine]p\_min\  = \ 
              p\_0; \ \[IndentingNewLine]Y\_0\  = \ 
              f[p\_0]; \ \[IndentingNewLine]Y\_1\  = \ 
              f[p\_1]; \ \[IndentingNewLine]Y\_2\  = \ 
              f[p\_2]; \ \[IndentingNewLine]Y\_min\  = \ 
              Y\_0; \ \[IndentingNewLine]Print["\<p\>"\_\(3  k + 1\), "\<  = \
\>", PaddedForm[p\_1, {9, 8}\ ], "\<,  f[\>", 
              PaddedForm[p\_1, {9, 8}\ ], "\< ] = \>", 
              PaddedForm[
                Y\_1, {11, 
                  10}]\ ]; \[IndentingNewLine]Print["\<p\>"\_\(3  k + 2\), \
"\<  = \>", PaddedForm[p\_2, {9, 8}\ ], "\<,  f[\>", 
              PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
              PaddedForm[Y\_2, {11, 10}]\ ]; \[IndentingNewLine]j = 
              0; \ \[IndentingNewLine]While[\ 
              j < Jmax\  && \ Abs[h] > \[Delta], \ \[IndentingNewLine]If[\ 
                Y\_0 \[LessEqual] 
                  Y\_1, \ \[IndentingNewLine]Module[{}, \ \
\[IndentingNewLine]p\_2\  = \ p\_1; \ \[IndentingNewLine]Y\_2\  = \ 
                    Y\_1; \ \[IndentingNewLine]h\  = \ 
                    h\/2; \ \[IndentingNewLine]p\_1\  = \ 
                    p\_0\  + \ h; \ \[IndentingNewLine]Y\_1\  = \ 
                    f[p\_1]; \ \[IndentingNewLine]Print["\<q\>"\_\(3  k + 2, \
j\), "\< = \>", PaddedForm[p\_1, {9, 8}\ ], "\<,  f[\>", 
                    PaddedForm[p\_1, {9, 8}\ ], "\< ] = \>", 
                    PaddedForm[
                      Y\_1, {11, 
                        10}]\ ];\[IndentingNewLine]\ ], \ \[IndentingNewLine]\
\(Module[{}, \ \[IndentingNewLine]\(If[\ 
                        Y\_2 < 
                          Y\_1, \ \[IndentingNewLine]\(Module[{}, \ \
\[IndentingNewLine]p\_1\  = \ p\_2; \ \[IndentingNewLine]Y\_1\  = \ 
                              Y\_2; \ \[IndentingNewLine]h\  = \ 
                              2\ h; \ \[IndentingNewLine]p\_2\  = \ 
                              p\_0 + 2\ h; \ \[IndentingNewLine]Y\_2\  = \ 
                              f[p\_2]; \ \
\[IndentingNewLine]Print["\<q\>"\_\(3  k + 2, j\), "\<q\>"\_\(3  k + 2, j\), \
"\< = \>", PaddedForm[p\_2, {9, 8}\ ], "\<,  f[\>", 
                              PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
                              PaddedForm[
                                Y\_2, {11, 
                                  10}]\ ];\[IndentingNewLine]\ ];\)\ ];\)\ ];\
\)\ ]; \ \[IndentingNewLine]j\  = \ 
                j + 1;\ \ ]; \ \[IndentingNewLine]H\_min\  = \ \(h \((4\ Y\_1 \
- 3\ Y\_0 - Y\_2)\)\)\/\(2 \((2\ Y\_1 - \ Y\_0 - Y\_2)\)\); \ \
\[IndentingNewLine]p\_min\  = \ 
              p\_0\  + \ H\_min; \ \[IndentingNewLine]Y\_min\  = \ 
              f[p\_min]; \ \[IndentingNewLine]Print["\<p\>"\_\(3  k + 3\), \
"\<  = \>", PaddedForm[p\_min, {9, 8}\ ], "\<,  f[\>", 
              PaddedForm[p\_min, {9, 8}\ ], "\< ] = \>", 
              PaddedForm[Y\_min, {11, 10}]\ ]; \[IndentingNewLine]h\  = \ 
              Abs[h]; \ \[IndentingNewLine]H\_0\  = \ 
              Abs[H\_min]; \ \[IndentingNewLine]H\_1\  = \ 
              Abs[H\_min - h]; \ \[IndentingNewLine]H\_2\  = \ 
              Abs[H\_min - 2\ h]; \ \[IndentingNewLine]If[\ H\_0 < h, \ 
              h = H\_0\ ]; \ \[IndentingNewLine]If[\ H\_1 < h, \ 
              h = H\_1\ ]; \ \[IndentingNewLine]If[\ H\_2 < h, \ 
              h = H\_2\ ]; \ \[IndentingNewLine]If[\ h \[Equal] 0, \ 
              h = H\_min\ ]; \ \[IndentingNewLine]e\_0\  = \ 
              Abs[Y\_0 - Y\_min]; \ \[IndentingNewLine]e\_1\  = \ 
              Abs[Y\_1 - Y\_min]; \ \[IndentingNewLine]e\_2\  = \ 
              Abs[Y\_2 - Y\_min]; \ \[IndentingNewLine]If[\ 
              e\_0 \[NotEqual] 0\  && \ e\_0 < Err, \ 
              Err = e\_0\ ]; \ \[IndentingNewLine]If[\ 
              e\_1 \[NotEqual] 0\  && \ e\_1 < Err, \ 
              Err = e\_1\ ]; \ \[IndentingNewLine]If[\ 
              e\_2 \[NotEqual] 0\  && \ e\_2 < Err, \ 
              Err = e\_2\ ]; \ \[IndentingNewLine]If[\ 
              e\_0 \[Equal] 0\  && \ e\_1 \[Equal] 0\  && \ 
                e\_2 \[Equal] 0, \ 
              Err = 0\ ]; \ \ \[IndentingNewLine]p\_0\  = \ 
              p\_min; \ \[IndentingNewLine]k\  = \ 
              k + 1;\ \ ];\ \ ];\)\(\ \ \ \)\)\)], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 1.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Find the minimum of the function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[x] = x\^2\  - \ Sin[x]\)]],
  StyleBox["  on the interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  "  ",
  StyleBox["using the quadratic search method.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^2 - Sin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 1}, PlotRange \[Rule] {{0, 1}, {\(-0.25\), 0.2}}, 
        Ticks \[Rule] {Range[0, 1, 0.2], Range[\(-0.4\), 0.2, 0.1]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<   y = f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[TextData[{
  "Set  ",
  Cell[BoxData[
      \(p\_0 = a\)]],
  ",  and  ",
  Cell[BoxData[
      \(p\_1 = b\)]],
  ",  and  ",
  Cell[BoxData[
      \(h = \(b - a\)\/2\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(a = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(h = \(b - a\)\/2;\)\ \), "\[IndentingNewLine]", 
    \(\(p\_0 = a;\)\ \), "\[IndentingNewLine]", 
    \(\(p\_1\  = \ p\_0 + h;\)\ \), "\[IndentingNewLine]", 
    \(\(p\_2\  = \ p\_0 + 2\ h;\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_0\  = \ f[p\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_1\  = \ f[p\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_2\  = \ f[p\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< h = \>", h];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", 
        p\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\) = \>\"", 
        p\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_2\) = \>\"", 
        p\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_0\) = f[\!\(p\_0\)] = f[\>\"", 
        PaddedForm[p\_0, {9, 8}], "\< ] = \>", 
        Y\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_1\) = f[\!\(p\_1\)] = f[\>\"", 
        PaddedForm[p\_1, {9, 8}], "\< ] = \>", 
        Y\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_2\) = f[\!\(p\_2\)] = f[\>\"", 
        PaddedForm[p\_2, {9, 8}], "\< ] = \>", Y\_2];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["We must decide whether to use  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_0\ , p\_1\ , p\_2\)]],
  StyleBox[" or change the step size to  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\/2\)]],
  StyleBox[" or  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(2  h\)]],
  StyleBox["  and recompute some of these values.  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(If[\ 
        Y\_0 \[LessEqual] 
          Y\_1, \ \[IndentingNewLine]Module[{}, \ \[IndentingNewLine]p\_2\  = \
\ p\_1; \ \[IndentingNewLine]Y\_2\  = \ Y\_1; \ \[IndentingNewLine]h\  = \ 
            h\/2; \ \[IndentingNewLine]p\_1\  = \ 
            p\_0\  + \ h; \ \[IndentingNewLine]Y\_1\  = \ 
            f[p\_1]; \ \[IndentingNewLine]Print["\<p\>"\_1, "\< = \>", 
            PaddedForm[p\_1, {9, 8}\ ], "\<,  f[\>", 
            PaddedForm[p\_1, {9, 8}\ ], "\< ] = \>", 
            PaddedForm[
              Y\_1, {11, 
                10}]\ ];\[IndentingNewLine]\ ], \ \
\[IndentingNewLine]\(Module[{}, \ \[IndentingNewLine]\(If[\ 
                Y\_2 < Y\_1, \ \[IndentingNewLine]\(Module[{}, \ \
\[IndentingNewLine]p\_1\  = \ p\_2; \ \[IndentingNewLine]Y\_1\  = \ 
                      Y\_2; \ \[IndentingNewLine]h\  = \ 
                      2\ h; \ \[IndentingNewLine]p\_2\  = \ 
                      p\_0 + 2\ h; \ \[IndentingNewLine]Y\_2\  = \ 
                      f[p\_2]; \ \[IndentingNewLine]Print["\<p\>"\_2, "\<q\>"\
\_\(3  k + 2, j\), "\< = \>", PaddedForm[p\_2, {9, 8}\ ], "\<,  f[\>", 
                      PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
                      PaddedForm[
                        Y\_2, {11, 
                          10}]\ ];\[IndentingNewLine]\ ];\)\ ];\)\ ];\)\ ];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< h = \>", h];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", 
        p\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\) = \>\"", 
        p\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_2\) = \>\"", 
        p\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_0\) = f[\!\(p\_0\)] = f[\>\"", 
        PaddedForm[p\_0, {9, 8}], "\< ] = \>", 
        Y\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_1\) = f[\!\(p\_1\)] = f[\>\"", 
        PaddedForm[p\_1, {9, 8}], "\< ] = \>", 
        Y\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_2\) = f[\!\(p\_2\)] = f[\>\"", 
        PaddedForm[p\_2, {9, 8}], "\< ] = \>", Y\_2];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["The step size has not changed and we now compute ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_min\  = \ p\_0\  + \ H\_min\)]],
  StyleBox[".  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[{
    \(\(H\_min\  = \ \(h \((4  Y\_1 - 3  Y\_0 - Y\_2)\)\)\/\(2 \((2\ Y\_1 - \ \
Y\_0 - Y\_2)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(p\_min\  = \ p\_0\  + \ H\_min;\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_min\  = \ f[p\_min];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< h = \>", h];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", 
        p\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\) = \>\"", 
        p\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_2\) = \>\"", 
        p\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_0\) = f[\!\(p\_0\)] = f[\>\"", 
        PaddedForm[p\_0, {9, 8}], "\< ] = \>", 
        Y\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_1\) = f[\!\(p\_1\)] = f[\>\"", 
        PaddedForm[p\_1, {9, 8}], "\< ] = \>", 
        Y\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_2\) = f[\!\(p\_2\)] = f[\>\"", 
        PaddedForm[p\_2, {9, 8}], "\< ] = \>", 
        Y\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_min\) = \!\(\(h \((4  Y\_1 - 3  Y\_0 - \
Y\_2)\)\)\/\(2 \((2  Y\_1 - Y\_0 - Y\_2)\)\)\)\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_min\) = h(4 \!\(Y\_1\)-3 \
\!\(Y\_0\)-\!\(Y\_2\))/2(2 \!\(Y\_1\)- \!\(Y\_0\)-\!\(Y\_2\))\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_min\) = \>\"", h, "\<(\>", 
        4\ Y\_1 - 3\ Y\_0 - Y\_2, "\<)/(2(\>", 
        2\ Y\_1 - \ Y\_0 - Y\_2, "\<))\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_min\) = \>\"", h, "\<(\>", 
        4\ Y\_1 - 3\ Y\_0 - Y\_2, "\<)/(\>", 
        2 \((2\ Y\_1 - \ Y\_0 - 
              Y\_2)\), "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_min\) = \!\(p\_0\) + \!\(H\_min\)\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_min\) = \>\"", p\_0, "\< + (\>", 
        H\_min, "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_min\) = \>\"", 
        p\_min];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_min\) = f[\!\(p\_min\)] = f[\>\"", 
        PaddedForm[p\_min, {9, 8}], "\< ] = \>", Y\_min];\)\ \)}], "Input"],

Cell[TextData[StyleBox["We use the \"latest three values\" and change the \
step size and continue the iteration with the following three values used in \
the interpolating quadratic. ",
  FontFamily->"Times-Roman"]], "Text"],

Cell[BoxData[{
    \(\(p\_0\  = \ p\_min;\)\), "\[IndentingNewLine]", 
    \(\(H\_0\  = \ Abs[H\_min];\)\ \), "\[IndentingNewLine]", 
    \(\(H\_1\  = \ Abs[H\_min - h];\)\ \), "\[IndentingNewLine]", 
    \(\(H\_2\  = \ Abs[H\_min - 2\ h];\)\ \), "\[IndentingNewLine]", 
    \(\(If[\ H\_0 < h, \ h = H\_0\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(If[\ H\_1 < h, \ h = H\_1\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(If[\ H\_2 < h, \ h = H\_2\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(p\_1\  = \ p\_0 + h;\)\ \), "\[IndentingNewLine]", 
    \(\(p\_2\  = \ p\_0 + 2\ h;\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_0\  = \ f[p\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_1\  = \ f[p\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Y\_2\  = \ f[p\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< h = \>", h];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = \>\"", 
        p\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\) = \>\"", 
        p\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_2\) = \>\"", 
        p\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_0\) = f[\!\(p\_0\)] = f[\>\"", 
        PaddedForm[p\_0, {9, 8}], "\< ] = \>", 
        PaddedForm[Y\_0, {11, 10}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_1\) = f[\!\(p\_1\)] = f[\>\"", 
        PaddedForm[p\_1, {9, 8}], "\< ] = \>", 
        PaddedForm[Y\_1, {11, 10}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Y\_2\) = f[\!\(p\_2\)] = f[\>\"", 
        PaddedForm[p\_2, {9, 8}], "\< ] = \>", 
        PaddedForm[Y\_2, {11, 10}]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["The last three values will be labeled ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_3, p\_4, p\_5\)]],
  StyleBox[" by the subroutine.  The list of computations obtained by using \
the ",
    FontFamily->"Times-Roman"],
  StyleBox["Quadraticearch",
    FontFamily->"Courier New"],
  StyleBox[" subroutine are:  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[
    \(\(QuadraticSearch[0.0, 1.0, 10\^\(-6\), 10\^\(-6\)];\)\)], "Input"],

Cell[TextData[{
  "Let us compare these answers with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine ",
  StyleBox["FindMinimum",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sol = FindMinimum[f[x], {x, 0.5}];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print[sol];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\[RightDoubleBracket]\)\
\), 8]];\)\ \), "\n", 
    \(\(Print["\<f[p] = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), 
          8]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Algorithm ",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["(Cubic Search for a Minimum",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[")",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[".",
    FontFamily->"New Century Schlbk",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontFamily->"New Century Schlbk"],
  "To numerically approximate the minimum of  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  "  by using a \"cubic interpolative\" search.  Proceed with the method only \
if  ",
  Cell[BoxData[
      \(f \((x)\)\)]],
  "  is a unimodal function on the interval  ",
  Cell[BoxData[
      \(\([a, b]\)\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  "Start with  ",
  Cell[BoxData[
      \(p\_0 = a\)]],
  ",  ",
  Cell[BoxData[
      \(p\_1 = b\)]],
  ",  and  ",
  Cell[BoxData[
      \(h\_0\  = \ \(2 \((f[p\_1] - f[p\_0])\)\)\/\(f'\)[p\_0]\)]],
  "  and use the following sequence steps in the iteration: \n\n\t\t",
  Cell[BoxData[
      \(F\ \  = \ \ f[p\_\(k + 1\)] - f[p\_k]\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(G\ \  = \ \ \(h\_k\) \((\(f'\)[p\_\(k + 1\)] - \(f'\)[p\_k])\)\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(\[Alpha]\ \  = \ \ G\  - 2 \((F - h\_k\ \(f'\)[p\_k])\)\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(\[Gamma]\ \  = \ \ \(\(-2\)\ h\_k\ \(f'\)[p\_k]\)\/\(\((G - 3\ \
\[Alpha])\) + \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ h\_k\ \[Alpha]\ \(f'\)[p\_k]\
\)\)\)]],
  "  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\(p\_\(k + 2\)\), "=", 
        StyleBox[" ",
          FontFamily->"Times-Roman"], \(p\_k + \[Gamma]\ h\_k\)}]]],
  "  \n\n\t\t",
  Cell[BoxData[
      \(h\_\(k + 1\)\  = \ p\_\(k + 2\) - p\_\(k + 1\)\)]],
  "  \n\t\t\n\t\tfor   ",
  Cell[BoxData[
      \(k = 0, 1, 2,  ... , n\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Programs",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/QuadraticSearchProg.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/n2003/QuadraticSearchProg.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  "
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica Subroutine (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["Cubic Search",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[" for a Minimum).",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(CubicSearch[a0_, b0_, max_]\), ":=", "\[IndentingNewLine]", 
          
          RowBox[{"Module", "[", 
            
            RowBox[{\({a\  = \ N[a0], b\  = \ N[b0], c, d, h, k, m, r, Ya, 
                Yb, Yc, Yd}\), ",", " ", "\[IndentingNewLine]", 
              
              RowBox[{\(p\_0\  = \ a\), ";", 
                "\[IndentingNewLine]", \(Print["\<p\>"\_0, "\< = \>", 
                  PaddedForm[p\_0, {9, 8}\ ], "\<,  f[\>", 
                  PaddedForm[p\_0, {9, 8}\ ], "\< ] = \>", 
                  PaddedForm[f[p\_0], {11, 10}]\ ]\), ";", 
                "\[IndentingNewLine]", \(Clear[h]\), ";", 
                "\[IndentingNewLine]", \(h\_0\  = \ \(2 \((f[b] - f[a])\)\)\/\
\(f'\)[a]\), ";", "\[IndentingNewLine]", \(p\_1\  = \ p\_0 + h\_0\), ";", 
                "\[IndentingNewLine]", \(Print["\<p\>"\_1, "\< = \>", 
                  PaddedForm[p\_1, {9, 8}\ ], "\<,  f[\>", 
                  PaddedForm[p\_1, {9, 8}\ ], "\< ] = \>", 
                  PaddedForm[f[p\_1], {11, 10}]\ ]\), ";", 
                "\[IndentingNewLine]", \(m = 1\), ";", "\[IndentingNewLine]", 
                
                RowBox[{"While", "[", " ", 
                  
                  RowBox[{\(m \[LessEqual] max\), ",", "\[IndentingNewLine]", 
                    
                    
                    RowBox[{\(F\ \  = \ \ f[p\_1] - f[p\_0]\), ";", 
                      "\[IndentingNewLine]", \(G\ \  = \ \ \(h\_0\) \((\(f'\)[
                                p\_1] - \(f'\)[p\_0])\)\), ";", 
                      "\[IndentingNewLine]", \(\[Alpha]\ \  = \ \ G\  - 
                          2 \((F - h\_0\ \(f'\)[p\_0])\)\), ";", 
                      "\[IndentingNewLine]", \(\[Gamma]\ \  = \ \ \(\(-2\)\ h\
\_0\ \(f'\)[p\_0]\)\/\(\((G - 3\ \[Alpha])\) + \@\(\((G - 3\ \[Alpha])\)\^2 - \
12\ h\_0\ \[Alpha]\ \(f'\)[p\_0]\)\)\), ";", " ", "\[IndentingNewLine]", 
                      RowBox[{\(p\_2\), "=", 
                        StyleBox[" ",
                          
                          FontFamily->
                            "Times-Roman"], \(p\_0 + \[Gamma]\ h\_0\)}], ";", 
                      " ", "\[IndentingNewLine]", \(m = m + 1\), ";", 
                      "\[IndentingNewLine]", \(Print["\<p\>"\_m, "\< = \>", 
                        PaddedForm[p\_2, {9, 8}\ ], "\<,  f[\>", 
                        PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
                        PaddedForm[f[p\_2], {11, 10}]\ ]\), ";", 
                      "\[IndentingNewLine]", \(p\_0\  = \ p\_1\), ";", 
                      "\[IndentingNewLine]", \(p\_1\  = \ p\_2\), ";", 
                      "\[IndentingNewLine]", \(h\_0\  = \ p\_1 - p\_0\), 
                      ";"}]}], " ", "]"}], ";", " ", 
                "\[IndentingNewLine]", \(Print["\<After m = \>", 
                  m - 1, "\< iterations\>"]\), ";", " ", 
                "\[IndentingNewLine]", \(Print["\<f[x] = \>", f[x]]\), ";", 
                "\[IndentingNewLine]", \(Print["\<f[\>", 
                  PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
                  PaddedForm[f[p\_2], {11, 10}]\ ]\), ";", 
                "\[IndentingNewLine]", \(Return[{f[p\_2], p\_2}\ ]\)}]}], 
            "]"}]}], ";"}], " "}]], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 2.",
    FontFamily->"Times-Bold",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  Find the minimum of the function  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[x] = x\^2\  - \ Sin[x]\)]],
  StyleBox["  on the interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  "  ",
  StyleBox["using the cubic search method.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[x_] = x\^2 - Sin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 1}, PlotRange \[Rule] {{0, 1}, {\(-0.25\), 0.2}}, 
        Ticks \[Rule] {Range[0, 1, 0.2], Range[\(-0.4\), 0.2, 0.1]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<   y = f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[TextData[{
  "Set ",
  Cell[BoxData[
      \(p\_0 = a\)]],
  ", and determine the first value of  ",
  StyleBox["h",
    FontFamily->"Courier New"],
  " ",
  StyleBox[" and use it to compute ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_1\  = \ p\_0 + h\)]],
  StyleBox[".  \nObserve that the algorithm is ",
    FontFamily->"Times-Roman"],
  StyleBox["not",
    FontFamily->"Times-Roman",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" a bracketing method and  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_1\)]],
  " does not lie in",
  StyleBox[" the given interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(a = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(p\_0\  = \ a;\)\), "\[IndentingNewLine]", 
    \(\(Clear[h];\)\), "\[IndentingNewLine]", 
    \(\(h\_0\  = \ \(2 \((f[b] - f[a])\)\)\/\(f'\)[a];\)\), "\
\[IndentingNewLine]", 
    \(\(p\_1\  = \ p\_0 + h\_0;\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[x] = \>", \(f'\)[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    a = \>", a];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<    b = \>", b];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[a] = \>", f[a]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[b] = \>", f[b]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[a] = \>", \(f'\)[a]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_0\) = a = \>\"", 
        p\_0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(h\_0\) = \!\(\(2 \((f[b] - \
f[a])\)\)\/\(f'\)[a]\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(h\_0\) = 2(\>\"", f[b], "\< - (\>", 
        f[a], "\<)/(\>", \(f'\)[a], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(h\_0\) = 2(\>\"", 
        f[b]\  - \ f[a], "\<)/(\>", \(f'\)[
          a], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\) = \!\(p\_0\) + \!\(h\_0\)\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(p\_1\) = \>\"", p\_1];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Now compute the values  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(F, G, \[Alpha], \[Gamma]\)]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(p\_2\), "=", 
        StyleBox[" ",
          FontFamily->"Times-Roman"], \(p\_0 + \[Gamma]\ h\_0\)}]]],
  ". "
}], "Text"],

Cell[BoxData[{\(F\ \  = \ \ f[p\_1] - 
          f[p\_0];\), "\[IndentingNewLine]", \(G\ \  = \ \ \(h\_0\) \((\(f'\)[
                p\_1] - \(f'\)[
                p\_0])\);\), "\[IndentingNewLine]", \(\[Alpha]\ \  = \ \ G\  \
- 2 \((F - h\_0\ \(f'\)[p\_0])\);\), "\[IndentingNewLine]", 
    RowBox[{\(\[Gamma]\ \  = \ \ \(\(-2\)\ h\_0\ \(f'\)[p\_0]\)\/\(\((G - 3\ \
\[Alpha])\) + \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ h\_0\ \[Alpha]\ \(f'\)[p\_0]\
\)\);\), " "}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(p\_2\), "=", 
          StyleBox[" ",
            FontFamily->"Times-Roman"], \(p\_0 + \[Gamma]\ h\_0\)}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\< F = \>", F];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\< G = \>", G];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\< \[Alpha] = \>", \[Alpha]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print["\< \[Gamma] = \>", \[Gamma]];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(p\_0\) = \>\"", p\_0];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(p\_2\) = \>\"", \*"\"\<\!\(p\_0\) + \[Gamma] \
\!\(h\_0\)\>\""];\), " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(p\_2\) = \>\"", 
          p\_0, "\< + (\>", \[Gamma], "\<)(\>", \ h\_0, "\<)\>"];\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(p\_2\) = \>\"", p\_2];\), " "}]}], "Input"],

Cell[TextData[{
  StyleBox["Now set  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(h\_1\  = \ \(p\_2 - p\_1\  = \ 0.767363664551212`\)\)]],
  StyleBox["  and continue the iteration process.  \nThe list of computations \
are obtained by using the ",
    FontFamily->"Times-Roman"],
  StyleBox["CubicSearch",
    FontFamily->"Courier New"],
  StyleBox[" subroutine are:  ",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[BoxData[
    \(\(CubicSearch[0.0, 1.0, 4];\)\)], "Input"],

Cell[TextData[{
  "Let us compare these answers with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s subroutine ",
  StyleBox["FindMinimum",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sol = FindMinimum[f[x], {x, 0.5}];\)\ \), "\n", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \), "\n", 
    \(\(Print[sol];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  p  = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(2, 1, 2\)\(\[RightDoubleBracket]\)\
\), 8]];\)\ \), "\n", 
    \(\(Print["\<f[p] = \>", 
        NumberForm[
          sol\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), 
          8]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["The value of the function at  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(p\_4\  = \ 0.45018361\)]],
  StyleBox["  is  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(f[p\_4]\  = \ \(-0.23246558\)\)]],
  StyleBox[",  which compares favorably with the minimum value found by the \
Secant Method for finding the root of",
    FontFamily->"Times-Roman"],
  "  ",
  Cell[BoxData[
      \(g \((x)\) = f' \((x)\)\)]],
  ".  The values obtained by the Secant Method are included below for \
comparison purposes."
}], "Text"],

Cell[BoxData[
    \(\(\(SecantMethod[x0_, x1_, 
        max_]\)\(:=\)\(\[IndentingNewLine]\)\(Module[{\(k\)\(,\)}, \
\[IndentingNewLine]k\  = \ 1; \ \[IndentingNewLine]p0\  = \ 
          N[x0]; \ \[IndentingNewLine]p1\  = \ 
          N[x1]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_0\) = \>\"", 
          PaddedForm[p0, {9, 8}], \*"\"\<,   g[\!\(p\_0\)] = \>\"", 
          NumberForm[g[p0], 
            10]\ ]; \ \[IndentingNewLine]Print[\*"\"\<\!\(p\_1\) = \>\"", 
          PaddedForm[p1, {9, 8}], \*"\"\<,   g[\!\(p\_1\)] = \>\"", 
          NumberForm[g[p1], 10]\ ]; \ \ \[IndentingNewLine]p2\  = \ 
          p1; \ \[IndentingNewLine]p1\  = \ p0; \ \[IndentingNewLine]While[\ 
          k < max, \[IndentingNewLine]p0\  = \ 
            p1; \ \[IndentingNewLine]p1\  = \ 
            p2; \ \[IndentingNewLine]p2\  = \ 
            p1\  - \ \(g[p1] \((p1\  - \ p0)\)\)\/\(g[p1]\  - \ g[p0]\); \ \
\[IndentingNewLine]k\  = \ 
            k + 1; \ \[IndentingNewLine]Print["\<p\>"\_k, "\< = \>", 
            PaddedForm[p2, {9, 8}], "\<,   g[\>", "\<p\>"\_k, "\<] = \>", 
            NumberForm[g[p2], 
              10]\ ];\ ]; \ \[IndentingNewLine]Print["\<g[x] = \>", 
          g[x]]; \[IndentingNewLine]Print["\<  p  = \>", 
          NumberForm[p2, 
            8]\ ]; \ \[IndentingNewLine]Print["\< \[CapitalDelta]p  = \
\[PlusMinus]\>", Abs[p2 - p1]\ ]; \ \[IndentingNewLine]Print["\<g[p] = \>", 
          NumberForm[g[p2], 10]\ ];\ ]\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(f[x_] = x\^2 - Sin[x];\)\ \ \), "\[IndentingNewLine]", 
    \(\(g[x_] = \(f'\)[x];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, 0, 1}, PlotRange \[Rule] {{0, 1}, {\(-0.25\), 0.2}}, 
        Ticks \[Rule] {Range[0, 1, 0.2], Range[\(-0.4\), 0.2, 0.1]}, 
        PlotStyle \[Rule] Magenta];\)\ \), "\n", 
    \(\(Print["\<   y =  f[x] = \>", f[x]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[x] = f'[x] = \>", g[x]];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(SecantMethod[0, 1, 7];\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Various Scenarios",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" and Animations for the Quadrat and Cubic Search Methods.",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`FilledPlot`\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(QuadraticSearch[x0_, 
          x1_, \[Delta]_, \[Epsilon]_] := \[IndentingNewLine]Module[{a = \(a0 \
= x0\), b = \(b0 = x1\), e, H, Jmax = 50, 
            Kmax = 50}, \ \[IndentingNewLine]p\_0 = 
            N[x0]; \ \[IndentingNewLine]gr0 = 
            Plot[f[x], {x, a0, b0}, 
              PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.75}}, 
              PlotStyle \[Rule] Magenta, 
              DisplayFunction \[Rule] Identity]; \ \[IndentingNewLine]Err = 
            1.0; \ h = \(x1 - x0\)\/2; \ 
          k = 0; \ \[IndentingNewLine]While[\ 
            k < Kmax\  && \ 
              Err > \[Epsilon], \ \[IndentingNewLine]If[\ \(f'\)[p\_0] > 0, 
              h\  = \(-Abs[h]\)]; p\_1 = p\_0 + h; p\_2 = p\_0 + 2\ h; 
            p\_min = p\_0; Y\_0 = f[p\_0]; Y\_1 = f[p\_1]; Y\_2 = f[p\_2]; 
            Y\_min = Y\_0; \ 
            j = 0; \ \[IndentingNewLine]While[\ 
              j < Jmax\  && \ Abs[h] > \[Delta], \ \[IndentingNewLine]If[\ 
                Y\_0 \[LessEqual] Y\_1, \ \[IndentingNewLine]Module[{}, 
                  p\_2 = p\_1; Y\_2 = Y\_1; h = h\/2; \ p\_1 = p\_0 + h; 
                  Y\_1 = f[
                      p\_1]; \ \[IndentingNewLine]pointsab = {\ {Red, 
                        PointSize[0.02], Point[{p\_0, f[p\_0]}], 
                        Point[{p\_2, f[p\_2]}]}, {Blue, PointSize[0.02], 
                        Point[{p\_1, 
                            f[p\_1]}]}}; \ \ \[IndentingNewLine]dotsab = 
                    Graphics[pointsab]; \ \ \[IndentingNewLine]Show[gr0, gr1, 
                    dotsab, 
                    PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
                    Ticks \[Rule] {Range[0, 2, 0.1], Range[0, 2, 0.1]}, 
                    DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<q\>"\_\(3  k + 2, j\), "\< = \>", 
                    PaddedForm[p\_1, {9, 8}\ ], "\<,  f[\>", 
                    PaddedForm[p\_1, {9, 8}\ ], "\< ] = \>", 
                    PaddedForm[
                      Y\_1, {11, 
                        10}]\ ];], \ \[IndentingNewLine]\(Module[{}, \ \
\[IndentingNewLine]\(If[\ 
                        Y\_2 < 
                          Y\_1, \ \[IndentingNewLine]\(Module[{}, \ \
\[IndentingNewLine]p\_1 = p\_2; Y\_1 = Y\_2; h = 2\ h; p\_2 = p\_0 + 2\ h; 
                            Y\_2 = 
                              f[p\_2]; \ \[IndentingNewLine]pointsab = {{Red, 
                                  PointSize[0.02], Point[{p\_0, f[p\_0]}], 
                                  Point[{p\_1, f[p\_1]}]}, {Blue, 
                                  PointSize[0.02], 
                                  Point[{p\_2, 
                                      f[p\_2]}]}}; \ \ \
\[IndentingNewLine]dotsab = Graphics[pointsab]; \ \ \[IndentingNewLine]Show[
                              gr0, gr1, dotsab, 
                              PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 
                                    0.72}}, 
                              Ticks \[Rule] {Range[0, 2, 0.1], 
                                  Range[0, 2, 0.1]}, 
                              DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<q\>"\_\(3  k + 2, j\), "\<q\>"\_\(3  k + 2, j\), \
"\< = \>", PaddedForm[p\_2, {9, 8}\ ], "\<,  f[\>", 
                              PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
                              PaddedForm[
                                Y\_2, {11, 10}]\ ];\ ];\)\ ];\)\ ];\)\ ]; \ 
              j\  = \ j + 1;\ \ ]; \ \[IndentingNewLine]pointsab = {{Red, 
                  PointSize[0.02], Point[{p\_0, f[p\_0]}], 
                  Point[{p\_1, f[p\_1]}], 
                  Point[{p\_2, f[p\_2]}]}}; \ \ \[IndentingNewLine]dotsab = 
              Graphics[pointsab]; \ \ \[IndentingNewLine]gr1 = 
              FilledPlot[f[x], {x, p\_0, p\_2}, 
                PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
                PlotStyle \[Rule] Red, 
                Fills \[Rule] {RGBColor[1, 0.8, 0.85]}, Curves \[Rule] Front, 
                DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[
              gr0, gr1, dotsab, 
              PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
              Ticks \[Rule] {Range[0, 2, 0.1], Range[0, 2, 0.1]}, 
              DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<p\>"\_\(3  k\), "\<  = \>", 
              PaddedForm[p\_0, {9, 8}\ ], "\<,  f[\>", 
              PaddedForm[p\_0, {9, 8}\ ], "\< ] = \>", 
              PaddedForm[
                Y\_0, {11, 
                  10}]\ ]; \[IndentingNewLine]Print["\<p\>"\_\(3  k + 1\), \
"\<  = \>", PaddedForm[p\_1, {9, 8}\ ], "\<,  f[\>", 
              PaddedForm[p\_1, {9, 8}\ ], "\< ] = \>", 
              PaddedForm[
                Y\_1, {11, 
                  10}]\ ]; \[IndentingNewLine]Print["\<p\>"\_\(3  k + 2\), \
"\<  = \>", PaddedForm[p\_2, {9, 8}\ ], "\<,  f[\>", 
              PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
              PaddedForm[
                Y\_2, {11, 
                  10}]\ ]; \[IndentingNewLine]H\_min = \(h \((4  Y\_1 - 3  \
Y\_0 - Y\_2)\)\)\/\(2 \((2  Y\_1 - Y\_0 - Y\_2)\)\); \ 
            p\_min = p\_0 + H\_min; Y\_min = f[p\_min]; h = Abs[h]; 
            H\_0 = Abs[H\_min]; H\_1 = Abs[H\_min - h]; 
            H\_2 = Abs[H\_min - 2\ h]; If[\ H\_0 < h, h = H\_0\ ]; 
            If[\ H\_1 < h, h = H\_1\ ]; If[\ H\_2 < h, h = H\_2\ ]; 
            If[\ h \[Equal] 0, \ h = H\_min\ ]; e\_0 = Abs[Y\_0 - Y\_min]; 
            e\_1 = Abs[Y\_1 - Y\_min]; e\_2 = Abs[Y\_2 - Y\_min]; 
            If[\ e\_0 \[NotEqual] 0\  && \ e\_0 < Err, Err = e\_0\ ]; 
            If[\ e\_1 \[NotEqual] 0\  && \ e\_1 < Err, Err = e\_1\ ]; 
            If[\ e\_2 \[NotEqual] 0\  && \ e\_2 < Err, Err = e\_2\ ]; 
            If[\ e\_0 \[Equal] 0\  && \ e\_1 \[Equal] 0\  && \ 
                e\_2 \[Equal] 0, Err = 0]; \ \ \[IndentingNewLine]p\_0\  = \ 
              p\_min; \ k\  = \ k + 1;\ \ ]; \ \[IndentingNewLine]p\_1\  = \ 
            p\_0 + h; \ 
          p\_2\  = \ 
            p\_0 + 2\ h; \ \[IndentingNewLine]pointsab = {{Red, 
                PointSize[0.02], Point[{p\_0, f[p\_0]}], 
                Point[{p\_1, f[p\_1]}], 
                Point[{p\_2, f[p\_2]}]}}; \ \ \[IndentingNewLine]dotsab = 
            Graphics[pointsab]; \ \ \[IndentingNewLine]gr1 = 
            FilledPlot[f[x], {x, p\_0, p\_2}, 
              PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
              PlotStyle \[Rule] Red, Fills \[Rule] {RGBColor[1, 0.8, 0.85]}, 
              Curves \[Rule] Front, 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[gr0, 
            gr1, dotsab, 
            PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
            Ticks \[Rule] {Range[0, 2, 0.1], Range[0, 2, 0.1]}, 
            DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<p\>"\_\(3  k\), "\<  = \>", 
            PaddedForm[p\_min, {9, 8}\ ], "\<,  f[\>", 
            PaddedForm[p\_min, {9, 8}\ ], "\< ] = \>", 
            PaddedForm[Y\_min, {11, 10}]\ ];];\)\ \ \ \)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  "Find the minimum of  ",
  Cell[BoxData[
      \(f[x] = 1\/2 + x\^5 - \(4\/5\) x\)],
    AspectRatioFixed->True],
  StyleBox["  on the interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  "  ",
  StyleBox["using the quadratic search method.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = 1\/2 + x\^5 - \(4\/5\) x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a0 = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(QuadraticSearch[a0, b0, 10\^\(-6\), 
        10\^\(-6\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Quadratic Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/a2001/Animations/Optimization/\
Quadratic1/Quadraticaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Quadratic Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Optimization/\
Quadratic1/Quadraticaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Quadratic Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/a2001/Animations/Optimization/\
Quadratic1/Quadratic.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Quadratic Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Optimization/\
Quadratic1/Quadratic.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations. "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Needs["\<Graphics`Colors`\>"];\), "  "}], "\[IndentingNewLine]",
   
    RowBox[{
      RowBox[{
        RowBox[{\(CubicSearch[a0_, b0_, max_]\), ":=", "\[IndentingNewLine]", 
          
          RowBox[{"Module", "[", 
            
            RowBox[{\({a\  = \ N[a0], b\  = \ N[b0], c, d, h, k, m, r, Ya, 
                Yb, Yc, Yd}\), ",", " ", "\[IndentingNewLine]", 
              
              RowBox[{\(p\_0 = a\), ";", \(Clear[h]\), 
                ";", \(h\_0 = \(2 \((f[b] - f[a])\)\)\/\(f'\)[a]\), 
                ";", \(p\_1 = p\_0 + h\_0\), ";", 
                "\[IndentingNewLine]", \(pointsab = {{Red, PointSize[0.02], 
                      Point[{p\_0, f[p\_0]}], Point[{p\_1, f[p\_1]}]}}\), ";",
                 "  ", "\[IndentingNewLine]", \(dotsab = Graphics[pointsab]\),
                 ";", "  ", 
                "\[IndentingNewLine]", \(gr0 = 
                  Plot[f[x], {x, a0, b0}, 
                    PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.75}}, 
                    PlotStyle \[Rule] Magenta, 
                    DisplayFunction \[Rule] Identity]\), ";", " ", 
                "\[IndentingNewLine]", \(Show[gr0, dotsab, 
                  PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 0.72}}, 
                  Ticks \[Rule] {Range[0, 2, 0.1], Range[0, 2, 0.1]}, 
                  DisplayFunction \[Rule] $DisplayFunction]\), ";", " ", 
                "\[IndentingNewLine]", \(Print["\<p\>"\_0, "\< = \>", 
                  PaddedForm[p\_0, {9, 8}\ ], "\<,  f[\>", 
                  PaddedForm[p\_0, {9, 8}\ ], "\< ] = \>", 
                  PaddedForm[f[p\_0], {11, 10}]\ ]\), ";", 
                "\[IndentingNewLine]", \(Print["\<p\>"\_1, "\< = \>", 
                  PaddedForm[p\_1, {9, 8}\ ], "\<,  f[\>", 
                  PaddedForm[p\_1, {9, 8}\ ], "\< ] = \>", 
                  PaddedForm[f[p\_1], {11, 10}]\ ]\), ";", 
                "\[IndentingNewLine]", \(m = 1\), ";", "\[IndentingNewLine]", 
                
                RowBox[{"While", "[", " ", 
                  RowBox[{\(m \[LessEqual] max\), ",", 
                    
                    RowBox[{\(F = f[p\_1] - f[p\_0]\), 
                      ";", \(G = \(h\_0\) \((\(f'\)[p\_1] - \(f'\)[p\_0])\)\),
                       ";", \(\[Alpha] = G - 2 \((F - h\_0\ \(f'\)[p\_0])\)\),
                       ";", \(\[Gamma] = \(\(-2\)\ h\_0\ \
\(f'\)[p\_0]\)\/\(\((G - 3\ \[Alpha])\) + \@\(\((G - 3\ \[Alpha])\)\^2 - 12\ \
h\_0\ \[Alpha]\ \(f'\)[p\_0]\)\)\), ";", " ", 
                      RowBox[{\(p\_2\), "=", 
                        StyleBox[" ",
                          
                          FontFamily->
                            "Times-Roman"], \(p\_0 + \[Gamma]\ h\_0\)}], 
                      ";", \(m = m + 1\), ";", 
                      "\[IndentingNewLine]", \(pointsab = {{Red, 
                            PointSize[0.02], Point[{p\_0, f[p\_0]}], 
                            Point[{p\_1, f[p\_1]}]}, {Blue, PointSize[0.02], 
                            Point[{p\_2, f[p\_2]}]}}\), ";", "  ", 
                      "\[IndentingNewLine]", \(dotsab = Graphics[pointsab]\), 
                      ";", "  ", 
                      "\[IndentingNewLine]", \(Show[gr0, dotsab, 
                        PlotRange \[Rule] {{a0 - 0.05, b0 + 0.05}, {0, 
                              0.72}}, 
                        Ticks \[Rule] {Range[0, 2, 0.1], Range[0, 2, 0.1]}, 
                        DisplayFunction \[Rule] $DisplayFunction]\), ";", " ",
                       "\[IndentingNewLine]", \(Print["\<p\>"\_m, "\< = \>", 
                        PaddedForm[p\_2, {9, 8}\ ], "\<,  f[\>", 
                        PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
                        PaddedForm[f[p\_2], {11, 10}]\ ]\), ";", 
                      "\[IndentingNewLine]", \(p\_0 = p\_1\), 
                      ";", \(p\_1 = p\_2\), ";", \(h\_0 = p\_1 - p\_0\), 
                      ";"}]}], " ", "]"}], ";", " ", 
                "\[IndentingNewLine]", \(Print["\<After m = \>", 
                  m - 1, "\< iterations\>"]\), ";", " ", 
                "\[IndentingNewLine]", \(Print["\<f[x] = \>", f[x]]\), ";", 
                "\[IndentingNewLine]", \(Print["\<f[\>", 
                  PaddedForm[p\_2, {9, 8}\ ], "\< ] = \>", 
                  PaddedForm[f[p\_2], {11, 10}]\ ]\), ";", 
                "\[IndentingNewLine]", \(Return[{f[p\_2], p\_2}\ ]\)}]}], 
            "]"}]}], ";"}], " "}]}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontFamily->"Times-Bold",
    FontWeight->"Bold"],
  "Find the minimum of  ",
  Cell[BoxData[
      \(f[x] = 1\/2 + x\^5 - \(4\/5\) x\)],
    AspectRatioFixed->True],
  StyleBox["  on the interval  ",
    FontFamily->"Times-Roman"],
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  "  ",
  StyleBox["using the cubic search method.",
    FontFamily->"Times-Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[x_] = 1\/2 + x\^5 - \(4\/5\) x;\)\ \ \), "\[IndentingNewLine]", 
    \(\(a0 = 0.0;\)\ \), "\[IndentingNewLine]", 
    \(\(b0 = 1.0;\)\ \), "\[IndentingNewLine]", 
    \(\(CubicSearch[a0, b0, 7];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f[x] = \>", f[x]];\)\ \)}], "Input"],

Cell[TextData[{
  StyleBox["Animation 1.  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  " ",
  StyleBox[ButtonBox["Cubic Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/a2001/Animations/Optimization/Cubic1/\
Cubicaa.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cubic Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Optimization/Cubic1/\
Cubic.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  " ",
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.250004]],
  "  Internet hyperlink. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Animations (",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox[ButtonBox["Cubic Search",
    ButtonData:>{
      URL[ 
      "http://mathews.ecs.fullerton.edu/a2001/Animations/Optimization/Cubic1/\
Cubic.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Cubic Search",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/a2001/Animations/Optimization/Cubic1/\
Cubic.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  "  Internet hyperlinks to animations. "
}], "Text"],

Cell[TextData[StyleBox["Research Experience for Undergraduates",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ "http://mathews.ecs.fullerton.edu/n2003/QuadraticSearchBib.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox[ButtonBox["Quadratic and Cubic Search",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/n2003/QuadraticSearchBib.html"],
       None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "  Internet hyperlinks to web sites and a bibliography of articles.  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Numerical Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 199, 5, 35, "Text"],
Cell[1978, 60, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3457, 112, 1336, 41, 106, "Text"],
Cell[4796, 155, 1027, 44, 109, "Text"],
Cell[5826, 201, 1710, 72, 90, "Text"],
Cell[7539, 275, 2170, 65, 166, "Text"],
Cell[9712, 342, 940, 33, 55, "Text"],
Cell[10655, 377, 2616, 81, 188, "Text"],
Cell[13274, 460, 1549, 45, 151, "Text"],
Cell[14826, 507, 412, 12, 75, "Text"],
Cell[15241, 521, 585, 17, 75, "Text"],
Cell[15829, 540, 1205, 33, 185, "Text"],
Cell[17037, 575, 338, 11, 77, "Text"],
Cell[17378, 588, 654, 23, 33, "Text"],
Cell[18035, 613, 1332, 44, 71, "Text"],
Cell[19370, 659, 2916, 106, 196, "Text"],
Cell[22289, 767, 1217, 40, 134, "Text"],
Cell[23509, 809, 1175, 42, 128, "Text"],
Cell[24687, 853, 1159, 32, 233, "Text"],
Cell[25849, 887, 1525, 41, 276, "Text"],
Cell[27377, 930, 484, 14, 152, "Text"],
Cell[27864, 946, 784, 23, 109, "Text"],
Cell[28651, 971, 842, 23, 147, "Text"],
Cell[29496, 996, 1353, 38, 290, "Text"],
Cell[30852, 1036, 1453, 27, 267, "Text"],
Cell[32308, 1065, 1605, 54, 71, "Text"],
Cell[33916, 1121, 654, 23, 33, "Text"],
Cell[34573, 1146, 1007, 32, 52, "Text"],
Cell[35583, 1180, 633, 21, 33, "Text"],
Cell[36219, 1203, 346, 10, 33, "Text"],
Cell[36568, 1215, 5102, 87, 1305, "Input"],
Cell[41673, 1304, 472, 16, 33, "Text"],

Cell[CellGroupData[{
Cell[42170, 1324, 101, 2, 33, "Text"],
Cell[42274, 1328, 408, 6, 90, "Input"],
Cell[42685, 1336, 237, 12, 36, "Text"],
Cell[42925, 1350, 1404, 26, 384, "Input"],
Cell[44332, 1378, 436, 15, 36, "Text"],
Cell[44771, 1395, 2269, 42, 589, "Input"],
Cell[47043, 1439, 232, 7, 33, "Text"],
Cell[47278, 1448, 2439, 45, 481, "Input"],
Cell[49720, 1495, 225, 3, 33, "Text"],
Cell[49948, 1500, 1740, 30, 430, "Input"],
Cell[51691, 1532, 400, 12, 33, "Text"],
Cell[52094, 1546, 87, 1, 31, "Input"],
Cell[52184, 1549, 251, 10, 33, "Text",
  Evaluatable->False],
Cell[52438, 1561, 535, 12, 130, "Input"]
}, Closed]],
Cell[52988, 1576, 961, 32, 49, "Text"],
Cell[53952, 1610, 1107, 36, 315, "Text"],
Cell[55062, 1648, 633, 21, 33, "Text"],
Cell[55698, 1671, 342, 10, 33, "Text"],
Cell[56043, 1683, 3333, 59, 533, "Input"],
Cell[59379, 1744, 468, 16, 33, "Text"],

Cell[CellGroupData[{
Cell[59872, 1764, 101, 2, 33, "Text"],
Cell[59976, 1768, 408, 6, 90, "Input"],
Cell[60387, 1776, 702, 27, 52, "Text"],
Cell[61092, 1805, 1644, 29, 482, "Input"],
Cell[62739, 1836, 309, 11, 33, "Text"],
Cell[63051, 1849, 1466, 27, 293, "Input"],
Cell[64520, 1878, 427, 12, 52, "Text"],
Cell[64950, 1892, 62, 1, 30, "Input"],
Cell[65015, 1895, 251, 10, 33, "Text",
  Evaluatable->False],
Cell[65269, 1907, 535, 12, 130, "Input"],
Cell[65807, 1921, 571, 17, 52, "Text"],
Cell[66381, 1940, 1473, 25, 410, "Input"],
Cell[67857, 1967, 568, 9, 130, "Input"],
Cell[68428, 1978, 69, 1, 30, "Input"]
}, Closed]],
Cell[68512, 1982, 322, 10, 32, "Text"],
Cell[68837, 1994, 7359, 126, 1043, "Input"],
Cell[76199, 2122, 499, 19, 36, "Text"],

Cell[CellGroupData[{
Cell[76723, 2145, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[76876, 2151, 336, 6, 124, "Input"],
Cell[77215, 2159, 778, 26, 33, "Text"]
}, Closed]],
Cell[78008, 2188, 772, 24, 30, "Text"],
Cell[78783, 2214, 4532, 79, 532, "Input"],
Cell[83318, 2295, 495, 19, 36, "Text"],

Cell[CellGroupData[{
Cell[83838, 2318, 150, 4, 33, "Text",
  Evaluatable->False],
Cell[83991, 2324, 302, 5, 123, "Input"],
Cell[84296, 2331, 752, 26, 33, "Text"]
}, Closed]],
Cell[85063, 2360, 748, 24, 30, "Text"],
Cell[85814, 2386, 158, 3, 35, "Text"],
Cell[85975, 2391, 577, 16, 33, "Text"],
Cell[86555, 2409, 293, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

