(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13056,        320]*)
(*NotebookOutlinePosition[     13745,        344]*)
(*  CellTagsIndexPosition[     13701,        340]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Numerical Methods ",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" Notebooks",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["Numerical Methods using ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["Complementary software supplements for  ",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox[" \n",
    FontSize->14],
  StyleBox[ButtonBox["Numerical Methods textbooks",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox[ButtonBox["John H. Mathews and Kurtis Fink, 2004",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  StyleBox["  ",
    FontSize->14,
    FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  "                        ",
  StyleBox["Chapter 1.  Calculus and Fundamentals\n",
    FontWeight->"Bold"],
  "                           1. Calculus Review I\n                          \
 2. Calculus Review II\n                           2. Big \"O\" Truncation \
Error"
}], "Text"],

Cell[TextData[{
  "                        ",
  StyleBox["Chapter 2.  The Solution of Nonlinear Equations f(x) = 0\n",
    FontWeight->"Bold"],
  "                           1. Fixed Point Iteration\n                      \
     2. Bisection Method\n                           3. False Position or \
Regula Falsi Method\n                           4. Newton-Raphson Method\n    \
                       5. Secant Method\n                           6. \
Muller's Method\n                           7. Aitken's Method & Steffensen's \
Acceleration\n                           8. Accelerated & Modified \
Newton-Raphson\n                           9. Improved Newton Method\n        \
                  10. Halley's Method\n                          11. Horner's \
Method\n                          12. Lin-Bairstow Method\n                   \
       13. Brent's Method\n                          14. Graeffe's Method\n   \
                       15. Nonlinear Systems\n                          16. \
Broyden's Method"
}], "Text"],

Cell[TextData[{
  "                        ",
  StyleBox["Chapter 3.  The Solution of Linear Systems AX = B\n",
    FontWeight->"Bold"],
  "                           1. Triangular Systems and Back Substitution\n   \
                        2. Gauss-Jordan Elimination and Pivoting\n            \
               3. Tri-Diagonal Matrices\n                           4. \
Inverse Matrix\n                           5. LU Factorization\n              \
             6. Cholesky, Doolittle and Crout Factorizations\n                \
           7. Jacobi and Gauss-Seidel Iteration\n                           \
8. Successive Over Relaxation - SOR\n                           9. Pivoting \
Methods\n                          10. Iterative Refinement\n                 \
         11. Row Reduced Echelon Form\n                          12. \
Homogeneous Linear Systems\n                          13. Kirchoff's Law\n    \
                      14. Leontief Model\n                          15. \
Linear Programming-Simplex Method"
}], "Text"],

Cell[TextData[{
  "                        ",
  StyleBox["Chapter 4.  Interpolation and Polynomial Approximation\n",
    FontWeight->"Bold"],
  "                           1. Maclaurin and Taylor Series\n                \
           2. Lagrange Polynomial Interpolation and Approximation\n           \
                3. Newton Interpolation Polynomial\n                          \
 4. Hermite Polynomial Interpolation\n                           5. Cubic \
Splines\n                           6. B-Splines\n                           \
7. B\[EAcute]zier Curves B\[EAcute]zier Curves\n                           8. \
Chebyshev Approximation Polynomial\n                           9. Pade \
Approximation\n                          10. Rational Approximation\n         \
                 11. Aitken's and Neville's Interpolation\n                   \
       12. Legendre Polynomials\n                          13. The Tangent \
Parabola\n                          14. Catenary"
}], "Text"],

Cell[TextData[{
  "                        ",
  StyleBox["Chapter 5.  Curve Fitting\n",
    FontWeight->"Bold"],
  "                           1. Least Squares Lines\n                        \
   2. Least Squares Polynomials\n                           3. Nonlinear \
Curve Fitting\n                           4. Logistic Curve\n                 \
          5. FFT and Trigonometric Polynomials \n                           \
6. Conic Fit\n                           7. Circle of Curvature"
}], "Text"],

Cell[TextData[{
  "                        ",
  StyleBox["Chapter 6.  Numerical Differentiation\n",
    FontWeight->"Bold"],
  "                           1. Numerical Differentiation \n                 \
          2. Richardson Extrapolation\n                           3. Derive \
Numerical Differentiation Formulae"
}], "Text"],

Cell[TextData[{
  "                       ",
  StyleBox["Chapter 7.   Numerical Integration\n",
    FontWeight->"Bold"],
  "                           1. Riemann Sums\n                           2. \
Midpoint Rule\n                           3. Newton-Cotes Integration\n       \
                    4. Trapezoidal Rule for Numerical Integration\n           \
                5. Simpson's Rule for Numerical Integration\n                 \
          6. Simpson's 3/8 Rule for Numerical Integration\n                   \
        7. Boole's Rule\n                           8. Romberg Integration\n  \
                         9. Adaptive Simpson's Rule\n                         \
 10. Gauss-Legendre Quadrature\n                          11. Cubic Spline \
Quadrature  \n                          12. Monte Carlo Pi\n                  \
        13. Monte Carlo Integration\n                          14. 2D \
Trapezoidal and Simpson Rules"
}], "Text"],

Cell[TextData[{
  "                       ",
  StyleBox["Chapter 8.   Solution of Differential Equations\n",
    FontWeight->"Bold"],
  "                           1. Euler's Method for ODE's\n                   \
        2. Taylor Series Method for ODE's\n                           3. \
Runge-Kutta Method\n                           4. Runge-Kutta-Fehlberg Method\
\n                           5. Adams-Bashforth-Moulton Method\n              \
             6. Milne-Simpson's Method\n                           7. \
Shooting Methods for ODE's\n                           8. Finite Difference \
Method for ODE's\n                           9. Galerkin's Method\n           \
               10. Painleve Property\n                          11. \
Lotka-Volterra Model\n                          12. Pendulum\n                \
          13. Projectile Motion\n                          14. Lorenz \
Attractor\n                          15. van der Pol System\n                 \
         16. Harvesting Model\n                          17. Frobenius Series \
Solution\n                          18. Picard Iteration\n                    \
      19. Spring-Mass Systems"
}], "Text"],

Cell[TextData[{
  "                       ",
  StyleBox["Chapter 9.   Solution of Partial Differential Equations\n",
    FontWeight->"Bold"],
  "                           1. Finite Difference Method\n                   \
        2. Crank-Nicolson Method\n                           3. Elliptic \
PDE's"
}], "Text"],

Cell[TextData[{
  "                       ",
  StyleBox["Chapter 10.   Eigenvalues and Eigenvectors\n",
    FontWeight->"Bold"],
  "                           1. Eigenvalues and Eigenvectors\n               \
            2. Power method\n                           3. Jacobi method\n    \
                       4. Householder Transformations\n                       \
    5. QR method\n                           6. Compartment Model\n           \
                7. Earthquake Model\n                           8. Matrix \
Exponential\n                           9. Faddeev-Leverrier Method \n        \
                  10. Hessenberg Factorization"
}], "Text"],

Cell[TextData[{
  "                       ",
  StyleBox["Chapter 11.   Numerical Optimization\n",
    FontWeight->"Bold"],
  "                           1. Golden Ratio Search\n                        \
   2. Fibonacci Search\n                           3. Quadratic Interpolative \
Search\n                           4. Nelder Mead Method\n                    \
       5. Powell's Method\n                           6. Steepest Descent - \
Gradient Search\n                           7. Newton's Search Method"
}], "Text"],

Cell[TextData[{
  StyleBox["\t\tJohn H. Mathews\n\t\tDepartment of Mathematics\n\t\t\
California State University Fullerton\n\t\tFullerton, CA 92834 USA\n\t\t\
Phone: (714) - 278-3631\n\t\tFAX: (714) - 278-3972\n\t\te-mail: ",
    FontWeight->"Bold"],
  StyleBox["mathews@fullerton.edu",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->True}],
  StyleBox["\n\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.199222, 0.996109]],
  StyleBox[ButtonBox["http://math.fullerton.edu/mathews/",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.199222, 0.996109]],
  StyleBox[ButtonBox["Numerical Analysis Project",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->True}]
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.199222, 0.996109]],
  StyleBox[ButtonBox["http://math.fullerton.edu/mathews/numerical.htm",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/numerical.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{1010, 651},
WindowMargins->{{-1, Automatic}, {Automatic, 0}},
ShowCellLabel->False
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 480, 17, 36, "Text"],
Cell[2259, 72, 1464, 49, 99, "Text"]
}, Closed]],
Cell[3738, 124, 300, 7, 87, "Text"],
Cell[4041, 133, 1029, 16, 337, "Text"],
Cell[5073, 151, 1037, 16, 318, "Text"],
Cell[6113, 169, 988, 15, 299, "Text"],
Cell[7104, 186, 502, 9, 166, "Text"],
Cell[7609, 197, 330, 7, 90, "Text"],
Cell[7942, 206, 951, 15, 299, "Text"],
Cell[8896, 223, 1182, 18, 394, "Text"],
Cell[10081, 243, 315, 7, 90, "Text"],
Cell[10399, 252, 664, 11, 223, "Text"],
Cell[11066, 265, 523, 9, 166, "Text"],
Cell[11592, 276, 689, 17, 166, "Text"],
Cell[12284, 295, 389, 11, 33, "Text"],
Cell[12676, 308, 376, 10, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

